@@ -1,6 +1,6 @@
 /* ************************************************************************** */
 /*                                                                            */
-/*     Copyright (C) 2011-2012 Pierre Biava (grisbi@pierre.biava.name)        */
+/*     Copyright (C) 2011-2013 Pierre Biava (grisbi@pierre.biava.name)        */
 /*                   2011 Guillaume Verger (guillaume.verger@laposte.net)     */
 /*          http://www.grisbi.org                                             */
 /*                                                                            */
@@ -21,7 +21,7 @@
 /* ************************************************************************** */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <gdk/gdk.h>
@@ -36,6 +36,7 @@
 #include "bet_data.h"
 #include "bet_hist.h"
 #include "dialog.h"
+#include "grisbi_app.h"
 #include "gsb_automem.h"
 #include "gsb_data_account.h"
 #include "gsb_data_budget.h"
@@ -45,6 +46,7 @@
 #include "gsb_file.h"
 #include "navigation.h"
 #include "structures.h"
+#include "utils.h"
 #include "utils_gtkbuilder.h"
 #include "utils_dates.h"
 #include "utils_real.h"
@@ -108,8 +110,8 @@ struct _struct_bet_graph_button
     GCallback callback;                 /* fonction de callback */
     gboolean is_visible;                /* TRUE si le bouton est visible dans la barre d'outils */
     gint origin_tab;                    /* BET_ONGLETS_PREV ou BET_ONGLETS_HIST */
-    GtkWidget *box;
-    GtkWidget *button;
+    GtkWidget *toolbar;
+    GtkToolItem *button;
     GtkWidget *tree_view;
     struct_bet_graph_prefs *prefs;      /* préférences pour le graphique */
 };
@@ -178,23 +180,6 @@ static struct_bet_graph_button *struct_initialise_bet_graph_button ( void )
 }
 
 
-/**
- *
- *
- * \param
- *
- * \return TRUE
- * */
-static void struct_free_bet_graph_button ( struct_bet_graph_button *self )
-{
-    g_free ( self->name );
-    g_free ( self->filename );
-    g_free ( self->service_id );
-
-    g_free ( self );
-}
-
-
 /**
  *
  *
@@ -317,11 +302,8 @@ static gboolean bet_graph_populate_sectors_by_sub_divisions ( struct_bet_graph_d
     {
         gint account_number;
         gchar *libelle_division = self -> tab_libelle[0];
-        gchar **tab_libelle_division;
         gdouble *tab_montant_division = self -> tab_Y;
 
-        tab_libelle_division = &libelle_division;
-
         /* test du numero de compte */
         gtk_tree_model_get ( GTK_TREE_MODEL ( model ), &iter,
                         SPP_HISTORICAL_ACCOUNT_NUMBER, &account_number,
@@ -449,7 +431,6 @@ static void bet_graph_affiche_sub_divisions ( struct_bet_graph_data *parent,
     GtkWidget *notebook;
     GtkWidget *box_pie;
     gchar *title;
-    gint result;
     struct_bet_graph_data *self;
 
     /* initialisation de la structure des données */
@@ -472,9 +453,9 @@ static void bet_graph_affiche_sub_divisions ( struct_bet_graph_data *parent,
         gtk_window_set_transient_for ( GTK_WINDOW ( dialog ), GTK_WINDOW ( parent_widget ) );
     }
     gtk_widget_set_size_request ( dialog, 600, 400 );
-    gtk_signal_connect ( GTK_OBJECT ( dialog ),
+    g_signal_connect ( G_OBJECT ( dialog ),
                         "destroy",
-                        GTK_SIGNAL_FUNC ( gtk_widget_destroy ),
+                        G_CALLBACK ( gtk_widget_destroy ),
                         NULL);
 
     /* set the title */
@@ -497,7 +478,7 @@ static void bet_graph_affiche_sub_divisions ( struct_bet_graph_data *parent,
     notebook = GTK_WIDGET ( gtk_builder_get_object ( bet_graph_builder, "notebook_sub_div" ) );
     gtk_notebook_set_show_tabs ( GTK_NOTEBOOK ( notebook ), FALSE );
 
-    box_pie = gtk_vbox_new ( FALSE, 0 );
+    box_pie = gtk_box_new ( GTK_ORIENTATION_VERTICAL, 0 );
     gtk_notebook_append_page ( GTK_NOTEBOOK ( notebook ), box_pie, gtk_label_new ( _("Graph") ) );
 
     /* Set the graph */
@@ -513,12 +494,12 @@ static void bet_graph_affiche_sub_divisions ( struct_bet_graph_data *parent,
     self->valid_data = bet_graph_populate_sectors_by_sub_divisions ( self, div_number );
 
     if ( self->valid_data )
-        result = bet_graph_affiche_camemberts ( self );
+        bet_graph_affiche_camemberts ( self );
 
     /* show or hide widgets */
     gtk_widget_show_all ( dialog );
 
-    result = gtk_dialog_run ( GTK_DIALOG ( dialog ) );
+    gtk_dialog_run ( GTK_DIALOG ( dialog ) );
 
     /* free the data */
     struct_free_bet_graph_data ( self );
@@ -643,9 +624,7 @@ static gboolean bet_graph_on_motion ( GtkWidget *event_box,
     if ( strcmp ( self->service_id, "GogBarColPlot" ) == 0 )
     {
         index = gog_plot_view_get_data_at_point ( GOG_PLOT_VIEW ( view ), event->x, event->y, &series );
-        if ( index == -1 )
-            buf = NULL;
-        else
+        if ( index != -1 )
         {
             double const *x;
             double const *y;
@@ -687,37 +666,29 @@ static gboolean bet_graph_on_motion ( GtkWidget *event_box,
                         utils_real_get_string_with_currency_from_double (
                         self->tab_Y[index-1], self->currency_number ) );
         }
-        else
-            buf = NULL;
         gog_chart_map_free ( map );
     }
     else if (  strcmp ( self->service_id, "GogPiePlot" ) == 0 )
     {
         index = gog_plot_view_get_data_at_point ( GOG_PLOT_VIEW ( view ), event->x, event->y, &series );
-        if ( index == -1 )
-            buf = NULL;
-        else
+        if ( index != -1 )
         {
             double const *x;
             double const *y;
 
             gog_series_get_xy_data ( series, &x, &y );
-            buf = g_strdup_printf ("%s : %s (%.2f%%)", self->tab_vue_libelle[index],
-                        utils_real_get_string_with_currency_from_double (
-                        y[index], self->currency_number ),
-                        ( 100*y[index]/self->montant ) );
+            buf = g_strdup_printf (
+                    "<markup><span font_weight=\"bold\">%s</span>\n%s (%.2f%%)</markup>",
+                    self->tab_vue_libelle[index],
+                    utils_real_get_string_with_currency_from_double ( y[index], self->currency_number ),
+                    100*y[index]/self->montant
+                    );
         }
     }
 
-    if ( buf )
-    {
-        gtk_widget_set_tooltip_text ( GTK_WIDGET ( self->widget ), buf );
-        g_free ( buf );
-    }
-    else
-        gtk_widget_set_tooltip_text ( GTK_WIDGET ( self->widget ), "" );
+    gtk_widget_set_tooltip_markup ( GTK_WIDGET ( self->widget ), buf );
+    g_free ( buf );
 
-    /* return value */
     return TRUE;
 }
 
@@ -745,7 +716,7 @@ static GogPlot *bet_graph_create_graph_page  ( struct_bet_graph_data *self,
     if ( add_page )
     {
         /* Set the new page */
-        child = gtk_vbox_new (FALSE, 0);
+        child = gtk_box_new ( GTK_ORIENTATION_VERTICAL, 0 );
         gtk_notebook_prepend_page ( self->notebook, child, gtk_label_new ( _("Graph") ) );
     }
     else
@@ -814,9 +785,8 @@ static gboolean bet_graph_affiche_XY_line ( struct_bet_graph_data *self )
     GOStyle *style;
     GogObject *axis;
     GogObject *axis_line = NULL;
-    GogObject *grid_line;
     GError *error = NULL;
-    gchar *position;
+    const gchar *position;
     struct_bet_graph_prefs *prefs;
 
     prefs = self->prefs;
@@ -890,9 +860,9 @@ static gboolean bet_graph_affiche_XY_line ( struct_bet_graph_data *self )
         {
             axis = gog_object_get_child_by_name ( GOG_OBJECT ( self->chart ), "Y-Axis" );
 
-            grid_line = gog_object_add_by_name ( GOG_OBJECT ( axis ), "MajorGrid", NULL );
+            gog_object_add_by_name ( GOG_OBJECT ( axis ), "MajorGrid", NULL );
             if ( prefs->minor_grid_y )
-                grid_line = gog_object_add_by_name ( GOG_OBJECT ( axis ), "MinorGrid", NULL );
+                gog_object_add_by_name ( GOG_OBJECT ( axis ), "MinorGrid", NULL );
         }
     }
 
@@ -1394,13 +1364,9 @@ static gboolean bet_graph_populate_sectors_by_hist_data ( struct_bet_graph_data
     if ( gtk_tree_model_get_iter_first ( model, &iter ) )
     {
         gint account_number;
-        gint type_compte;
         gchar *libelle_division = self -> tab_libelle[0];
-        gchar **tab_libelle_division;
         gdouble *tab_montant_division = self -> tab_Y;
 
-        tab_libelle_division = &libelle_division;
-
         /* test du numero de compte */
         gtk_tree_model_get ( GTK_TREE_MODEL ( model ), &iter,
                         SPP_HISTORICAL_ACCOUNT_NUMBER, &account_number,
@@ -1408,7 +1374,6 @@ static gboolean bet_graph_populate_sectors_by_hist_data ( struct_bet_graph_data
         if ( account_number != self -> account_number )
             return FALSE;
 
-        type_compte = gsb_data_account_get_kind ( account_number );
         do
         {
             gchar *desc = NULL;
@@ -1472,7 +1437,6 @@ static gboolean bet_graph_populate_lines_by_forecast_data ( struct_bet_graph_dat
     if ( gtk_tree_model_get_iter_first ( model, &iter ) )
     {
         gchar *libelle_axe_x = self -> tab_libelle[0];
-        gchar **tab_libelle_axe_x;
         gdouble *tab_Y = self -> tab_Y;
         gdouble montant = 0.;
         GDate *first_date;
@@ -1482,19 +1446,20 @@ static gboolean bet_graph_populate_lines_by_forecast_data ( struct_bet_graph_dat
         GDateMonth month_courant = G_DATE_BAD_MONTH;
         gint nbre_iterations = 0;
 
-        tab_libelle_axe_x = &libelle_axe_x;
-
         do
         {
             gchar *amount;
             gchar *str_date;
-            GValue date_value = {0,};
+            GValue date_value = G_VALUE_INIT;
             GDate *date;
             GDateDay day;
             GDateMonth month;
             gint diff_jours;
             gint i;
 
+			if (G_IS_VALUE (&date_value))
+				g_value_init ( &date_value, G_TYPE_DATE );
+
             gtk_tree_model_get_value ( model,
                         &iter,
                         SPP_ESTIMATE_TREE_SORT_DATE_COLUMN, &date_value );
@@ -1571,7 +1536,7 @@ static gboolean bet_graph_populate_lines_by_forecast_data ( struct_bet_graph_dat
 
                 break;
             }
-
+			g_value_unset (&date_value);
         }
         while ( gtk_tree_model_iter_next ( GTK_TREE_MODEL ( model ), &iter ) );
 
@@ -1618,78 +1583,61 @@ static gboolean bet_graph_notebook_change_page ( GtkNotebook *notebook,
 static void bet_graph_popup_choix_graph_activate ( GtkMenuItem *menuitem,
                         struct_bet_graph_button *self )
 {
-    GtkWidget *parent;
-    GList *tmp_list;
-    gint origin_tab = 0;
+    GtkToolItem *item;
+    gchar *tmp_str;
+    gint nbre_elemnts;
+    struct_bet_graph_prefs *prefs;
 
-    parent = gtk_widget_get_parent ( self->box );
-    tmp_list = g_object_get_data ( G_OBJECT ( parent ), "button_list" );
+    prefs = self->prefs;
 
-    while ( tmp_list )
+    /* on définit l'origine du bouton */
+    if ( self->origin_tab == BET_ONGLETS_PREV )
     {
-        struct_bet_graph_button *self;
-        struct_bet_graph_prefs *prefs;
-
-        self = tmp_list -> data;
-
-        prefs = self->prefs;
-        origin_tab = self->origin_tab;
-        if ( self->is_visible == TRUE )
-        {
-            self->is_visible = FALSE;
-            if ( strcmp ( self->service_id, "GogLinePlot" ) == 0 )
-                prefs->type_graph = 1;
-            else
-                prefs->type_graph = 0;
-            origin_tab = self->origin_tab;
-
-            break;
-        }
-
-        tmp_list = tmp_list -> next;
+        tmp_str = g_strdup ( "forecast_graph" );
+        nbre_elemnts = gtk_toolbar_get_n_items ( GTK_TOOLBAR ( self->toolbar ) ) -1;
+    }
+    else
+    {
+        tmp_str = g_strdup ( "historical_graph" );
+        nbre_elemnts = gtk_toolbar_get_n_items ( GTK_TOOLBAR ( self->toolbar ) ) -1;
     }
 
-    gtk_container_foreach ( GTK_CONTAINER ( self->box ), ( GtkCallback ) gtk_widget_destroy, NULL );
+    /* on change le type de graphique */
+    prefs->type_graph = !prefs->type_graph;
 
-    self->is_visible = TRUE;
-    self->button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
-                        self->name,
-                        self->filename,
-                        NULL,
-                        NULL );
+    item = gtk_toolbar_get_nth_item ( GTK_TOOLBAR ( self->toolbar ), nbre_elemnts );
+    if ( item )
+        gtk_container_remove ( GTK_CONTAINER ( self->toolbar ), GTK_WIDGET ( item ) );
 
-    g_object_set_data ( G_OBJECT ( self->button ), "service_id", self->service_id );
-    g_object_set_data ( G_OBJECT ( self->button ), "origin_tab", GINT_TO_POINTER ( origin_tab ) );
-    g_signal_connect ( G_OBJECT ( self->button ),
-                        "clicked",
-                        self->callback,
+    item = bet_graph_button_menu_new ( self->toolbar,
+                        tmp_str,
+                        G_CALLBACK ( self->callback ),
                         self->tree_view );
 
-    gtk_box_pack_start ( GTK_BOX ( self->box ), self->button, TRUE, TRUE, 0 );
+    g_free ( tmp_str );
 
-    gsb_file_set_modified ( TRUE );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( self->toolbar ), item, -1 );
+
+    gtk_widget_show_all ( self->toolbar );
 
     /* on lance le graphique */
-    gtk_button_clicked ( GTK_BUTTON ( self->button ) );
+    g_signal_emit_by_name( item, "clicked", self->tree_view, NULL );
 }
 
 
 /**
+ * construit le menu popup du bouton
  *
- *
- * \param
- * \param
+ * \param button
  * \param
  *
  * \return FALSE
  * */
-static gboolean bet_graph_popup_choix_graph_menu ( GtkWidget *button,
-                        GdkEventButton *event,
+static void bet_graph_popup_choix_graph_menu ( GtkWidget *button,
                         GList *liste )
 {
     GtkWidget *menu;
     GtkWidget *menu_item;
-    GtkWidget *icon;
     GList *tmp_list;
 
     menu = gtk_menu_new ();
@@ -1702,9 +1650,8 @@ static gboolean bet_graph_popup_choix_graph_menu ( GtkWidget *button,
 
         self = tmp_list -> data;
 
-        icon = gtk_image_new_from_file ( g_build_filename ( gsb_dirs_get_pixmaps_dir ( ), self->filename, NULL ) );
-        menu_item = gtk_image_menu_item_new_with_label  ( self->name );
-        gtk_image_menu_item_set_image ( GTK_IMAGE_MENU_ITEM ( menu_item ), icon );
+        menu_item = gtk_menu_item_new_with_label (self->name);
+
         g_signal_connect ( G_OBJECT ( menu_item ),
                         "activate",
                         G_CALLBACK ( bet_graph_popup_choix_graph_activate ),
@@ -1717,15 +1664,8 @@ static gboolean bet_graph_popup_choix_graph_menu ( GtkWidget *button,
         tmp_list = tmp_list -> next;
     }
 
+    gtk_menu_tool_button_set_menu ( GTK_MENU_TOOL_BUTTON ( button ), menu );
     gtk_widget_show_all ( menu );
-    gtk_menu_popup ( GTK_MENU ( menu ),
-                        NULL, button,
-                        set_popup_position,
-                        button,
-                        1,
-                        gtk_get_current_event_time ( ) );
-
-    return FALSE;
 }
 
 
@@ -1751,16 +1691,14 @@ static gboolean bet_graph_populate_lines_by_historical_line ( struct_bet_graph_d
     gchar *desc;
     gchar *str_amount = NULL;
     gchar *libelle_axe_x = self->tab_libelle[0];
-    gchar **tab_libelle_axe_x;
     gdouble *tab_Y = self->tab_Y;
     gdouble *tab_Y2 = self->tab_Y2;
     gint div_number;
     gint sub_div_nb;
     gint fyear_number;
     gint i;
-    gboolean line_graph;
-    gsb_real tab[12];
-    gsb_real tab2[12];
+    GsbReal tab[12];
+    GsbReal tab2[12];
 
     selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( self -> tree_view ) );
 
@@ -1792,67 +1730,64 @@ static gboolean bet_graph_populate_lines_by_historical_line ( struct_bet_graph_d
     g_hash_table_iter_init ( &hash_iter, list_transactions );
     while ( g_hash_table_iter_next ( &hash_iter, &key, &value ) )
     {
-        TransactionCurrentFyear *self = ( TransactionCurrentFyear* ) value;
+        TransactionCurrentFyear *tcf = ( TransactionCurrentFyear* ) value;
 
-        if ( self->div_nb == div_number )
+        if ( tcf->div_nb == div_number )
         {
-            date_month = g_date_get_month ( self->date );
+            date_month = g_date_get_month ( tcf->date );
             if ( sub_div_nb > 0 )
             {
-                if ( self->sub_div_nb == sub_div_nb )
+                if ( tcf->sub_div_nb == sub_div_nb )
                 {
-                    switch ( self->type_de_transaction )
+                    switch ( tcf->type_de_transaction )
                     {
                         case 0:
                             if ( fyear_number > 0 )
-                                tab[date_month-1] = gsb_real_add ( tab[date_month-1], self->amount );
+                                tab[date_month-1] = gsb_real_add ( tab[date_month-1], tcf->amount );
                             break;
                         case 1:
                             if ( fyear_number > 0 )
-                                tab2[date_month-1] = gsb_real_add ( tab2[date_month-1], self->amount );
+                                tab2[date_month-1] = gsb_real_add ( tab2[date_month-1], tcf->amount );
                             else
-                                tab[date_month-1] = gsb_real_add ( tab[date_month-1], self->amount );
+                                tab[date_month-1] = gsb_real_add ( tab[date_month-1], tcf->amount );
                             break;
                         case 2:
-                            tab[date_month-1] = gsb_real_add ( tab[date_month-1], self->amount );
+                            tab[date_month-1] = gsb_real_add ( tab[date_month-1], tcf->amount );
                             if ( fyear_number > 0 )
-                                tab2[date_month-1] = gsb_real_add ( tab2[date_month-1], self->amount );
+                                tab2[date_month-1] = gsb_real_add ( tab2[date_month-1], tcf->amount );
                             break;
                     }
                 }
             }
             else
             {
-                switch ( self->type_de_transaction )
+                switch ( tcf->type_de_transaction )
                 {
                     case 0:
                         if ( fyear_number > 0 )
-                            tab[date_month-1] = gsb_real_add ( tab[date_month-1], self->amount );
+                            tab[date_month-1] = gsb_real_add ( tab[date_month-1], tcf->amount );
                         break;
                     case 1:
                         if ( fyear_number > 0 )
-                            tab2[date_month-1] = gsb_real_add ( tab2[date_month-1], self->amount );
+                            tab2[date_month-1] = gsb_real_add ( tab2[date_month-1], tcf->amount );
                         else
-                            tab[date_month-1] = gsb_real_add ( tab[date_month-1], self->amount );
+                            tab[date_month-1] = gsb_real_add ( tab[date_month-1], tcf->amount );
                         break;
                     case 2:
-                        tab[date_month-1] = gsb_real_add ( tab[date_month-1], self->amount );
+                        tab[date_month-1] = gsb_real_add ( tab[date_month-1], tcf->amount );
                         if ( fyear_number > 0 )
-                            tab2[date_month-1] = gsb_real_add ( tab2[date_month-1], self->amount );
+                            tab2[date_month-1] = gsb_real_add ( tab2[date_month-1], tcf->amount );
                         break;
                 }
             }
         }
     }
 
-    tab_libelle_axe_x = &libelle_axe_x;
-
     /* On commence par le début de l'exercice courant puis on balaie les douze mois */
     start_current_fyear = bet_historical_get_start_date_current_fyear ();
     date_month = g_date_get_month ( start_current_fyear );
     today_month = g_date_get_month ( gdate_today () );
 
-    line_graph = strcmp ( self->service_id, "GogLinePlot" ) == 0 ? 1:0;
     for ( i = 0; i < 12; i++ )
     {
         if ( fyear_number > 0 )
@@ -1865,7 +1800,7 @@ static gboolean bet_graph_populate_lines_by_historical_line ( struct_bet_graph_d
         /* Pour un graphique line on n'affiche pas 0 comme donnée des mois futurs */
         if ( strcmp ( self->service_id, "GogLinePlot" ) == 0 )
         {
-            if ( i < today_month )
+            if ( i < (gint) today_month )
             {
                 tab_Y[self->nbre_elemnts] = gsb_real_real_to_double ( tab[date_month-1] );
                 if ( fyear_number > 0 )
@@ -1933,34 +1868,24 @@ static GDate *bet_graph_get_date_debut_periode ( void )
 /**
  * retourne un bouton pour choisir entre un graph ligne ou colonne
  *
- * \param
- * \param
- * \param
- * \param
+ * \param type_graph    forecast_graph or historical_graph
+ * \param callback
+ * \paramtree_view
  *
- * \return button
+ * \return item
  * */
-GtkWidget *bet_graph_button_menu_new ( GsbButtonStyle style,
+GtkToolItem *bet_graph_button_menu_new ( GtkWidget *toolbar,
                         const gchar *type_graph,
                         GCallback callback,
                         GtkWidget *tree_view )
 {
-    GtkWidget *arrow_button = NULL;
-    GtkWidget *arrow;
-    GtkWidget *box;
-    GtkWidget *box_button;
+    GtkToolItem *item = NULL;
     GList *liste = NULL;
+    gchar *tooltip = NULL;
     gint origin_tab = 0;
     struct_bet_graph_button *self;
     struct_bet_graph_prefs *prefs = NULL;
 
-    /* boite qui contiendra les deux boutons */
-    box = gtk_hbox_new ( FALSE, 0 );
-
-    /* boite qui contiendra le bouton actif */
-    box_button = gtk_vbox_new ( TRUE, 0 );
-    gtk_box_pack_start ( GTK_BOX ( box ), box_button, FALSE, FALSE, 0 );
-
     /* initialisation des préférences */
     if ( strcmp ( type_graph, "forecast_graph" ) == 0 )
     {
@@ -1968,7 +1893,7 @@ GtkWidget *bet_graph_button_menu_new ( GsbButtonStyle style,
             prefs_prev = struct_initialise_bet_graph_prefs ();
         prefs = prefs_prev;
         origin_tab = BET_ONGLETS_PREV;
-        gtk_widget_set_tooltip_text ( GTK_WIDGET ( box_button ), _("Display the graph of forecast") );
+        tooltip = g_strdup ( _("Display the graph of forecast") );
     }
     else if ( strcmp ( type_graph, "historical_graph" ) == 0 )
     {
@@ -1976,38 +1901,33 @@ GtkWidget *bet_graph_button_menu_new ( GsbButtonStyle style,
             prefs_hist = struct_initialise_bet_graph_prefs ();
         prefs = prefs_hist;
         origin_tab = BET_ONGLETS_HIST;
-        gtk_widget_set_tooltip_text ( GTK_WIDGET ( box_button ), _("Display the monthly graph") );
+        tooltip = g_strdup ( _("Display the monthly graph") );
     }
 
     /* initialisation des données du premier bouton */
     self = struct_initialise_bet_graph_button ( );
 
     self->name = g_strdup ( _("Column") );
-    self->filename = g_strdup ( "graph-histo.png" );
+    self->filename = g_strdup ( "gsb-graph-histo-24.png" );
     self->service_id = g_strdup ( "GogBarColPlot" );
     self->callback = callback;
-    self->box = box_button;
+    self->toolbar = toolbar;
     self->tree_view = tree_view;
     self->origin_tab = origin_tab;
     self->prefs = prefs;
 
     /* si ce boutton est celui par défaut on l'affiche */
-    if ( prefs->type_graph == 0 )
+    if ( prefs && prefs->type_graph == 0 )
     {
         self->is_visible = TRUE;
-        self->button = gsb_automem_imagefile_button_new ( style,
-                    self->name,
-                    self->filename,
-                    NULL,
-                    NULL );
-
+        item = utils_buttons_tool_menu_new_from_image_label ( self->filename, self->name );
+        self->button = item;
         g_object_set_data ( G_OBJECT ( self->button ), "service_id", self->service_id );
         g_object_set_data ( G_OBJECT ( self->button ), "origin_tab", GINT_TO_POINTER ( origin_tab ) );
         g_signal_connect ( G_OBJECT ( self->button ),
-                    "clicked",
-                    self->callback,
-                    self->tree_view );
-        gtk_box_pack_start ( GTK_BOX ( self->box ), self->button, TRUE, TRUE, 0 );
+                        "clicked",
+                        self->callback,
+                        self->tree_view );
     }
     liste = g_list_append ( liste, self );
 
@@ -2015,50 +1935,43 @@ GtkWidget *bet_graph_button_menu_new ( GsbButtonStyle style,
     self = struct_initialise_bet_graph_button ( );
 
     self->name = g_strdup ( _("Line") );
-    self->filename = g_strdup ( "graph-line.png" );
+    self->filename = g_strdup ( "gsb-graph-line-24.png" );
     self->service_id = g_strdup ( "GogLinePlot" );
     self->callback = callback;
-    self->box = box_button;
+    self->toolbar = toolbar;
     self->tree_view = tree_view;
     self->origin_tab = origin_tab;
     self->prefs = prefs;
 
     /* si ce boutton est celui par défaut on l'affiche */
-    if ( prefs->type_graph == 1 )
+    if ( prefs && prefs->type_graph == 1 )
     {
         self->is_visible = TRUE;
-        self->button = gsb_automem_imagefile_button_new ( style,
-                    self->name,
-                    self->filename,
-                    NULL,
-                    NULL );
-
+        item = utils_buttons_tool_menu_new_from_image_label ( self->filename, self->name );
+        self->button = item;
         g_object_set_data ( G_OBJECT ( self->button ), "service_id", self->service_id );
         g_object_set_data ( G_OBJECT ( self->button ), "origin_tab", GINT_TO_POINTER ( origin_tab ) );
         g_signal_connect ( G_OBJECT ( self->button ),
-                    "clicked",
-                    self->callback,
-                    self->tree_view );
-        gtk_box_pack_start ( GTK_BOX ( self->box ), self->button, TRUE, TRUE, 0 );
+                        "clicked",
+                        self->callback,
+                        self->tree_view );
     }
     liste = g_list_append ( liste, self );
 
-    /* on attache la liste des boutons servira  plus tard */
-    g_object_set_data ( G_OBJECT ( box ), "button_list", liste );
+    if ( tooltip )
+    {
+        gtk_tool_item_set_tooltip_text ( GTK_TOOL_ITEM ( item ), tooltip );
+        g_free ( tooltip );
+    }
 
-    /* bouton qui ouvre le menu de choix du bouton actif */
-    arrow_button = gtk_button_new ();
-    gtk_button_set_relief ( GTK_BUTTON ( arrow_button ),GTK_RELIEF_NONE );
-    arrow = gtk_arrow_new ( GTK_ARROW_DOWN, GTK_SHADOW_NONE );
-    gtk_container_add ( GTK_CONTAINER ( arrow_button ), arrow );
-    gtk_box_pack_start ( GTK_BOX ( box ), arrow_button, FALSE, FALSE, 0 );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( arrow_button ), _("Select the chart type") );
-    g_signal_connect ( G_OBJECT ( arrow_button ),
-                        "button-press-event",
+    gtk_menu_tool_button_set_menu ( GTK_MENU_TOOL_BUTTON ( item ), gtk_menu_new () );
+
+    g_signal_connect ( G_OBJECT ( item ),
+                        "show-menu",
                         G_CALLBACK ( bet_graph_popup_choix_graph_menu ),
                         liste );
 
-    return box;
+    return item;
 }
 
 
@@ -2072,7 +1985,7 @@ GtkWidget *bet_graph_button_menu_new ( GsbButtonStyle style,
 gchar *bet_graph_get_configuration_string ( gint origin_tab )
 {
     gchar *new_str = NULL;
-    gchar *tmp_str = NULL;
+    const gchar *tmp_str = NULL;
     struct_bet_graph_prefs *prefs = NULL;
 
     if ( origin_tab == BET_ONGLETS_PREV )
@@ -2086,6 +1999,9 @@ gchar *bet_graph_get_configuration_string ( gint origin_tab )
         tmp_str = "historical_prefs";
     }
 
+	if (NULL == prefs)
+		return NULL;
+
     new_str = g_markup_printf_escaped ( "\t<Bet_graph prefs=\"%s:%d:%d:%d:%d:%d:%d:%d:%.0f:%d:%d:%d:%d\" />\n",
                         tmp_str,
                         prefs->type_graph,
@@ -2154,18 +2070,18 @@ void bet_graph_line_graph_new ( GtkWidget *button,
 
     /* Création de la fenêtre de dialogue pour le graph */
     dialog = GTK_WIDGET ( gtk_builder_get_object ( bet_graph_builder, "bet_graph_dialog" ) );
-    gtk_window_set_transient_for ( GTK_WINDOW ( dialog ), GTK_WINDOW ( run.window ) );
+    gtk_window_set_transient_for ( GTK_WINDOW ( dialog ), GTK_WINDOW ( grisbi_app_get_active_window (NULL) ) );
     gtk_widget_set_size_request ( dialog, PAGE_WIDTH+30, PAGE_HEIGHT+70 );
-    gtk_signal_connect ( GTK_OBJECT ( dialog ),
+    g_signal_connect ( G_OBJECT ( dialog ),
                         "destroy",
-                        GTK_SIGNAL_FUNC ( gtk_widget_destroy ),
+                        G_CALLBACK ( gtk_widget_destroy ),
                         NULL);
 
     /* initialise le bouton show_grid avec la préférence "Major_grid" */
     self->button_show_grid = GTK_WIDGET ( gtk_builder_get_object ( bet_graph_builder, "button_show_grid" ) );
     gtk_button_set_image ( GTK_BUTTON ( self->button_show_grid ),
                         gtk_image_new_from_file ( g_build_filename ( gsb_dirs_get_pixmaps_dir ( ),
-                        "grille.png", NULL ) ) );
+                        "gsb-grille-16.png", NULL ) ) );
     if ( prefs->major_grid_y )
         bet_graph_show_grid_button_configure ( self, TRUE, -1 );
     g_signal_connect ( self->button_show_grid,
@@ -2208,7 +2124,7 @@ void bet_graph_line_graph_new ( GtkWidget *button,
     gtk_widget_show_all ( dialog );
     gtk_notebook_set_current_page ( self->notebook, 0 );
 
-    result = gtk_dialog_run ( GTK_DIALOG ( dialog ) );
+    gtk_dialog_run ( GTK_DIALOG ( dialog ) );
 
     /* free the data */
     struct_free_bet_graph_data ( self );
@@ -2290,18 +2206,18 @@ void bet_graph_montly_graph_new ( GtkWidget *button,
 
     /* Création de la fenêtre de dialogue pour le graph */
     dialog = GTK_WIDGET ( gtk_builder_get_object ( bet_graph_builder, "bet_graph_dialog" ) );
-    gtk_window_set_transient_for ( GTK_WINDOW ( dialog ), GTK_WINDOW ( run.window ) );
+    gtk_window_set_transient_for ( GTK_WINDOW ( dialog ), GTK_WINDOW ( grisbi_app_get_active_window (NULL) ) );
     gtk_widget_set_size_request ( dialog, PAGE_WIDTH+30, PAGE_HEIGHT+70 );
-    gtk_signal_connect ( GTK_OBJECT ( dialog ),
+    g_signal_connect ( G_OBJECT ( dialog ),
                         "destroy",
-                        GTK_SIGNAL_FUNC ( gtk_widget_destroy ),
+                        G_CALLBACK ( gtk_widget_destroy ),
                         NULL);
 
     /* initialise le bouton show_grid avec la préférence "Major_grid" */
     self->button_show_grid = GTK_WIDGET ( gtk_builder_get_object ( bet_graph_builder, "button_show_grid" ) );
     gtk_button_set_image ( GTK_BUTTON ( self->button_show_grid ),
                         gtk_image_new_from_file ( g_build_filename ( gsb_dirs_get_pixmaps_dir ( ),
-                        "grille.png", NULL ) ) );
+                        "gsb-grille-16.png", NULL ) ) );
     if ( self->prefs->major_grid_y )
         bet_graph_show_grid_button_configure ( self, TRUE, -1 );
     g_signal_connect ( self->button_show_grid,
@@ -2342,7 +2258,7 @@ void bet_graph_montly_graph_new ( GtkWidget *button,
     gtk_widget_show_all ( dialog );
     gtk_notebook_set_current_page ( self->notebook, 0 );
 
-    result = gtk_dialog_run ( GTK_DIALOG ( dialog ) );
+    gtk_dialog_run ( GTK_DIALOG ( dialog ) );
 
     /* free the data */
     g_object_unref ( G_OBJECT ( bet_graph_builder ) );
@@ -2374,8 +2290,10 @@ void bet_graph_sectors_graph_new ( GtkWidget *button,
     gint currency_number;
     struct_bet_graph_data *self_credit;
     struct_bet_graph_data *self_debit;
+	GrisbiWinEtat *w_etat;
 
     devel_debug (NULL);
+	w_etat = grisbi_win_get_w_etat ();
 
     /* Initialisation d'un nouveau GtkBuilder */
     if ( !bet_graph_initialise_builder ( ) )
@@ -2383,11 +2301,11 @@ void bet_graph_sectors_graph_new ( GtkWidget *button,
 
     /* Création de la fenêtre de dialogue pour le graph */
     dialog = GTK_WIDGET ( gtk_builder_get_object ( bet_graph_builder, "bet_graph_dialog" ) );
-    gtk_window_set_transient_for ( GTK_WINDOW ( dialog ), GTK_WINDOW ( run.window ) );
+    gtk_window_set_transient_for ( GTK_WINDOW ( dialog ), GTK_WINDOW ( grisbi_app_get_active_window (NULL) ) );
     gtk_widget_set_size_request ( dialog, PAGE_WIDTH+30, PAGE_HEIGHT+70 );
-    gtk_signal_connect ( GTK_OBJECT ( dialog ),
+    g_signal_connect ( G_OBJECT ( dialog ),
                         "destroy",
-                        GTK_SIGNAL_FUNC ( gtk_widget_destroy ),
+                        G_CALLBACK ( gtk_widget_destroy ),
                         NULL);
 
     /* set the title */
@@ -2418,7 +2336,10 @@ void bet_graph_sectors_graph_new ( GtkWidget *button,
     self_debit->account_number = account_number;
     self_debit->currency_number = currency_number;
     self_debit->type_infos = 1;
-    self_debit->title = g_strdup ( _("Expenses") );
+	if (w_etat->metatree_assoc_mode)
+		self_debit->title = g_strdup ("Charges");
+	else
+		self_debit->title = g_strdup ( _("Expenses") );
     self_debit->service_id = g_strdup ( "GogPiePlot" );
     self_debit->is_legend = TRUE;
 
@@ -2439,7 +2360,11 @@ void bet_graph_sectors_graph_new ( GtkWidget *button,
     self_credit->account_number = account_number;
     self_credit->currency_number = currency_number;
     self_credit->type_infos = 0;
-    self_credit->title = g_strdup ( _("Incomes") );
+	if (w_etat->metatree_assoc_mode)
+		self_credit->title = g_strdup ("Produits");
+	else
+		self_credit->title = g_strdup ( _("Incomes") );
+
     self_credit->service_id = g_strdup ( "GogPiePlot" );
     self_credit->is_legend = TRUE;
 
@@ -2546,7 +2471,6 @@ void struct_free_bet_graph_prefs ( void )
 
 
 #endif /* HAVE_GOFFICE */
-
 /**
  *
  *
