@@ -22,7 +22,7 @@
 /* ************************************************************************** */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -36,9 +36,8 @@
 #include "bet_tab.h"
 #include "dialog.h"
 #include "export_csv.h"
-#include "fenetre_principale.h"
+#include "grisbi_app.h"
 #include "gsb_automem.h"
-#include "gsb_color.h"
 #include "gsb_data_account.h"
 #include "gsb_data_currency.h"
 #include "gsb_data_fyear.h"
@@ -46,6 +45,7 @@
 #include "gsb_file.h"
 #include "gsb_fyear.h"
 #include "gsb_real.h"
+#include "gsb_rgba.h"
 #include "mouse.h"
 #include "navigation.h"
 #include "print_tree_view_list.h"
@@ -53,7 +53,7 @@
 #include "traitement_variables.h"
 #include "utils.h"
 #include "utils_dates.h"
-#include "utils_file_selection.h"
+#include "utils_files.h"
 #include "utils_real.h"
 #include "utils_str.h"
 #include "erreur.h"
@@ -87,7 +87,7 @@ static void bet_historical_export_tab ( GtkWidget *menu_item,
                         GtkTreeView *tree_view );
 static gboolean bet_historical_fyear_create_combobox_store ( void );
 static void bet_historical_fyear_hide_present_futures_fyears ( void );
-static gsb_real bet_historical_get_children_amount ( GtkTreeModel *model, GtkTreeIter *parent );
+static GsbReal bet_historical_get_children_amount ( GtkTreeModel *model, GtkTreeIter *parent );
 static GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container );
 static gboolean bet_historical_get_full_div ( GtkTreeModel *model, GtkTreeIter *parent );
 static gint bet_historical_get_type_transaction ( const GDate *date,
@@ -116,7 +116,6 @@ static gboolean bet_historical_set_full_sub_div ( GtkTreeModel *model, GtkTreeIt
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GtkWidget *account_page;
 /*END_EXTERN*/
 
 /* blocage des signaux pour le tree_view pour les comptes de type GSB_TYPE_CASH */
@@ -135,8 +134,8 @@ static GHashTable *list_trans_hist = NULL;
 GtkTreeModel *bet_fyear_model = NULL;
 
 /**
- * this is a tree model filter from fyear_model_filter wich
- * show only the financial years wich must be showed
+ * this is a tree model filter from fyear_model_filter which
+ * show only the financial years which must be showed
  * */
 GtkTreeModel *bet_fyear_model_filter = NULL;
 
@@ -151,31 +150,34 @@ GtkWidget *bet_historical_create_page ( void )
 {
     GtkWidget *widget;
     GtkWidget *page;
+    GtkWidget *frame;
     GtkWidget *hbox;
-    GtkWidget *align;
     GtkWidget *label_title;
     GtkWidget *button_1, *button_2;
     GtkWidget *tree_view;
+    GtkWidget *account_page;
     gpointer pointeur;
 
     devel_debug (NULL);
-    page = gtk_vbox_new ( FALSE, 5 );
+    page = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
     gtk_widget_set_name ( page, "historical_page" );
 
-    /* titre de la page */
-    align = gtk_alignment_new (0.5, 0.0, 0.0, 0.0);
-    gtk_box_pack_start ( GTK_BOX ( page ), align, FALSE, FALSE, 5) ;
+    account_page = grisbi_win_get_account_page ();
 
+    /* frame pour la barre d'outils */
+    frame = gtk_frame_new ( NULL );
+    gtk_box_pack_start ( GTK_BOX ( page ), frame, FALSE, FALSE, 0 );
+
+    /* titre de la page */
     label_title = gtk_label_new ( "bet_hist_title" );
-    gtk_container_add ( GTK_CONTAINER ( align ), label_title );
-    g_object_set_data ( G_OBJECT ( account_page ), "bet_hist_title", label_title);
+	gtk_widget_set_halign (label_title, GTK_ALIGN_CENTER);
+    gtk_box_pack_start ( GTK_BOX ( page ), label_title, FALSE, FALSE, 5);
+    g_object_set_data ( G_OBJECT ( grisbi_win_get_account_page () ), "bet_hist_title", label_title);
 
     /* Choix des données sources */
-    align = gtk_alignment_new (0.5, 0.0, 0.0, 0.0);
-    gtk_box_pack_start ( GTK_BOX ( page ), align, FALSE, FALSE, 5) ;
-
-    hbox = gtk_hbox_new ( FALSE, 5 );
-    gtk_container_add ( GTK_CONTAINER ( align ), hbox );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+	gtk_widget_set_halign (hbox, GTK_ALIGN_CENTER);
+    gtk_box_pack_start ( GTK_BOX ( page ), hbox, FALSE, FALSE, 5);
     g_object_set_data ( G_OBJECT ( account_page ), "bet_historical_data", hbox );
 
     button_1 = gtk_radio_button_new_with_label ( NULL,
@@ -232,16 +234,11 @@ GtkWidget *bet_historical_create_page ( void )
     g_object_set_data ( G_OBJECT ( tree_view ), "label_title", label_title );
 
     /* set the color of selected row */
-    utils_set_tree_view_selection_and_text_color ( tree_view );
+	gtk_widget_set_name (tree_view, "tree_view");
 
     /* on y ajoute la barre d'outils */
-    bet_historical_toolbar = gtk_handle_box_new ( );
-    g_object_set_data ( G_OBJECT ( bet_historical_toolbar ), "tree_view", tree_view );
-    g_object_set_data ( G_OBJECT ( bet_historical_toolbar ), "page", page );
-    gtk_widget_show ( bet_historical_toolbar );
-
-    gtk_box_pack_start ( GTK_BOX ( page ), bet_historical_toolbar, FALSE, FALSE, 0 );
-    gtk_box_reorder_child ( GTK_BOX ( page ), bet_historical_toolbar, 0 );
+    bet_historical_toolbar = bet_historical_create_toolbar ( page, tree_view );
+    gtk_container_add ( GTK_CONTAINER ( frame ), bet_historical_toolbar );
 
     gtk_widget_show_all ( page );
 
@@ -330,7 +327,7 @@ gboolean bet_historical_div_toggle_clicked ( GtkCellRendererToggle *renderer,
         else
         {
             GtkTreeIter parent;
-            gsb_real amount;
+            GsbReal amount;
 
             if ( gtk_tree_model_iter_parent ( GTK_TREE_MODEL ( model ), &parent, &iter ) )
             {
@@ -419,7 +416,7 @@ void bet_historical_div_cell_edited (GtkCellRendererText *cell,
         gchar *tmp_str;
         gchar *str_amount;
         gboolean is_parent = FALSE;
-        gsb_real number;
+        GsbReal number;
 
         gtk_tree_model_get ( GTK_TREE_MODEL ( model ), &iter,
                         SPP_HISTORICAL_SELECT_COLUMN, &valeur,
@@ -497,6 +494,7 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
 {
     GtkWidget *scrolled_window;
     GtkWidget *tree_view;
+    GtkWidget *account_page;
     GtkTreeStore *tree_model;
     GtkTreeSelection *tree_selection;
     GtkCellRenderer *cell;
@@ -504,8 +502,11 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
     gchar *title;
 
     /* devel_debug (NULL); */
+    account_page = grisbi_win_get_account_page ();
     tree_view = gtk_tree_view_new ( );
-    gtk_tree_view_set_rules_hint ( GTK_TREE_VIEW (tree_view), FALSE );
+	gtk_widget_set_name (tree_view, "tree_view");
+	gtk_widget_set_tooltip_text (tree_view, _("Amount retained: Enter a negative number for a debit\n"
+											  "a positive number for a credit"));
     g_object_set_data ( G_OBJECT ( account_page ), "hist_tree_view", tree_view );
 
     tree_model = gtk_tree_store_new ( SPP_HISTORICAL_NUM_COLUMNS,
@@ -523,7 +524,7 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
                         G_TYPE_INT,         /* SPP_HISTORICAL_DIV_NUMBER        */
                         G_TYPE_INT,         /* SPP_HISTORICAL_SUB_DIV_NUMBER    */
                         G_TYPE_BOOLEAN,     /* SPP_HISTORICAL_EDITED_COLUMN     */
-                        GDK_TYPE_COLOR );   /* SPP_HISTORICAL_BACKGROUND_COLOR  */
+                        GDK_TYPE_RGBA );    /* SPP_HISTORICAL_BACKGROUND_COLOR  */
     gtk_tree_view_set_model ( GTK_TREE_VIEW (tree_view), GTK_TREE_MODEL ( tree_model ) );
     g_object_unref ( G_OBJECT ( tree_model ) );
 
@@ -554,7 +555,7 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
     column = gtk_tree_view_column_new_with_attributes ( _("Select"),
                         cell,
                         "active", SPP_HISTORICAL_SELECT_COLUMN,
-                        "cell-background-gdk", SPP_HISTORICAL_BACKGROUND_COLOR,
+                        "cell-background-rgba", SPP_HISTORICAL_BACKGROUND_COLOR,
                         NULL);
     gtk_tree_view_column_set_alignment ( column, 0.5 );
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( tree_view ), column );
@@ -568,7 +569,7 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
     column = gtk_tree_view_column_new_with_attributes ( title,
                         cell,
                         "text", SPP_HISTORICAL_DESC_COLUMN,
-                        "cell-background-gdk", SPP_HISTORICAL_BACKGROUND_COLOR,
+                        "cell-background-rgba", SPP_HISTORICAL_BACKGROUND_COLOR,
                         NULL);
     g_object_set_data ( G_OBJECT ( account_page ), "historical_column_source",
                         column );
@@ -579,13 +580,15 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
     g_object_set_data ( G_OBJECT ( column ), "num_col_model",
                         GINT_TO_POINTER ( SPP_HISTORICAL_DESC_COLUMN ) );
 
+	g_free (title);
+
     /* amount column */
     cell = gtk_cell_renderer_text_new ( );
     column = gtk_tree_view_column_new_with_attributes (
                         _("Amount"), cell,
                         "text", SPP_HISTORICAL_BALANCE_COLUMN,
                         "foreground", SPP_HISTORICAL_BALANCE_COLOR,
-                        "cell-background-gdk", SPP_HISTORICAL_BACKGROUND_COLOR,
+                        "cell-background-rgba", SPP_HISTORICAL_BACKGROUND_COLOR,
                         NULL);
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( tree_view ),
                         GTK_TREE_VIEW_COLUMN ( column ) );
@@ -603,7 +606,7 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
                         _("Average"), cell,
                         "text", SPP_HISTORICAL_AVERAGE_COLUMN,
                         "foreground", SPP_HISTORICAL_BALANCE_COLOR,
-                        "cell-background-gdk", SPP_HISTORICAL_BACKGROUND_COLOR,
+                        "cell-background-rgba", SPP_HISTORICAL_BACKGROUND_COLOR,
                         NULL);
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( tree_view ),
                         GTK_TREE_VIEW_COLUMN ( column ) );
@@ -621,7 +624,7 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
                         _("Current fyear"), cell,
                         "text", SPP_HISTORICAL_CURRENT_COLUMN,
                         "foreground", SPP_HISTORICAL_BALANCE_COLOR,
-                        "cell-background-gdk", SPP_HISTORICAL_BACKGROUND_COLOR,
+                        "cell-background-rgba", SPP_HISTORICAL_BACKGROUND_COLOR,
                         NULL);
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( tree_view ),
                         GTK_TREE_VIEW_COLUMN ( column ) );
@@ -636,12 +639,13 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
     /* amount retained column */
     cell = gtk_cell_renderer_text_new ( );
     g_object_set_data ( G_OBJECT ( account_page ), "edited_cell", cell );
+	gtk_cell_renderer_set_padding (GTK_CELL_RENDERER (cell), MARGIN_BOX, 0);
     column = gtk_tree_view_column_new_with_attributes (
                         _("Amount retained"), cell,
                         "text", SPP_HISTORICAL_RETAINED_COLUMN,
                         "foreground", SPP_HISTORICAL_BALANCE_COLOR,
                         "editable", SPP_HISTORICAL_EDITED_COLUMN,
-                        "cell-background-gdk", SPP_HISTORICAL_BACKGROUND_COLOR,
+                        "cell-background-rgba", SPP_HISTORICAL_BACKGROUND_COLOR,
                         NULL);
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( tree_view ),
                         GTK_TREE_VIEW_COLUMN ( column ) );
@@ -693,6 +697,7 @@ void bet_historical_populate_data ( gint account_number )
 {
     GtkWidget *tree_view;
     GtkTreeModel *model;
+    GtkTreePath *path = NULL;
     gint fyear_number;
     GDate *date_jour;
     GDate *date_min;
@@ -703,7 +708,7 @@ void bet_historical_populate_data ( gint account_number )
     TransactionCurrentFyear *tcf = NULL;
 
     devel_debug_int ( account_number );
-    tree_view = g_object_get_data (G_OBJECT ( account_page ), "bet_historical_treeview" );
+    tree_view = g_object_get_data (G_OBJECT ( grisbi_win_get_account_page () ), "bet_historical_treeview" );
     if ( GTK_IS_TREE_VIEW ( tree_view ) == FALSE )
         return;
 
@@ -792,13 +797,16 @@ void bet_historical_populate_data ( gint account_number )
     bet_historical_affiche_div ( list_div, tree_view );
 
     g_hash_table_remove_all ( list_div );
+	g_hash_table_unref (list_div);
     g_date_free ( date_jour );
     g_date_free ( date_min );
     g_date_free ( date_max );
     g_date_free ( start_current_fyear );
 
     bet_historical_set_background_color ( tree_view );
-    bet_array_list_select_path ( tree_view, NULL );
+	path = gtk_tree_path_new_first ();
+    bet_array_list_select_path (tree_view, path);
+    gtk_tree_path_free (path);
 }
 
 
@@ -810,11 +818,7 @@ void bet_historical_populate_data ( gint account_number )
  * */
 gboolean bet_historical_affiche_div ( GHashTable  *list_div, GtkWidget *tree_view )
 {
-    GtkTreeModel *model;
-
     /* devel_debug (NULL); */
-    model = gtk_tree_view_get_model ( GTK_TREE_VIEW ( tree_view ) );
-
     g_hash_table_foreach ( list_div, bet_historical_populate_div_model, tree_view );
 
     return FALSE;
@@ -831,8 +835,8 @@ void bet_historical_populate_div_model ( gpointer key,
                         gpointer value,
                         gpointer user_data )
 {
-    SH *sh = ( SH* ) value;
-    SBR *sbr = sh -> sbr;
+    BetHist *sh = (BetHist*) value;
+    BetRange *sbr = sh -> sbr;
     GtkTreeView *tree_view = ( GtkTreeView * ) user_data;
     GtkTreeModel *model;
     GtkTreeIter parent;
@@ -851,11 +855,11 @@ void bet_historical_populate_div_model ( gpointer key,
     gint nbre_sub_div = 0;
     gboolean sub_div_visible = FALSE;
     gboolean edited = TRUE;
-    gsb_real period = { 12, 0 };
-    gsb_real average;
-    gsb_real retained;
-    gsb_real amount;
-    kind_account kind;
+    GsbReal period = { 12, 0 };
+    GsbReal average;
+    GsbReal retained;
+    GsbReal amount;
+    KindAccount kind;
 
     div_number = sh -> div;
     div_name = bet_data_get_div_name ( div_number, 0, NULL );
@@ -924,8 +928,8 @@ void bet_historical_populate_div_model ( gpointer key,
     g_hash_table_iter_init ( &iter, sh -> list_sub_div );
     while ( g_hash_table_iter_next ( &iter, &sub_key, &sub_value ) )
     {
-        SH *sub_sh = ( SH* ) sub_value;
-        SBR *sub_sbr = sub_sh -> sbr;
+        BetHist *sub_sh = (BetHist* ) sub_value;
+        BetRange *sub_sbr = sub_sh -> sbr;
         GtkTreeIter fils;
         gchar **tab_str = NULL;
 
@@ -1139,7 +1143,7 @@ void bet_historical_refresh_data ( GtkTreeModel *tab_model,
     GtkTreeIter fils_iter;
 
     devel_debug (NULL);
-    tree_view = g_object_get_data ( G_OBJECT ( account_page ), "bet_historical_treeview" );
+    tree_view = g_object_get_data ( G_OBJECT (grisbi_win_get_account_page () ), "bet_historical_treeview" );
     model = gtk_tree_view_get_model ( GTK_TREE_VIEW ( tree_view ) );
 
     if ( gtk_tree_model_get_iter_first ( GTK_TREE_MODEL ( model ), &iter ) )
@@ -1232,7 +1236,7 @@ gboolean bet_historical_set_full_sub_div ( GtkTreeModel *model, GtkTreeIter *par
 {
     GtkTreeView *tree_view;
     GtkTreeIter fils_iter;
-    gint edited;
+    gint edited = 0;
 
     if ( gtk_tree_model_iter_children ( GTK_TREE_MODEL ( model ), &fils_iter, parent ) )
     {
@@ -1241,7 +1245,7 @@ gboolean bet_historical_set_full_sub_div ( GtkTreeModel *model, GtkTreeIter *par
         gint account_nb;
         gint div_number;
         gint sub_div_nb;
-        gsb_real retained;
+        GsbReal retained;
 
         do
         {
@@ -1272,7 +1276,7 @@ gboolean bet_historical_set_full_sub_div ( GtkTreeModel *model, GtkTreeIter *par
 
     if ( edited )
     {
-        tree_view = g_object_get_data ( G_OBJECT ( account_page ),
+        tree_view = g_object_get_data ( G_OBJECT ( grisbi_win_get_account_page () ),
                         "bet_historical_treeview" );
         gtk_tree_view_collapse_row ( tree_view,
                         gtk_tree_model_get_path ( model, parent ) );
@@ -1331,11 +1335,11 @@ gboolean bet_historical_set_empty_sub_div ( GtkTreeModel *model, GtkTreeIter *pa
  *
  *
  * */
-gsb_real bet_historical_get_children_amount ( GtkTreeModel *model, GtkTreeIter *parent )
+GsbReal bet_historical_get_children_amount ( GtkTreeModel *model, GtkTreeIter *parent )
 {
     GtkTreeIter fils_iter;
     gchar *str_amount;
-    gsb_real amount = null_real;
+    GsbReal amount = null_real;
 
     if ( gtk_tree_model_iter_children ( GTK_TREE_MODEL ( model ), &fils_iter, parent ) )
     {
@@ -1430,7 +1434,7 @@ void bet_historical_row_collapse_all ( GtkTreeView *tree_view,
                         GtkTreeModel *model )
 {
     if ( tree_view == NULL )
-        tree_view = g_object_get_data ( G_OBJECT ( account_page ), "bet_historical_treeview" );
+        tree_view = g_object_get_data ( G_OBJECT ( grisbi_win_get_account_page () ), "bet_historical_treeview" );
     gtk_tree_view_collapse_row ( tree_view,
                 gtk_tree_model_get_path ( model, iter ) );
     gtk_tree_selection_select_iter ( gtk_tree_view_get_selection (
@@ -1479,11 +1483,8 @@ void bet_historical_context_menu ( GtkWidget *tree_view )
     menu = gtk_menu_new ();
 
     /* Add last amount menu */
-    menu_item = gtk_image_menu_item_new_with_label ( _("Assign the amount of the last operation") );
-    gtk_image_menu_item_set_image ( GTK_IMAGE_MENU_ITEM ( menu_item ),
-                        gtk_image_new_from_stock ( GTK_STOCK_ADD,
-                        GTK_ICON_SIZE_MENU ) );
-
+    menu_item = utils_menu_item_new_from_image_label ("gtk-add-16.png",
+													  _("Assign the amount of the last operation"));
     g_signal_connect ( G_OBJECT ( menu_item ),
                         "activate",
                         G_CALLBACK ( bet_historical_add_last_amount ),
@@ -1502,11 +1503,7 @@ void bet_historical_context_menu ( GtkWidget *tree_view )
 
 
     /* Add average amount menu */
-    menu_item = gtk_image_menu_item_new_with_label ( _("Copy the average amount") );
-    gtk_image_menu_item_set_image ( GTK_IMAGE_MENU_ITEM ( menu_item ),
-                        gtk_image_new_from_stock ( GTK_STOCK_COPY,
-                        GTK_ICON_SIZE_MENU ) );
-
+    menu_item = utils_menu_item_new_from_image_label ("gtk-copy-16.png", _("Copy the average amount"));
     g_signal_connect ( G_OBJECT ( menu_item ),
                         "activate",
                         G_CALLBACK ( bet_historical_add_average_amount ),
@@ -1516,8 +1513,14 @@ void bet_historical_context_menu ( GtkWidget *tree_view )
 
     /* Finish all. */
     gtk_widget_show_all ( menu );
+
+#if GTK_CHECK_VERSION (3,22,0)
+	gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
+#else
+
     gtk_menu_popup ( GTK_MENU( menu ), NULL, NULL, NULL, NULL,
                         3, gtk_get_current_event_time ( ) );
+#endif
 }
 
 
@@ -1540,7 +1543,7 @@ void bet_historical_add_last_amount ( GtkWidget *menu_item,
     gint currency_number;
     gchar *tmp_str;
     gchar *str_amount;
-    gsb_real amount;
+    GsbReal amount;
 
     if ( !gtk_tree_selection_get_selected ( GTK_TREE_SELECTION ( tree_selection ),
      &model, &iter ) )
@@ -1623,12 +1626,14 @@ gboolean bet_historical_initializes_account_settings ( gint account_number )
 {
     GtkWidget *button = NULL;
     GtkWidget *combo = NULL;
+    GtkWidget *account_page;
     GtkTreeViewColumn *column;
     gchar *title;
     gint fyear_number;
     gint origin;
     gpointer pointeur;
 
+    account_page = grisbi_win_get_account_page ();
     /* set data origin */
     origin = gsb_data_account_get_bet_hist_data ( account_number );
     if ( origin )
@@ -1693,6 +1698,7 @@ gboolean bet_historical_set_background_color ( GtkWidget *tree_view )
 
     if ( gtk_tree_model_get_iter_first ( GTK_TREE_MODEL ( model ), &iter ) )
     {
+		GtkTreePath *path;
         gint current_color = 0;
 
         do
@@ -1700,26 +1706,27 @@ gboolean bet_historical_set_background_color ( GtkWidget *tree_view )
             gtk_tree_store_set ( GTK_TREE_STORE ( model ),
                         &iter,
                         SPP_HISTORICAL_BACKGROUND_COLOR,
-                        gsb_color_get_couleur_with_indice ( "couleur_fond", current_color ),
+                        gsb_rgba_get_couleur_with_indice ( "couleur_fond", current_color ),
                         -1 );
             current_color = !current_color;
 
+			path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &iter);
             if ( gtk_tree_model_iter_children ( GTK_TREE_MODEL ( model ), &fils_iter, &iter )
              &&
-              gtk_tree_view_row_expanded ( GTK_TREE_VIEW ( tree_view ),
-              gtk_tree_model_get_path ( GTK_TREE_MODEL ( model ), &iter ) ) )
+              gtk_tree_view_row_expanded ( GTK_TREE_VIEW ( tree_view ), path))
             {
                 do
                 {
                     gtk_tree_store_set ( GTK_TREE_STORE ( model ),
                         &fils_iter,
                         SPP_HISTORICAL_BACKGROUND_COLOR,
-                        gsb_color_get_couleur_with_indice ( "couleur_fond", current_color ),
+                        gsb_rgba_get_couleur_with_indice ( "couleur_fond", current_color ),
                         -1 );
                     current_color = !current_color;
                 }
                 while ( gtk_tree_model_iter_next ( GTK_TREE_MODEL ( model ), &fils_iter ) );
             }
+			gtk_tree_path_free (path);
         }
         while ( gtk_tree_model_iter_next ( GTK_TREE_MODEL ( model ), &iter ) );
     }
@@ -1736,18 +1743,18 @@ gboolean bet_historical_set_background_color ( GtkWidget *tree_view )
  * */
 void bet_historical_g_signal_block_tree_view ( void )
 {
+    GtkWidget *account_page;
     GtkTreeView *tree_view;
     gpointer cell;
     GtkTreeModel *tree_model;
 
+    account_page = grisbi_win_get_account_page ();
     hist_block_signal = TRUE;
     tree_view = g_object_get_data ( G_OBJECT ( account_page ), "hist_tree_view" );
     tree_model = gtk_tree_view_get_model ( GTK_TREE_VIEW ( tree_view ) );
 
     cell = g_object_get_data ( G_OBJECT ( account_page ), "toggle_cell" );
     g_signal_handlers_block_by_func ( cell, bet_historical_div_toggle_clicked, tree_model );
-
-    cell = g_object_get_data ( G_OBJECT ( account_page ), "edited_cell" );
     g_signal_handlers_block_by_func ( tree_view, bet_historical_button_press, NULL );
 }
 
@@ -1760,12 +1767,14 @@ void bet_historical_g_signal_block_tree_view ( void )
  * */
 void bet_historical_g_signal_unblock_tree_view ( void )
 {
+    GtkWidget *account_page;
     GtkTreeView *tree_view;
     gpointer cell;
     GtkTreeModel *tree_model;
 
     if ( hist_block_signal == FALSE )
         return;
+    account_page = grisbi_win_get_account_page ();
 
     hist_block_signal = FALSE;
     tree_view = g_object_get_data ( G_OBJECT ( account_page ), "hist_tree_view" );
@@ -1773,8 +1782,6 @@ void bet_historical_g_signal_unblock_tree_view ( void )
     cell = g_object_get_data ( G_OBJECT ( account_page ), "toggle_cell" );
 
     g_signal_handlers_unblock_by_func ( cell, bet_historical_div_toggle_clicked, tree_model );
-
-    cell = g_object_get_data ( G_OBJECT ( account_page ), "edited_cell" );
     g_signal_handlers_unblock_by_func ( tree_view, bet_historical_button_press, NULL );
 }
 
@@ -1806,7 +1813,7 @@ void bet_historical_set_page_title ( gint account_number )
                     gsb_data_fyear_get_name ( result ),
                     gsb_data_account_get_name ( account_number ) );
 
-    widget = GTK_WIDGET ( g_object_get_data ( G_OBJECT ( account_page ), "bet_hist_title") );
+    widget = GTK_WIDGET ( g_object_get_data ( G_OBJECT ( grisbi_win_get_account_page () ), "bet_hist_title") );
     gtk_label_set_label ( GTK_LABEL ( widget ), title );
 
     g_free ( hist_srce_name );
@@ -1896,7 +1903,7 @@ void bet_historical_fyear_hide_present_futures_fyears ( void )
     tmp_list = gsb_data_fyear_get_fyears_list ( );
     while (tmp_list)
     {
-        struct_fyear *fyear;
+        FyearStruct *fyear;
 
         fyear = tmp_list -> data;
 
@@ -1930,63 +1937,50 @@ void bet_historical_fyear_hide_present_futures_fyears ( void )
 GtkWidget *bet_historical_create_toolbar ( GtkWidget *parent,
                         GtkWidget *tree_view )
 {
-    GtkWidget *hbox;
-    GtkWidget *button;
+    GtkWidget *toolbar;
+    GtkToolItem *item;
 
-    /* Hbox */
-    hbox = gtk_hbox_new ( FALSE, 0 );
+    toolbar = gtk_toolbar_new ( );
+    g_object_set_data ( G_OBJECT ( toolbar ), "tree_view", tree_view );
+    g_object_set_data ( G_OBJECT ( toolbar ), "page", parent );
 
     /* print button */
-    button = gsb_automem_stock_button_new ( conf.display_toolbar,
-                        GTK_STOCK_PRINT,
-                        _("Print"),
-                        NULL,
-                        NULL );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Print the array") );
-    g_signal_connect ( G_OBJECT ( button ),
+    item = utils_buttons_tool_button_new_from_image_label ("gtk-print-24.png", _("Print"));
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ), _("Print the array") );
+    g_signal_connect ( G_OBJECT ( item ),
                         "clicked",
                         G_CALLBACK ( bet_historical_print_tab ),
                         tree_view );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 5 );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     /* Export button */
-    button = gsb_automem_stock_button_new ( conf.display_toolbar,
-					   GTK_STOCK_SAVE,
-					   _("Export"),
-					   NULL,
-					   NULL );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Export the array") );
-    g_signal_connect ( G_OBJECT ( button ),
+    item = utils_buttons_tool_button_new_from_image_label ("gsb-export-24.png", _("Export"));
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ), _("Export the array") );
+    g_signal_connect ( G_OBJECT ( item ),
                         "clicked",
                         G_CALLBACK ( bet_historical_export_tab ),
                         tree_view );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 5 );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
 #ifdef HAVE_GOFFICE
     /* sectors button */
-    button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
-                        _("Data graph"),
-                        "graph-sectors.png",
-                        NULL,
-                        NULL );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Display the pie graph") );
-    g_signal_connect ( G_OBJECT ( button ),
+    item = utils_buttons_tool_button_new_from_image_label ("gsb-graph-sectors-24.png", _("Data graph"));
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ), _("Display the pie graph") );
+    g_signal_connect ( G_OBJECT ( item ),
                         "clicked",
                         G_CALLBACK ( bet_graph_sectors_graph_new ),
                         tree_view );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 5 );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     /* monthly button */
-    button = bet_graph_button_menu_new ( conf.display_toolbar,
+    item = bet_graph_button_menu_new ( toolbar,
                         "historical_graph",
                         G_CALLBACK ( bet_graph_montly_graph_new ),
                         tree_view );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 5 );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 #endif /* HAVE_GOFFICE */
 
-    gtk_widget_show_all ( hbox );
-
-    return ( hbox );
+    return ( toolbar );
 
 }
 
@@ -1997,25 +1991,9 @@ GtkWidget *bet_historical_create_toolbar ( GtkWidget *parent,
  *
  *
  * */
-void bet_historical_update_toolbar ( void )
+void bet_historical_update_toolbar ( gint toolbar_style )
 {
-    GtkWidget *page;
-    GtkWidget *tree_view;
-    GList *list = NULL;
-
-    page = g_object_get_data ( G_OBJECT ( bet_historical_toolbar ), "page" );
-    tree_view = g_object_get_data ( G_OBJECT ( bet_historical_toolbar ), "tree_view" );
-
-    list = gtk_container_get_children ( GTK_CONTAINER ( bet_historical_toolbar ) );
-
-    if ( list )
-    {
-        gtk_container_remove ( GTK_CONTAINER ( bet_historical_toolbar ),
-                               GTK_WIDGET ( list -> data ) );
-        g_list_free ( list );
-    }
-    gtk_container_add ( GTK_CONTAINER ( bet_historical_toolbar ),
-                        bet_historical_create_toolbar ( page, tree_view ) );
+    gtk_toolbar_set_style ( GTK_TOOLBAR ( bet_historical_toolbar ), toolbar_style );
 }
 
 
@@ -2034,10 +2012,10 @@ void bet_historical_export_tab ( GtkWidget *menu_item,
     gchar *tmp_last_directory;
 
     dialog = gtk_file_chooser_dialog_new ( _("Export the historical data"),
-					   GTK_WINDOW ( run.window ),
+					   GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
 					   GTK_FILE_CHOOSER_ACTION_SAVE,
-					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					   GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+					   "gtk-cancel", GTK_RESPONSE_CANCEL,
+					   "gtk-save", GTK_RESPONSE_OK,
 					   NULL);
 
     gtk_file_chooser_set_current_name ( GTK_FILE_CHOOSER ( dialog ), "division.csv");
@@ -2050,8 +2028,8 @@ void bet_historical_export_tab ( GtkWidget *menu_item,
     switch ( resultat )
     {
 	case GTK_RESPONSE_OK :
-	    filename = file_selection_get_filename ( GTK_FILE_CHOOSER ( dialog ) );
-        tmp_last_directory = file_selection_get_last_directory ( GTK_FILE_CHOOSER ( dialog ), TRUE );
+	    filename = gtk_file_chooser_get_filename ( GTK_FILE_CHOOSER ( dialog ) );
+        tmp_last_directory = utils_files_selection_get_last_directory ( GTK_FILE_CHOOSER ( dialog ), TRUE );
         gsb_file_update_last_path ( tmp_last_directory );
         g_free ( tmp_last_directory );
 	    gtk_widget_destroy ( GTK_WIDGET ( dialog ) );
