@@ -32,7 +32,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -46,7 +46,6 @@
 /*END_INCLUDE*/
 
 /*START_STATIC*/
-static void custom_list_class_init (CustomListClass *klass);
 static void custom_list_finalize (GObject *object);
 static GType custom_list_get_column_type (GtkTreeModel *tree_model,
 					  gint          index);
@@ -61,7 +60,6 @@ static void custom_list_get_value (GtkTreeModel *tree_model,
 				   GtkTreeIter  *iter,
 				   gint          column,
 				   GValue       *value);
-static void custom_list_init (CustomList *custom_list);
 static gboolean custom_list_iter_children (GtkTreeModel *tree_model,
 					   GtkTreeIter  *iter,
 					   GtkTreeIter  *parent);
@@ -82,13 +80,13 @@ static void custom_list_tree_model_init (GtkTreeModelIface *iface);
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GdkColor text_color[2];
+extern GdkRGBA text_color[2];
 /*END_EXTERN*/
 
 
 G_DEFINE_TYPE_EXTENDED (
     CustomList, custom_list, G_TYPE_OBJECT, 0,
-    G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL, custom_list_tree_model_init));
+    G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL, custom_list_tree_model_init))
 
 
 /**
@@ -199,18 +197,17 @@ static void custom_list_init (CustomList *custom_list)
 {
     custom_list->n_columns = CUSTOM_MODEL_N_COLUMNS;
 
-    custom_list->column_types[0] = G_TYPE_STRING;  	/* col 0 ( check by default) */
+    custom_list->column_types[0] = G_TYPE_STRING;  	    /* col 0 ( check by default) */
     custom_list->column_types[1] = G_TYPE_STRING;   	/* col 1 ( date by default) */
     custom_list->column_types[2] = G_TYPE_STRING;    	/* col 2 ( payee by default) */
     custom_list->column_types[3] = G_TYPE_STRING;     	/* col 3 ( P/R by default) */
     custom_list->column_types[4] = G_TYPE_STRING;     	/* col 4 ( debit by default) */
     custom_list->column_types[5] = G_TYPE_STRING;     	/* col 5 ( credit by default) */
     custom_list->column_types[6] = G_TYPE_STRING;     	/* col 6 ( balance by default) */
-
-    custom_list->column_types[7] = GDK_TYPE_COLOR;     	/* col 7 ( color of bg ) */
-    custom_list->column_types[8] = GDK_TYPE_COLOR; 	/* col 8 ( bg saved when selected ) */
+    custom_list->column_types[7] = GDK_TYPE_RGBA;     	/* col 7 ( color of bg ) */
+    custom_list->column_types[8] = GDK_TYPE_RGBA; 	    /* col 8 ( bg saved when selected ) */
     custom_list->column_types[9] = G_TYPE_STRING;     	/* col 9 ( color of amount ) */
-    custom_list->column_types[10] = GDK_TYPE_COLOR; 	/* col 10 ( color of the text ) */
+    custom_list->column_types[10] = GDK_TYPE_RGBA; 	    /* col 10 ( color of the text ) */
     custom_list->column_types[11] = G_TYPE_POINTER;     /* col 11 ( transaction struct address ) */
     custom_list->column_types[12] = G_TYPE_INT;     	/* col 12 ( what is line ) */
     custom_list->column_types[13] = G_TYPE_STRING;    	/* col 12 ( font ) */
