@@ -331,33 +331,27 @@ static gboolean grisbi_win_hpaned_size_allocate (GtkWidget *hpaned_general,
 
 /* FORM_GENERAL */
 /**
- * utile pour gérer la dimension du formulaire
+ * Positionne le label des rapprochements à la fin du label de l'expander
+ * utile juste pour les comptes.
  *
  * \param GtkWidget			form
  * \param GtkAllocation 	allocation
  * \param gpointer			NULL
  *
  * \return FALSE
- */
-static gboolean grisbi_win_form_size_allocate (GtkWidget *form_general,
+ **/
+static gboolean grisbi_win_form_size_allocate (GtkWidget *form_expander,
                                                GtkAllocation *allocation,
                                                GrisbiWin *win)
 {
-	GtkWidget *form_expander;
-
-	/* On sort immédiatement */
-	/* fixe partiellement un bug de maj de la liste des opérations */
-	//~ if (grisbi_win_get_prefs_dialog (NULL))
-	//~ {
-		return FALSE;
-	//~ }
-
-	form_expander = g_object_get_data (G_OBJECT (form_general), "form_expander");
-	if (form_expander)
+	if (gsb_gui_navigation_get_current_page () == GSB_ACCOUNT_PAGE)
 	{
 		GtkWidget *expander_label;
+		gint new_width;
 
-		conf.form_expander_label_width = 0.95*allocation->width;
+		new_width = 0.93*(conf.main_width - conf.panel_width);
+
+		conf.form_expander_label_width = new_width;
 
 		expander_label = gtk_expander_get_label_widget (GTK_EXPANDER(form_expander));
 		gtk_widget_set_size_request (expander_label, conf.form_expander_label_width, -1);
@@ -366,19 +360,19 @@ static gboolean grisbi_win_form_size_allocate (GtkWidget *form_general,
     return FALSE;
 }
 
-static gboolean grisbi_win_expander_label_set_initial_width (GtkWidget *form_general)
+/**
+ * Init the width of expander
+ *
+ * \param expander	Expanded.
+ *
+ * \return
+ **/
+static void grisbi_win_expander_label_set_initial_width (GtkWidget *form_expander)
 {
-	GtkWidget *form_expander;
 	GtkWidget *expander_label;
 
-	form_expander = g_object_get_data (G_OBJECT (form_general), "form_expander");
-	if (form_expander)
-	{
-		expander_label = gtk_expander_get_label_widget (GTK_EXPANDER(form_expander));
-		gtk_widget_set_size_request (expander_label, conf.form_expander_label_width, -1);
-	}
-
-    return FALSE;
+	expander_label = gtk_expander_get_label_widget (GTK_EXPANDER(form_expander));
+	gtk_widget_set_size_request (expander_label, conf.form_expander_label_width, -1);
 }
 
 /**
@@ -572,47 +566,45 @@ static gboolean grisbi_win_fill_general_notebook (GrisbiWin *win)
  */
 static GtkWidget *grisbi_win_create_general_notebook (GrisbiWin *win)
 {
+	GtkWidget *sw_general;
 	GtkWidget *grid;
-	GtkWidget *sw;
 	GrisbiWinPrivate *priv;
 
     devel_debug ("create_main_notebook");
 	priv = grisbi_win_get_instance_private (GRISBI_WIN (win));
 
-    /* the main right page is a grid with a notebook on the top and the form on the bottom */
-	grid = gtk_grid_new ();
-
-	/* adding a scrolled window for low resolution */
-    sw = gtk_scrolled_window_new (NULL, NULL);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
+    sw_general = gtk_scrolled_window_new (NULL, NULL);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw_general),
                                     GTK_POLICY_AUTOMATIC,
                                     GTK_POLICY_AUTOMATIC);
 
-  	gtk_grid_attach (GTK_GRID (grid), sw, 0,0,1,1);
+    /* the main right page is a grid with a notebook on the top and the form on the bottom */
+	grid = gtk_grid_new ();
+	gtk_container_add (GTK_CONTAINER(sw_general), grid);
 
 	/* append the notebook */
     priv->notebook_general = gtk_notebook_new ();
     gtk_notebook_set_show_tabs (GTK_NOTEBOOK (priv->notebook_general), FALSE);
     gtk_notebook_set_show_border (GTK_NOTEBOOK (priv->notebook_general), FALSE);
-	gtk_container_add (GTK_CONTAINER(sw), priv->notebook_general);
+  	gtk_grid_attach (GTK_GRID (grid), priv->notebook_general, 0,0,1,1);
 
-    gtk_widget_show (priv->notebook_general);
 
     /* append the form */
     priv->form_general = grisbi_win_form_new (win);
 	gtk_grid_attach (GTK_GRID (grid), priv->form_general, 0,1,1,1);
-	grisbi_win_expander_label_set_initial_width (priv->form_general);
+	grisbi_win_expander_label_set_initial_width (priv->form_expander);
     gtk_widget_hide (priv->form_general);
-    g_signal_connect (G_OBJECT (priv->form_general),
+    g_signal_connect (G_OBJECT (priv->form_expander),
                       "size_allocate",
                       G_CALLBACK (grisbi_win_form_size_allocate),
                       win);
 
 	/* show widgets */
-	gtk_widget_show (sw);
+	gtk_widget_show (sw_general);
     gtk_widget_show (grid);
+    gtk_widget_show (priv->notebook_general);
 
-    return grid;
+    return sw_general;
 }
 
 /* VBOX_GENERAL */
@@ -941,6 +933,7 @@ static void grisbi_win_init (GrisbiWin *win)
     /* creation et initialisation de la structure w_run */
     priv->w_run = g_malloc0 (sizeof (GrisbiWinRun));
 	(priv->w_run)->account_number_is_0 = FALSE;
+	(priv->w_run)->new_account_file = FALSE;
 	(priv->w_run)->prefs_expand_tree = TRUE;
 	(priv->w_run)->prefs_selected_row = g_strdup ("0:0");
 
@@ -1444,7 +1437,7 @@ void grisbi_win_menu_move_to_acc_new (void)
     GMenuItem *menu_item;
     GSList *tmp_list;
 
-    win = grisbi_app_get_active_window (NULL);
+	win = grisbi_app_get_active_window (NULL);
     priv = grisbi_win_get_instance_private (GRISBI_WIN (win));
 
     menu = grisbi_app_get_menu_edit ();
@@ -1491,8 +1484,6 @@ void grisbi_win_menu_move_to_acc_new (void)
 
     menu_item = g_menu_item_new_submenu (_("Move transaction to another account"), (GMenuModel*) submenu);
     g_menu_item_set_detailed_action (menu_item, "win.move-to-acc");
-    action = g_action_map_lookup_action (G_ACTION_MAP (win), "move-to-acc");
-    g_simple_action_set_enabled (G_SIMPLE_ACTION (action), FALSE);
 
     g_menu_insert_item (G_MENU (menu), 3, menu_item);
     g_object_unref (menu_item);
@@ -1512,10 +1503,6 @@ void grisbi_win_menu_move_to_acc_update (gboolean active)
     GrisbiWin *win;
     GAction *action;
     GSList *tmp_list;
-    static gboolean flag_active = FALSE;
-
-    if (flag_active == active)
-        return;
 
     win = grisbi_app_get_active_window (NULL);
 
@@ -1548,7 +1535,6 @@ void grisbi_win_menu_move_to_acc_update (gboolean active)
         }
         tmp_list = tmp_list->next;
     }
-    flag_active = active;
 }
 
 /* MAIN WINDOW */
@@ -1679,7 +1665,7 @@ void grisbi_win_set_size_and_position (GtkWindow *win)
 {
 	GrisbiWinPrivate *priv;
     GdkGeometry size_hints = {
-    1200, 600, -1, -1, 1240, 640, 10, 10, 1.5, 1.5, GDK_GRAVITY_NORTH_WEST
+    1000, 700, -1, -1, 1000, 700, 10, 10, 1.5, 1.5, GDK_GRAVITY_NORTH_WEST
   };
 
     priv = grisbi_win_get_instance_private (GRISBI_WIN (win));
@@ -1696,7 +1682,7 @@ void grisbi_win_set_size_and_position (GtkWindow *win)
     if (conf.main_width && conf.main_height)
         gtk_window_set_default_size (GTK_WINDOW (win), conf.main_width, conf.main_height);
     else
-        gtk_window_set_default_size (GTK_WINDOW (win), 900, 600);
+        gtk_window_set_default_size (GTK_WINDOW (win), 1024, 768);
 
     /* display window at position */
     gtk_window_move (GTK_WINDOW (win), conf.x_position, conf.y_position);
@@ -2233,6 +2219,9 @@ void grisbi_win_headings_update_title (gchar *title)
 {
 	GrisbiWinPrivate *priv;
 
+	if (!conf.show_headings_bar)
+		return;
+
 	priv = grisbi_win_get_instance_private (GRISBI_WIN (grisbi_app_get_active_window (NULL)));
 
     grisbi_win_headings_private_update_label_markup (GTK_LABEL (priv->headings_title), title, TRUE);
@@ -2248,6 +2237,9 @@ void grisbi_win_headings_update_suffix (const gchar *suffix)
 {
 	GrisbiWinPrivate *priv;
 
+	if (!conf.show_headings_bar)
+		return;
+
 	priv = grisbi_win_get_instance_private (GRISBI_WIN (grisbi_app_get_active_window (NULL)));
     grisbi_win_headings_private_update_label_markup (GTK_LABEL (priv->headings_suffix), suffix, FALSE);
 }
@@ -2318,8 +2310,9 @@ void grisbi_win_status_bar_wait (gboolean force_update)
 {
     GrisbiWin *win;
 	GrisbiWinPrivate *priv;
-    GdkDisplay *display;
+    GdkCursor *cursor;
     GdkDevice *device;
+    GdkDisplay *display;
     GdkWindow *current_window;
     GdkWindow *run_window;
 
@@ -2327,7 +2320,9 @@ void grisbi_win_status_bar_wait (gboolean force_update)
 	priv = grisbi_win_get_instance_private (GRISBI_WIN (win));
 
     run_window = gtk_widget_get_window (GTK_WIDGET (win));
-    display = gdk_window_get_display (run_window);
+	display = gdk_window_get_display (run_window);
+    cursor = gdk_cursor_new_for_display (display, GDK_HAND2);
+    gdk_window_set_cursor (run_window, cursor);
 
 #if GTK_CHECK_VERSION (3,20,0)
 	GdkSeat *default_seat;
@@ -2341,22 +2336,17 @@ void grisbi_win_status_bar_wait (gboolean force_update)
     device = gdk_device_manager_get_client_pointer (device_manager);
 #endif
 
-    gdk_window_set_cursor (run_window, gdk_cursor_new_for_display (display, GDK_WATCH));
-
     current_window = gdk_device_get_window_at_position (device, NULL, NULL);
-
     if (current_window && GDK_IS_WINDOW (current_window) && current_window != run_window)
     {
-        GdkWindow *parent = gdk_window_get_toplevel (current_window);
+        GdkWindow *parent;
 
-        if (parent && parent != current_window)
+		parent = gdk_window_get_toplevel (current_window);
+		if (parent && parent != current_window)
         {
             current_window = parent;
         }
-
-        gdk_window_set_cursor (current_window,
-                               gdk_cursor_new_for_display (gdk_display_get_default (),
-                                                           GDK_WATCH));
+        gdk_window_set_cursor (current_window, cursor);
 
         priv->tracked_window = current_window;
     }
@@ -2365,7 +2355,6 @@ void grisbi_win_status_bar_wait (gboolean force_update)
         update_gui ();
 }
 
-
 /**
  * Change current cursor to default cursor.
  *
