@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2009 Cédric Auger (cedric@grisbi.org)            */
 /*          2004-2009 Benjamin Drieu (bdrieu@april.org)                       */
-/*                      2009 Pierre Biava (grisbi@pierre.biava.name)          */
+/*                 2009-2017 Pierre Biava (grisbi@pierre.biava.name)          */
 /*      2009 Thomas Peel (thomas.peel@live.fr)                                */
 /*          http://www.grisbi.org                                             */
 /*                                                                            */
@@ -30,7 +30,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -40,9 +40,11 @@
 /*START_INCLUDE*/
 #include "gsb_account_property.h"
 #include "dialog.h"
+#include "grisbi_win.h"
 #include "gsb_account.h"
 #include "gsb_autofunc.h"
 #include "gsb_bank.h"
+#include "gsb_category.h"
 #include "utils_buttons.h"
 #include "gsb_currency.h"
 #include "gsb_data_account.h"
@@ -57,7 +59,6 @@
 #include "accueil.h"
 #include "menu.h"
 #include "gsb_scheduler_list.h"
-#include "main.h"
 #include "traitement_variables.h"
 #include "utils_str.h"
 #include "utils.h"
@@ -94,7 +95,7 @@ static gboolean gsb_account_property_iban_focus_in_event ( GtkWidget *entry,
 static gboolean gsb_account_property_iban_focus_out_event ( GtkWidget *entry,
                         GdkEventFocus *ev,
                         gpointer data );
-static struct iso_13616_iban *gsb_account_property_iban_get_struc ( gchar *pays );
+static struct Iso13616Iban *gsb_account_property_iban_get_struc ( gchar *pays );
 static void gsb_account_property_iban_insert_text ( GtkEditable *entry,
                         gchar *text,
                         gint length,
@@ -108,14 +109,14 @@ static void gsb_account_property_iban_set_iban ( const gchar *iban );
 static void gsb_account_property_iban_switch_bank_data ( gboolean sensitive );
 /*END_STATIC*/
 
-struct iso_13616_iban
+struct Iso13616Iban
 {
-    gchar *locale;
-    gchar *iban;
+    const gchar *locale;
+    const gchar *iban;
     gint nbre_char;
 };
 
-static struct iso_13616_iban iso_13616_ibans [] = {
+static struct Iso13616Iban iso_13616_ibans [] = {
     { "XX", "XXkk XXXX XXXX XXXX XXXX XXXX XXXX XXXX XX", 34 },
     { "AD", "ADkk BBBB SSSS CCCC CCCC CCCC", 24 },
     { "AT", "ATkk BBBB BCCC CCCC CCCC", 20 },
@@ -141,7 +142,7 @@ static struct iso_13616_iban iso_13616_ibans [] = {
     { "NL", "NLkk BBBB CCCC CCCC CC", 18 },
     { "PT", "PTkk BBBB BBBB CCCC CCCC CCCK K", 25 },
     { "SE", "SEkk BBBB CCCC CCCC CCCC CCCC", 24 },
-    { NULL },
+    { NULL, NULL, 0 },
 };
 
 static GtkWidget *edit_bank_button = NULL;
@@ -154,7 +155,7 @@ static GtkWidget *label_code_banque = NULL;
 static GtkWidget *detail_guichet = NULL;
 static GtkWidget *detail_no_compte = NULL;
 static GtkWidget *detail_cle_compte = NULL;
-GtkWidget *detail_devise_compte = NULL;
+       GtkWidget *detail_devise_compte = NULL;
 static GtkWidget *detail_compte_cloture = NULL;
 static GtkWidget *detail_solde_init = NULL;
 static GtkWidget *detail_solde_mini_autorise = NULL;
@@ -167,6 +168,7 @@ static GtkWidget *label_code_bic = NULL;
 static GtkWidget *label_guichet = NULL;
 static GtkWidget *label_no_compte = NULL;
 static GtkWidget *label_cle_compte = NULL;
+static GtkWidget *paddingbox_detail_compte;
 
 
 enum origin
@@ -177,7 +179,7 @@ enum origin
     PROPERTY_CLOSED_ACCOUNT,
     PROPERTY_INIT_BALANCE,
     PROPERTY_WANTED_BALANCE,
-    PROPERTY_HOLDER_NAME,
+    PROPERTY_HOLDER_NAME
 };
 
 /*START_EXTERN*/
@@ -195,48 +197,45 @@ GtkWidget *gsb_account_property_create_page ( void )
 {
     GtkWidget *onglet, *vbox, *scrolled_window, *hbox, *vbox2;
     GtkWidget *label, *scrolled_window_text, *paddingbox;
-    GtkSizeGroup * size_group;
-    GtkWidget *align;
+    GtkSizeGroup *size_group;
 
     devel_debug ( NULL );
 
     /* la fenetre ppale est une vbox avec les détails en haut et appliquer en bas */
-    onglet = gtk_vbox_new ( FALSE, 5 );
+    onglet = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
     gtk_widget_set_name ( onglet, "properties_page" );
-    gtk_container_set_border_width ( GTK_CONTAINER ( onglet ), 10 );
+    gtk_container_set_border_width ( GTK_CONTAINER ( onglet ), BOX_BORDER_WIDTH );
 
     size_group = gtk_size_group_new ( GTK_SIZE_GROUP_HORIZONTAL );
 
     /* Création du bouton pour modifier l'icône de compte. C'est un moyen de
      * contourner le bug du gtk_viewport */
-    align = gtk_alignment_new (0.5, 0.0, 0.0, 0.0);
-    bouton_icon = gtk_button_new ( );
+    bouton_icon = gtk_button_new ();
     gtk_widget_set_size_request ( bouton_icon, -1, 40 );
+    gtk_widget_set_halign ( bouton_icon, GTK_ALIGN_CENTER );
     gtk_button_set_relief ( GTK_BUTTON ( bouton_icon ), GTK_RELIEF_NORMAL );
-    gtk_container_add ( GTK_CONTAINER ( align ), bouton_icon );
-    gtk_box_pack_start ( GTK_BOX ( onglet ), align, FALSE, FALSE, 0);
+    gtk_box_pack_start ( GTK_BOX ( onglet ), bouton_icon, FALSE, FALSE, 0);
 
     /* partie du haut avec les détails du compte */
     scrolled_window = gtk_scrolled_window_new ( FALSE, FALSE );
     gtk_scrolled_window_set_policy ( GTK_SCROLLED_WINDOW ( scrolled_window ),
                         GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
+    gtk_scrolled_window_set_shadow_type ( GTK_SCROLLED_WINDOW ( scrolled_window ), GTK_SHADOW_OUT );
     gtk_box_pack_start ( GTK_BOX ( onglet ), scrolled_window, TRUE, TRUE, 0 );
 
-    vbox = gtk_vbox_new ( FALSE, 5 );
-
-    gtk_scrolled_window_add_with_viewport ( GTK_SCROLLED_WINDOW ( scrolled_window ), vbox );
-    gtk_viewport_set_shadow_type ( GTK_VIEWPORT ( GTK_BIN ( scrolled_window ) -> child ),
-                        GTK_SHADOW_NONE );
+    vbox = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
+    utils_widget_set_padding (vbox, MARGIN_START, 0);
+    gtk_container_add ( GTK_CONTAINER ( scrolled_window ), vbox );
 
     /* création de la ligne des détails du compte */
-    paddingbox = new_paddingbox_with_title (vbox, FALSE, _("Account details"));
+    paddingbox_detail_compte = new_paddingbox_with_title (vbox, FALSE, _("Account details"));
 
    /* création de la ligne du nom du compte */
-    hbox = gtk_hbox_new ( FALSE, 6 );
-    gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_box_pack_start ( GTK_BOX (paddingbox_detail_compte), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Account name: ") );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
@@ -253,11 +252,11 @@ GtkWidget *gsb_account_property_create_page ( void )
     gtk_box_pack_start ( GTK_BOX ( hbox ), detail_nom_compte, TRUE, TRUE, 0 );
 
     /* create the box of kind of account */
-    hbox = gtk_hbox_new ( FALSE, 6 );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_box_pack_start ( GTK_BOX (paddingbox_detail_compte), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Account type: ") );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
@@ -271,11 +270,11 @@ GtkWidget *gsb_account_property_create_page ( void )
     gtk_box_pack_start ( GTK_BOX(hbox), detail_type_compte, TRUE, TRUE, 0);
 
     /* create the currency line */
-    hbox = gtk_hbox_new ( FALSE, 6 );
-    gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_box_pack_start ( GTK_BOX (paddingbox_detail_compte), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Account currency: ") );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
@@ -294,7 +293,7 @@ GtkWidget *gsb_account_property_create_page ( void )
                         GINT_TO_POINTER (PROPERTY_CLOSED_ACCOUNT),
                         G_CALLBACK (gsb_data_account_set_closed_account),
                         0 );
-    gtk_box_pack_start ( GTK_BOX(paddingbox), detail_compte_cloture, FALSE, FALSE, 0 );
+    gtk_box_pack_start ( GTK_BOX (paddingbox_detail_compte), detail_compte_cloture, FALSE, FALSE, 0 );
 
     /* set the callback for the button_icon */
     gtk_button_set_relief ( GTK_BUTTON ( bouton_icon ), GTK_RELIEF_NONE );
@@ -306,11 +305,11 @@ GtkWidget *gsb_account_property_create_page ( void )
 
     /* création de la ligne du titulaire du compte */
     paddingbox = new_paddingbox_with_title ( vbox, FALSE, _("Account holder"));
-    hbox = gtk_hbox_new ( FALSE, 6 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Holder name: ") );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
@@ -326,10 +325,10 @@ GtkWidget *gsb_account_property_create_page ( void )
     gtk_box_pack_start ( GTK_BOX(hbox), detail_titulaire_compte, TRUE, TRUE, 0);
 
     /* address of the holder line */
-    hbox = gtk_hbox_new ( FALSE, 6 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
-    vbox2 = gtk_vbox_new (FALSE, 0);
+    vbox2 = gtk_box_new ( GTK_ORIENTATION_VERTICAL, 0 );
     gtk_box_pack_start ( GTK_BOX (hbox), vbox2, FALSE, FALSE, 0 );
 
     /* we need to create first the text_view because used in callbacks */
@@ -338,7 +337,6 @@ GtkWidget *gsb_account_property_create_page ( void )
                         NULL,
                         G_CALLBACK (gsb_data_account_set_holder_address),
                         0 );
-    gtk_widget_set_size_request ( detail_adresse_titulaire, -1, 70 );
 
     /* now the checkbutton for different address */
     button_holder_address = gsb_autofunc_checkbutton_new (
@@ -347,7 +345,6 @@ GtkWidget *gsb_account_property_create_page ( void )
                         detail_adresse_titulaire,
                         NULL,
                         0 );
-    gtk_button_set_alignment ( GTK_BUTTON (button_holder_address), 0.0, 0.0 );
     gtk_box_pack_start ( GTK_BOX(vbox2), button_holder_address, FALSE, FALSE, 0);
 
     /* if un-select the holder's button address, we need to erase the tree_view,
@@ -363,21 +360,20 @@ GtkWidget *gsb_account_property_create_page ( void )
                         GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
     gtk_scrolled_window_set_shadow_type ( GTK_SCROLLED_WINDOW(scrolled_window_text),
                         GTK_SHADOW_IN );
-    gtk_box_pack_start ( GTK_BOX(hbox), scrolled_window_text, TRUE, TRUE, 0);
-
+    gtk_widget_set_size_request (scrolled_window_text, -1, 120);
+    gtk_box_pack_start (GTK_BOX (hbox), scrolled_window_text, TRUE, TRUE, 0);
 
     /* text view created before */
     gtk_container_add ( GTK_CONTAINER ( scrolled_window_text ), detail_adresse_titulaire );
     gtk_widget_set_sensitive (detail_adresse_titulaire, FALSE);
 
-
     /* création de la ligne de l'établissement financier */
     paddingbox = new_paddingbox_with_title ( vbox, FALSE, _("Bank"));
-    hbox = gtk_hbox_new ( FALSE, 6 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Financial institution: ") );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
@@ -388,7 +384,7 @@ GtkWidget *gsb_account_property_create_page ( void )
                         NULL );
     gtk_box_pack_start ( GTK_BOX(hbox), bank_list_combobox, TRUE, TRUE, 0);
 
-    edit_bank_button = gtk_button_new_from_stock ( GTK_STOCK_EDIT );
+    edit_bank_button = utils_buttons_button_new_from_stock ("gtk-edit", _("Modify"));
     gtk_button_set_relief ( GTK_BUTTON ( edit_bank_button ), GTK_RELIEF_NONE );
     g_signal_connect ( G_OBJECT ( edit_bank_button ),
                         "clicked",
@@ -397,25 +393,25 @@ GtkWidget *gsb_account_property_create_page ( void )
     gtk_box_pack_start ( GTK_BOX ( hbox ), edit_bank_button, FALSE, FALSE, 0 );
 
     /* création du numéro BIC */
-    hbox = gtk_hbox_new ( FALSE, 6 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("BIC code: ") );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
     label_code_bic = gtk_label_new ( NULL );
-    gtk_misc_set_alignment ( GTK_MISC(label_code_bic), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label_code_bic), MISC_LEFT, MISC_VERT_CENTER );
     gtk_label_set_justify ( GTK_LABEL(label_code_bic), GTK_JUSTIFY_RIGHT );
     gtk_box_pack_start ( GTK_BOX(hbox), label_code_bic, TRUE, TRUE, 0 );
 
      /* création de la ligne du numéro IBAN */
-    hbox = gtk_hbox_new ( FALSE, 6 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("IBAN number: ") );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
@@ -440,30 +436,30 @@ GtkWidget *gsb_account_property_create_page ( void )
     gtk_box_pack_start ( GTK_BOX ( hbox ), detail_IBAN, FALSE, FALSE, 0 );
 
     /* create the code of bank */
-    hbox = gtk_hbox_new ( FALSE, 6 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Bank sort code: ") );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
     label_code_banque = gtk_label_new ( NULL );
-    gtk_misc_set_alignment ( GTK_MISC(label_code_banque), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label_code_banque), MISC_LEFT, MISC_VERT_CENTER );
     gtk_label_set_justify ( GTK_LABEL(label_code_banque), GTK_JUSTIFY_RIGHT );
     gtk_box_pack_start ( GTK_BOX(hbox), label_code_banque, TRUE, TRUE, 0 );
 
     /* création de la ligne du guichet */
-    hbox = gtk_hbox_new ( FALSE, 6 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Bank branch code: ") );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
     label_guichet = gtk_label_new ( NULL );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_box_pack_start ( GTK_BOX(hbox), label_guichet, FALSE, FALSE, 0 );
 
@@ -475,16 +471,16 @@ GtkWidget *gsb_account_property_create_page ( void )
     gtk_box_pack_start ( GTK_BOX(hbox), detail_guichet, TRUE, TRUE, 0);
 
     /* création de la ligne du numéro du compte */
-    hbox = gtk_hbox_new ( FALSE, 6 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Account number / Key: ") );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
     label_no_compte = gtk_label_new ( NULL );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_box_pack_start ( GTK_BOX(hbox), label_no_compte, FALSE, FALSE, 0 );
 
@@ -504,19 +500,18 @@ GtkWidget *gsb_account_property_create_page ( void )
     gtk_box_pack_start ( GTK_BOX ( hbox ), detail_cle_compte, FALSE, FALSE, 0 );
 
     label_cle_compte = gtk_label_new ( NULL );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_box_pack_start ( GTK_BOX(hbox), label_cle_compte, FALSE, FALSE, 0 );
 
-
     /* création de la ligne du solde initial */
     paddingbox = new_paddingbox_with_title ( vbox, FALSE, _("Balances"));
 
-    hbox = gtk_hbox_new ( FALSE, 6 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Initial balance: ") );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 0 );
 
@@ -526,13 +521,12 @@ GtkWidget *gsb_account_property_create_page ( void )
                         G_CALLBACK (gsb_data_account_set_init_balance), 0);
     gtk_box_pack_start ( GTK_BOX ( hbox ), detail_solde_init, TRUE, TRUE, 0 );
 
-
     /* création de la ligne du solde mini autorisé */
-    hbox = gtk_hbox_new ( FALSE, 6 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Minimum authorised balance: ") );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 0 );
 
@@ -543,13 +537,12 @@ GtkWidget *gsb_account_property_create_page ( void )
                         0);
     gtk_box_pack_start ( GTK_BOX ( hbox ), detail_solde_mini_autorise, TRUE, TRUE, 0 );
 
-
     /* création de la ligne du solde mini voulu */
-    hbox = gtk_hbox_new ( FALSE, 6 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Minimum desired balance: ") );
-    gtk_misc_set_alignment ( GTK_MISC(label), MISC_LEFT, MISC_VERT_CENTER );
+    utils_labels_set_alignment ( GTK_LABEL(label), MISC_LEFT, MISC_VERT_CENTER );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 0 );
 
@@ -574,7 +567,7 @@ GtkWidget *gsb_account_property_create_page ( void )
                         G_CALLBACK (gsb_data_account_set_comment),
                         0);
 
-    gtk_widget_set_size_request ( detail_commentaire, -1, 70 );
+    gtk_widget_set_size_request (scrolled_window_text, -1, 150);
     gtk_container_add ( GTK_CONTAINER ( scrolled_window_text ), detail_commentaire );
 
     gtk_widget_show_all ( onglet );
@@ -591,6 +584,7 @@ GtkWidget *gsb_account_property_create_page ( void )
  * */
 void gsb_account_property_fill_page ( void )
 {
+	GtkWidget *label;
     gint bank_number;
     gint current_account;
     GtkWidget *image;
@@ -599,6 +593,23 @@ void gsb_account_property_fill_page ( void )
 
     current_account = gsb_gui_navigation_get_current_account ();
 
+	/* set label of paddingbox file_selection_page */
+	label = g_object_get_data (G_OBJECT (paddingbox_detail_compte), "paddingbox_label");
+	if (label)
+	{
+		gchar *str_to_free;
+		gchar *tmp_str1;
+		gchar *tmp_str2;
+
+		str_to_free = g_strdup_printf (" N° %d", current_account);
+		tmp_str1 = g_strconcat (_("Account details"), str_to_free, NULL);
+		tmp_str2 = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>", tmp_str1);
+		gtk_label_set_markup (GTK_LABEL (label), tmp_str2);
+		g_free (str_to_free);
+		g_free(tmp_str1);
+		g_free (tmp_str2);
+	}
+
     gsb_autofunc_entry_set_value (detail_nom_compte,
                         gsb_data_account_get_name (current_account), current_account);
 
@@ -671,6 +682,10 @@ gboolean gsb_account_property_changed_bank_label ( GtkWidget *combobox,
         return FALSE;
 
     bank_number = gsb_bank_list_get_bank_number (combobox);
+    if ( bank_number == 0 )
+        gtk_widget_set_sensitive ( GTK_WIDGET (edit_bank_button), FALSE );
+    else
+        gtk_widget_set_sensitive ( GTK_WIDGET (edit_bank_button), TRUE );
 
     gsb_account_property_set_label_code_banque ( bank_number );
     gsb_account_property_set_label_code_bic ( bank_number );
@@ -726,12 +741,12 @@ gboolean gsb_account_property_changed ( GtkWidget *widget,
     switch (origin)
     {
     case PROPERTY_NAME:
-        gsb_navigation_update_account_label (account_number);
+        gsb_gui_navigation_update_account_label (account_number);
         gsb_gui_navigation_update_account ( account_number );
         break;
     case PROPERTY_CLOSED_ACCOUNT:
         gsb_gui_navigation_update_account ( account_number );
-        gsb_menu_update_accounts_in_menus ();
+        grisbi_win_menu_move_to_acc_update  ( FALSE );
 
         /* update the name of accounts in form */
         gsb_account_update_combo_list ( gsb_form_scheduler_get_element_widget (
@@ -812,8 +827,7 @@ gboolean gsb_account_property_change_currency ( GtkWidget *combobox,
     tmpstr = g_strdup_printf ( _("You are changing the currency of the account, do you want to change the currency of the transactions too?\n(yes will change all the transactions currency from %s to %s, all the transactions with another currency will stay the same).\n\nArchived and reconcilied transactions will be left unmodified."),
 				      gsb_data_currency_get_name (account_currency_number),
 				      gsb_data_currency_get_name (new_currency_number));
-    result = question_yes_no_hint ( _("Change the transactions currency"),
-				    tmpstr,
+    result = question_yes_no (tmpstr, _("Change the transactions currency"),
 				    GTK_RESPONSE_NO );
     g_free ( tmpstr );
 
@@ -909,7 +923,7 @@ void gsb_account_property_iban_insert_text ( GtkEditable *entry,
                         gint *position,
                         GtkWidget *combobox )
 {
-    static struct iso_13616_iban *s_iban = iso_13616_ibans;
+    static struct Iso13616Iban *s_iban = iso_13616_ibans;
     gchar *iban;
     gint nbre_char;
 
@@ -930,7 +944,7 @@ void gsb_account_property_iban_insert_text ( GtkEditable *entry,
     /* on autorise ou pas la saisie des données banquaires */
     if ( g_utf8_strlen (iban, -1) == 0 )
         gsb_account_property_iban_switch_bank_data ( TRUE );
-    else if ( GTK_WIDGET_IS_SENSITIVE ( bank_list_combobox ) )
+    else if ( gtk_widget_is_sensitive ( bank_list_combobox ) )
         gsb_account_property_iban_switch_bank_data ( FALSE );
 
     /* on contrôle l'existence d'un modèle pour le numéro IBAN */
@@ -970,7 +984,7 @@ void gsb_account_property_iban_delete_text ( GtkEditable *entry,
     /* on autorise ou pas la saisie des données banquaires */
     if ( start_pos == 0 )
         gsb_account_property_iban_switch_bank_data ( TRUE );
-    else if ( GTK_WIDGET_IS_SENSITIVE ( bank_list_combobox ) )
+    else if ( gtk_widget_is_sensitive ( bank_list_combobox ) )
         gsb_account_property_iban_switch_bank_data ( FALSE );
 }
 
@@ -982,9 +996,9 @@ void gsb_account_property_iban_delete_text ( GtkEditable *entry,
  *
  * \return une structure modèle (XX si pays non défini)
  * */
-struct iso_13616_iban *gsb_account_property_iban_get_struc ( gchar *pays )
+struct Iso13616Iban *gsb_account_property_iban_get_struc ( gchar *pays )
 {
-    struct iso_13616_iban *s_iban = iso_13616_ibans;
+    struct Iso13616Iban *s_iban = iso_13616_ibans;
 
     while (s_iban -> iban )
     {
@@ -1014,13 +1028,13 @@ gboolean gsb_account_property_iban_key_press_event ( GtkWidget *entry,
 
     switch ( ev -> keyval )
     {
-	case GDK_Escape :
+	case GDK_KEY_Escape :
 
         return TRUE;
 	    break;
 
-	case GDK_KP_Enter :
-	case GDK_Return :
+	case GDK_KEY_KP_Enter :
+	case GDK_KEY_Return :
         iban = gtk_editable_get_chars ( GTK_EDITABLE (entry), 0, -1 );
         if ( gsb_account_property_iban_control_iban (iban) == 0 )
         {
@@ -1116,14 +1130,14 @@ gboolean gsb_account_property_iban_focus_out_event ( GtkWidget *entry,
  * */
 gboolean gsb_account_property_iban_set_bank_from_iban ( gchar *iban )
 {
-    struct iso_13616_iban *s_iban;
+    struct Iso13616Iban *s_iban;
     gchar *model;
     gchar *tmpstr;
     gchar *ptr_1;
     gchar *ptr_2;
     gchar *code;
-    gint pos_char_1;
-    gint pos_char_2;
+    glong pos_char_1;
+    glong pos_char_2;
     gint bank_number;
     gint current_account;
     gunichar c;
@@ -1214,11 +1228,15 @@ gboolean gsb_account_property_iban_set_bank_from_iban ( gchar *iban )
         pos_char_2 = g_utf8_pointer_to_offset ( model, ptr_2 );
 
         code = g_utf8_strncpy ( code, ptr_1, (pos_char_2 - pos_char_1) + 1 );
+		gtk_label_set_text ( GTK_LABEL (label_guichet), code );
+		gtk_widget_show ( label_guichet );
     }
     else
+	{
         code = g_strdup ( "" );
-    gtk_label_set_text ( GTK_LABEL (label_guichet), code );
-    gtk_widget_show ( label_guichet );
+		gtk_label_set_text ( GTK_LABEL (label_guichet), code );
+		gtk_widget_show ( label_guichet );
+	}
 
     /* set bank_account_number */
     c = 'C';
@@ -1287,9 +1305,11 @@ void gsb_account_property_iban_set_iban ( const gchar *iban )
  * */
 void gsb_account_property_iban_switch_bank_data ( gboolean sensitive )
 {
+    gtk_widget_set_sensitive ( GTK_WIDGET (bank_list_combobox), sensitive );
+    gtk_widget_set_sensitive ( GTK_WIDGET (edit_bank_button), sensitive );
+
     if ( sensitive )
     {
-        gtk_widget_set_sensitive ( GTK_WIDGET (bank_list_combobox), sensitive );
         gsb_account_property_iban_clear_label_data ( );
         gtk_widget_show ( GTK_WIDGET (detail_guichet) );
         gtk_widget_hide ( GTK_WIDGET (label_guichet) );
@@ -1300,7 +1320,6 @@ void gsb_account_property_iban_switch_bank_data ( gboolean sensitive )
     }
     else
     {
-        gtk_widget_set_sensitive ( GTK_WIDGET (bank_list_combobox), sensitive );
         gtk_widget_hide ( GTK_WIDGET (detail_guichet) );
         gtk_widget_show ( GTK_WIDGET (label_guichet) );
         gtk_widget_hide ( GTK_WIDGET (detail_no_compte) );
@@ -1359,7 +1378,7 @@ void gsb_account_property_iban_clear_label_data ( void )
  * */
 gint gsb_account_property_iban_control_iban ( gchar *iban )
 {
-    struct iso_13616_iban *s_iban;
+    struct Iso13616Iban *s_iban;
     gchar *model;
     gchar *tmp_str = NULL;
     gchar *substr;
@@ -1522,20 +1541,24 @@ gboolean gsb_account_property_focus_out ( GtkWidget *widget,
         /* update the scheduler list */
         gsb_scheduler_list_fill_list (gsb_scheduler_list_get_tree_view ());
 
-        /*update the the view menu */
-        gsb_menu_update_accounts_in_menus ();
+        /*update the view menu */
+		grisbi_win_menu_move_to_acc_delete ();
+        grisbi_win_menu_move_to_acc_new ();
 
         /* update the name of accounts in form */
         gsb_account_update_combo_list ( gsb_form_scheduler_get_element_widget (
                         SCHEDULED_FORM_ACCOUNT), FALSE );
 
+		/* update categories combofix */
+		gsb_category_update_combofix (FALSE);
+
         /* Replace trees contents. */
         categories_fill_list ();
         budgetary_lines_fill_list ();
         payees_fill_list ();
         break;
     case PROPERTY_HOLDER_NAME:
-        gsb_main_set_grisbi_title ( account_number );
+        grisbi_win_set_window_title ( account_number );
         break;
     }
 
