@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -35,10 +35,12 @@
 
 /*START_INCLUDE*/
 #include "gsb_assistant.h"
+#include "dialog.h"
+#include "grisbi_app.h"
+#include "gsb_dirs.h"
 #include "structures.h"
 #include "utils.h"
 #include "utils_str.h"
-#include "gsb_dirs.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -99,56 +101,55 @@ static gboolean gsb_assistant_change_page ( GtkNotebook *notebook,
  *
  */
 GtkWidget * gsb_assistant_new ( const gchar * title, const gchar * explanation,
-                        gchar * image_filename,
+                        const gchar * image_filename,
                         GCallback enter_callback )
 {
+    GtkWindow *window;
     GtkWidget * assistant, *notebook, *hbox, *label, *image, *view, *eb;
     GtkWidget * button_cancel, * button_prev, * button_next;
     GtkWidget *button_select;
-    GtkStyle * style;
     GtkTextBuffer * buffer;
     gchar *tmpstr;
     gint width = 140;
 
+    window = GTK_WINDOW (grisbi_app_get_active_window (NULL));
     assistant = gtk_dialog_new_with_buttons ( title,
-                        GTK_WINDOW ( run.window ),
-                        GTK_DIALOG_MODAL | GTK_DIALOG_NO_SEPARATOR,
+                        GTK_WINDOW ( window ),
+                        GTK_DIALOG_MODAL,
+                        NULL, 0,
                         NULL );
 
     gtk_window_set_default_size ( GTK_WINDOW ( assistant ), 800, 500 );
     gtk_window_set_position ( GTK_WINDOW ( assistant ), GTK_WIN_POS_CENTER_ON_PARENT );
     gtk_window_set_resizable ( GTK_WINDOW ( assistant ), TRUE );
-    g_object_set_data ( G_OBJECT ( run.window ), "assistant", assistant );
+    g_object_set_data ( G_OBJECT ( window ), "assistant", assistant );
 
     button_select = gtk_toggle_button_new_with_label ( _("Select all") );
     gtk_widget_set_size_request ( button_select, width, -1 );
-    gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG ( assistant )->action_area ),
-                        button_select, FALSE, FALSE, 0 );
     g_object_set_data ( G_OBJECT(assistant), "button_select", button_select );
 
     button_cancel = gtk_dialog_add_button ( GTK_DIALOG(assistant),
-                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL );
+                        "gtk-cancel", GTK_RESPONSE_CANCEL );
     gtk_widget_set_size_request ( button_cancel, width, -1 );
     g_object_set_data ( G_OBJECT(assistant), "button_cancel", button_cancel );
 
     button_prev = gtk_dialog_add_button ( GTK_DIALOG(assistant),
-                        GTK_STOCK_GO_BACK, GTK_RESPONSE_NO );
+                        "gtk-go-back", GTK_RESPONSE_NO );
     gtk_widget_set_size_request ( button_prev, width, -1 );
     g_object_set_data ( G_OBJECT(assistant), "button_prev", button_prev );
     gtk_widget_set_sensitive ( button_prev, FALSE );
 
     button_next = gtk_dialog_add_button ( GTK_DIALOG(assistant),
-                        GTK_STOCK_GO_FORWARD, GTK_RESPONSE_YES );
+                        "gtk-go-forward", GTK_RESPONSE_YES );
     gtk_widget_set_size_request ( button_next, width, -1 );
     g_object_set_data ( G_OBJECT(assistant), "button_next", button_next );
 
     eb = gtk_event_box_new ();
-    style = gtk_widget_get_style ( eb );
-    gtk_widget_modify_bg ( eb, 0, &(style -> bg[GTK_STATE_ACTIVE]) );
+    gtk_widget_set_name (eb, "grey_box");
 
-    hbox = gtk_hbox_new ( FALSE, 12 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_container_add ( GTK_CONTAINER(eb), hbox );
-    gtk_container_set_border_width ( GTK_CONTAINER(hbox), 12 );
+    gtk_container_set_border_width ( GTK_CONTAINER(hbox), BOX_BORDER_WIDTH );
 
     label = gtk_label_new ( NULL );
     tmpstr = g_markup_printf_escaped (
@@ -158,19 +159,19 @@ GtkWidget * gsb_assistant_new ( const gchar * title, const gchar * explanation,
     gtk_box_pack_start ( GTK_BOX(hbox), label, TRUE, TRUE, 0 );
 
     if (!image_filename)
-        image_filename = "grisbi.png";
+        image_filename = "grisbi-32.png";
 
     tmpstr = g_build_filename ( gsb_dirs_get_pixmaps_dir ( ), image_filename, NULL);
     image = gtk_image_new_from_file ( tmpstr );
     g_free ( tmpstr );
     gtk_box_pack_start ( GTK_BOX(hbox), image, FALSE, FALSE, 0 );
 
-    gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG(assistant) -> vbox ), eb, FALSE, FALSE, 0 );
+    gtk_box_pack_start ( GTK_BOX ( dialog_get_content_area ( assistant ) ), eb, FALSE, FALSE, 0 );
 
     notebook = gtk_notebook_new ();
     gtk_notebook_set_show_tabs ( GTK_NOTEBOOK(notebook), FALSE );
     gtk_notebook_set_show_border ( GTK_NOTEBOOK(notebook), FALSE );
-    gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG(assistant) -> vbox ), notebook, TRUE, TRUE, 0 );
+    gtk_box_pack_start ( GTK_BOX ( dialog_get_content_area ( assistant ) ), notebook, TRUE, TRUE, 0 );
 
     view = gtk_text_view_new ();
     gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (view), GTK_WRAP_WORD);
@@ -254,8 +255,10 @@ void gsb_assistant_add_page ( GtkWidget * assistant, GtkWidget * widget, gint po
  */
 GtkResponseType gsb_assistant_run ( GtkWidget * assistant )
 {
-    GtkWidget * notebook, * button_prev;
+    GtkWidget *notebook;
+    GtkWidget *button_prev;
     GtkWidget *button_select;
+    GtkWidget *button_next;
 
     button_prev = g_object_get_data ( G_OBJECT(assistant), "button_prev" );
     button_select = g_object_get_data ( G_OBJECT ( assistant ), "button_select" );
@@ -264,10 +267,11 @@ GtkResponseType gsb_assistant_run ( GtkWidget * assistant )
     gtk_widget_hide ( button_select );
 
     notebook = g_object_get_data ( G_OBJECT(assistant), "notebook" );
-    gtk_notebook_set_current_page ( GTK_NOTEBOOK (notebook),
-			    0 );
-    gtk_widget_grab_focus (GTK_WIDGET (g_object_get_data (G_OBJECT (assistant),
-							  "button_next")));
+    gtk_notebook_set_current_page ( GTK_NOTEBOOK (notebook), 0 );
+
+	button_next = g_object_get_data (G_OBJECT (assistant), "button_next");
+	gtk_widget_set_sensitive (button_next, TRUE);
+    gtk_widget_grab_focus (GTK_WIDGET (button_next));
 
     while ( TRUE )
     {
@@ -298,7 +302,7 @@ GtkResponseType gsb_assistant_run ( GtkWidget * assistant )
 		gtk_widget_set_sensitive ( button_prev, TRUE );
 		if ( gtk_notebook_get_n_pages ( GTK_NOTEBOOK(notebook) ) == ( next + 1 ) )
 		{
-		    gsb_assistant_change_button_next ( assistant, GTK_STOCK_CLOSE,
+		    gsb_assistant_change_button_next ( assistant, "gtk-close",
 						       GTK_RESPONSE_APPLY );
 		    gsb_assistant_sensitive_button_prev ( assistant,
 							  FALSE );
@@ -310,7 +314,7 @@ GtkResponseType gsb_assistant_run ( GtkWidget * assistant )
 	    case GTK_RESPONSE_NO:
 		if ( next == -1 )
 		{
-		    gsb_assistant_change_button_next ( assistant, GTK_STOCK_GO_FORWARD,
+		    gsb_assistant_change_button_next ( assistant, "gtk-go-forward",
 						       GTK_RESPONSE_YES );
 		}
 
@@ -384,6 +388,7 @@ void gsb_assistant_set_next ( GtkWidget * assistant, gint page, gint next )
  */
 gboolean gsb_assistant_sensitive_button_next ( GtkWidget * assistant, gboolean state )
 {
+	devel_debug_int (state);
     gtk_widget_set_sensitive ( g_object_get_data ( G_OBJECT (assistant), "button_next" ),
 			       state );
 
@@ -422,7 +427,7 @@ void gsb_assistant_next_page ( GtkWidget *assistant )
  *
  *
  */
-void gsb_assistant_change_button_next ( GtkWidget * assistant, gchar * title,
+void gsb_assistant_change_button_next ( GtkWidget * assistant, const gchar * title,
 					GtkResponseType response )
 {
     GtkWidget * button_next;
