@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -68,12 +68,12 @@ static gboolean gsb_assistant_account_toggled_kind_account ( GtkWidget *button,
 
 static gchar * new_icon = NULL;
 
-enum first_assistant_page
+enum FirstAccountAssistantPage
 {
     ACCOUNT_ASSISTANT_INTRO= 0,
     ACCOUNT_ASSISTANT_PAGE_2,
     ACCOUNT_ASSISTANT_PAGE_3,
-    ACCOUNT_ASSISTANT_PAGE_FINISH,
+    ACCOUNT_ASSISTANT_PAGE_FINISH
 };
 
 
@@ -165,12 +165,11 @@ static GtkWidget *gsb_assistant_account_page_2 ( GtkWidget *assistant )
 	_("Assets account\nSpecial account to represent an asset, like a car or special subscriptions."),
 	NULL };
 
-    page = gtk_hbox_new (FALSE, 15);
-    gtk_container_set_border_width ( GTK_CONTAINER (page),
-				     10 );
+    page = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER (page), BOX_BORDER_WIDTH );
 
     vbox = new_vbox_with_title_and_icon ( _("Account type selection"),
-					  "ac_bank.png" );
+					  "gsb-ac-bank-32.png" );
     gtk_box_pack_start ( GTK_BOX (page),
 			 vbox,
 			 TRUE, TRUE, 0 );
@@ -178,7 +177,7 @@ static GtkWidget *gsb_assistant_account_page_2 ( GtkWidget *assistant )
     label = gtk_label_new (_("Please select type for this account.\n"
 			     "The account will be created with default payment methods chosen according to your choice.\n"
 			     "If you are unsure and novice to accounting, we advise that you choose a bank account.\n"));
-    gtk_misc_set_alignment ( GTK_MISC (label),
+    utils_labels_set_alignment ( GTK_LABEL (label),
 			     0, 0.5 );
     gtk_box_pack_start ( GTK_BOX (vbox),
 			 label,
@@ -224,29 +223,23 @@ static GtkWidget *gsb_assistant_account_page_2 ( GtkWidget *assistant )
 static GtkWidget *gsb_assistant_account_page_3 ( GtkWidget *assistant )
 {
     GtkWidget *page, *label, *button, *table;
-    GtkWidget *align;
     GtkWidget *image;
     struct lconv *locale = gsb_locale_get_locale ( );
 
-    page = gtk_hbox_new (FALSE, 15);
-    gtk_container_set_border_width ( GTK_CONTAINER (page),
-				     10 );
+    page = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER (page), BOX_BORDER_WIDTH );
 
-    table = gtk_table_new ( 3, 4, FALSE );
-    gtk_table_set_row_spacings ( GTK_TABLE ( table ), 6 );
-    gtk_table_set_col_spacings ( GTK_TABLE ( table ), 6 );
+    table = gtk_grid_new ();
+    gtk_grid_set_row_spacing (GTK_GRID (table), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (table), 6);
 
     gtk_box_pack_start ( GTK_BOX (page), table,
 			 FALSE, FALSE, 0 );
 
     /* choose the currency */
     label = gtk_label_new ( _("Currency for the account: ") );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.5 );
-    gtk_table_attach ( GTK_TABLE ( table ), label,
-		       0, 1, 0, 1,
-		       GTK_SHRINK | GTK_FILL,
-		       GTK_SHRINK | GTK_FILL,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.5 );
+    gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
 
     /* Guesstimate default currency from locale.  Default is USD since
      * this would confuse US folks while rest of the world is used to
@@ -259,11 +252,7 @@ static GtkWidget *gsb_assistant_account_page_3 ( GtkWidget *assistant )
 
     /* create the currency combobox */
     account_combobox_currency = gsb_currency_make_combobox (TRUE);
-    gtk_table_attach ( GTK_TABLE ( table ), account_combobox_currency,
-		       1, 2, 0, 1,
-		       GTK_SHRINK | GTK_FILL,
-		       GTK_SHRINK | GTK_FILL,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (table), account_combobox_currency, 1, 0, 1, 1);
 
     /* propose to add a currency */
     button = gtk_button_new_with_label (_("Add/Change..."));
@@ -271,20 +260,12 @@ static GtkWidget *gsb_assistant_account_page_3 ( GtkWidget *assistant )
 		       "clicked",
 		       G_CALLBACK (gsb_currency_config_add_currency_set_combobox),
 		       account_combobox_currency );
-    gtk_table_attach ( GTK_TABLE ( table ), button,
-		       2, 3, 0, 1,
-		       GTK_SHRINK | GTK_FILL,
-		       GTK_SHRINK | GTK_FILL,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (table), button, 2, 0, 1, 1);
 
     /* choose the bank */
     label = gtk_label_new ( _("Bank for the account: ") );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.5 );
-    gtk_table_attach ( GTK_TABLE ( table ), label,
-		       0, 1, 1, 2,
-		       GTK_SHRINK | GTK_FILL,
-		       GTK_SHRINK | GTK_FILL,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.5 );
+    gtk_grid_attach (GTK_GRID (table), label, 0, 1, 1, 1);
 
     account_combobox_bank = gsb_bank_create_combobox (0 );
 
@@ -296,44 +277,28 @@ static GtkWidget *gsb_assistant_account_page_3 ( GtkWidget *assistant )
     {
 	gsb_bank_list_set_bank ( account_combobox_bank, 0 );
     }
-    gtk_table_attach ( GTK_TABLE ( table ), account_combobox_bank,
-		       1, 2, 1, 2,
-		       GTK_SHRINK | GTK_FILL,
-		       GTK_SHRINK | GTK_FILL,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (table), account_combobox_bank, 1, 1, 1, 1);
 
     /* set the initial amount */
     label = gtk_label_new ( _("Opening balance: ") );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.5 );
-    gtk_table_attach ( GTK_TABLE ( table ), label,
-		       0, 1, 2, 3,
-		       GTK_SHRINK | GTK_FILL,
-		       GTK_SHRINK | GTK_FILL,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.5 );
+    gtk_grid_attach (GTK_GRID (table), label, 0, 2, 1, 1);
 
     account_entry_initial_amount = gtk_entry_new ();
-    gtk_table_attach ( GTK_TABLE ( table ), account_entry_initial_amount,
-		       1, 2, 2, 3,
-		       GTK_SHRINK | GTK_FILL,
-		       GTK_SHRINK | GTK_FILL,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (table), account_entry_initial_amount, 1, 2, 1, 1);
 
     /* création du choix de l'icône du compte */
     /* Récupération de l'icône par défaut */
-    align = gtk_alignment_new (0.5,0.5,1,1);
-    gtk_alignment_set_padding ( GTK_ALIGNMENT ( align ), 0, 0, 20, 20 );
     button = gtk_button_new ( );
     gtk_widget_set_size_request ( button, 80, 80 );
     image = gtk_image_new_from_pixbuf (
                 gsb_data_account_get_account_standard_pixbuf ( 0 ) );
     gtk_button_set_image ( GTK_BUTTON ( button ), image);
     gtk_button_set_relief ( GTK_BUTTON ( button ), GTK_RELIEF_NORMAL );
-    gtk_container_add (GTK_CONTAINER (align), button);
-    gtk_table_attach ( GTK_TABLE ( table ), align,
-		       3, 4, 0, 3,
-		       GTK_FILL | GTK_FILL,
-		       GTK_FILL | GTK_FILL,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (table), button, 3, 0, 1, 3);
+	utils_widget_set_padding (button, 20, 0);
+	gtk_widget_set_halign (button, GTK_ALIGN_CENTER);
+	gtk_widget_set_valign (button, GTK_ALIGN_CENTER);
     g_object_set_data ( G_OBJECT (assistant), "bouton_icon", button );
     g_signal_connect ( G_OBJECT( button ),
                             "clicked",
@@ -361,11 +326,10 @@ static GtkWidget *gsb_assistant_account_page_finish ( GtkWidget *assistant )
     GtkWidget *label;
     GtkWidget *hbox;
 
-    page = gtk_hbox_new (FALSE, 15);
-    gtk_container_set_border_width ( GTK_CONTAINER (page),
-				     10 );
+    page = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER (page), BOX_BORDER_WIDTH );
 
-    vbox = gtk_vbox_new (FALSE, 5);
+    vbox = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX (page),
 			 vbox,
 			 FALSE, FALSE, 0 );
@@ -374,14 +338,14 @@ static GtkWidget *gsb_assistant_account_page_finish ( GtkWidget *assistant )
     label = gtk_label_new (_("You are about to validate the new account.\n"
 			     "You juste have to enter a name and finish the assistant.\n"
 			     "More options are available in the account configuration page once you created it.\n"));
-    gtk_misc_set_alignment ( GTK_MISC (label),
+    utils_labels_set_alignment ( GTK_LABEL (label),
 			     0.5, 0.5 );
     gtk_box_pack_start ( GTK_BOX (vbox),
 			 label,
 			 FALSE, FALSE, 0 );
 
     /* enter the name */
-    hbox = gtk_hbox_new ( FALSE, 5);
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX);
     gtk_box_pack_start ( GTK_BOX (vbox),
 			 hbox,
 			 FALSE, FALSE, 0 );
@@ -466,7 +430,7 @@ gboolean gsb_assistant_account_toggled_kind_account ( GtkWidget *button,
 						      GtkWidget *assistant )
 {
     GtkWidget *bouton_icon, *image;
-    kind_account account_kind;
+    KindAccount account_kind;
 
     account_kind = GPOINTER_TO_INT ( g_object_get_data
                 ( G_OBJECT (button), "account_kind"));
