@@ -28,7 +28,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -37,6 +37,7 @@
 /*START_INCLUDE*/
 #include "gsb_assistant_archive.h"
 #include "etats_support.h"
+#include "grisbi_win.h"
 #include "gsb_assistant.h"
 #include "gsb_calendar_entry.h"
 #include "gsb_data_archive.h"
@@ -79,7 +80,7 @@ static gboolean gsb_assistant_archive_update_labels ( GtkWidget *assistant );
 /*START_EXTERN*/
 /*END_EXTERN*/
 
-enum archive_assistant_page
+enum ArchiveAssistantPage
 {
     ARCHIVE_ASSISTANT_INTRO= 0,
     ARCHIVE_ASSISTANT_MENU,
@@ -151,7 +152,7 @@ GtkResponseType gsb_assistant_archive_run ( gboolean origin )
     /* create the assistant */
     assistant = gsb_assistant_new ( _("Archive transactions"),
 				    tmpstr,
-				    "archive.png",
+				    "gsb-archive-32.png",
 				    G_CALLBACK (gsb_assistant_archive_switch_to_intro));
     g_free (tmpstr);
 
@@ -199,15 +200,15 @@ static GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant )
     GtkWidget *button;
     GtkWidget *hbox;
 
-    page = gtk_hbox_new (FALSE, 15);
-    gtk_container_set_border_width ( GTK_CONTAINER (page), 10 );
+    page = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER (page), BOX_BORDER_WIDTH );
 
-    vbox = gtk_vbox_new (FALSE, 5);
+    vbox = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX);
     gtk_box_pack_start ( GTK_BOX (page), vbox, FALSE, FALSE, 0 );
 
     /* set up the menu */
     label = gtk_label_new (_("Please select a way to select transactions for this archive"));
-    gtk_misc_set_alignment ( GTK_MISC (label), 0, 0.5 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5 );
     gtk_box_pack_start ( GTK_BOX (vbox), label,  FALSE, FALSE, 0 );
 
     /* archive by date */
@@ -221,11 +222,11 @@ static GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant )
 
     label = gtk_label_new ( _("Grisbi will archive all transactions between initial and "
                         "final dates.") );
-    gtk_misc_set_alignment ( GTK_MISC (label), 0, 0.5 );
-    gtk_misc_set_padding ( GTK_MISC (label), 24, 0 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5 );
+    utils_widget_set_padding (GTK_WIDGET (label), 24, 0);
     gtk_box_pack_start ( GTK_BOX (vbox), label, FALSE, FALSE, 0 );
 
-    hbox = gtk_hbox_new ( FALSE, 6 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     g_signal_connect ( G_OBJECT (button),
                         "toggled",
                         G_CALLBACK  (sens_desensitive_pointeur),
@@ -233,7 +234,7 @@ static GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant )
     gtk_box_pack_start ( GTK_BOX (vbox), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Initial date: " ) );
-    gtk_misc_set_padding ( GTK_MISC (label), 24, 0 );
+    utils_widget_set_padding (GTK_WIDGET (label), 24, 0);
     gtk_box_pack_start ( GTK_BOX (hbox), label, FALSE, FALSE, 0 );
 
     initial_date = gsb_calendar_entry_new (FALSE);
@@ -245,7 +246,7 @@ static GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant )
     gtk_box_pack_start ( GTK_BOX (hbox), initial_date, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Final date: ") );
-    gtk_misc_set_padding ( GTK_MISC (label), 24, 0 );
+    utils_widget_set_padding (GTK_WIDGET (label), 24, 0);
     gtk_box_pack_start ( GTK_BOX (hbox), label, FALSE, FALSE, 0 );
 
     final_date = gsb_calendar_entry_new (FALSE);
@@ -269,11 +270,11 @@ static GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant )
 
     label = gtk_label_new ( _("Grisbi will archive all transactions belonging to a "
                         "financial year." ) );
-    gtk_misc_set_padding ( GTK_MISC (label), 24, 0 );
-    gtk_misc_set_alignment ( GTK_MISC (label), 0, 0.5 );
+    utils_widget_set_padding (GTK_WIDGET (label), 24, 0);
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5 );
     gtk_box_pack_start ( GTK_BOX (vbox), label, FALSE, FALSE, 0 );
 
-    hbox = gtk_hbox_new ( FALSE, 10 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     g_signal_connect ( G_OBJECT (button),
                         "toggled",
                         G_CALLBACK  ( sens_desensitive_pointeur ),
@@ -281,7 +282,7 @@ static GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant )
     gtk_box_pack_start ( GTK_BOX (vbox), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Financial year: ") );
-    gtk_misc_set_padding ( GTK_MISC (label), 24, 0 );
+    utils_widget_set_padding (GTK_WIDGET (label), 24, 0);
     gtk_box_pack_start ( GTK_BOX (hbox), label, FALSE, FALSE, 0 );
 
     financial_year_button = gsb_fyear_make_combobox (FALSE);
@@ -293,7 +294,7 @@ static GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant )
     gtk_box_pack_start ( GTK_BOX (hbox), financial_year_button, FALSE, FALSE, 0 );
     gtk_widget_set_sensitive ( hbox, FALSE );
 
-    /* archive by budget */
+    /* archive by report */
     button = gtk_radio_button_new_with_label ( gtk_radio_button_get_group (
                         GTK_RADIO_BUTTON ( button ) ),
                         _("Archive by report"));
@@ -305,11 +306,11 @@ static GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant )
     gtk_box_pack_start ( GTK_BOX (vbox), button, FALSE, FALSE, 0 );
 
     label = gtk_label_new (_("Grisbi will archive transactions selected by a report." ));
-    gtk_misc_set_padding ( GTK_MISC (label), 24, 0 );
-    gtk_misc_set_alignment ( GTK_MISC (label), 0, 0.5 );
+    utils_widget_set_padding (GTK_WIDGET (label), 24, 0);
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5 );
     gtk_box_pack_start ( GTK_BOX (vbox), label, FALSE, FALSE, 0 );
 
-    hbox = gtk_hbox_new ( FALSE, 10 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     g_signal_connect ( G_OBJECT (button),
                         "toggled",
                         G_CALLBACK  (sens_desensitive_pointeur),
@@ -317,7 +318,7 @@ static GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant )
     gtk_box_pack_start ( GTK_BOX (vbox), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Report: ") );
-    gtk_misc_set_padding ( GTK_MISC (label), 24, 0 );
+    utils_widget_set_padding (GTK_WIDGET (label), 24, 0);
     gtk_box_pack_start ( GTK_BOX (hbox), label, FALSE, FALSE, 0 );
     report_button = gsb_report_make_combobox ();
     g_signal_connect_object ( G_OBJECT (report_button),
@@ -329,7 +330,7 @@ static GtkWidget *gsb_assistant_archive_page_menu ( GtkWidget *assistant )
     gtk_widget_set_sensitive ( hbox, FALSE );
 
     label_archived = gtk_label_new (NULL);
-    gtk_misc_set_alignment ( GTK_MISC (label_archived), 0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL (label_archived), 0, 0 );
     gtk_box_pack_start ( GTK_BOX (vbox), label_archived, FALSE, FALSE, 0 );
 
     gsb_assistant_sensitive_button_next ( assistant, FALSE );
@@ -353,18 +354,17 @@ static GtkWidget *gsb_assistant_archive_page_archive_name ( GtkWidget *assistant
     GtkWidget *vbox;
     GtkWidget *label;
 
-    page = gtk_hbox_new (FALSE, 15);
-    gtk_container_set_border_width ( GTK_CONTAINER (page),
-				     10 );
+    page = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER (page), BOX_BORDER_WIDTH );
 
-    vbox = gtk_vbox_new (FALSE, 5);
+    vbox = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX);
     gtk_box_pack_start ( GTK_BOX (page),
 			 vbox,
 			 FALSE, FALSE, 0 );
 
     /* set up the menu */
     label = gtk_label_new ( _("Please choose a name for archive: ") );
-    gtk_misc_set_alignment ( GTK_MISC (label),
+    utils_labels_set_alignment ( GTK_LABEL (label),
 			     0, 0.5 );
     gtk_box_pack_start ( GTK_BOX (vbox),
 			 label,
@@ -402,13 +402,12 @@ static GtkWidget *gsb_assistant_archive_page_success ( void )
     GtkTextBuffer * buffer;
     GtkTextIter iter;
 
-    page = gtk_vbox_new ( FALSE, 0 );
-    gtk_container_set_border_width ( GTK_CONTAINER (page),
-				     0 );
+    page = gtk_box_new ( GTK_ORIENTATION_VERTICAL, 0 );
+    gtk_container_set_border_width ( GTK_CONTAINER (page), BOX_BORDER_WIDTH );
 
     /* we create 2 vbox, one for congratulation, one for failed,
      * only one will be showed */
-    vbox_congratulation = gtk_vbox_new (FALSE, 0);
+    vbox_congratulation = gtk_box_new ( GTK_ORIENTATION_VERTICAL, 0);
     gtk_box_pack_start ( GTK_BOX (page),
 			 vbox_congratulation,
 			 TRUE, TRUE, 0 );
@@ -448,7 +447,7 @@ static GtkWidget *gsb_assistant_archive_page_success ( void )
 			     -1 );
 
     /* make the failed box */
-    vbox_failed = gtk_vbox_new (FALSE, 0 );
+    vbox_failed = gtk_box_new ( GTK_ORIENTATION_VERTICAL, 0 );
     gtk_box_pack_start ( GTK_BOX (page),
 			 vbox_failed,
 			 TRUE, TRUE, 0 );
@@ -507,7 +506,7 @@ static gboolean gsb_assistant_archive_switch_to_intro ( GtkWidget *assistant,
 
     /* enter into the intro page */
     gsb_assistant_change_button_next ( assistant,
-				       GTK_STOCK_GO_FORWARD, GTK_RESPONSE_YES );
+				       "gtk-go-forward", GTK_RESPONSE_YES );
     gsb_assistant_sensitive_button_next ( assistant,
 					  TRUE );
     return FALSE;
@@ -532,7 +531,7 @@ static gboolean gsb_assistant_archive_switch_to_menu ( GtkWidget *assistant,
     /* enter into the menu page */
     gtk_label_set_text ( GTK_LABEL (label_archived), NULL );
     gsb_assistant_change_button_next ( assistant,
-                        GTK_STOCK_GO_FORWARD, GTK_RESPONSE_YES );
+                        "gtk-go-forward", GTK_RESPONSE_YES );
     gsb_assistant_archive_update_labels ( assistant );
 
     /* set the initial date to the first transaction in grisbi */
@@ -585,9 +584,9 @@ static gboolean gsb_assistant_archive_switch_to_archive_name ( GtkWidget *assist
     gchar * string = NULL;
 
     gsb_assistant_change_button_next ( assistant,
-                    GTK_STOCK_APPLY, GTK_RESPONSE_YES );
+                    "gtk-apply", GTK_RESPONSE_YES );
 
-    if ( GTK_WIDGET_IS_SENSITIVE (initial_date) )
+    if ( gtk_widget_is_sensitive (initial_date) )
     {
         gchar * sdate, * fdate;
 
@@ -597,7 +596,7 @@ static gboolean gsb_assistant_archive_switch_to_archive_name ( GtkWidget *assist
         g_free ( sdate );
         g_free ( fdate );
     }
-    else if ( GTK_WIDGET_IS_SENSITIVE (financial_year_button) )
+    else if ( gtk_widget_is_sensitive (financial_year_button) )
     {
         gint fyear;
 
@@ -605,7 +604,7 @@ static gboolean gsb_assistant_archive_switch_to_archive_name ( GtkWidget *assist
         string = g_strdup_printf ( _("Archive of financial year %s"),
                             gsb_data_fyear_get_name ( fyear ) );
     }
-    else if ( GTK_WIDGET_IS_SENSITIVE (report_button) )
+    else if ( gtk_widget_is_sensitive (report_button) )
     {
         gint report_number;
         report_number = gsb_report_get_report_from_combobox (report_button);
@@ -648,6 +647,8 @@ static gboolean gsb_assistant_archive_switch_to_success ( GtkWidget *assistant,
     GtkTextBuffer * buffer;
     GtkTextIter     iter;
     gint account_nb;
+	guint archived_transaction_count;
+	GrisbiWinRun *w_run;
 
     /* This would typically happen if user selected a time period
      * with no transactions related. */
@@ -670,10 +671,10 @@ static gboolean gsb_assistant_archive_switch_to_success ( GtkWidget *assistant,
     }
 
     gsb_assistant_change_button_next ( assistant,
-                        GTK_STOCK_CLOSE, GTK_RESPONSE_APPLY );
+                        "gtk-close", GTK_RESPONSE_APPLY );
 
     /* fill the archive */
-    if (GTK_WIDGET_IS_SENSITIVE (initial_date))
+    if (gtk_widget_is_sensitive (initial_date))
     {
         GDate *init_gdate;
         GDate *final_gdate;
@@ -686,10 +687,10 @@ static gboolean gsb_assistant_archive_switch_to_success ( GtkWidget *assistant,
         g_date_free (init_gdate);
         g_date_free (final_gdate);
     }
-    else if (GTK_WIDGET_IS_SENSITIVE (financial_year_button))
+    else if (gtk_widget_is_sensitive (financial_year_button))
         gsb_data_archive_set_fyear ( archive_number,
                         gsb_fyear_get_fyear_from_combobox ( financial_year_button,NULL ) );
-    else if (GTK_WIDGET_IS_SENSITIVE (report_button) )
+    else if (gtk_widget_is_sensitive (report_button) )
     {
         gint report_number;
 
@@ -714,13 +715,17 @@ static gboolean gsb_assistant_archive_switch_to_success ( GtkWidget *assistant,
         tmp_list = tmp_list -> next;
     }
 
-    /* create again the list of archives by account */
-    gsb_data_archive_store_init_variables ();
-    gsb_data_archive_store_create_list ( );
-    gsb_transactions_list_fill_archive_store ( );
+    /* create the list of archives by account when file is loaded */
+	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
+	if (w_run->file_is_loading)
+	{
+		gsb_data_archive_store_init_variables ();
+		gsb_data_archive_store_create_list ( );
+		gsb_transactions_list_fill_archive_store ( );
+	}
 
     /* set the message */
-    guint archived_transaction_count = g_slist_length (list_transaction_to_archive);
+    archived_transaction_count = g_slist_length (list_transaction_to_archive);
     string = g_strdup_printf ( _("Archive '%s' was successfully created and %d transactions "
                                  "out of %d were archived.\n\n"),
                         gsb_data_archive_get_name (archive_number),
@@ -731,7 +736,7 @@ static gboolean gsb_assistant_archive_switch_to_success ( GtkWidget *assistant,
     buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (congratulations_view));
     gtk_text_buffer_get_iter_at_mark ( buffer, &iter,
                         gtk_text_buffer_get_mark ( buffer, "status" ) );
-    gtk_text_buffer_insert ( buffer, &iter, string, strlen(string) );
+    gtk_text_buffer_insert ( buffer, &iter, string, (gint)strlen(string) );
 
     g_free (string);
 
@@ -811,7 +816,7 @@ static gboolean gsb_assistant_archive_update_labels ( GtkWidget *assistant )
     /* ok for now the choice is on initial/final date */
     if ( gtk_notebook_get_current_page (GTK_NOTEBOOK(notebook)) == ARCHIVE_ASSISTANT_MENU )
     {
-        if ( GTK_WIDGET_IS_SENSITIVE (initial_date) )
+        if ( gtk_widget_is_sensitive (initial_date) )
         {
             GDate *init_gdate;
             GDate *final_gdate;
@@ -885,7 +890,7 @@ static gboolean gsb_assistant_archive_update_labels ( GtkWidget *assistant )
             }
 
         /* ok for now the choice is on fyear */
-        else if (  GTK_WIDGET_IS_SENSITIVE ( financial_year_button ) )
+        else if (  gtk_widget_is_sensitive ( financial_year_button ) )
         {
             gint fyear_number;
             string = NULL;
@@ -926,7 +931,7 @@ static gboolean gsb_assistant_archive_update_labels ( GtkWidget *assistant )
             }
         }
         /* ok for now the choice is on report */
-        else if (  GTK_WIDGET_IS_SENSITIVE (report_button))
+        else if (  gtk_widget_is_sensitive (report_button))
         {
             gint report_number;
             string = NULL;
@@ -984,7 +989,7 @@ static gboolean gsb_assistant_archive_update_labels ( GtkWidget *assistant )
 
 
 /**
- * add a transaction (in fact is pointer) to the list of transactions wich will be archived
+ * add a transaction (in fact is pointer) to the list of transactions which will be archived
  * add too all the linked transactions with it
  *  ie :    the contra-transfer if exists
  *      if child, the mother and the other children
