@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -68,7 +68,7 @@ enum archives_export_columns {
     ARCHIVES_EXPORT_FYEAR_NAME,
     ARCHIVES_EXPORT_REPORT_TITLE,
     ARCHIVES_EXPORT_NUMBER,
-    NUM_ARCHIVES_EXPORT_COLUMNS,
+    NUM_ARCHIVES_EXPORT_COLUMNS
 };
 
 static GtkWidget *archive_export_treeview = NULL;
@@ -110,7 +110,7 @@ GtkResponseType gsb_assistant_archive_export_run ( void )
 				    _("This assistant will help you to export an archive into gsb, QIF or CSV format."
 				      "Note that nothing will be deleted in Grisbi, it's just an export."
 				      "If you want to delete the archive from Grisbi, you need to do it from the preference window."),
-				    "archive.png",
+				    "gsb-export-archive-32.png",
 				    G_CALLBACK (gsb_assistant_archive_switch));
     gsb_assistant_add_page ( assistant,
 			     gsb_assistant_archive_export_page_choose (assistant),
@@ -159,8 +159,8 @@ static GtkWidget *gsb_assistant_archive_export_page_choose ( GtkWidget *assistan
     GSList *tmp_list;
 
     /* create the page */
-    vbox_page = gtk_vbox_new ( FALSE, 0);
-    gtk_container_set_border_width ( GTK_CONTAINER(vbox_page), 12 );
+    vbox_page = gtk_box_new ( GTK_ORIENTATION_VERTICAL, 0);
+    gtk_container_set_border_width ( GTK_CONTAINER(vbox_page), BOX_BORDER_WIDTH );
     paddingbox = new_paddingbox_with_title (vbox_page, TRUE,
 					    _("Select the archive to export"));
 
@@ -186,7 +186,7 @@ static GtkWidget *gsb_assistant_archive_export_page_choose ( GtkWidget *assistan
 					G_TYPE_STRING,
 					G_TYPE_INT );
     archive_export_treeview = gtk_tree_view_new_with_model ( GTK_TREE_MODEL (archive_model) );
-    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (archive_export_treeview), TRUE);
+	gtk_widget_set_name (archive_export_treeview, "tree_view");
     gtk_container_add ( GTK_CONTAINER (scrolled_window),
 			archive_export_treeview );
 
@@ -286,25 +286,25 @@ static GtkWidget *gsb_assistant_archive_export_page_name ( GtkWidget *assistant
 {
     GtkWidget * vbox, * hbox;
 
-    vbox = gtk_vbox_new ( FALSE, 6 );
-    gtk_container_set_border_width ( GTK_CONTAINER(vbox), 12 );
+    vbox = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER(vbox), BOX_BORDER_WIDTH );
 
     archive_export_label = gtk_label_new ( NULL );
-    gtk_misc_set_alignment ( GTK_MISC ( archive_export_label ), 0, 0.5);
+    utils_labels_set_alignment ( GTK_LABEL ( archive_export_label ), 0, 0.5);
     gtk_label_set_justify ( GTK_LABEL ( archive_export_label ), GTK_JUSTIFY_LEFT );
     gtk_box_pack_start ( GTK_BOX ( vbox ), archive_export_label, FALSE, FALSE, 0 );
 
     /* Layout */
-    hbox = gtk_hbox_new ( FALSE, 6 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX ( hbox ),
 			 gtk_label_new ( _("Export format: ") ),
 			 FALSE, FALSE, 0 );
 
     /* Combo box */
-    archive_export_combobox = gtk_combo_box_new_text();
-    gtk_combo_box_append_text ( GTK_COMBO_BOX(archive_export_combobox), _("Grisbi (GSB) format" ) );
-    gtk_combo_box_append_text ( GTK_COMBO_BOX(archive_export_combobox), _("QIF format" ) );
-    gtk_combo_box_append_text ( GTK_COMBO_BOX(archive_export_combobox), _("CSV format" ) );
+    archive_export_combobox = gtk_combo_box_text_new ();
+    gtk_combo_box_text_append_text ( GTK_COMBO_BOX_TEXT (archive_export_combobox), _("Grisbi (GSB) format" ) );
+    gtk_combo_box_text_append_text ( GTK_COMBO_BOX_TEXT (archive_export_combobox), _("QIF format" ) );
+    gtk_combo_box_text_append_text ( GTK_COMBO_BOX_TEXT (archive_export_combobox), _("CSV format" ) );
     gtk_box_pack_start ( GTK_BOX ( hbox ), archive_export_combobox, TRUE, TRUE, 0 );
 
     archive_export_filechooser = gtk_file_chooser_widget_new ( GTK_FILE_CHOOSER_ACTION_SAVE );
@@ -329,11 +329,11 @@ static GtkWidget *gsb_assistant_archive_export_page_succes ( GtkWidget *assistan
 {
     GtkWidget *vbox;
 
-    vbox = gtk_vbox_new ( FALSE, 6 );
-    gtk_container_set_border_width ( GTK_CONTAINER(vbox), 12 );
+    vbox = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER(vbox), BOX_BORDER_WIDTH );
 
     archive_export_label_success = gtk_label_new ( NULL );
-    gtk_misc_set_alignment ( GTK_MISC (archive_export_label_success), 0, 0.5);
+    utils_labels_set_alignment ( GTK_LABEL (archive_export_label_success), 0, 0.5);
     gtk_label_set_justify ( GTK_LABEL (archive_export_label_success), GTK_JUSTIFY_LEFT );
     gtk_box_pack_start ( GTK_BOX ( vbox ), archive_export_label_success, FALSE, FALSE, 0 );
 
@@ -392,7 +392,7 @@ static gboolean gsb_assistant_archive_switch ( GtkWidget *assistant,
 	    /* need to set the next button to the next function,
 	     * because if the export failed and the user did previous button,
 	     * the next button stay in the close state */
-	    gsb_assistant_change_button_next ( assistant, GTK_STOCK_GO_FORWARD,
+	    gsb_assistant_change_button_next ( assistant, "gtk-go-forward",
 					       GTK_RESPONSE_YES );
 
 	    break;
@@ -440,7 +440,7 @@ static gboolean gsb_assistant_archive_switch ( GtkWidget *assistant,
 	    else
 	    {
 		gtk_label_set_text ( GTK_LABEL (archive_export_label_success),
-				     _("Error!\nAn error occured while saving the archive.\n\nPlease press the Previous button to correct the problem,\nor the close button to cancel the action."));
+				     _("Error!\nAn error occurred while saving the archive.\n\nPlease press the Previous button to correct the problem,\nor the close button to cancel the action."));
 		gsb_assistant_sensitive_button_prev ( assistant, TRUE );
 	    }
     }
