@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -78,7 +78,7 @@ static gboolean gsb_assistant_reconcile_config_update_manu_asso ( GtkWidget *ass
 /*START_EXTERN*/
 /*END_EXTERN*/
 
-enum reconcile_assistant_page
+enum ReconcileAssistantPage
 {
     RECONCILE_ASSISTANT_INTRO= 0,
     RECONCILE_ASSISTANT_MENU,
@@ -201,7 +201,7 @@ GtkResponseType gsb_assistant_reconcile_config_run ( void )
 						       transactions_to_link );
     assistant = gsb_assistant_new ( _("Associate orphan transactions to a reconciliation"),
 				    tmpstr,
-				    "reconat.png",
+				    "gsb-reconat-32.png",
 				    NULL );
     g_free ( tmpstr );
 
@@ -261,28 +261,28 @@ static GtkWidget *gsb_assistant_reconcile_config_page_menu ( GtkWidget *assistan
     GtkWidget *button;
 	gchar* tmpstr;
 
-    page = gtk_vbox_new (FALSE, 5);
-    gtk_container_set_border_width ( GTK_CONTAINER(page), 12 );
+    page = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX);
+    gtk_container_set_border_width ( GTK_CONTAINER(page), BOX_BORDER_WIDTH );
 
     tmpstr = g_strdup_printf (_("Still %d transactions to link with a reconciliation."),
 								   transactions_to_link);
     label_transactions_to_link_1 = gtk_label_new (tmpstr );
     g_free ( tmpstr );
-    gtk_misc_set_alignment ( GTK_MISC (label_transactions_to_link_1),
+    utils_labels_set_alignment ( GTK_LABEL (label_transactions_to_link_1),
 			     0, 0.5 );
 
     gtk_box_pack_start ( GTK_BOX (page),
 			 label_transactions_to_link_1,
 			 FALSE, FALSE, 0 );
 
-    separator = gtk_hseparator_new ();
+    separator = gtk_separator_new ( GTK_ORIENTATION_HORIZONTAL );
     gtk_box_pack_start ( GTK_BOX (page),
 			 separator,
 			 FALSE, FALSE, 0 );
 
     /* set up the menu */
     label = gtk_label_new (_("Choose the next operation to do: "));
-    gtk_misc_set_alignment ( GTK_MISC (label),
+    utils_labels_set_alignment ( GTK_LABEL (label),
 			     0, 0.5 );
     gtk_box_pack_start ( GTK_BOX (page),
 			 label,
@@ -303,7 +303,7 @@ static GtkWidget *gsb_assistant_reconcile_config_page_menu ( GtkWidget *assistan
 
     label = gtk_label_new (_("	After a long use, some transactions may be before the first known reconciliation.\n"
 			     "	You can create all the previous needed reconciliations here."));
-    gtk_misc_set_alignment ( GTK_MISC (label),
+    utils_labels_set_alignment ( GTK_LABEL (label),
 			     0, 0.5 );
     gtk_box_pack_start ( GTK_BOX (page),
 			 label,
@@ -325,7 +325,7 @@ static GtkWidget *gsb_assistant_reconcile_config_page_menu ( GtkWidget *assistan
     label = gtk_label_new (_("	This will make all the work for you if you create "
                         "previously all the needed reconciliations\n"
                         "	and adjust the date of the known reconciliations."));
-    gtk_misc_set_alignment ( GTK_MISC (label),
+    utils_labels_set_alignment ( GTK_LABEL (label),
 			     0, 0.5 );
     gtk_box_pack_start ( GTK_BOX (page),
 			 label,
@@ -347,7 +347,7 @@ static GtkWidget *gsb_assistant_reconcile_config_page_menu ( GtkWidget *assistan
 
     label = gtk_label_new (_("	You control all and have a lot of time to spend on your computer !\n"
 			     "	(you will be able to choose a reconciliation for each orphan transaction)."));
-    gtk_misc_set_alignment ( GTK_MISC (label),
+    utils_labels_set_alignment ( GTK_LABEL (label),
 			     0, 0.5 );
     gtk_box_pack_start ( GTK_BOX (page),
 			 label,
@@ -377,88 +377,77 @@ static GtkWidget *gsb_assistant_reconcile_config_page_new_reconcile ( void )
     GtkWidget *button;
     GtkWidget *hbox;
 
-    page = gtk_vbox_new ( FALSE, 0 );
-    gtk_container_set_border_width ( GTK_CONTAINER(page), 12 );
+    page = gtk_box_new ( GTK_ORIENTATION_VERTICAL, 0 );
+    gtk_container_set_border_width ( GTK_CONTAINER(page), BOX_BORDER_WIDTH );
 
     paddingbox = new_paddingbox_with_title ( page, FALSE,
 					     _("Fill the fields and click the button \"Create the new reconciliation\""));
 
     /* create the table, this is the same as the reconcile config,
      * but here it's to create new ones */
-	table = gtk_table_new ( 4, 3, FALSE );
-	gtk_table_set_row_spacings ( GTK_TABLE ( table ), 6 );
-	gtk_table_set_col_spacings ( GTK_TABLE ( table ), 6 );
+	table = gtk_grid_new ();
+	gtk_grid_set_row_spacing (GTK_GRID (table), 6);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 6);
 	gtk_box_pack_start ( GTK_BOX (paddingbox), table, FALSE, FALSE, 0 );
 
 	/* set the name */
 	label = gtk_label_new ( _("Reconciliation reference: ") );
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+	utils_labels_set_alignment ( GTK_LABEL (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-	gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 0, 1,
-			GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
 
 	reconcile_name_entry = gtk_entry_new ();
-	gtk_table_attach ( GTK_TABLE ( table ), reconcile_name_entry, 1, 2, 0, 1,
-			GTK_EXPAND | GTK_FILL, 0, 10, 0 );
+	gtk_grid_attach (GTK_GRID (table), reconcile_name_entry, 1, 0, 1, 1);
 
 	/* set the choice of account */
 	label = gtk_label_new ( _("Account: ") );
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+	utils_labels_set_alignment ( GTK_LABEL (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-	gtk_table_attach ( GTK_TABLE ( table ), label, 2, 3, 0, 1,
-			GTK_SHRINK | GTK_FILL, 0, 10, 0 );
+	gtk_grid_attach (GTK_GRID (table), label, 2, 0, 1, 1);
 
 	reconcile_account_button = gsb_account_create_combo_list ( NULL, NULL, TRUE );
 	gtk_combo_box_set_active ( GTK_COMBO_BOX (reconcile_account_button), 0 );
-	gtk_table_attach ( GTK_TABLE ( table ), reconcile_account_button, 3, 4, 0, 1,
-			GTK_EXPAND | GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table), reconcile_account_button, 3, 0, 1, 1);
 
 	/* set the initial date */
 	label = gtk_label_new ( _("Initial date: ") );
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+	utils_labels_set_alignment ( GTK_LABEL (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-	gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 1, 2,
-			GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table), label, 0, 1, 1, 1);
 
 	reconcile_init_date_entry = gsb_calendar_entry_new (FALSE);
-	gtk_table_attach ( GTK_TABLE ( table ), reconcile_init_date_entry, 1, 2, 1, 2,
-			GTK_EXPAND | GTK_FILL, 0, 10, 0 );
+	gtk_grid_attach (GTK_GRID (table), reconcile_init_date_entry, 1, 1, 1, 1);
 
 	/* set the final date */
 	label = gtk_label_new ( _("Final date: ") );
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+	utils_labels_set_alignment ( GTK_LABEL (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-	gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 2, 3,
-			GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table), label, 0, 2, 1, 1);
 
 	reconcile_final_date_entry = gsb_calendar_entry_new (FALSE);
-	gtk_table_attach ( GTK_TABLE ( table ), reconcile_final_date_entry, 1, 2, 2, 3,
-			GTK_EXPAND | GTK_FILL, 0, 10, 0 );
+	gtk_grid_attach (GTK_GRID (table), reconcile_final_date_entry, 1, 2, 1, 1);
 
 	/* set the initial balance */
 	label = gtk_label_new ( _("Initial balance: ") );
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+	utils_labels_set_alignment ( GTK_LABEL (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-	gtk_table_attach ( GTK_TABLE ( table ), label, 2, 3, 1, 2,
-			GTK_SHRINK | GTK_FILL, 0, 10, 0 );
+	gtk_grid_attach (GTK_GRID (table), label, 2, 1, 1,1);
 
 	reconcile_init_balance_entry = gtk_entry_new ();
-	gtk_table_attach ( GTK_TABLE ( table ), reconcile_init_balance_entry, 3, 4, 1, 2,
-			GTK_EXPAND | GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table), reconcile_init_balance_entry, 3, 1, 1, 1);
 
     /* set the final balance */
 	label = gtk_label_new ( _("Final balance: ") );
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+	utils_labels_set_alignment ( GTK_LABEL (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-	gtk_table_attach ( GTK_TABLE ( table ), label, 2, 3, 2, 3,
-			GTK_SHRINK | GTK_FILL, 0, 10, 0 );
+	gtk_grid_attach (GTK_GRID (table), label, 2, 2, 1, 1);
 
 	reconcile_final_balance_entry = gtk_entry_new ();
-	gtk_table_attach ( GTK_TABLE ( table ), reconcile_final_balance_entry, 3, 4, 2, 3,
-			GTK_EXPAND | GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table), reconcile_final_balance_entry, 3, 2, 1, 1);
 
     /* create the button */
-    hbox = gtk_hbox_new (TRUE, 0);
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, 0 );
+    gtk_box_set_homogeneous ( GTK_BOX ( hbox ), TRUE );
     gtk_box_pack_start ( GTK_BOX (page),
 			 hbox,
 			 FALSE, FALSE,
@@ -523,8 +512,8 @@ static GtkWidget *gsb_assistant_reconcile_config_page_automatically_associate (
     GtkWidget *label;
     GtkWidget *hbox;
 
-    page = gtk_vbox_new (FALSE, 5);
-    gtk_container_set_border_width ( GTK_CONTAINER(page), 12 );
+    page = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX);
+    gtk_container_set_border_width ( GTK_CONTAINER(page), BOX_BORDER_WIDTH );
 
     /* for now we juste create the widgets, but cannot fill here,
      * we will fill when the user come to that page */
@@ -534,7 +523,7 @@ static GtkWidget *gsb_assistant_reconcile_config_page_automatically_associate (
 			 label_transactions_to_link_2,
 			 FALSE, FALSE, 0 );
 
-    separator = gtk_hseparator_new ();
+    separator = gtk_separator_new ( GTK_ORIENTATION_HORIZONTAL );
     gtk_box_pack_start ( GTK_BOX (page),
 			 separator,
 			 FALSE, FALSE, 0 );
@@ -544,7 +533,7 @@ static GtkWidget *gsb_assistant_reconcile_config_page_automatically_associate (
 			     "If all the orphan transactions cannot be linked here, you should check\n"
 			     "if you did create all the necessary reconciliations (first choice in the assistant\n"
 			     "menu page) or check the transactions themselves."));
-    gtk_misc_set_alignment ( GTK_MISC (label),
+    utils_labels_set_alignment ( GTK_LABEL (label),
 			     0, 0.5 );
     gtk_box_pack_start ( GTK_BOX (page),
 			 label,
@@ -557,7 +546,8 @@ static GtkWidget *gsb_assistant_reconcile_config_page_automatically_associate (
 			 FALSE, FALSE, 12 );
 
     /* set the button to run the association */
-    hbox = gtk_hbox_new (TRUE, 0);
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_box_set_homogeneous ( GTK_BOX ( hbox ), TRUE );
     gtk_box_pack_start ( GTK_BOX (page),
 			 hbox,
 			 FALSE, FALSE,
@@ -604,8 +594,8 @@ static GtkWidget *gsb_assistant_reconcile_config_page_manually_associate ( GtkWi
     };
 
 
-    page = gtk_vbox_new ( FALSE, 0 );
-    gtk_container_set_border_width ( GTK_CONTAINER(page), 12 );
+    page = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER(page), BOX_BORDER_WIDTH );
 
     /* the number of transactions to link */
     label_transactions_to_link_3 = gtk_label_new (NULL);
@@ -613,14 +603,14 @@ static GtkWidget *gsb_assistant_reconcile_config_page_manually_associate ( GtkWi
 			 label_transactions_to_link_3,
 			 FALSE, FALSE, 0 );
 
-    separator = gtk_hseparator_new ();
+    separator = gtk_separator_new ( GTK_ORIENTATION_HORIZONTAL );
     gtk_box_pack_start ( GTK_BOX (page),
 			 separator,
 			 FALSE, FALSE, 0 );
 
     /* now we can show the list of orphans transactions */
     label = gtk_label_new (_("Select the transaction(s) you want to associate with a reconciliation: "));
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.0 );
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.0 );
     gtk_box_pack_start ( GTK_BOX (page),
 			 label,
 			 FALSE, FALSE, 10 );
@@ -642,8 +632,8 @@ static GtkWidget *gsb_assistant_reconcile_config_page_manually_associate ( GtkWi
 				 G_TYPE_STRING,
 				 G_TYPE_INT );
     treeview_transactions_to_link = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
+	gtk_widget_set_name (treeview_transactions_to_link, "tree_view");
     g_object_unref (G_OBJECT(store));
-    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_transactions_to_link), TRUE);
     gtk_tree_selection_set_mode ( gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview_transactions_to_link)),
 				  GTK_SELECTION_MULTIPLE );
     gtk_container_add ( GTK_CONTAINER (scrolled_window),
@@ -676,7 +666,8 @@ static GtkWidget *gsb_assistant_reconcile_config_page_manually_associate ( GtkWi
     }
 
     /* set the button to associate */
-    hbox = gtk_hbox_new (TRUE, 0);
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_box_set_homogeneous ( GTK_BOX ( hbox ), TRUE );
     gtk_box_pack_start ( GTK_BOX (page),
 			 hbox,
 			 FALSE, FALSE,
@@ -707,8 +698,8 @@ static GtkWidget *gsb_assistant_reconcile_config_page_success ( void )
     GtkWidget *page;
     GtkWidget *label;
 
-    page = gtk_vbox_new ( FALSE, 0 );
-    gtk_container_set_border_width ( GTK_CONTAINER(page), 12 );
+    page = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER(page), BOX_BORDER_WIDTH );
 
     label = gtk_label_new (_("Congratulations!\n\n"
 			     "You have linked all the transactions without reconciliation.\n"
@@ -833,7 +824,7 @@ static gboolean gsb_assistant_reconcile_config_page_add_new_reconcile ( GtkWidge
     gsb_data_reconcile_set_account ( reconcile_number,
                         gsb_account_get_combo_account_number ( reconcile_account_button ) );
 
-    /* erase the entries but not the account wich can be used again */
+    /* erase the entries but not the account which can be used again */
     gtk_entry_set_text ( GTK_ENTRY (reconcile_name_entry), "" );
     gtk_entry_set_text ( GTK_ENTRY (reconcile_init_date_entry), "" );
     gtk_entry_set_text ( GTK_ENTRY (reconcile_final_date_entry), "" );
@@ -893,7 +884,7 @@ gboolean gsb_assistant_reconcile_config_update_auto_asso ( GtkWidget *assistant,
     gtk_label_set_text ( GTK_LABEL (label_transactions_to_link_2),
 			 string);
     g_free (string);
-    gtk_misc_set_alignment ( GTK_MISC (label_transactions_to_link_2),
+    utils_labels_set_alignment ( GTK_LABEL (label_transactions_to_link_2),
 			     0, 0.5 );
 
     /* calculate how many transactions can be associated automatically,
@@ -1011,7 +1002,7 @@ static gboolean gsb_assistant_reconcile_config_lauch_auto_asso ( GtkWidget *butt
 	gtk_label_set_text ( GTK_LABEL (label_transactions_to_link_2),
 			     string);
 	g_free (string);
-	gtk_misc_set_alignment ( GTK_MISC (label_transactions_to_link_2),
+	utils_labels_set_alignment ( GTK_LABEL (label_transactions_to_link_2),
 				 0, 0.5 );
 
 	gtk_label_set_text ( GTK_LABEL (label_possible_association),
@@ -1054,7 +1045,7 @@ gboolean gsb_assistant_reconcile_config_update_manu_asso ( GtkWidget *assistant,
     gtk_label_set_text ( GTK_LABEL (label_transactions_to_link_3),
 			 string);
     g_free (string);
-    gtk_misc_set_alignment ( GTK_MISC (label_transactions_to_link_3),
+    utils_labels_set_alignment ( GTK_LABEL (label_transactions_to_link_3),
 			     0, 0.5 );
 
     /* fill the list with the transactions to link */
@@ -1165,8 +1156,7 @@ static gboolean gsb_assistant_reconcile_config_lauch_manu_asso ( GtkWidget *butt
 		{
 		    dialogue_error (_("All the selected transactions have to belong to the same account !"));
 		    /* erase the path_list */
-		    g_list_foreach (path_list, (GFunc) gtk_tree_path_free, NULL);
-		    g_list_free (path_list);
+		    g_list_free_full (path_list, (GDestroyNotify) gtk_tree_path_free);
 		    return FALSE;
 		}
 	    }
@@ -1177,8 +1167,7 @@ static gboolean gsb_assistant_reconcile_config_lauch_manu_asso ( GtkWidget *butt
     if (account_number == -1)
     {
 	/* erase the path_list */
-	g_list_foreach (path_list, (GFunc) gtk_tree_path_free, NULL);
-	g_list_free (path_list);
+	g_list_free_full (path_list, (GDestroyNotify) gtk_tree_path_free);
 	return FALSE;
     }
 
@@ -1187,18 +1176,18 @@ static gboolean gsb_assistant_reconcile_config_lauch_manu_asso ( GtkWidget *butt
     dialog = gtk_dialog_new_with_buttons ( _("Selection of a reconciliation"),
 					   GTK_WINDOW ( assistant ),
 					   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					   GTK_STOCK_OK, GTK_RESPONSE_OK,
+					   "gtk-cancel", GTK_RESPONSE_CANCEL,
+					   "gtk-ok", GTK_RESPONSE_OK,
 					   NULL );
 
     gtk_window_set_default_size ( GTK_WINDOW ( dialog ), 770, 412 );
     gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
     gtk_window_set_resizable ( GTK_WINDOW ( dialog ), TRUE );
-    gtk_container_set_border_width ( GTK_CONTAINER ( dialog ), 12 );
+    gtk_container_set_border_width ( GTK_CONTAINER ( dialog ), BOX_BORDER_WIDTH );
 
     label = gtk_label_new ( _("Select the reconciliation to associate to the selected transactions: ") );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.0 );
-    gtk_box_pack_start ( GTK_BOX (GTK_DIALOG (dialog) -> vbox),
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.0 );
+    gtk_box_pack_start ( GTK_BOX ( dialog_get_content_area ( dialog ) ),
 			 label,
 			 FALSE, FALSE,
 			 10 );
@@ -1208,7 +1197,7 @@ static gboolean gsb_assistant_reconcile_config_lauch_manu_asso ( GtkWidget *butt
     gtk_scrolled_window_set_policy ( GTK_SCROLLED_WINDOW (scrolled_window),
 				     GTK_POLICY_AUTOMATIC,
 				     GTK_POLICY_AUTOMATIC );
-    gtk_box_pack_start ( GTK_BOX (GTK_DIALOG (dialog) -> vbox),
+    gtk_box_pack_start ( GTK_BOX ( dialog_get_content_area ( dialog ) ),
 			 scrolled_window,
 			 TRUE, TRUE,
 			 0 );
@@ -1219,8 +1208,8 @@ static gboolean gsb_assistant_reconcile_config_lauch_manu_asso ( GtkWidget *butt
 					G_TYPE_STRING,
 					G_TYPE_INT );
     dialog_tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (dialog_store));
+	gtk_widget_set_name (dialog_tree_view, "tree_view");
     g_object_unref (G_OBJECT(dialog_store));
-    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (dialog_tree_view), TRUE);
     gtk_container_add ( GTK_CONTAINER (scrolled_window),
 			dialog_tree_view );
 
@@ -1341,8 +1330,7 @@ static gboolean gsb_assistant_reconcile_config_lauch_manu_asso ( GtkWidget *butt
     }
 
     /* erase the path_list */
-    g_list_foreach (path_list, (GFunc) gtk_tree_path_free, NULL);
-    g_list_free (path_list);
+    g_list_free_full (path_list, (GDestroyNotify) gtk_tree_path_free);
 
     /* now there is 2 way :
      * either transactions_to_link is 0, we go directly to the succes page
