@@ -30,7 +30,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -39,6 +39,7 @@
 /*START_INCLUDE*/
 #include "gsb_bank.h"
 #include "dialog.h"
+#include "grisbi_app.h"
 #include "gsb_account_property.h"
 #include "gsb_autofunc.h"
 #include "gsb_data_account.h"
@@ -49,7 +50,9 @@
 #include "structures.h"
 #include "traitement_variables.h"
 #include "utils.h"
+#include "utils_buttons.h"
 #include "utils_editables.h"
+#include "utils_prefs.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -86,6 +89,7 @@ enum bank_list_col
    BANK_VIEW_NAME_COL = 0,
    BANK_TALKER_COL,
    BANK_NUMBER,
+   BANK_ROW_COLOR,
    BANK_LIST_COL_NB
 };
 
@@ -178,7 +182,7 @@ GtkWidget *gsb_bank_create_combobox ( gint index )
  *
  * \param combobox
  *
- * \return the bank number, 0 for none, -1 for 'new bank'
+ * \return the bank number, 0 for none, -1 for 'new bank', -2 'Inconnu'
  * */
 gint gsb_bank_list_get_bank_number ( GtkWidget *combobox )
 {
@@ -186,11 +190,11 @@ gint gsb_bank_list_get_bank_number ( GtkWidget *combobox )
     gint bank_number;
 
     if (!combobox)
-	return -1;
+	return -2;
 
     if (!gtk_combo_box_get_active_iter ( GTK_COMBO_BOX (combobox),
 					 &iter))
-	return -1;
+	return -2;
 
     gtk_tree_model_get ( GTK_TREE_MODEL (bank_list_model),
 			 &iter,
@@ -256,7 +260,7 @@ gboolean gsb_bank_list_set_bank ( GtkWidget *combobox,
  * callback called when click on the edit-bank in the property of account
  * show a window with the parameters of the bank in the combobox
  *
- * \param button the button wich was clicked
+ * \param button the button which was clicked
  * \param combobox the combobox selected a bank
  *
  * \return FALSE
@@ -270,9 +274,11 @@ gboolean gsb_bank_edit_from_button ( GtkWidget *button,
 
     /* if bank_number = 0, it's none ; -1 : it's new bank, so don't edit */
     if ( bank_number <= 0 )
-	return FALSE;
+        return FALSE;
 
+    delete_bank_button = NULL;
     gsb_bank_edit_bank ( bank_number, combobox );
+
     return FALSE;
 }
 
@@ -305,7 +311,7 @@ static gboolean gsb_bank_update_selected_line_model ( GtkWidget *combobox )
 {
     GtkTreeIter iter;
     GSList *list_tmp;
-    gint save_bank_number = -1;
+    gint save_bank_number = -2;
 
     /* save the selection */
     if (combobox)
@@ -352,13 +358,13 @@ static gboolean gsb_bank_update_selected_line_model ( GtkWidget *combobox )
                         BANK_NAME_COL, NULL,
                         -1 );
 
-    /* item to add a bank : the number is -2 */
+    /* item to add a bank : the number is -1 */
     gtk_list_store_append ( GTK_LIST_STORE ( bank_list_model ), &iter );
-    gtk_list_store_set ( GTK_LIST_STORE ( bank_list_model ),
+    gtk_list_store_set (GTK_LIST_STORE ( bank_list_model ),
                         &iter,
                         BANK_NAME_COL, _("Add new bank"),
-                        BANK_NUMBER_COL, -2,
-                        -1 );
+                        BANK_NUMBER_COL, -1,
+                        -1);
 
     /* restore the selection */
     if ( combobox )
@@ -413,8 +419,8 @@ static gboolean gsb_bank_list_changed ( GtkWidget *combobox,
 
     bank_number = gsb_bank_list_get_bank_number (combobox);
 
-    /* check if not new bank, ie -2 */
-    if ( bank_number != -2 )
+    /* check if not new bank, ie -1 */
+    if (bank_number != -1)
     {
         gsb_data_account_set_bank ( gsb_gui_navigation_get_current_account ( ), bank_number );
         /* Mark file as modified */
@@ -423,7 +429,7 @@ static gboolean gsb_bank_list_changed ( GtkWidget *combobox,
     }
 
     /* asked to add a new bank */
-    bank_number = gsb_bank_edit_bank ( bank_number, combobox );
+    gsb_bank_edit_bank ( bank_number, combobox );
 
     return FALSE;
 }
@@ -441,58 +447,48 @@ static gboolean gsb_bank_list_changed ( GtkWidget *combobox,
  * 	to let grisbi choose between sensitive or net, set default_sensitive to FALSE
  * \returns A newly allocated vbox
  */
-GtkWidget *gsb_bank_create_page ( gboolean default_sensitive )
+GtkWidget *gsb_bank_create_page (gboolean default_sensitive,
+								 gint bank_details_height)
 {
     GtkWidget *vbox_pref;
-    GtkWidget *scrolled_window, *vbox, *vbox2;
-    GtkWidget *button, *hbox, *paddingbox;
+    GtkWidget *scrolled_window, *vbox2;
+    GtkWidget *button;
+    GtkWidget *vpaned;
+    GtkWidget *paned1, *paned2;
+    GtkWidget *paddinggrid;
+    GtkWidget *paned2_sw;
     GtkListStore *store;
     GtkTreeSelection *selection;
     gint i;
-    gchar *titles[] = {
-	_("Bank"), _("Contact name")
-    };
-    gfloat alignment[] = {
-	COLUMN_LEFT, COLUMN_LEFT
-    };
-    GtkWidget *vpaned;
-    GtkWidget *paned1, *paned2;
+    gint nbre_bank = 0;
+    gint sw_height = 0;
+    gchar *titles[] = {_("Bank"), _("Contact name")};
+    gfloat alignment[] = {COLUMN_LEFT, COLUMN_LEFT};
 
-    vbox_pref = new_vbox_with_title_and_icon ( _("Banks"), "banks.png" );
+    vbox_pref = new_vbox_with_title_and_icon ( _("Banks"), "gsb-banks-32.png" );
 
-    vpaned = gtk_vpaned_new ();
-    gtk_box_pack_start ( GTK_BOX (vbox_pref),
-			 vpaned,
-			 TRUE, TRUE, 0 );
+    vpaned = gtk_paned_new (GTK_ORIENTATION_VERTICAL);
+    gtk_box_pack_start ( GTK_BOX (vbox_pref), vpaned, TRUE, TRUE, 0 );
 
     /* Create bank list */
-    paned1 = gtk_vbox_new (FALSE, 0);
-    gtk_paned_pack1 ( GTK_PANED (vpaned), paned1,
-		      FALSE, FALSE );
+    paned1 = gtk_box_new ( GTK_ORIENTATION_VERTICAL, 0);
+    gtk_paned_pack1 ( GTK_PANED (vpaned), paned1, FALSE, FALSE );
 
-    paddingbox = new_paddingbox_with_title ( paned1, FALSE,
-					     _("Known banks") );
+    paddinggrid = utils_prefs_paddinggrid_new_with_title (paned1, _("Known banks"));
 
-    hbox = gtk_hbox_new ( FALSE, 10 );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox,
-			 FALSE, FALSE, 0);
-
-    scrolled_window = gtk_scrolled_window_new ( NULL, NULL );
-    gtk_scrolled_window_set_policy ( GTK_SCROLLED_WINDOW ( scrolled_window ),
-				     GTK_POLICY_NEVER,
-				     GTK_POLICY_AUTOMATIC);
-    gtk_box_pack_start ( GTK_BOX ( hbox ), scrolled_window,
-			 TRUE, TRUE, 0);
+    scrolled_window = utils_prefs_scrolled_window_new (NULL, GTK_SHADOW_IN, SW_COEFF_UTIL_PG, SW_MIN_HEIGHT);
+	gtk_widget_set_hexpand (scrolled_window, TRUE);
+    gtk_grid_attach (GTK_GRID (paddinggrid), scrolled_window, 0, 0, 2, 3);
 
     /* set the store */
     store = gtk_list_store_new ( BANK_LIST_COL_NB,
 				 G_TYPE_STRING,
 				 G_TYPE_STRING,
-				 G_TYPE_INT );
+				 G_TYPE_INT,
+				 GDK_TYPE_RGBA);
     bank_list_tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
+	gtk_widget_set_name (bank_list_tree_view, "tree_view");
     g_object_unref (G_OBJECT(store));
-    gtk_tree_view_set_rules_hint ( GTK_TREE_VIEW (bank_list_tree_view),
-				   TRUE );
     gtk_container_add ( GTK_CONTAINER (scrolled_window),
 			bank_list_tree_view );
 
@@ -521,9 +517,11 @@ GtkWidget *gsb_bank_create_page ( gboolean default_sensitive )
 
 	gtk_tree_view_column_pack_start ( column, cell, TRUE );
 	gtk_tree_view_column_set_title ( column, titles[i] );
-	gtk_tree_view_column_set_attributes (column, cell,
-					     "text", i,
-					     NULL);
+	gtk_tree_view_column_set_attributes (column,
+										 cell,
+										 "text", i,
+										 "cell-background-rgba", BANK_NUMBER + 1,
+										 NULL);
 	gtk_tree_view_column_set_expand ( column, TRUE );
 	gtk_tree_view_column_set_resizable ( column,
 					     TRUE );
@@ -539,7 +537,7 @@ GtkWidget *gsb_bank_create_page ( gboolean default_sensitive )
 	GSList *tmp_list;
 
 	tmp_list = gsb_data_bank_get_bank_list ();
-
+    nbre_bank = g_slist_length (tmp_list);
 	while ( tmp_list )
 	{
 	    gint bank_number;
@@ -559,54 +557,67 @@ GtkWidget *gsb_bank_create_page ( gboolean default_sensitive )
 	}
     }
 
-    /* Handle Add & Remove buttons */
-    vbox = gtk_vbox_new ( FALSE, 5 );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), vbox,
-			 FALSE, FALSE, 0 );
+    /* set the height of sw */
+    if (default_sensitive)
+    {
+        sw_height = 80;
+    }
+    else
+    {
+        if ( nbre_bank <= 3 )
+            sw_height = 110;
+        else if (nbre_bank > 5)
+            sw_height = 200;
+        else
+            sw_height = (33 * nbre_bank) + 10;
+    }
+
+    g_object_set_data (G_OBJECT (scrolled_window), "height", GINT_TO_POINTER (sw_height));
+
+	/* set column color */
+	utils_set_list_store_background_color (bank_list_tree_view, BANK_NUMBER + 1);
+
     /* Add button */
-    button = gtk_button_new_from_stock (GTK_STOCK_ADD);
-    g_signal_connect ( G_OBJECT ( button ), "clicked",
-		       G_CALLBACK  ( gsb_bank_add ),
-		       NULL );
-    gtk_box_pack_start ( GTK_BOX ( vbox ), button,
-			 FALSE, FALSE, 5 );
+    button = utils_buttons_button_new_from_stock ("gtk-add", _("Add"));
+    gtk_widget_set_margin_end (button, MARGIN_END);
+    utils_widget_set_padding (button, 0, MARGIN_TOP);
+    g_signal_connect (G_OBJECT ( button ),
+                      "clicked",
+                      G_CALLBACK  (gsb_bank_add),
+                      NULL);
+    gtk_grid_attach (GTK_GRID (paddinggrid), button, 0, 3, 1, 1);
+
     /* Remove button */
-    delete_bank_button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
+    delete_bank_button = utils_buttons_button_new_from_stock ("gtk-remove", _("Remove"));
+    utils_widget_set_padding (delete_bank_button, 0, MARGIN_TOP);
     gtk_widget_set_sensitive ( delete_bank_button, FALSE );
-    g_signal_connect ( G_OBJECT ( delete_bank_button ), "clicked",
-		       G_CALLBACK ( gsb_bank_delete ),
-		       NULL );
-    gtk_box_pack_start ( GTK_BOX ( vbox ), delete_bank_button,
-			 FALSE, FALSE, 5 );
+    g_signal_connect (G_OBJECT (delete_bank_button),
+                      "clicked",
+                      G_CALLBACK (gsb_bank_delete),
+                      NULL);
+    gtk_grid_attach (GTK_GRID (paddinggrid), delete_bank_button, 1, 3, 1, 1);
 
+	/* Add a scroll because bank details are huge */
+    paned2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+    gtk_paned_pack2 (GTK_PANED (vpaned), paned2, FALSE, FALSE);
 
-    /* Add a scroll because bank details are huge */
-    paned2 = gtk_vbox_new (FALSE, 0);
-    gtk_paned_pack2 ( GTK_PANED (vpaned), paned2,
-		      TRUE, FALSE );
+	paddinggrid = utils_prefs_paddinggrid_new_with_title (paned2, _("Bank details"));
 
-    scrolled_window = gtk_scrolled_window_new ( FALSE, FALSE );
-    gtk_scrolled_window_set_policy ( GTK_SCROLLED_WINDOW ( scrolled_window ),
-				     GTK_POLICY_NEVER,
-				     GTK_POLICY_AUTOMATIC );
-    gtk_box_pack_start ( GTK_BOX ( paned2 ), scrolled_window,
-			 TRUE, TRUE, 5 );
-    vbox2 = gtk_vbox_new ( FALSE, 0 );
-    gtk_scrolled_window_add_with_viewport ( GTK_SCROLLED_WINDOW ( scrolled_window ),
-					    vbox2 );
-    gtk_scrolled_window_set_shadow_type ( GTK_SCROLLED_WINDOW ( scrolled_window ),
-					  GTK_SHADOW_NONE );
-    gtk_viewport_set_shadow_type ( GTK_VIEWPORT ( GTK_BIN ( scrolled_window ) -> child ),
-				   GTK_SHADOW_NONE );
-    gtk_widget_set_sensitive ( vbox2, FALSE );
+    paned2_sw = utils_prefs_scrolled_window_new (NULL, GTK_SHADOW_IN, SW_COEFF_UTIL_SW, bank_details_height);
+	gtk_widget_set_hexpand (paned2_sw, TRUE);
+    gtk_grid_attach (GTK_GRID (paddinggrid), paned2_sw, 0, 0, 1, 1);
 
-    gsb_bank_create_form ( vbox2, NULL );
+    vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+    gtk_container_add (GTK_CONTAINER (paned2_sw), vbox2);
+    gtk_widget_set_sensitive (vbox2, FALSE);
+
+    gsb_bank_create_form (vbox2, NULL);
 
     /* connect the selection with vbox2, the container of the form */
     g_signal_connect ( G_OBJECT (selection),
-		       "changed",
-		       G_CALLBACK (gsb_bank_list_change_selection),
-		       vbox2 );
+                      "changed",
+                      G_CALLBACK (gsb_bank_list_change_selection),
+                      vbox2);
 
     return ( vbox_pref );
 }
@@ -655,27 +666,22 @@ static gboolean gsb_bank_list_change_selection ( GtkTreeSelection *selection,
 static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
                         GtkWidget *combobox )
 {
-    GtkWidget *paddingbox, *table, *label, *scrolled_window;
+    GtkWidget *label;
+    GtkWidget *scrolled_window;
+    GtkWidget *paddinggrid;
     GtkSizeGroup * size_group;
 
     /* Bank details */
-    paddingbox = new_paddingbox_with_title ( parent, TRUE, _("Bank details") );
+    paddinggrid = utils_prefs_paddinggrid_new_with_title ( parent, _("Generalities") );
 
-    /* Create a table to align things nicely */
-    table = gtk_table_new ( 10, 2, FALSE );
-    gtk_table_set_col_spacings ( GTK_TABLE ( table ), 5 );
-    gtk_table_set_row_spacings ( GTK_TABLE ( table ), 5 );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), table, TRUE, TRUE, 5 );
+    gtk_grid_set_column_spacing (GTK_GRID (paddinggrid), 5);
+    gtk_grid_set_row_spacing (GTK_GRID (paddinggrid), 5);
     size_group = gtk_size_group_new ( GTK_SIZE_GROUP_HORIZONTAL );
 
     /* Bank name item */
     label = gtk_label_new ( _("Name: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-                label, 0, 1, 0, 1,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 0, 1, 1);
 
     if ( combobox )
         bank_name = gsb_autofunc_entry_new ( NULL, NULL, NULL, NULL, 0 );
@@ -686,19 +692,12 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
                         G_CALLBACK ( gsb_data_bank_set_name ),
                         0 );
     gtk_size_group_add_widget ( size_group, bank_name );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       bank_name, 1, 2, 0, 1,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), bank_name, 1, 0, 1, 1);
 
     /* Bank Sort code item */
     label = gtk_label_new ( _("Sort code: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 1, 2,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 1, 1, 1);
 
     if ( combobox )
         bank_code = gsb_autofunc_entry_new ( NULL, NULL, NULL, NULL, 0 );
@@ -709,19 +708,12 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
                         G_CALLBACK ( gsb_data_bank_set_code ),
                         0 );
     gtk_size_group_add_widget ( size_group, bank_code );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       bank_code, 1, 2, 1, 2,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), bank_code, 1, 1, 1, 1);
 
     /* Bank BIC code item */
     label = gtk_label_new ( _("BIC code: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 2, 3,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 2, 1, 1);
 
     if ( combobox )
         bank_BIC = gsb_autofunc_entry_new ( NULL, NULL, NULL, NULL, 0 );
@@ -732,20 +724,17 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
                         G_CALLBACK ( gsb_data_bank_set_bic ),
                         0 );
     gtk_size_group_add_widget ( size_group, bank_BIC );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       bank_BIC, 1, 2, 2, 3,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), bank_BIC, 1, 2, 1, 1);
 
     /* Bank address */
     label = gtk_label_new ( _("Address: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 4, 5,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0);
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 3, 1, 1);
+
     scrolled_window = gtk_scrolled_window_new ( FALSE, FALSE );
+    gtk_widget_set_size_request ( scrolled_window, -1, 100 );
+    if ( combobox )
+        gtk_widget_set_hexpand (scrolled_window, TRUE);
     gtk_scrolled_window_set_policy ( GTK_SCROLLED_WINDOW ( scrolled_window ),
 				     GTK_POLICY_NEVER,
 				     GTK_POLICY_AUTOMATIC );
@@ -761,22 +750,14 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
                         NULL,
                         G_CALLBACK ( gsb_data_bank_set_bank_address ),
                         0 );
-    gtk_widget_set_size_request ( bank_adr, -1, 70 );
     gtk_container_add ( GTK_CONTAINER ( scrolled_window ), bank_adr );
     gtk_size_group_add_widget ( size_group, bank_adr );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       scrolled_window, 1, 2, 4, 5,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), scrolled_window, 1, 3, 1, 1 );
 
     /* Phone number */
     label = gtk_label_new ( _("Phone: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 5, 6,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 4, 1, 1);
 
     if ( combobox )
         bank_tel = gsb_autofunc_entry_new ( NULL, NULL, NULL, NULL, 0 );
@@ -787,19 +768,12 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
                         G_CALLBACK ( gsb_data_bank_set_bank_tel ),
                         0 );
     gtk_size_group_add_widget ( size_group, bank_tel );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       bank_tel, 1, 2, 5, 6,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), bank_tel, 1, 4, 1, 1);
 
     /* E-mail */
     label = gtk_label_new ( _("E-Mail: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 7, 8,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 5, 1, 1);
 
     if ( combobox )
         bank_mail = gsb_autofunc_entry_new ( NULL, NULL, NULL, NULL, 0 );
@@ -810,49 +784,35 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
                         G_CALLBACK ( gsb_data_bank_set_bank_mail ),
                         0 );
     gtk_size_group_add_widget ( size_group, bank_mail );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       bank_mail, 1, 2, 7, 8,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), bank_mail, 1, 5, 1, 1);
 
     /* Website */
     label = gtk_label_new ( _("Website: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 9, 10,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 6, 1, 1);
     if ( combobox )
         bank_web = gsb_autofunc_entry_new ( NULL, NULL, NULL, NULL, 0 );
     else
+    {
         bank_web = gsb_autofunc_entry_new ( NULL,
                         NULL,
                         NULL,
                         G_CALLBACK ( gsb_data_bank_set_bank_web ),
                         0 );
+        gtk_widget_set_size_request ( bank_web, 500, -1);
+    }
     gtk_size_group_add_widget ( size_group, bank_web );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       bank_web, 1, 2, 9, 10,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), bank_web, 1, 6, 1, 1);
 
     /* Contact */
-    paddingbox = new_paddingbox_with_title ( parent, FALSE, _("Contact") );
-    table = gtk_table_new ( 2, 2, FALSE );
-    gtk_table_set_col_spacings ( GTK_TABLE ( table ), 5 );
-    gtk_table_set_row_spacings ( GTK_TABLE ( table ), 5 );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), table,
-			 TRUE, TRUE, 5 );
+    paddinggrid = utils_prefs_paddinggrid_new_with_title ( parent, _("Contact") );
+    gtk_grid_set_column_spacing (GTK_GRID (paddinggrid), 5);
+    gtk_grid_set_row_spacing (GTK_GRID (paddinggrid), 5);
 
     /* Name */
     label = gtk_label_new ( _("Name: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 0, 1,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 0, 1, 1);
 
     if ( combobox )
         bank_contact_name = gsb_autofunc_entry_new ( NULL, NULL, NULL, NULL, 0 );
@@ -863,20 +823,14 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
                         G_CALLBACK ( gsb_data_bank_set_correspondent_name ),
                         0 );
     gtk_size_group_add_widget ( size_group, bank_contact_name );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       bank_contact_name, 1, 2, 0, 1,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    if ( combobox )
+        gtk_widget_set_hexpand (bank_contact_name, TRUE);
+    gtk_grid_attach (GTK_GRID (paddinggrid), bank_contact_name, 1, 0, 1, 1);
 
     /* Phone number */
     label = gtk_label_new ( _("Phone: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 1, 2,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
-
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 1, 1, 1);
 
     if ( combobox )
         bank_contact_tel = gsb_autofunc_entry_new ( NULL, NULL, NULL, NULL, 0 );
@@ -887,42 +841,12 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
                         G_CALLBACK ( gsb_data_bank_set_correspondent_tel ),
                         0 );
     gtk_size_group_add_widget ( size_group, bank_contact_tel );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       bank_contact_tel, 1, 2, 1, 2,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
-
-    /* Fax */
-    label = gtk_label_new ( _("Fax: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 3, 4,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
-
-    if ( combobox )
-        bank_contact_fax = gsb_autofunc_entry_new ( NULL, NULL, NULL, NULL, 0 );
-    else
-        bank_contact_fax = gsb_autofunc_entry_new ( NULL,
-                        NULL,
-                        NULL,
-                        G_CALLBACK ( gsb_data_bank_set_correspondent_fax ),
-                        0 );
-    gtk_size_group_add_widget ( size_group, bank_contact_fax );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       bank_contact_fax, 1, 2, 3, 4,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), bank_contact_tel, 1, 1, 1, 1);
 
     /* E-Mail */
     label = gtk_label_new ( _("E-Mail: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 2, 3,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 2, 1, 1);
 
     if ( combobox )
         bank_contact_mail = gsb_autofunc_entry_new ( NULL, NULL, NULL, NULL, 0 );
@@ -933,31 +857,50 @@ static GtkWidget *gsb_bank_create_form ( GtkWidget *parent,
                         G_CALLBACK ( gsb_data_bank_set_correspondent_mail ),
                         0 );
     gtk_size_group_add_widget ( size_group, bank_contact_mail );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       bank_contact_mail, 1, 2, 2, 3,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), bank_contact_mail, 1, 2, 1, 1);
+
+    /* Fax */
+    label = gtk_label_new ( _("Fax: ") );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 3, 1, 1);
+
+    if ( combobox )
+        bank_contact_fax = gsb_autofunc_entry_new ( NULL, NULL, NULL, NULL, 0 );
+    else
+        bank_contact_fax = gsb_autofunc_entry_new ( NULL,
+                        NULL,
+                        NULL,
+                        G_CALLBACK ( gsb_data_bank_set_correspondent_fax ),
+                        0 );
+    gtk_size_group_add_widget ( size_group, bank_contact_fax );
+    gtk_grid_attach (GTK_GRID (paddinggrid), bank_contact_fax, 1, 3, 1, 1);
 
     /* Notes */
-    paddingbox = new_paddingbox_with_title ( parent, FALSE, _("Notes") );
+    paddinggrid = utils_prefs_paddinggrid_new_with_title ( parent,_("Notes") );
     scrolled_window = gtk_scrolled_window_new ( FALSE, FALSE );
+    gtk_widget_set_size_request ( scrolled_window, -1, 100 );
     gtk_scrolled_window_set_policy ( GTK_SCROLLED_WINDOW ( scrolled_window ),
 				     GTK_POLICY_NEVER,
 				     GTK_POLICY_AUTOMATIC );
     gtk_scrolled_window_set_shadow_type ( GTK_SCROLLED_WINDOW(scrolled_window),
 					  GTK_SHADOW_IN );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), scrolled_window,
-			 TRUE, TRUE, 5 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), scrolled_window, 0, 0, 1, 1 );
 
-    if ( combobox )
+    if (combobox)
+    {
         bank_notes = gsb_autofunc_textview_new ( NULL, NULL, NULL, NULL, 0 );
+        gtk_widget_set_hexpand (bank_notes, TRUE);
+    }
     else
+    {
         bank_notes = gsb_autofunc_textview_new ( NULL,
                         NULL,
                         NULL,
                         G_CALLBACK ( gsb_data_bank_set_bank_note ),
                         0 );
-    gtk_widget_set_size_request ( bank_notes, -1, 100 );
+        gtk_widget_set_size_request ( scrolled_window, 700, 150);
+    }
+
     gtk_container_add ( GTK_CONTAINER ( scrolled_window ), bank_notes );
 
     return parent;
@@ -1022,14 +965,14 @@ static gboolean gsb_bank_update_form ( gint bank_number,
 static gboolean gsb_bank_edit_bank ( gint bank_number,
                         GtkWidget *combobox )
 {
-    GtkWidget *dialog, *form, *scrolled_window, *vbox;
+    GtkWidget *dialog, *scrolled_window, *vbox;
     gint result;
 
     dialog = gtk_dialog_new_with_buttons ( _("Edit bank"),
-					   GTK_WINDOW ( run.window ),
+					   GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
 					   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					   GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
+					   "gtk-cancel", GTK_RESPONSE_CANCEL,
+					   "gtk-apply", GTK_RESPONSE_APPLY,
 					   NULL );
 
     gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
@@ -1040,19 +983,17 @@ static gboolean gsb_bank_edit_bank ( gint bank_number,
 				     GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC );
     gtk_scrolled_window_set_shadow_type ( GTK_SCROLLED_WINDOW(scrolled_window),
 					  GTK_SHADOW_NONE );
-    gtk_container_add ( GTK_CONTAINER ( GTK_DIALOG(dialog)->vbox ), scrolled_window );
+    gtk_container_add ( GTK_CONTAINER ( dialog_get_content_area ( dialog ) ), scrolled_window );
     gtk_widget_set_size_request ( scrolled_window, 600, 400 );
 
-    vbox = gtk_vbox_new ( FALSE, 6 );
-    gtk_container_set_border_width ( GTK_CONTAINER (vbox), 12 );
-    form = gsb_bank_create_form ( vbox, combobox );
-    gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled_window), vbox);
-    gtk_viewport_set_shadow_type ( GTK_VIEWPORT (GTK_BIN(scrolled_window) -> child ),
-				   GTK_SHADOW_NONE );
+    vbox = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER (vbox), BOX_BORDER_WIDTH );
+    gsb_bank_create_form ( vbox, combobox );
+    gtk_container_add ( GTK_CONTAINER (scrolled_window), vbox);
 
-    gtk_widget_show_all ( GTK_DIALOG(dialog)->vbox );
+    gtk_widget_show_all ( dialog );
 
-    if ( bank_number == -2 )
+    if (bank_number == -1)
     {
         gchar *tmp_str;
 
@@ -1062,25 +1003,36 @@ static gboolean gsb_bank_edit_bank ( gint bank_number,
 
     }
     else
-        gsb_bank_update_form ( bank_number, GTK_DIALOG(dialog)->vbox );
+        gsb_bank_update_form ( bank_number, dialog_get_content_area ( dialog ) );
 
-    result = gtk_dialog_run ( GTK_DIALOG(dialog ) );
+    result = gtk_dialog_run ( GTK_DIALOG ( dialog ) );
 
     if ( result == GTK_RESPONSE_APPLY )
     {
-        if ( bank_number == -2 )
-            bank_number = gsb_data_bank_new ( _("New bank") );
+        if (bank_number == -1)
+            bank_number = gsb_data_bank_new (_("New bank"));
 
-        gsb_bank_update_bank_data ( bank_number );
-        gsb_bank_update_selected_line_model ( combobox );
-        gsb_bank_list_set_bank ( combobox, bank_number );
+
+        /* on bloque la fonction de callback */
+        g_signal_handlers_block_by_func (G_OBJECT (combobox),
+                                         G_CALLBACK (gsb_bank_list_changed),
+                                         NULL);
+
+        gsb_bank_update_bank_data (bank_number);
+        gsb_bank_update_selected_line_model (combobox);
+        gsb_bank_list_set_bank (combobox, bank_number);
 
         /* Mark file as modified */
-        gsb_file_set_modified ( TRUE );
+        gsb_file_set_modified (TRUE);
+
+        /* on débloque la fonction de callback */
+        g_signal_handlers_unblock_by_func (G_OBJECT (combobox),
+                                           G_CALLBACK (gsb_bank_list_changed),
+                                           NULL);
     }
     else
     {
-        if ( bank_number == -2 )
+        if (bank_number == -1)
         {
             gint account_number;
 
@@ -1263,8 +1215,7 @@ static gboolean gsb_bank_delete ( GtkWidget *button,
     {
 	gchar* tmpstr = g_strdup_printf ( _("Bank \"%s\" is used by one or several accounts.\nDo you really want to remove it?"),
 							  gsb_data_bank_get_name (bank_number));
-	result = question_yes_no_hint ( _("Confirmation of bank removal"),
-					tmpstr,
+	result = question_yes_no (tmpstr, _("Confirmation of bank removal"),
 					GTK_RESPONSE_NO );
        g_free ( tmpstr );
     }
@@ -1272,8 +1223,7 @@ static gboolean gsb_bank_delete ( GtkWidget *button,
     {
         gchar* tmpstr = g_strdup_printf ( _("Are you sure you want to remove bank \"%s\"?\n"),
 							  gsb_data_bank_get_name (bank_number));
-	result = question_yes_no_hint ( _("Confirmation of bank removal"),
-					tmpstr,
+	result = question_yes_no (tmpstr, _("Confirmation of bank removal"),
 					GTK_RESPONSE_NO );
        g_free ( tmpstr );
     }
