@@ -27,7 +27,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -37,6 +37,7 @@
 /*START_INCLUDE*/
 #include "gsb_currency_link_config.h"
 #include "utils_dates.h"
+#include "dialog.h"
 #include "gsb_currency.h"
 #include "gsb_data_account.h"
 #include "gsb_data_currency.h"
@@ -47,6 +48,8 @@
 #include "structures.h"
 #include "traitement_variables.h"
 #include "utils.h"
+#include "utils_buttons.h"
+#include "utils_prefs.h"
 #include "utils_real.h"
 /*END_INCLUDE*/
 
@@ -69,9 +72,10 @@ static gboolean gsb_currency_link_config_select_currency ( GtkTreeSelection *tre
 /*START_EXTERN*/
 /*END_EXTERN*/
 
+static GtkWidget *delete_link_button;
 
 /** Columns numbers for links list  */
-enum link_list_column {
+enum LinkListColumns {
     LINK_1_COLUMN = 0,
     LINK_CURRENCY1_COLUMN,
     LINK_EQUAL_COLUMN,
@@ -80,9 +84,40 @@ enum link_list_column {
     LINK_DATE_COLUMN,
     LINK_INVALID_COLUMN,
     LINK_NUMBER_COLUMN,
-    NUM_LINKS_COLUMNS,
+	LINK_BACKGROUND_COLOR,
+    NUM_LINKS_COLUMNS
 };
 
+/******************************************************************************/
+/* Private Functions                                                          */
+/******************************************************************************/
+/**
+ *
+ *
+ * \param
+ * \param
+ *
+ * \return
+ * */
+static gboolean gsb_currency_link_config_change_selection (GtkTreeSelection *selection,
+                                                           gpointer null)
+{
+    GSList *tmp_list;
+    gint nbre_links;
+
+    tmp_list = gsb_data_currency_link_get_currency_link_list ();
+    nbre_links = g_slist_length (tmp_list);
+    if (nbre_links)
+        gtk_widget_set_sensitive (delete_link_button, TRUE);
+    else
+        gtk_widget_set_sensitive (delete_link_button, FALSE);
+
+    return FALSE;
+}
+
+/******************************************************************************/
+/* Public Functions                                                           */
+/******************************************************************************/
 /**
  * create the currency_link page for the config
  *
@@ -92,31 +127,28 @@ enum link_list_column {
  * */
 GtkWidget *gsb_currency_link_config_create_page ( void )
 {
-    GtkWidget *vbox_pref, *label, *paddingbox, *hbox;
-    GtkWidget *scrolled_window, *vbox;
+    GtkWidget *vbox_pref, *label, *hbox;
+    GtkWidget *paddinggrid;
+    GtkWidget *scrolled_window;
     GtkWidget *button;
-    GtkTreeView *tree_view;
-    GtkTreeModel *tree_model;
     GtkWidget *entry;
     GtkWidget *combobox;
+    GtkTreeView *tree_view;
+    GtkTreeModel *tree_model;
     gint width_entry = 170;
 
-    vbox_pref = new_vbox_with_title_and_icon ( _("Links between currencies"), "currencies.png" );
-    paddingbox = new_paddingbox_with_title (vbox_pref, TRUE, _("Known links"));
+    vbox_pref = new_vbox_with_title_and_icon (_("Links between currencies"), "gsb-currencies-32.png");
+    paddinggrid = utils_prefs_paddinggrid_new_with_title (vbox_pref, _("Known links"));
 
-    hbox = gtk_hbox_new ( FALSE, 5 );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, TRUE, TRUE, 0);
 
     /* links list */
-    scrolled_window = gtk_scrolled_window_new ( NULL, NULL );
-    gtk_scrolled_window_set_policy ( GTK_SCROLLED_WINDOW ( scrolled_window ),
-				     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    scrolled_window = utils_prefs_scrolled_window_new (NULL, GTK_SHADOW_IN, SW_COEFF_UTIL_PG, SW_MIN_HEIGHT);
+    gtk_grid_attach (GTK_GRID (paddinggrid), scrolled_window, 0, 0, 2, 3);
 
     /* Create it. */
     tree_view = GTK_TREE_VIEW ( gsb_currency_link_config_create_list () );
     tree_model = gtk_tree_view_get_model ( tree_view );
     gtk_container_add ( GTK_CONTAINER ( scrolled_window ), GTK_WIDGET(tree_view) );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), scrolled_window, TRUE, TRUE, 0);
     g_signal_connect ( gtk_tree_view_get_selection (GTK_TREE_VIEW ( tree_view ) ),
 		       "changed",
 		       G_CALLBACK ( gsb_currency_link_config_select_currency ),
@@ -134,42 +166,42 @@ GtkWidget *gsb_currency_link_config_create_page ( void )
 	    gsb_currency_link_config_fill_list ( tree_model );
 
     /* Create Add/Remove buttons */
-    vbox = gtk_vbox_new ( FALSE, 5 );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), vbox, FALSE, FALSE, 0 );
 
     /* Button "Add" */
-    button = gtk_button_new_from_stock (GTK_STOCK_ADD);
+    button = utils_buttons_button_new_from_stock ("gtk-add", _("Add"));
+    gtk_widget_set_margin_end (button, MARGIN_END);
+    utils_widget_set_padding (button, 0, MARGIN_TOP);
     g_signal_connect_swapped ( G_OBJECT ( button ),
 			       "clicked",
 			       G_CALLBACK  ( gsb_currency_link_config_add_link ),
 			       tree_view );
-    gtk_box_pack_start ( GTK_BOX ( vbox ), button, FALSE, FALSE, 5 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), button, 0, 3, 1, 1);
 
     /* Button "Remove" */
-    button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
-    g_signal_connect_swapped ( G_OBJECT ( button ),
+    delete_link_button = utils_buttons_button_new_from_stock ("gtk-remove", _("Remove"));
+    utils_widget_set_padding (delete_link_button, 0, MARGIN_TOP);
+    gtk_widget_set_sensitive (delete_link_button, FALSE);
+    g_signal_connect_swapped ( G_OBJECT ( delete_link_button ),
 			       "clicked",
 			       G_CALLBACK ( gsb_currency_link_config_remove_link ),
 			       tree_view );
-    gtk_box_pack_start ( GTK_BOX ( vbox ), button, FALSE, FALSE, 5 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), delete_link_button, 1, 3, 1, 1);
 
     /* Input form for currencies */
-    paddingbox = new_paddingbox_with_title (vbox_pref, FALSE, _("Link properties"));
+    paddinggrid = utils_prefs_paddinggrid_new_with_title (vbox_pref, _("Link properties"));
 
     /* Create hbox line */
-    hbox = gtk_hbox_new ( FALSE, 5 );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ),
-			 hbox,
-			 TRUE, TRUE, 0 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_widget_set_margin_top (hbox, MARGIN_TOP);
+    gtk_grid_attach (GTK_GRID (paddinggrid), hbox, 0, 0, 1, 1);
 
     gtk_widget_set_sensitive ( hbox, FALSE );
     g_object_set_data ( G_OBJECT (tree_model), "hbox_line", hbox );
 
     /* Create first currency link entry */
     label = gtk_label_new (_("1 "));
-    gtk_box_pack_start ( GTK_BOX (hbox),
-			 label,
-			 FALSE, FALSE, 0 );
+    gtk_box_pack_start ( GTK_BOX (hbox), label, FALSE, FALSE, 0 );
+
     combobox = gsb_currency_make_combobox (TRUE);
     gtk_widget_set_size_request ( combobox, width_entry, -1 );
     g_object_set_data ( G_OBJECT (tree_model), "combobox_1", combobox );
@@ -177,26 +209,20 @@ GtkWidget *gsb_currency_link_config_create_page ( void )
 			       "changed",
 			       G_CALLBACK (gsb_currency_link_config_modify_link),
 			       tree_view );
-    gtk_box_pack_start ( GTK_BOX (hbox),
-			 combobox,
-			 FALSE, FALSE, 0 );
+    gtk_box_pack_start ( GTK_BOX (hbox), combobox, FALSE, FALSE, 0 );
 
     /* create the exchange rate between the 2 currencies */
     label = gtk_label_new (_(" = "));
-    gtk_box_pack_start ( GTK_BOX (hbox),
-			 label,
-			 FALSE, FALSE, 0 );
+    gtk_box_pack_start ( GTK_BOX (hbox), label, FALSE, FALSE, 0 );
+
     entry = gtk_entry_new ();
     gtk_widget_set_size_request ( entry, width_entry/2, -1 );
-    g_object_set_data ( G_OBJECT (tree_model),
-			"exchange_entry", entry );
+    g_object_set_data ( G_OBJECT (tree_model), "exchange_entry", entry );
     g_signal_connect_swapped ( G_OBJECT (entry),
 			       "changed",
 			       G_CALLBACK (gsb_currency_link_config_modify_link),
 			       tree_view );
-    gtk_box_pack_start ( GTK_BOX (hbox),
-			 entry,
-			 FALSE, FALSE, 0 );
+    gtk_box_pack_start ( GTK_BOX (hbox), entry, FALSE, FALSE, 0 );
 
     /* Create second currency link entry */
     combobox = gsb_currency_make_combobox (TRUE);
@@ -206,12 +232,11 @@ GtkWidget *gsb_currency_link_config_create_page ( void )
 			       "changed",
 			       G_CALLBACK (gsb_currency_link_config_modify_link),
 			       tree_view );
-    gtk_box_pack_start ( GTK_BOX (hbox),
-			 combobox,
-			 FALSE, FALSE, 0 );
+    gtk_box_pack_start ( GTK_BOX (hbox), combobox, FALSE, FALSE, 0 );
 
     /* create fixed exchange rate */
     button = gtk_check_button_new_with_label ( _("Fixed exchange rate") );
+    gtk_widget_set_margin_top (button, MARGIN_TOP);
     gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( button ), FALSE );
     gtk_widget_set_sensitive ( button, FALSE );
     g_object_set_data ( G_OBJECT ( tree_model ), "fixed_button", button );
@@ -219,21 +244,23 @@ GtkWidget *gsb_currency_link_config_create_page ( void )
                         "toggled",
                         G_CALLBACK ( gsb_currency_link_config_button_fixed_changed ),
                         tree_view );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), button, FALSE, FALSE, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), button, 0, 1, 1, 1);
 
     /* Create warning label */
     label = gtk_label_new (NULL);
+    gtk_widget_set_margin_top (label, 2*MARGIN_TOP);
     g_object_set_data ( G_OBJECT (tree_model), "warning_label", label );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ),
-			 label,
-			 FALSE, FALSE, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 2, 1, 1);
 
-    return ( vbox_pref );
+	/* set alternate color of treeview */
+	utils_set_list_store_background_color (GTK_WIDGET (tree_view), LINK_BACKGROUND_COLOR);
+
+	return ( vbox_pref );
 }
 
 
 /**
- * create the tree wich contains the currency list
+ * create the tree which contains the currency list
  * used both for the currency known list, and the currency to add list
  *
  * \param
@@ -242,6 +269,7 @@ GtkWidget *gsb_currency_link_config_create_page ( void )
  */
 GtkWidget *gsb_currency_link_config_create_list ( void )
 {
+    GtkTreeSelection *selection;
     GtkListStore * model;
     GtkWidget * treeview;
     gint i;
@@ -263,21 +291,27 @@ GtkWidget *gsb_currency_link_config_create_list ( void )
 	   LINK_EXCHANGE_COLUMN,
 	   LINK_CURRENCY2_COLUMN,
        LINK_DATE_COLUMN,
-	   LINK_NUMBER_COLUMN */
-    model = gtk_list_store_new ( NUM_LINKS_COLUMNS,
-				 G_TYPE_STRING,
-				 G_TYPE_STRING,
-				 G_TYPE_STRING,
-				 G_TYPE_STRING,
-				 G_TYPE_STRING,
-				 G_TYPE_STRING,
-				 G_TYPE_STRING,
-				 G_TYPE_INT );
+	   LINK_NUMBER_COLUMN
+	   LINK_BACKGROUND_COLOR */
+    model = gtk_list_store_new (NUM_LINKS_COLUMNS,
+								G_TYPE_STRING,
+								G_TYPE_STRING,
+								G_TYPE_STRING,
+								G_TYPE_STRING,
+								G_TYPE_STRING,
+								G_TYPE_STRING,
+								G_TYPE_STRING,
+								G_TYPE_INT,
+								GDK_TYPE_RGBA);
 
     /* Create tree tree_view */
     treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(model));
+ 	gtk_widget_set_name (treeview, "tree_view");
     g_object_unref (G_OBJECT(model));
-    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
+
+    /* connect the selection */
+    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
+    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_SINGLE);
 
     /* for all the columns it's a text */
     cell_renderer = gtk_cell_renderer_text_new ();
@@ -289,26 +323,27 @@ GtkWidget *gsb_currency_link_config_create_list ( void )
      * the last value of the model mustn't be to text...
      * so LINK_NUMBER_COLUMN must be the first column after the last column showed */
 
-    for (i=0 ; i< LINK_NUMBER_COLUMN; i++ )
+    for (i=0 ; i< LINK_NUMBER_COLUMN - 1; i++ )
     {
 	GtkTreeViewColumn *column = NULL;
 
 	if ( i == LINK_INVALID_COLUMN )
 	{
-	    column = gtk_tree_view_column_new_with_attributes ( title[i],
-								gtk_cell_renderer_pixbuf_new (),
-								"stock-id", i,
-								NULL );
+	    column = gtk_tree_view_column_new_with_attributes (title[i],
+														   gtk_cell_renderer_pixbuf_new (),
+														   "stock-id", i,
+														   "cell-background-rgba", LINK_BACKGROUND_COLOR,
+														   NULL);
 	}
 	else
 	{
-	    column = gtk_tree_view_column_new_with_attributes ( title[i],
-								cell_renderer,
-								"text", i,
-								NULL );
+	    column = gtk_tree_view_column_new_with_attributes (title[i],
+														   cell_renderer,
+														   "text", i,
+														   "cell-background-rgba", LINK_BACKGROUND_COLOR,
+														   NULL);
 	    gtk_tree_view_column_set_sizing ( column,
 					      GTK_TREE_VIEW_COLUMN_AUTOSIZE );
-	    gtk_tree_view_column_set_expand ( column, TRUE );
 	}
 	gtk_tree_view_column_set_expand ( column, TRUE );
 	gtk_tree_view_append_column ( GTK_TREE_VIEW(treeview),
@@ -319,6 +354,12 @@ GtkWidget *gsb_currency_link_config_create_list ( void )
     gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE(model),
 					  LINK_CURRENCY1_COLUMN, GTK_SORT_ASCENDING);
 
+    /* Set signal */
+    g_signal_connect (G_OBJECT (selection),
+                      "changed",
+                      G_CALLBACK (gsb_currency_link_config_change_selection),
+                      NULL);
+
     return treeview;
 }
 
@@ -377,7 +418,7 @@ void gsb_currency_link_config_append_line ( GtkTreeModel *model,
     strdate = gsb_format_gdate ( gsb_data_currency_link_get_modified_date ( link_number ) );
 
     if ( gsb_data_currency_link_get_invalid_link (link_number))
-	invalid = GTK_STOCK_DIALOG_WARNING;
+	invalid = "gtk-dialog-warning";
     else
 	invalid = NULL;
 
@@ -426,25 +467,18 @@ gboolean gsb_currency_link_config_select_currency ( GtkTreeSelection *tree_selec
 					   &iter ))
 	return FALSE;
 
-    gtk_tree_model_get ( GTK_TREE_MODEL (model),
-			 &iter,
-			 LINK_NUMBER_COLUMN, &link_number,
-			 -1 );
+    gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, LINK_NUMBER_COLUMN, &link_number, -1);
 
     /* normally should not happen */
     if (!link_number)
-	    return FALSE;
+        return FALSE;
 
-    gtk_widget_set_sensitive (  GTK_WIDGET (
-                        g_object_get_data ( G_OBJECT ( model ), "hbox_line") ),
-			            TRUE );
+    gtk_widget_set_sensitive (GTK_WIDGET (g_object_get_data (G_OBJECT (model), "hbox_line")),
+                                  TRUE );
 
-    combobox_1 = g_object_get_data ( G_OBJECT (model),
-				     "combobox_1" );
-    combobox_2 = g_object_get_data ( G_OBJECT (model),
-				     "combobox_2" );
-    exchange_entry = g_object_get_data ( G_OBJECT (model),
-					 "exchange_entry" );
+    combobox_1 = g_object_get_data ( G_OBJECT (model), "combobox_1" );
+    combobox_2 = g_object_get_data ( G_OBJECT (model), "combobox_2" );
+    exchange_entry = g_object_get_data ( G_OBJECT (model), "exchange_entry" );
     button = g_object_get_data ( G_OBJECT (model), "fixed_button" );
     gtk_widget_set_sensitive ( button, TRUE );
 
@@ -489,8 +523,7 @@ gboolean gsb_currency_link_config_select_currency ( GtkTreeSelection *tree_selec
 				      tree_view );
 
     /* set or hide the warning label */
-    label = g_object_get_data (G_OBJECT (model),
-			       "warning_label");
+    label = g_object_get_data (G_OBJECT (model), "warning_label");
 
     if ( gsb_data_currency_link_get_invalid_link (link_number))
     {
@@ -523,7 +556,7 @@ gboolean gsb_currency_link_config_modify_link ( GtkWidget *tree_view )
     GtkWidget *label;
 	gchar* tmpstr;
     gchar *strdate;
-    gsb_real number;
+    GsbReal number;
 
     if ( !gtk_tree_selection_get_selected ( gtk_tree_view_get_selection (
                         GTK_TREE_VIEW ( tree_view ) ),
@@ -550,7 +583,7 @@ gboolean gsb_currency_link_config_modify_link ( GtkWidget *tree_view )
     number = utils_real_get_from_string ( gtk_entry_get_text ( GTK_ENTRY (exchange_entry) ) );
     if ( number.exponent > 8 )
         gtk_entry_set_max_length (GTK_ENTRY (exchange_entry),
-                        strlen( gtk_entry_get_text ( GTK_ENTRY ( exchange_entry ) ) - 1) );
+                        (gint)strlen( gtk_entry_get_text ( GTK_ENTRY ( exchange_entry ) ) - 1) );
 
     gsb_data_currency_link_set_first_currency ( link_number,
 						gsb_currency_get_currency_from_combobox (combobox_1));
@@ -562,7 +595,7 @@ gboolean gsb_currency_link_config_modify_link ( GtkWidget *tree_view )
     strdate = gsb_format_gdate ( gsb_data_currency_link_get_modified_date ( link_number ) );
 
     if ( gsb_data_currency_link_get_invalid_link (link_number))
-	invalid = GTK_STOCK_DIALOG_WARNING;
+	invalid = "gtk-dialog-warning";
     else
 	invalid = NULL;
 
@@ -610,6 +643,18 @@ gboolean gsb_currency_link_config_add_link ( GtkWidget *tree_view )
     gint link_number;
     GtkTreeModel *model;
     GtkTreeIter iter;
+    GSList *tmp_list;
+    gint nbre_devises;
+
+    tmp_list = gsb_data_currency_get_currency_list ();
+    nbre_devises = g_slist_length (tmp_list);
+    if (nbre_devises == 1)
+    {
+        dialogue_hint (_("You must create at least another currency to continue."),
+                        _("The number of currencies is insufficient"));
+
+        return FALSE;
+    }
 
     model = gtk_tree_view_get_model ( GTK_TREE_VIEW (tree_view));
 
@@ -619,17 +664,18 @@ gboolean gsb_currency_link_config_add_link ( GtkWidget *tree_view )
      * so we set the 2 currencies on the number 1, even if it makes that link
      * invalid, but it's not a problem because i think the user will change
      * it quickly... */
-    gsb_data_currency_link_set_first_currency ( link_number,
-						1 );
-    gsb_data_currency_link_set_second_currency ( link_number,
-						 1 );
+    gsb_data_currency_link_set_first_currency ( link_number, 1 );
+    gsb_data_currency_link_set_second_currency ( link_number, 1 );
+
     gsb_currency_link_config_append_line ( model,
 					   link_number,
 					   &iter );
-    gtk_tree_selection_select_iter ( gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view)),
-				     &iter );
+
+    gtk_tree_selection_select_iter ( gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view)), &iter );
+	utils_set_list_store_background_color (GTK_WIDGET (tree_view), LINK_BACKGROUND_COLOR);
     gsb_file_set_modified ( TRUE );
-    return FALSE;
+
+	return FALSE;
 }
 
 
@@ -651,29 +697,27 @@ gboolean gsb_currency_link_config_remove_link ( GtkWidget *tree_view )
     if ( gtk_tree_selection_get_selected ( gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view)),
 					   &model,
 					   &iter ))
-    {
-    GtkWidget *label;
-	gint link_number;
+	{
+		GtkWidget *label;
+		gint link_number;
 
-	gtk_tree_model_get ( GTK_TREE_MODEL (model),
-			     &iter,
-			     LINK_NUMBER_COLUMN, &link_number,
-			     -1 );
-	gtk_list_store_remove ( GTK_LIST_STORE (model),
-				&iter );
-	gsb_data_currency_link_remove (link_number);
-	gtk_widget_set_sensitive ( GTK_WIDGET ( g_object_get_data ( G_OBJECT (model),
-								    "hbox_line")),
-				   FALSE );
+		gtk_tree_model_get ( GTK_TREE_MODEL (model),
+				&iter,
+				LINK_NUMBER_COLUMN, &link_number,
+				-1 );
+		/* set here to sensitive the delete_link_button */
+		gsb_data_currency_link_remove (link_number);
+		gtk_list_store_remove ( GTK_LIST_STORE (model), &iter );
+		gtk_widget_set_sensitive ( GTK_WIDGET ( g_object_get_data ( G_OBJECT (model), "hbox_line")),
+				FALSE );
 
-    /* hide the warning label */
-    label = g_object_get_data (G_OBJECT (model),
-			       "warning_label");
-    if ( GTK_WIDGET_VISIBLE ( label ) )
-        gtk_widget_hide (label);
+		/* hide the warning label */
+		label = g_object_get_data (G_OBJECT (model), "warning_label");
+		if ( gtk_widget_get_visible ( label ) )
+			gtk_widget_hide (label);
 
-        gsb_file_set_modified ( TRUE );
-    }
+		gsb_file_set_modified ( TRUE );
+	}
     return FALSE;
 }
 
@@ -686,7 +730,7 @@ gboolean gsb_currency_link_config_key_press ( GtkWidget *tree_view, GdkEventKey
 {
     switch ( ev -> keyval )
     {
-    case GDK_Delete:    /*  del  */
+    case GDK_KEY_Delete:    /*  del  */
         gsb_currency_link_config_remove_link ( tree_view );
         return TRUE;
         break;
