@@ -26,14 +26,14 @@
  * work with the archive store structure, no GUI here
  * the archive store are used to show the archive in the list of transactions
  * as an archive by itself contains several accounts and no balance for each account
- * at the opening of grisbi, we create an intermediate list of structures wich contains
+ * at the opening of grisbi, we create an intermediate list of structures which contains
  * the link to the archive, but 1 structure per account, with the number of transactions
  * and the balance for each.
  */
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -314,7 +314,7 @@ gint gsb_data_archive_store_get_account_number ( gint archive_store_number )
  *
  * \return the  of the archive or 0 if fail
  * */
-gsb_real gsb_data_archive_store_get_balance ( gint archive_store_number )
+GsbReal gsb_data_archive_store_get_balance ( gint archive_store_number )
 {
     struct_store_archive *archive;
 
@@ -477,10 +477,10 @@ static gint gsb_data_archive_store_new ( void )
  *
  *
  */
-gsb_real gsb_data_archive_store_get_archives_balance ( gint account_number )
+GsbReal gsb_data_archive_store_get_archives_balance ( gint account_number )
 {
     GSList *tmp_list;
-    gsb_real balance = null_real;
+    GsbReal balance = null_real;
 
     tmp_list = gsb_data_archive_store_get_archives_list ( );
 
