@@ -1,6 +1,6 @@
 /* ************************************************************************** */
 /*                                                                            */
-/*     Copyright (C)    2000-2008 Cdric Auger (cedric@grisbi.org)            */
+/*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
 /*          2009-2015 Pierre Biava (grisbi@pierre.biava.name)                 */
 /*          http://www.grisbi.org                                             */
@@ -28,7 +28,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -36,6 +36,7 @@
 
 /*START_INCLUDE*/
 #include "gsb_data_budget.h"
+#include "grisbi_win.h"
 #include "meta_budgetary.h"
 #include "imputation_budgetaire.h"
 #include "gsb_data_form.h"
@@ -49,14 +50,13 @@
 /*END_INCLUDE*/
 
 
-/**
- * \struct
- * Describe a budget
- */
-typedef struct
+/* struct Describe a budget */
+typedef struct _BudgetStruct		BudgetStruct;
+
+struct _BudgetStruct
 {
     /** @name budget content */
-    guint budget_number;
+    gint budget_number;
     gchar *budget_name;
     gint budget_type;		/**< 0:credit / 1:debit  */
 
@@ -65,37 +65,36 @@ typedef struct
     /** @name gui budget list content (not saved) */
     gint budget_nb_transactions;
     gint budget_nb_direct_transactions;
-    gsb_real budget_balance;
-    gsb_real budget_direct_balance;
-} struct_budget;
+    GsbReal budget_balance;
+    GsbReal budget_direct_balance;
+};
 
 
-/**
- * \struct
- * Describe a sub-budget
- */
-typedef struct
+/* struct Describe a sub-budget */
+typedef struct _SubBudgetStruct		SubBudgetStruct;
+
+struct _SubBudgetStruct
 {
     /** @name sub-budget content */
-    guint sub_budget_number;
+    gint sub_budget_number;
     gchar *sub_budget_name;
 
-    guint mother_budget_number;
+    gint mother_budget_number;
 
     /** @name gui sub-budget list content (not saved)*/
     gint sub_budget_nb_transactions;
-    gsb_real sub_budget_balance;
-} struct_sub_budget;
+    GsbReal sub_budget_balance;
+};
 
 
 /*START_STATIC*/
-static void _gsb_data_budget_free ( struct_budget* budget );
-static void _gsb_data_sub_budget_free ( struct_sub_budget* sub_budget );
+static void _gsb_data_budget_free ( BudgetStruct* budget );
+static void _gsb_data_sub_budget_free ( SubBudgetStruct* sub_budget );
 static GSList *gsb_data_budget_append_sub_budget_to_list ( GSList *budget_list,
                         GSList *sub_budget_list );
-static gint gsb_data_budget_get_pointer_from_name_in_glist ( struct_budget *budget,
+static gint gsb_data_budget_get_pointer_from_name_in_glist ( BudgetStruct *budget,
                         const gchar *name );
-static gint gsb_data_budget_get_pointer_from_sub_name_in_glist ( struct_sub_budget *sub_budget,
+static gint gsb_data_budget_get_pointer_from_sub_name_in_glist ( SubBudgetStruct *sub_budget,
                         const gchar *name );
 static gpointer gsb_data_budget_get_structure_in_list ( gint no_budget,
                         GSList *list );
@@ -105,22 +104,22 @@ static gint gsb_data_budget_new ( const gchar *name );
 static gint gsb_data_budget_new_sub_budget ( gint budget_number,
                         const gchar *name );
 static void gsb_data_budget_reset_counters ( void );
-static gint gsb_data_sub_budget_compare ( struct_sub_budget * a, struct_sub_budget * b );
+static gint gsb_data_sub_budget_compare ( SubBudgetStruct * a, SubBudgetStruct * b );
 /*END_STATIC*/
 
 /*START_EXTERN*/
 /*END_EXTERN*/
 
-/** contains the g_slist of struct_budget */
+/** contains the g_slist of BudgetStruct */
 static GSList *budget_list = NULL;
 
 /** a pointer to the last budget used (to increase the speed) */
-static struct_budget *budget_buffer;
-static struct_sub_budget *sub_budget_buffer;
+static BudgetStruct *budget_buffer;
+static SubBudgetStruct *sub_budget_buffer;
 
 /** a empty budget for the list of budgets
  * the number of the empty budget is 0 */
-static struct_budget *empty_budget = NULL;
+static BudgetStruct *empty_budget = NULL;
 
 
 /**
@@ -134,22 +133,13 @@ gboolean gsb_data_budget_init_variables ( void )
 {
     if ( budget_list )
     {
-        /* free memory used by the budget list */
-        GSList *tmp_list = budget_list;
-        while ( tmp_list )
-        {
-            struct_budget *budget;
-            budget = tmp_list -> data;
-            tmp_list = tmp_list -> next;
-	    _gsb_data_budget_free ( budget );
-        }
-	g_slist_free (budget_list);
+        g_slist_free_full ( budget_list, (GDestroyNotify) _gsb_data_budget_free );
+        budget_list = NULL;
     }
-    budget_list = NULL;
 
     /* recreate the empty budget */
     _gsb_data_budget_free ( empty_budget );
-    empty_budget = g_malloc0 ( sizeof ( struct_budget ));
+    empty_budget = g_malloc0 ( sizeof ( BudgetStruct ));
     empty_budget -> budget_name = g_strdup(_("No budget line"));
 
     budget_buffer = NULL;
@@ -161,36 +151,27 @@ gboolean gsb_data_budget_init_variables ( void )
 
 
 /**
- * This internal function is used to free the memory used by a struct_budget structure
+ * This internal function is used to free the memory used by a BudgetStruct structure
  */
-static void _gsb_data_budget_free ( struct_budget* budget )
+static void _gsb_data_budget_free ( BudgetStruct* budget )
 {
     if ( ! budget )
         return;
+
     /* free memory used by sub-bugdgets */
     if ( budget -> sub_budget_list)
-    {
-        GSList* sub_tmp_list = budget -> sub_budget_list;
-        while ( sub_tmp_list )
-        {
-	    struct_sub_budget *sub_budget;
-	    sub_budget = sub_tmp_list -> data;
-	    sub_tmp_list = sub_tmp_list -> next;
-	    _gsb_data_sub_budget_free ( sub_budget );
-        }
-	g_slist_free ( budget -> sub_budget_list );
-    }
-    if ( budget -> budget_name )
-	g_free ( budget -> budget_name);
+        g_slist_free_full ( budget -> sub_budget_list, (GDestroyNotify) _gsb_data_sub_budget_free );
+    g_free ( budget -> budget_name);
     g_free ( budget );
+
     if ( budget_buffer == budget )
-	budget_buffer = NULL;
+        budget_buffer = NULL;
 }
 
 /**
- * This internal function is used to free the memory used by a struct_sub_budget structure
+ * This internal function is used to free the memory used by a SubBudgetStruct structure
  */
-static void _gsb_data_sub_budget_free ( struct_sub_budget* sub_budget )
+static void _gsb_data_sub_budget_free ( SubBudgetStruct* sub_budget )
 {
     if ( ! sub_budget )
         return;
@@ -260,7 +241,7 @@ gpointer gsb_data_budget_get_structure_in_list ( gint no_budget,
 
     while ( tmp )
     {
-	struct_budget *budget;
+	BudgetStruct *budget;
 
 	budget = tmp -> data;
 
@@ -288,7 +269,7 @@ gpointer gsb_data_budget_get_sub_budget_structure ( gint no_budget,
                         gint no_sub_budget )
 {
     GSList *tmp;
-    struct_budget *budget;
+    BudgetStruct *budget;
 
     if (!no_budget
 	||
@@ -314,7 +295,7 @@ gpointer gsb_data_budget_get_sub_budget_structure ( gint no_budget,
 
     while ( tmp )
     {
-	struct_sub_budget *sub_budget;
+	SubBudgetStruct *sub_budget;
 
 	sub_budget = tmp -> data;
 
@@ -352,7 +333,7 @@ GSList *gsb_data_budget_get_budgets_list ( void )
  * */
 GSList *gsb_data_budget_get_sub_budget_list ( gint no_budget )
 {
-    struct_budget *budget;
+    BudgetStruct *budget;
 
     budget = gsb_data_budget_get_structure ( no_budget );
 
@@ -373,7 +354,7 @@ GSList *gsb_data_budget_get_sub_budget_list ( gint no_budget )
  * */
 gint gsb_data_budget_get_no_budget ( gpointer budget_ptr )
 {
-    struct_budget *budget;
+    BudgetStruct *budget;
 
     if ( !budget_ptr )
 	return 0;
@@ -393,7 +374,7 @@ gint gsb_data_budget_get_no_budget ( gpointer budget_ptr )
  * */
 gint gsb_data_budget_get_no_sub_budget ( gpointer sub_budget_ptr )
 {
-    struct_sub_budget *sub_budget;
+    SubBudgetStruct *sub_budget;
 
     if ( !sub_budget_ptr )
 	return 0;
@@ -419,7 +400,7 @@ gint gsb_data_budget_max_number ( void )
 
     while ( tmp )
     {
-	struct_budget *budget;
+	BudgetStruct *budget;
 
 	budget = tmp -> data;
 
@@ -441,17 +422,20 @@ gint gsb_data_budget_max_number ( void )
  * */
 gint gsb_data_budget_max_sub_budget_number ( gint budget_number )
 {
-    struct_budget *budget;
+    BudgetStruct *budget;
     GSList *tmp;
     gint number_tmp = 0;
 
     budget = gsb_data_budget_get_structure ( budget_number );
 
+    if (NULL == budget)
+        return 0;
+
     tmp = budget -> sub_budget_list;
 
     while ( tmp )
     {
-	struct_sub_budget *sub_budget;
+	SubBudgetStruct *sub_budget;
 
 	sub_budget = tmp -> data;
 
@@ -504,9 +488,9 @@ gint gsb_data_budget_new ( const gchar *name )
  * */
 gint gsb_data_budget_new_with_number ( gint number )
 {
-    struct_budget *budget;
+    BudgetStruct *budget;
 
-    budget = g_malloc0 ( sizeof ( struct_budget ));
+    budget = g_malloc0 ( sizeof ( BudgetStruct ));
     budget -> budget_number = number;
 
     budget_list = g_slist_append ( budget_list,
@@ -530,7 +514,8 @@ gint gsb_data_budget_new_with_number ( gint number )
  * */
 gboolean gsb_data_budget_remove ( gint no_budget )
 {
-    struct_budget *budget;
+    BudgetStruct *budget;
+	GtkWidget *combofix;
 
     budget = gsb_data_budget_get_structure ( no_budget );
 
@@ -542,6 +527,10 @@ gboolean gsb_data_budget_remove ( gint no_budget )
 
     _gsb_data_budget_free (budget);
 
+	combofix = gsb_form_widget_get_widget (TRANSACTION_FORM_BUDGET);
+	if (combofix)
+		gsb_budget_update_combofix (TRUE);
+
     return TRUE;
 }
 
@@ -558,8 +547,9 @@ gboolean gsb_data_budget_remove ( gint no_budget )
 gboolean gsb_data_budget_sub_budget_remove ( gint no_budget,
                         gint no_sub_budget )
 {
-    struct_budget *budget;
-    struct_sub_budget *sub_budget;
+    BudgetStruct *budget;
+    SubBudgetStruct *sub_budget;
+	GtkWidget *combofix;
 
     budget = gsb_data_budget_get_structure ( no_budget );
     sub_budget = gsb_data_budget_get_sub_budget_structure ( no_budget,
@@ -575,7 +565,11 @@ gboolean gsb_data_budget_sub_budget_remove ( gint no_budget,
 
     _gsb_data_sub_budget_free (sub_budget);
 
-    return TRUE;
+	combofix = gsb_form_widget_get_widget (TRANSACTION_FORM_BUDGET);
+	if (combofix)
+		gsb_budget_update_combofix (TRUE);
+
+	return TRUE;
 }
 
 
@@ -619,15 +613,15 @@ gint gsb_data_budget_new_sub_budget ( gint budget_number,
 gint gsb_data_budget_new_sub_budget_with_number ( gint number,
                         gint budget_number)
 {
-    struct_budget *budget;
-    struct_sub_budget *sub_budget;
+    BudgetStruct *budget;
+    SubBudgetStruct *sub_budget;
 
     budget = gsb_data_budget_get_structure ( budget_number );
 
     if (!budget)
 	return 0;
 
-    sub_budget = g_malloc0 ( sizeof (struct_sub_budget));
+    sub_budget = g_malloc0 ( sizeof (SubBudgetStruct));
     sub_budget -> sub_budget_number = number;
     sub_budget -> mother_budget_number = budget_number;
 
@@ -642,7 +636,7 @@ gint gsb_data_budget_new_sub_budget_with_number ( gint number,
 
 
 /**
- * return the number of the budget wich has the name in param
+ * return the number of the budget which has the name in param
  * create it if necessary
  *
  * \param name the name of the budget
@@ -670,7 +664,7 @@ gint gsb_data_budget_get_number_by_name ( const gchar *name,
 
     if ( list_tmp )
     {
-	struct_budget *budget;
+	BudgetStruct *budget;
 
 	budget = list_tmp -> data;
 	budget_number = budget -> budget_number;
@@ -690,7 +684,7 @@ gint gsb_data_budget_get_number_by_name ( const gchar *name,
 
 
 /**
- * return the number of the sub-budget wich has the name in param
+ * return the number of the sub-budget which has the name in param
  * create it if necessary
  *
  * \param budget_number the number of the budget
@@ -704,7 +698,7 @@ gint gsb_data_budget_get_sub_budget_number_by_name ( gint budget_number,
                         gboolean create )
 {
     GSList *list_tmp;
-    struct_budget *budget;
+    BudgetStruct *budget;
     gint sub_budget_number = 0;
 
     if (!name || !strlen (name))
@@ -721,7 +715,7 @@ gint gsb_data_budget_get_sub_budget_number_by_name ( gint budget_number,
 
     if ( list_tmp )
     {
-        struct_sub_budget *sub_budget;
+        SubBudgetStruct *sub_budget;
 
         sub_budget = list_tmp -> data;
         sub_budget_number = sub_budget -> sub_budget_number;
@@ -749,7 +743,7 @@ gint gsb_data_budget_get_sub_budget_number_by_name ( gint budget_number,
  *
  * \return 0 if it's the same name
  * */
-gint gsb_data_budget_get_pointer_from_name_in_glist ( struct_budget *budget,
+gint gsb_data_budget_get_pointer_from_name_in_glist ( BudgetStruct *budget,
                         const gchar *name )
 {
     return ( my_strcasecmp ( budget -> budget_name, name ) );
@@ -765,7 +759,7 @@ gint gsb_data_budget_get_pointer_from_name_in_glist ( struct_budget *budget,
  *
  * \return 0 if it's the same name
  * */
-gint gsb_data_budget_get_pointer_from_sub_name_in_glist ( struct_sub_budget *sub_budget,
+gint gsb_data_budget_get_pointer_from_sub_name_in_glist ( SubBudgetStruct *sub_budget,
                         const gchar *name )
 {
     return ( my_strcasecmp ( sub_budget -> sub_budget_name, name ));
@@ -787,11 +781,9 @@ gchar *gsb_data_budget_get_name ( gint no_budget,
                     gint no_sub_budget,
                     const gchar *return_value_error )
 {
-    struct_budget *budget;
+    BudgetStruct *budget;
     gchar *return_value;
 
-    devel_debug (NULL);
-
     budget = gsb_data_budget_get_structure ( no_budget );
 
     if (!budget || !no_budget)
@@ -801,7 +793,7 @@ gchar *gsb_data_budget_get_name ( gint no_budget,
 
     if ( no_sub_budget )
     {
-	struct_sub_budget *sub_budget;
+	SubBudgetStruct *sub_budget;
 
 	sub_budget = gsb_data_budget_get_sub_budget_structure ( no_budget,
 								no_sub_budget );
@@ -831,7 +823,7 @@ gchar *gsb_data_budget_get_name ( gint no_budget,
 gboolean gsb_data_budget_set_name ( gint no_budget,
                     const gchar *name )
 {
-    struct_budget *budget;
+    BudgetStruct *budget;
 
     budget = gsb_data_budget_get_structure ( no_budget );
 
@@ -873,7 +865,7 @@ gchar *gsb_data_budget_get_sub_budget_name ( gint no_budget,
                         gint no_sub_budget,
                         const gchar *return_value_error )
 {
-    struct_sub_budget *sub_budget;
+    SubBudgetStruct *sub_budget;
 
     sub_budget = gsb_data_budget_get_sub_budget_structure ( no_budget,
 							    no_sub_budget );
@@ -899,7 +891,7 @@ gboolean gsb_data_budget_set_sub_budget_name ( gint no_budget,
                         gint no_sub_budget,
                         const gchar *name )
 {
-    struct_sub_budget *sub_budget;
+    SubBudgetStruct *sub_budget;
 
     sub_budget = gsb_data_budget_get_sub_budget_structure ( no_budget,
 							    no_sub_budget );
@@ -930,7 +922,7 @@ gboolean gsb_data_budget_set_sub_budget_name ( gint no_budget,
  * \return a g_slist of g_slist of gchar *
  * */
 GSList *gsb_data_budget_get_name_list ( gboolean set_debit,
-                        gboolean set_credit )
+									   gboolean set_credit )
 {
     GSList *return_list;
     GSList *tmp_list;
@@ -942,49 +934,43 @@ GSList *gsb_data_budget_get_name_list ( gboolean set_debit,
     /* fill debit_list and/or credit_list and them sub-budgets */
     tmp_list = budget_list;
 
-    while ( tmp_list )
+    while (tmp_list)
     {
-	struct_budget *budget;
+		BudgetStruct *budget;
 
-	budget = tmp_list -> data;
+		budget = tmp_list->data;
 
-	if ( budget -> budget_type )
-	{
-	    if ( set_debit )
-	    {
-		debit_list = g_slist_append ( debit_list,
-					      budget -> budget_name);
-		debit_list = gsb_data_budget_append_sub_budget_to_list ( debit_list,
-									 budget -> sub_budget_list);
-	    }
-	}
-	else
-	{
-	    if ( set_credit )
-	    {
-		credit_list = g_slist_append ( credit_list,
-					       budget -> budget_name);
-		credit_list = gsb_data_budget_append_sub_budget_to_list ( credit_list,
-									  budget -> sub_budget_list);
-	    }
-	}
-	tmp_list = tmp_list -> next;
+		if ( budget->budget_type )
+		{
+			if (set_debit)
+			{
+				debit_list = g_slist_append (debit_list, g_strdup (budget->budget_name));
+				debit_list = gsb_data_budget_append_sub_budget_to_list (debit_list,
+																		budget->sub_budget_list);
+			}
+		}
+		else
+		{
+			if (set_credit)
+			{
+				credit_list = g_slist_append (credit_list, g_strdup (budget->budget_name));
+				credit_list = gsb_data_budget_append_sub_budget_to_list (credit_list,
+																		 budget->sub_budget_list);
+			}
+		}
+		tmp_list = tmp_list->next;
     }
 
     /* append what we need to return_list */
 
     if ( set_debit )
-	return_list = g_slist_append ( return_list,
-				       debit_list );
+		return_list = g_slist_append (return_list, debit_list);
     if ( set_credit )
-	return_list = g_slist_append ( return_list,
-				       credit_list );
+		return_list = g_slist_append (return_list, credit_list);
 
     return return_list;
 }
 
-
-
 /**
  * append the sub-budgets name with a tab at the beginning
  * to the list of budgets given in param
@@ -1006,7 +992,7 @@ GSList *gsb_data_budget_append_sub_budget_to_list ( GSList *budget_list,
 
     while (tmp_list)
     {
-	struct_sub_budget *sub_budget;
+	SubBudgetStruct *sub_budget;
 
 	sub_budget = tmp_list -> data;
 
@@ -1033,7 +1019,7 @@ GSList *gsb_data_budget_append_sub_budget_to_list ( GSList *budget_list,
  * */
 gint gsb_data_budget_get_type ( gint no_budget )
 {
-    struct_budget *budget;
+    BudgetStruct *budget;
 
     budget = gsb_data_budget_get_structure ( no_budget );
 
@@ -1056,7 +1042,7 @@ gint gsb_data_budget_get_type ( gint no_budget )
 gboolean gsb_data_budget_set_type ( gint no_budget,
                         gint budget_type )
 {
-    struct_budget *budget;
+    BudgetStruct *budget;
 
     budget = gsb_data_budget_get_structure ( no_budget );
 
@@ -1077,7 +1063,7 @@ gboolean gsb_data_budget_set_type ( gint no_budget,
  * */
 gint gsb_data_budget_get_nb_transactions ( gint no_budget )
 {
-    struct_budget *budget;
+    BudgetStruct *budget;
 
     budget = gsb_data_budget_get_structure ( no_budget );
 
@@ -1100,7 +1086,7 @@ gint gsb_data_budget_get_nb_transactions ( gint no_budget )
 gint gsb_data_budget_get_sub_budget_nb_transactions ( gint no_budget,
                         gint no_sub_budget )
 {
-    struct_sub_budget *sub_budget;
+    SubBudgetStruct *sub_budget;
 
     sub_budget = gsb_data_budget_get_sub_budget_structure ( no_budget,
 							    no_sub_budget );
@@ -1122,7 +1108,7 @@ gint gsb_data_budget_get_sub_budget_nb_transactions ( gint no_budget,
  * */
 gint gsb_data_budget_get_nb_direct_transactions ( gint no_budget )
 {
-    struct_budget *budget;
+    BudgetStruct *budget;
 
     budget = gsb_data_budget_get_structure ( no_budget );
 
@@ -1142,9 +1128,9 @@ gint gsb_data_budget_get_nb_direct_transactions ( gint no_budget )
  *
  * \return balance of the budget or 0 if problem
  * */
-gsb_real gsb_data_budget_get_balance ( gint no_budget )
+GsbReal gsb_data_budget_get_balance ( gint no_budget )
 {
-    struct_budget *budget;
+    BudgetStruct *budget;
 
     budget = gsb_data_budget_get_structure ( no_budget );
 
@@ -1163,10 +1149,10 @@ gsb_real gsb_data_budget_get_balance ( gint no_budget )
  *
  * \return balance of the sub-budget or 0 if problem
  * */
-gsb_real gsb_data_budget_get_sub_budget_balance ( gint no_budget,
+GsbReal gsb_data_budget_get_sub_budget_balance ( gint no_budget,
                         gint no_sub_budget )
 {
-    struct_sub_budget *sub_budget;
+    SubBudgetStruct *sub_budget;
 
     sub_budget = gsb_data_budget_get_sub_budget_structure ( no_budget,
 							    no_sub_budget );
@@ -1184,9 +1170,9 @@ gsb_real gsb_data_budget_get_sub_budget_balance ( gint no_budget,
  *
  * \return balance of the budget or 0 if problem
  * */
-gsb_real gsb_data_budget_get_direct_balance ( gint no_budget )
+GsbReal gsb_data_budget_get_direct_balance ( gint no_budget )
 {
-    struct_budget *budget;
+    BudgetStruct *budget;
 
     budget = gsb_data_budget_get_structure ( no_budget );
 
@@ -1213,7 +1199,7 @@ void gsb_data_budget_reset_counters ( void )
 
     while ( list_tmp )
     {
-	struct_budget *budget;
+	BudgetStruct *budget;
 	GSList *sub_list_tmp;
 
 	budget = list_tmp -> data;
@@ -1226,7 +1212,7 @@ void gsb_data_budget_reset_counters ( void )
 
 	while ( sub_list_tmp )
 	{
-	    struct_sub_budget *sub_budget;
+	    SubBudgetStruct *sub_budget;
 
 	    sub_budget = sub_list_tmp -> data;
 
@@ -1255,10 +1241,13 @@ void gsb_data_budget_reset_counters ( void )
 void gsb_data_budget_update_counters ( void )
 {
     GSList *list_tmp_transactions;
+	GrisbiWinEtat *w_etat;
+
+	w_etat = grisbi_win_get_w_etat ();
 
     gsb_data_budget_reset_counters ();
 
-    if ( etat.add_archive_in_total_balance )
+    if ( w_etat->metatree_add_archive_in_totals )
         list_tmp_transactions = gsb_data_transaction_get_complete_transactions_list ();
     else
         list_tmp_transactions = gsb_data_transaction_get_transactions_list ();
@@ -1288,8 +1277,8 @@ void gsb_data_budget_add_transaction_to_budget ( gint transaction_number,
                         gint budget_id,
                         gint sub_budget_id )
 {
-    struct_budget *budget;
-    struct_sub_budget *sub_budget;
+    BudgetStruct *budget;
+    SubBudgetStruct *sub_budget;
 
     /* if the transaction is a transfer or a split transaction, don't take it */
     if (gsb_data_transaction_get_split_of_transaction (transaction_number)
@@ -1303,18 +1292,19 @@ void gsb_data_budget_add_transaction_to_budget ( gint transaction_number,
     sub_budget = gsb_data_budget_get_sub_budget_structure ( budget_id ,
 							    sub_budget_id );
 
-    /* should not happen, this is if the transaction has a budget wich doesn't exist
+    /* should not happen, this is if the transaction has a budget which doesn't exist
      * we show a debug warning and get without budget */
     if (!budget)
     {
-	gchar *tmpstr;
-	tmpstr = g_strdup_printf ( _("The transaction %d has a budget n%d and sub-budget n%d but they don't exist."),
-				   transaction_number,
-				   budget_id,
-				   sub_budget_id );
-	warning_debug (tmpstr);
-	g_free (tmpstr);
-	budget = empty_budget;
+        gchar *tmpstr;
+
+        tmpstr = g_strdup_printf ( "The transaction %d has a budget %d and sub-budget %d but they don't exist.",
+                       transaction_number,
+                       budget_id,
+                       sub_budget_id );
+        warning_debug (tmpstr);
+        g_free (tmpstr);
+        budget = empty_budget;
     }
 
     /* now budget is on the budget structure or on empty_budget */
@@ -1356,8 +1346,8 @@ void gsb_data_budget_add_transaction_to_budget ( gint transaction_number,
  * */
 void gsb_data_budget_remove_transaction_from_budget ( gint transaction_number )
 {
-    struct_budget *budget;
-    struct_sub_budget *sub_budget;
+    BudgetStruct *budget;
+    SubBudgetStruct *sub_budget;
 
     budget = gsb_data_budget_get_structure ( gsb_data_transaction_get_budgetary_number (transaction_number));
     sub_budget = gsb_data_budget_get_sub_budget_structure ( gsb_data_transaction_get_budgetary_number (transaction_number),
@@ -1405,7 +1395,7 @@ void gsb_data_budget_remove_transaction_from_budget ( gint transaction_number )
  *
  * \return		Same as a <=> b.
  */
-gint gsb_data_sub_budget_compare ( struct_sub_budget * a, struct_sub_budget * b )
+gint gsb_data_sub_budget_compare ( SubBudgetStruct * a, SubBudgetStruct * b )
 {
     if ( a != b && a -> sub_budget_number == b -> sub_budget_number )
     {
@@ -1426,7 +1416,7 @@ gint gsb_data_sub_budget_compare ( struct_sub_budget * a, struct_sub_budget * b
  * \return	NULL if no error found.  A string describing any issue
  *		if any.
  */
-gchar * gsb_debug_duplicate_budget_check ()
+gchar * gsb_debug_duplicate_budget_check (void)
 {
     GSList * tmp;
     gint num_duplicate = 0;
@@ -1435,7 +1425,7 @@ gchar * gsb_debug_duplicate_budget_check ()
     tmp = budget_list;
     while ( tmp )
     {
-	struct_budget * budget = tmp -> data;
+	BudgetStruct * budget = tmp -> data;
 	GSList * tmp_sous_budget = budget -> sub_budget_list;
 
 	while ( tmp_sous_budget )
@@ -1451,12 +1441,11 @@ gchar * gsb_debug_duplicate_budget_check ()
 		gchar* tmpstr2 = g_strdup_printf (
 		                        _("In <i>%s</i>, <i>%s</i> is a duplicate of <i>%s</i>.\n"),
 					budget -> budget_name,
-					((struct_sub_budget *) tmp_sous_budget -> data) -> sub_budget_name,
-					((struct_sub_budget *) duplicate -> data) -> sub_budget_name );
+					((SubBudgetStruct *) tmp_sous_budget -> data) -> sub_budget_name,
+					((SubBudgetStruct *) duplicate -> data) -> sub_budget_name );
 		output = g_strconcat ( tmpstr1,
 				       tmpstr2,
 				       NULL );
-		g_free ( tmpstr1 );
 		g_free ( tmpstr2 );
 		num_duplicate ++;
 	    }
@@ -1482,14 +1471,14 @@ gchar * gsb_debug_duplicate_budget_check ()
  *
  * \return	TRUE on success.  FALSE otherwise.
  */
-gboolean gsb_debug_duplicate_budget_fix ()
+gboolean gsb_debug_duplicate_budget_fix (void)
 {
     GSList * tmp;
 
     tmp = budget_list;
     while ( tmp )
     {
-	struct_budget * budget = tmp -> data;
+	BudgetStruct * budget = tmp -> data;
 	GSList * tmp_sous_budget = budget -> sub_budget_list;
 
 	while ( tmp_sous_budget )
@@ -1500,7 +1489,7 @@ gboolean gsb_debug_duplicate_budget_fix ()
 					      (GCompareFunc) gsb_data_sub_budget_compare );
 	    if ( duplicate )
 	    {
-		struct_sub_budget * duplicate_budget = duplicate -> data;
+		SubBudgetStruct * duplicate_budget = duplicate -> data;
 
 		duplicate_budget -> sub_budget_number = gsb_data_budget_max_sub_budget_number ( budget -> budget_number ) + 1;
 	    }
@@ -1547,7 +1536,7 @@ void gsb_data_budget_set_budget_from_string ( gint transaction_number,
 
         /* we don't mind if tab_char exists and others, all the checks will be done in ...get_number_by_name */
         budget_number = gsb_data_budget_get_number_by_name ( g_strstrip ( tab_char[0] ),
-                                TRUE,
+                                !etat.combofix_force_category,
                                 gsb_data_transaction_get_amount ( transaction_number ).mantissa < 0 );
         gsb_data_transaction_set_budgetary_number ( transaction_number, budget_number );
 
@@ -1555,7 +1544,7 @@ void gsb_data_budget_set_budget_from_string ( gint transaction_number,
             gsb_data_transaction_set_sub_budgetary_number ( transaction_number,
                                 gsb_data_budget_get_sub_budget_number_by_name ( budget_number,
                                                         g_strstrip (tab_char[1]),
-                                                        TRUE ));
+                                                        !etat.combofix_force_category));
     }
     else
     {
@@ -1572,7 +1561,7 @@ void gsb_data_budget_set_budget_from_string ( gint transaction_number,
 
         /* we don't mind if tab_char exists and others, all the checks will be done in ...get_number_by_name */
         budget_number = gsb_data_budget_get_number_by_name ( tab_char[0],
-                                     TRUE,
+                                     !etat.combofix_force_category,
                                      gsb_data_scheduled_get_amount (transaction_number).mantissa <0 );
         gsb_data_scheduled_set_budgetary_number ( transaction_number,
                                 budget_number );
@@ -1580,7 +1569,7 @@ void gsb_data_budget_set_budget_from_string ( gint transaction_number,
             gsb_data_scheduled_set_sub_budgetary_number ( transaction_number,
                                   gsb_data_budget_get_sub_budget_number_by_name ( budget_number,
                                                           tab_char[1],
-                                                          TRUE ));
+                                                          !etat.combofix_force_category));
     }
     g_strfreev (tab_char);
 }
@@ -1595,7 +1584,7 @@ void gsb_data_budget_set_budget_from_string ( gint transaction_number,
  * */
 gint gsb_data_budget_get_sub_budget_list_length ( gint budget_number )
 {
-    struct_budget *budget;
+    BudgetStruct *budget;
 
     budget = gsb_data_budget_get_structure ( budget_number );
 
@@ -1607,7 +1596,7 @@ gint gsb_data_budget_get_sub_budget_list_length ( gint budget_number )
 
 
 /**
- * Teste l'existence d'un budget et le cre si ncessaire
+ * Teste l'existence d'un budget et le crée si nécessaire
  *
  *
  * \param gint          no_budget
@@ -1623,7 +1612,7 @@ gint gsb_data_budget_test_create_budget ( gint no_budget,
 {
     GSList *list_tmp;
     gint budget_number = 0;
-    struct_budget *budget;
+    BudgetStruct *budget;
 
     list_tmp = g_slist_find_custom ( budget_list,
                         name,
@@ -1656,7 +1645,7 @@ gint gsb_data_budget_test_create_budget ( gint no_budget,
 
 
 /**
- * Teste l'existence d'un sous budget et le cre si ncessaire
+ * Teste l'existence d'un sous budget et le crée si nécessaire
  *
  *
  * \param gint          no_budget
@@ -1670,11 +1659,13 @@ gboolean gsb_data_budget_test_create_sub_budget ( gint no_budget,
                         const gchar *name )
 {
     GSList *list_tmp;
-    gint sub_budget_number = 0;
-    struct_budget *budget;
-    struct_sub_budget *sub_budget;
+    BudgetStruct *budget;
+    SubBudgetStruct *sub_budget;
 
     budget = gsb_data_budget_get_structure ( no_budget );
+    if (NULL == budget)
+        return FALSE;
+
     list_tmp = g_slist_find_custom ( budget->sub_budget_list,
                         name,
                         (GCompareFunc) gsb_data_budget_get_pointer_from_sub_name_in_glist );
@@ -1687,13 +1678,13 @@ gboolean gsb_data_budget_test_create_sub_budget ( gint no_budget,
                         no_sub_budget );
         if ( !sub_budget )
         {
-            sub_budget_number = gsb_data_budget_new_sub_budget_with_number (
+            gsb_data_budget_new_sub_budget_with_number (
                         no_sub_budget, no_budget );
             gsb_data_budget_set_sub_budget_name ( no_budget, no_sub_budget, name );
         }
         else
         {
-            sub_budget_number = gsb_data_budget_new_sub_budget ( no_budget, name );
+            gsb_data_budget_new_sub_budget ( no_budget, name );
             gsb_budget_update_combofix ( FALSE );
         }
         return TRUE;
