@@ -26,7 +26,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -36,7 +36,7 @@
 /*START_INCLUDE*/
 #include "gsb_data_partial_balance.h"
 #include "dialog.h"
-#include "gsb_color.h"
+#include "grisbi_app.h"
 #include "gsb_currency_config.h"
 #include "gsb_currency.h"
 #include "gsb_data_account.h"
@@ -45,10 +45,12 @@
 #include "gsb_data_transaction.h"
 #include "navigation.h"
 #include "gsb_real.h"
+#include "gsb_rgba.h"
 #include "utils_real.h"
 #include "utils_str.h"
 #include "utils.h"
 #include "structures.h"
+#include "utils_prefs.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -60,7 +62,7 @@ typedef struct
     gint partial_balance_number;
     gchar *balance_name;
     gchar *liste_cptes;
-    kind_account kind;
+    KindAccount kind;
     gint currency;
     gboolean colorise;
 } struct_partial_balance;
@@ -179,13 +181,12 @@ gint gsb_partial_balance_new_at_position ( const gchar *name, gint pos )
 GtkListStore *gsb_partial_balance_create_model ( void )
 {
 
-    model_accueil = gtk_list_store_new ( 6, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-                        G_TYPE_STRING, G_TYPE_INT, G_TYPE_BOOLEAN );
+    model_accueil = gtk_list_store_new (7, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+										G_TYPE_STRING, G_TYPE_INT, G_TYPE_BOOLEAN, GDK_TYPE_RGBA);
 
     return model_accueil;
 }
 
-
 /**
  *
  * \param
@@ -226,6 +227,7 @@ void gsb_partial_balance_fill_model ( GtkListStore *list_store )
             kind_str = g_strdup ( _("Assets account") );
             break;
 
+		case GSB_TYPE_BANK:
         default:
             kind_str = g_strdup ( _("Bank account") );
         }
@@ -290,7 +292,7 @@ dialog_return:
          g_utf8_strchr  ( liste_cptes, -1, ';' ) )
         {
             position = gtk_spin_button_get_value_as_int ( GTK_SPIN_BUTTON ( spin_bouton ) );
-            if ( position > g_slist_length ( partial_balance_list ) )
+            if ( position > (gint) g_slist_length ( partial_balance_list ) )
                 partial_balance_number = gsb_partial_balance_new ( name );
             else
                 partial_balance_number = gsb_partial_balance_new_at_position (
@@ -444,7 +446,7 @@ dialog_return:
  * remove a partial_balance
  *
  * */
-void gsb_partial_balance_delete ( GtkWidget *button, GtkWidget *main_widget )
+void gsb_partial_balance_remove ( GtkWidget *button, GtkWidget *main_widget )
 {
     GtkTreeView *treeview;
     GtkTreeModel *model;
@@ -586,16 +588,16 @@ gboolean gsb_partial_balance_key_press ( GtkWidget *tree_view, GdkEventKey *ev )
 {
     switch ( ev -> keyval )
     {
-    case GDK_Return :   /* entrée */
-    case GDK_KP_Enter :
-    case GDK_Tab :
+    case GDK_KEY_Return :   /* entrée */
+    case GDK_KEY_KP_Enter :
+    case GDK_KEY_Tab :
         g_object_set_data ( G_OBJECT ( tree_view ), "treeview", tree_view );
         gsb_partial_balance_edit ( NULL, tree_view );
         return TRUE;
         break;
-    case GDK_Delete:    /*  del  */
+    case GDK_KEY_Delete:    /*  del  */
         g_object_set_data ( G_OBJECT ( tree_view ), "treeview", tree_view );
-        gsb_partial_balance_delete ( NULL, tree_view );
+        gsb_partial_balance_remove ( NULL, tree_view );
         return TRUE;
         break;
     }
@@ -907,7 +909,7 @@ gboolean gsb_data_partial_balance_set_name ( gint partial_balance_number,
  *
  * \return partial_balance type or 0 if the partial_balance doesn't exist
  * */
-kind_account gsb_data_partial_balance_get_kind ( gint partial_balance_number )
+KindAccount gsb_data_partial_balance_get_kind ( gint partial_balance_number )
 {
     struct_partial_balance *partial_balance;
 
@@ -928,7 +930,7 @@ kind_account gsb_data_partial_balance_get_kind ( gint partial_balance_number )
  * \return TRUE, ok ; FALSE, problem
  * */
 gboolean gsb_data_partial_balance_set_kind ( gint partial_balance_number,
-                        kind_account kind )
+                        KindAccount kind )
 {
     struct_partial_balance *partial_balance;
 
@@ -1036,7 +1038,7 @@ gboolean gsb_data_partial_balance_set_colorise ( gint partial_balance_number,
 gchar *gsb_data_partial_balance_get_marked_balance ( gint partial_balance_number )
 {
     struct_partial_balance *partial_balance;
-    gsb_real solde = null_real;
+    GsbReal solde = null_real;
     gchar **tab;
     gchar *string;
     gint i;
@@ -1053,7 +1055,7 @@ gchar *gsb_data_partial_balance_get_marked_balance ( gint partial_balance_number
     tab = g_strsplit ( partial_balance -> liste_cptes, ";", 0 );
     for ( i = 0; tab[i]; i++ )
     {
-        gsb_real tmp_real;
+        GsbReal tmp_real;
         gint account_nb;
         gint account_currency;
         gint link_number;
@@ -1081,16 +1083,20 @@ gchar *gsb_data_partial_balance_get_marked_balance ( gint partial_balance_number
     }
     g_strfreev ( tab );
 
-    if ( partial_balance -> colorise && solde.mantissa < 0 )
+    if (partial_balance->colorise)
     {
         gchar *color;
+		gchar *tmp_str;
 
-        color = gsb_color_get_couleur_to_string ( "couleur_solde_alarme_rouge_normal" );
-        string = g_strdup_printf ( "<span color=\"%s\">%s</span>",
-                        color,
-                        utils_real_get_string_with_currency (
-                        solde, partial_balance -> currency, TRUE ) );
+        if (solde.mantissa < 0)
+            color = g_strdup ("red");
+        else
+            color = g_strdup ("blue");
+
+		tmp_str = utils_real_get_string_with_currency (solde, partial_balance -> currency, TRUE);
+        string = g_strdup_printf ("<span color=\"%s\">%s</span>", color, tmp_str);
         g_free ( color );
+		g_free (tmp_str);
     }
     else
         string = utils_real_get_string_with_currency (
@@ -1104,10 +1110,10 @@ gchar *gsb_data_partial_balance_get_marked_balance ( gint partial_balance_number
  *
  *
  * */
-gsb_real gsb_data_partial_balance_get_current_amount ( gint partial_balance_number )
+GsbReal gsb_data_partial_balance_get_current_amount ( gint partial_balance_number )
 {
     struct_partial_balance *partial_balance;
-    gsb_real solde = null_real;
+    GsbReal solde = null_real;
     gchar **tab;
     gint i;
 
@@ -1123,7 +1129,7 @@ gsb_real gsb_data_partial_balance_get_current_amount ( gint partial_balance_numb
     tab = g_strsplit ( partial_balance -> liste_cptes, ";", 0 );
     for ( i = 0; tab[i]; i++ )
     {
-        gsb_real tmp_real;
+        GsbReal tmp_real;
         gint account_nb;
         gint account_currency;
         gint link_number;
@@ -1161,7 +1167,7 @@ gsb_real gsb_data_partial_balance_get_current_amount ( gint partial_balance_numb
 gchar *gsb_data_partial_balance_get_current_balance ( gint partial_balance_number )
 {
     struct_partial_balance *partial_balance;
-    gsb_real solde = null_real;
+    GsbReal solde = null_real;
     gchar *string;
 
     partial_balance = gsb_data_partial_balance_get_structure ( partial_balance_number );
@@ -1171,16 +1177,20 @@ gchar *gsb_data_partial_balance_get_current_balance ( gint partial_balance_numbe
 
     solde = gsb_data_partial_balance_get_current_amount ( partial_balance_number );
 
-    if ( partial_balance -> colorise && solde.mantissa < 0 )
+    if (partial_balance->colorise)
     {
         gchar *color;
+		gchar *tmp_str;
 
-        color = gsb_color_get_couleur_to_string ( "couleur_solde_alarme_rouge_normal" );
-        string = g_strdup_printf ( "<span color=\"%s\">%s</span>",
-                        color,
-                        utils_real_get_string_with_currency (
-                        solde, partial_balance -> currency, TRUE ) );
+        if (solde.mantissa < 0)
+            color = g_strdup ("red");
+        else
+            color = g_strdup ("blue");
+
+		tmp_str = utils_real_get_string_with_currency (solde, partial_balance -> currency, TRUE);
+        string = g_strdup_printf ( "<span color=\"%s\">%s</span>", color, tmp_str);
         g_free ( color );
+		g_free (tmp_str);
     }
     else
         string = utils_real_get_string_with_currency (
@@ -1254,8 +1264,7 @@ gboolean gsb_partial_balance_select_account ( GtkTreeSelection *selection,
         }
     }
 
-    g_list_foreach ( list, ( GFunc ) gtk_tree_path_free, NULL );
-    g_list_free ( list );
+    g_list_free_full ( list, ( GDestroyNotify ) gtk_tree_path_free );
 
     return TRUE;
 }
@@ -1276,8 +1285,8 @@ gboolean gsb_data_partial_balance_init_from_liste_cptes ( gint partial_balance_n
     gint i;
     gint account_nb;
     gint currency_nb = 0;
-    kind_account kind = -1;
-    kind_account kind_nb = -1;
+    KindAccount kind = -1;
+    KindAccount kind_nb = -1;
     gchar *tmp_str;
     gboolean return_val = TRUE;
     gboolean currency_mixte = FALSE;
@@ -1473,7 +1482,7 @@ GPtrArray *gsb_data_partial_balance_calculate_balances_at_date ( gint partial_ba
 
     partial_balance = gsb_data_partial_balance_get_structure ( partial_balance_number );
 
-    if ( !partial_balance_number )
+    if ( !partial_balance )
         return NULL;
 
     tab = g_strsplit ( partial_balance->liste_cptes, ";", 0 );
@@ -1493,8 +1502,8 @@ GPtrArray *gsb_data_partial_balance_calculate_balances_at_date ( gint partial_ba
     {
         gint account_number;
         gint floating_point;
-        gsb_real *balance;
-        gsb_real tmp_balance;
+        GsbReal *balance;
+        GsbReal tmp_balance;
 
         /* on remplit le tableau des numeros des comptes */
         account_number = utils_str_atoi ( tab[i] );
@@ -1505,14 +1514,14 @@ GPtrArray *gsb_data_partial_balance_calculate_balances_at_date ( gint partial_ba
         g_array_append_val ( floating_points, floating_point );
 
         /* on initialise le tableau des soldes de chaque compte */
-        balance = g_malloc0 ( sizeof ( gsb_real ) );
+        balance = g_malloc0 ( sizeof ( GsbReal ) );
         tmp_balance = gsb_data_account_get_init_balance ( account_number, floating_point );
         balance->mantissa = tmp_balance.mantissa;
         balance->exponent = tmp_balance.exponent;
         g_ptr_array_add ( current_balances, balance );
 
         /* on initialise le tableau des soldes en erreur de chaque compte */
-        balance = g_malloc0 ( sizeof ( gsb_real ) );
+        balance = g_malloc0 ( sizeof ( GsbReal ) );
         balance->mantissa = null_real.mantissa;
         balance->exponent = null_real.exponent;
         g_ptr_array_add ( current_balances_later, balance );
@@ -1547,13 +1556,13 @@ GPtrArray *gsb_data_partial_balance_calculate_balances_at_date ( gint partial_ba
             if ( trouve )
             {
                 gint floating_point;
-                gsb_real adjusted_amout;
-                gsb_real tmp_balance;
-                gsb_real *balance;
-                gsb_real current_balance;
+                GsbReal adjusted_amout;
+                GsbReal tmp_balance;
+                GsbReal *balance;
+                GsbReal current_balance;
 
                 floating_point = g_array_index ( floating_points, gint, i );
-                balance = (gsb_real *) g_ptr_array_index ( current_balances, i );
+                balance = (GsbReal *) g_ptr_array_index ( current_balances, i );
                 current_balance.mantissa = balance->mantissa;
                 current_balance.exponent = balance->exponent;
 
@@ -1567,9 +1576,9 @@ GPtrArray *gsb_data_partial_balance_calculate_balances_at_date ( gint partial_ba
                 }
                 else
                 {
-                    gsb_real *balance_later;
+                    GsbReal *balance_later;
 
-                    balance_later = (gsb_real *) g_ptr_array_index ( current_balances_later, i );
+                    balance_later = (GsbReal *) g_ptr_array_index ( current_balances_later, i );
                     balance_later->mantissa = G_MININT64;
                     balance_later->exponent = 0;
                 }
@@ -1583,6 +1592,58 @@ GPtrArray *gsb_data_partial_balance_calculate_balances_at_date ( gint partial_ba
     return current_balances;
 }
 
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
+void gsb_data_partial_balance_renum_account_number_0 (gint account_number)
+{
+    GSList *tmp_list;
+
+    tmp_list = partial_balance_list;
+    while (tmp_list)
+    {
+		gchar *liste_cptes;
+        struct_partial_balance *partial_balance;
+
+        partial_balance = tmp_list->data;
+		liste_cptes = partial_balance->liste_cptes;
+		printf ("liste_cptes = %s\n", liste_cptes);
+		if (g_strstr_len (liste_cptes, -1, "0"))
+		{
+			gchar **tab;
+			gint i;
+
+			tab = g_strsplit (liste_cptes, ";", 0);
+			for ( i = 0; tab[i]; i++ )
+			{
+				gint account_nb;
+
+				account_nb = utils_str_atoi (tab[i]);
+				if (account_nb == 0)
+				{
+					gchar *tmp_number_str;
+					gchar *str_to_free;
+					gchar *new_str;
+
+					tmp_number_str = utils_str_itoa (account_number);
+					str_to_free = tab[i];
+					tab[i] = tmp_number_str;
+					g_free (str_to_free);
+					new_str = g_strjoinv (";", tab);
+					g_free (partial_balance->liste_cptes);
+					partial_balance->liste_cptes = new_str;
+					g_strfreev (tab);
+					break;
+				}
+			}
+		}
+		tmp_list = tmp_list->next;
+	}
+}
 
 /*********************************************************************************************/
 /*              Interface                                                                    */
@@ -1604,7 +1665,7 @@ GtkWidget *gsb_partial_balance_create_list_accounts ( GtkWidget *entry )
     GtkTreeSelection *selection;
     gint i = 0;
 
-    vbox = gtk_vbox_new ( FALSE, 12 );
+    vbox = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
     sw = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw),
                         GTK_SHADOW_ETCHED_IN);
@@ -1638,9 +1699,9 @@ GtkWidget *gsb_partial_balance_create_list_accounts ( GtkWidget *entry )
         i = 10;
     /* create the treeview */
     treeview = gtk_tree_view_new_with_model ( GTK_TREE_MODEL ( list_store ) );
+ 	gtk_widget_set_name (treeview, "tree_view");
     g_object_unref ( list_store );
 
-    gtk_tree_view_set_rules_hint ( GTK_TREE_VIEW ( treeview ), TRUE );
     gtk_widget_set_size_request ( treeview, -1, i*20 );
     selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( treeview ) );
     gtk_tree_selection_set_mode ( selection, GTK_SELECTION_MULTIPLE );
@@ -1648,7 +1709,6 @@ GtkWidget *gsb_partial_balance_create_list_accounts ( GtkWidget *entry )
                         (GtkTreeSelectionFunc) gsb_partial_balance_select_account,
                         entry, NULL );
     gtk_container_add ( GTK_CONTAINER ( sw ), treeview );
-    gtk_container_set_resize_mode ( GTK_CONTAINER ( sw ), GTK_RESIZE_PARENT );
     gtk_box_pack_start ( GTK_BOX ( vbox ), sw, FALSE, FALSE, 0 );
     g_object_set_data ( G_OBJECT (vbox), "account_treeview", treeview );
 
@@ -1663,6 +1723,12 @@ GtkWidget *gsb_partial_balance_create_list_accounts ( GtkWidget *entry )
     gtk_tree_view_column_set_sort_column_id ( column, 0 );
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( treeview ), column );
 
+     /* account number */
+    cell = gtk_cell_renderer_text_new ();
+    column = gtk_tree_view_column_new_with_attributes (_("Account number"), cell, "text", 1, NULL);
+    gtk_tree_view_column_set_expand (column, TRUE);
+    gtk_tree_view_append_column (GTK_TREE_VIEW (treeview ), column);
+
     return vbox;
 }
 
@@ -1673,86 +1739,79 @@ GtkWidget *gsb_partial_balance_create_list_accounts ( GtkWidget *entry )
  * */
 GtkWidget *gsb_partial_balance_create_dialog ( gint action, gint spin_value )
 {
-    GtkWidget *dialog, *label, *table, *paddingbox, *main_vbox, *vbox;
+    GtkWidget *dialog, *label, *main_vbox;
+    GtkWidget *paddinggrid;
     GtkWidget *entry_name, *entry_list, *account_list, *bouton;
 
     devel_debug ( NULL);
 
     if ( action == 1 )
         dialog = gtk_dialog_new_with_buttons ( _("Add a partial balance"),
-                            GTK_WINDOW ( run.window ),
+                            GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
                             GTK_DIALOG_MODAL,
-                            GTK_STOCK_CANCEL, 0,
-                            GTK_STOCK_OK, 1,
+                            "gtk-cancel", 0,
+                            "gtk-ok", 1,
                             NULL );
     else
         dialog = gtk_dialog_new_with_buttons ( _("Modify a partial balance"),
-                            GTK_WINDOW ( run.window ),
+                            GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
                             GTK_DIALOG_MODAL,
-                            GTK_STOCK_CANCEL, 0,
-                            GTK_STOCK_OK, 1,
+                            "gtk-cancel", 0,
+                            "gtk-ok", 1,
                             NULL );
     gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
 
-    main_vbox = new_vbox_with_title_and_icon ( _("Partial balance details"), "payment.png" );
-    gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG ( dialog ) -> vbox ), main_vbox, TRUE, TRUE, 0 );
+    main_vbox = new_vbox_with_title_and_icon ( _("Partial balance details"), "gsb-payment-32.png" );
+    gtk_box_pack_start ( GTK_BOX ( dialog_get_content_area ( dialog ) ), main_vbox, TRUE, TRUE, 0 );
 
-    vbox = gtk_vbox_new ( FALSE, 12 );
-    gtk_box_pack_start ( GTK_BOX ( main_vbox ), vbox, TRUE, TRUE, 0 );
-    gtk_container_set_border_width ( GTK_CONTAINER ( vbox ), 12 );
-
-    paddingbox = new_paddingbox_with_title ( vbox,FALSE, _("Details") );
-
-    /* Create table */
-    table = gtk_table_new ( 6, 2, FALSE );
-    gtk_table_set_col_spacings ( GTK_TABLE ( table ), 5 );
-    gtk_table_set_row_spacings ( GTK_TABLE ( table ), 5 );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), table, TRUE, TRUE, 0 );
+    /* Create paddinggrid */
+    paddinggrid = utils_prefs_paddinggrid_new_with_title ( main_vbox, _("Details") );
+    gtk_grid_set_column_spacing (GTK_GRID (paddinggrid), 5);
+    gtk_grid_set_row_spacing (GTK_GRID (paddinggrid), 5);
 
     /* Partial balance name */
     label = gtk_label_new ( _("Name: ") );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 1 );
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0, 1 );
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 0, 1,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 0, 1, 1);
+
     entry_name = gtk_entry_new ( );
     gtk_entry_set_activates_default ( GTK_ENTRY ( entry_name ), TRUE );
-    gtk_table_attach ( GTK_TABLE ( table ), entry_name, 1, 2, 0, 1,
-                        GTK_EXPAND|GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), entry_name, 1, 0, 1, 1);
 
     /* List of the accounts */
     label = gtk_label_new ( _("Accounts list: ") );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 1);
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0, 1);
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
-    gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 1, 2,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 1, 1, 1);
+
     entry_list = gtk_entry_new ( );
     gtk_editable_set_editable ( GTK_EDITABLE ( entry_list ), FALSE );
     gtk_widget_set_sensitive ( entry_list, FALSE );
-    gtk_table_attach ( GTK_TABLE ( table ), entry_list, 1, 2, 1, 2,
-                        GTK_EXPAND|GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), entry_list, 1, 1, 1, 1);
+
     account_list = gsb_partial_balance_create_list_accounts ( entry_list );
-    gtk_table_attach ( GTK_TABLE ( table ), account_list, 0, 2, 2, 4,
-                        GTK_EXPAND | GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), account_list, 0, 2, 2, 2);
 
     /* create the position */
     label = gtk_label_new ( _("Position in the list of accounts: ") );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 1);
+    gtk_widget_set_margin_top (label, MARGIN_TOP);
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0, 1);
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
-    gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 4, 5,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 4, 1, 1);
+
     bouton = gtk_spin_button_new_with_range ( 1.0, spin_value, 1.0);
+    gtk_widget_set_margin_top (bouton, MARGIN_TOP);
     gtk_spin_button_set_value ( GTK_SPIN_BUTTON ( bouton ),
                         g_slist_length ( partial_balance_list ) + 1 );
-    gtk_table_attach ( GTK_TABLE ( table ), bouton, 1, 2, 4, 5,
-                        GTK_EXPAND | GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), bouton, 1, 4, 1, 1);
     g_object_set_data ( G_OBJECT ( dialog ), "spin_bouton", bouton );
 
     /* create the colorized button */
     bouton = gtk_check_button_new_with_label ( _("Colorized in red if the balance is negative") );
-    gtk_table_attach ( GTK_TABLE ( table ), bouton, 0, 2, 5, 6,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    gtk_widget_set_margin_top (bouton, MARGIN_TOP);
     g_object_set_data ( G_OBJECT ( dialog ), "colorise_bouton", bouton );
+    gtk_grid_attach (GTK_GRID (paddinggrid), bouton, 0, 5, 2, 1);
 
     g_object_set_data ( G_OBJECT ( dialog ), "entry_name", entry_name );
     g_object_set_data ( G_OBJECT ( dialog ), "entry_list", entry_list );
@@ -1769,23 +1828,22 @@ GtkWidget *gsb_partial_balance_create_dialog ( gint action, gint spin_value )
 gint gsb_partial_balance_request_currency ( GtkWidget *parent )
 {
     GtkWidget *dialog, *hbox, *label, *combo_devise;
-    gint currency_nb;
-    gint result;
+    gint currency_nb = 1;	/* Initialisation avec la première devise : fixe bug 1881 */
 
     dialog = gtk_dialog_new_with_buttons ( _("Enter the currency of the balance part"),
                             GTK_WINDOW ( parent ),
                             GTK_DIALOG_MODAL,
-                            GTK_STOCK_CANCEL, 0,
-                            GTK_STOCK_OK, 1,
+                            "gtk-cancel", 0,
+                            "gtk-ok", 1,
                             NULL );
     gtk_widget_set_size_request ( dialog, -1, 150 );
     gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
 
-    hbox = gtk_hbox_new ( FALSE, 5 );
-    gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG ( dialog ) -> vbox ), hbox, TRUE, FALSE, 0 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_box_pack_start ( GTK_BOX ( dialog_get_content_area( dialog ) ), hbox, TRUE, FALSE, 0 );
 
     label = gtk_label_new ( _("Select the currency of the partial balance: ") );
-    gtk_misc_set_alignment ( GTK_MISC  ( label ), 0, 1 );
+    utils_labels_set_alignment ( GTK_LABEL  ( label ), 0, 1 );
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, TRUE, TRUE, 0 );
 
@@ -1794,9 +1852,8 @@ gint gsb_partial_balance_request_currency ( GtkWidget *parent )
 
     gtk_widget_show_all ( GTK_WIDGET ( dialog ) );
 
-    gsb_currency_set_combobox_history ( combo_devise, 2 );
-    gsb_currency_set_combobox_history ( combo_devise, 1 );
-    result = gtk_dialog_run ( GTK_DIALOG ( dialog ) );
+    gsb_currency_set_combobox_history (combo_devise, currency_nb);
+    gtk_dialog_run ( GTK_DIALOG ( dialog ) );
 
     gtk_widget_destroy ( GTK_WIDGET ( dialog ) );
 
@@ -1809,13 +1866,13 @@ gint gsb_partial_balance_request_currency ( GtkWidget *parent )
  * \param partial_balance_number    numéro du solde partiel concerné
  * \param date                      date de calcul du solde
  *
- * \return gsb_real         le solde du solde partiel
+ * \return GsbReal         le solde du solde partiel
  * */
-gsb_real gsb_data_partial_balance_get_balance_at_date ( gint partial_balance_number,
+GsbReal gsb_data_partial_balance_get_balance_at_date ( gint partial_balance_number,
                         GDate *date )
 {
     struct_partial_balance *partial_balance;
-    gsb_real solde = null_real;
+    GsbReal solde = null_real;
     gchar **tab;
     gint i;
 
@@ -1831,7 +1888,7 @@ gsb_real gsb_data_partial_balance_get_balance_at_date ( gint partial_balance_num
     tab = g_strsplit ( partial_balance -> liste_cptes, ";", 0 );
     for ( i = 0; tab[i]; i++ )
     {
-        gsb_real tmp_real;
+        GsbReal tmp_real;
         gint account_number;
         gint account_currency;
         gint link_number;
