@@ -3,9 +3,9 @@
 /*                                                                            */
 /*                                  gsb_data_report_amount_comparison         */
 /*                                                                            */
-/*     Copyright (C)	2000-2007 Cdric Auger (cedric@grisbi.org)	      */
-/*			2003-2007 Benjamin Drieu (bdrieu@april.org)	      */
-/* 			http://www.grisbi.org				      */
+/*     Copyright (C)    2000-2007 Cédric Auger (cedric@grisbi.org)            */
+/*          2003-2007 Benjamin Drieu (bdrieu@april.org)                       */
+/*         http://www.grisbi.org                                              */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -30,7 +30,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -44,8 +44,9 @@
  * describe a report amount comparison
  * */
 
-typedef struct
-{
+typedef struct _AmountComparaison	AmountComparaison;
+
+struct _AmountComparaison {
     /** @name general stuff */
     gint amount_comparison_number;
     gint report_number;				/**< the associated report */
@@ -53,10 +54,10 @@ typedef struct
     /** @name saved values of the structure */
     gint link_to_last_amount_comparison;	/* -1=first comparison, 0=and, 1=or, 2=except */
     gint first_comparison;			/* 0= =, 1= <, 2= <=, 3= >, 4= >=, 5= !=, 6= =0, 7= !=0, 8= >0, 9= <0 */
-    gsb_real first_amount;
+    GsbReal first_amount;
     gint link_first_to_second_part;		/* 0=and, 1=or, 2=except, 3=none */
     gint second_comparison;			/* 0= =, 1= <, 2= <=, 3= >, 4= >=, 5= != */
-    gsb_real second_amount;
+    GsbReal second_amount;
 
     /** @name dynamic values used for the gui */
     gpointer hbox_line;
@@ -67,12 +68,12 @@ typedef struct
     gpointer hbox_second_part;
     gpointer button_second_comparison;
     gpointer entry_second_amount;
-} struct_amount_comparison;
+};
 
 
 /*START_STATIC*/
-static void _gsb_data_report_amount_comparison_free ( struct_amount_comparison *amount_comparison );
-static struct_amount_comparison *gsb_data_report_amount_comparison_get_struct_by_no ( gint amount_comparison_number );
+static void _gsb_data_report_amount_comparison_free ( AmountComparaison *amount_comparison );
+static AmountComparaison *gsb_data_report_amount_comparison_get_struct_by_no ( gint amount_comparison_number );
 static gint gsb_data_report_amount_comparison_max_number ( void );
 /*END_STATIC*/
 
@@ -81,11 +82,11 @@ static gint gsb_data_report_amount_comparison_max_number ( void );
 
 
 
-/** contains a g_slist of struct_amount_comparison */
+/** contains a g_slist of AmountComparaison */
 static GSList *amount_comparison_list = NULL;
 
 /** a pointers to the last amount comparison used (to increase the speed) */
-static struct_amount_comparison *amount_comparison_buffer;
+static AmountComparaison *amount_comparison_buffer;
 
 
 
@@ -103,7 +104,7 @@ gboolean gsb_data_report_amount_comparison_init_variables ( void )
         GSList* tmp_list = amount_comparison_list;
         while ( tmp_list )
         {
-	    struct_amount_comparison *amount_comparison;
+	    AmountComparaison *amount_comparison;
 	    amount_comparison = tmp_list -> data;
 	    tmp_list = tmp_list -> next;
 	    _gsb_data_report_amount_comparison_free ( amount_comparison );
@@ -127,7 +128,7 @@ gboolean gsb_data_report_amount_comparison_init_variables ( void )
  *
  * \return a pointer to the amount_comparison, NULL if not found
  * */
-static struct_amount_comparison *gsb_data_report_amount_comparison_get_struct_by_no ( gint amount_comparison_number )
+static AmountComparaison *gsb_data_report_amount_comparison_get_struct_by_no ( gint amount_comparison_number )
 {
     GSList *amount_comparison_list_tmp;
 
@@ -142,7 +143,7 @@ static struct_amount_comparison *gsb_data_report_amount_comparison_get_struct_by
 
     while ( amount_comparison_list_tmp )
     {
-	struct_amount_comparison *amount_comparison;
+	AmountComparaison *amount_comparison;
 
 	amount_comparison = amount_comparison_list_tmp -> data;
 
@@ -178,7 +179,7 @@ gint gsb_data_report_amount_comparison_max_number ( void )
 
     while ( tmp )
     {
-	struct_amount_comparison *amount_comparison;
+	AmountComparaison *amount_comparison;
 
 	amount_comparison = tmp -> data;
 
@@ -202,9 +203,9 @@ gint gsb_data_report_amount_comparison_max_number ( void )
  * */
 gint gsb_data_report_amount_comparison_new ( gint number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
-    amount_comparison = g_malloc0 ( sizeof ( struct_amount_comparison ));
+    amount_comparison = g_malloc0 ( sizeof ( AmountComparaison ));
 
     if ( number )
 	amount_comparison -> amount_comparison_number = number;
@@ -220,9 +221,9 @@ gint gsb_data_report_amount_comparison_new ( gint number )
 }
 
 /**
- * This function is called to free the memory used by a struct_amount_comparison structure
+ * This function is called to free the memory used by a AmountComparaison structure
  */
-static void _gsb_data_report_amount_comparison_free ( struct_amount_comparison *amount_comparison )
+static void _gsb_data_report_amount_comparison_free ( AmountComparaison *amount_comparison )
 {
     if ( ! amount_comparison )
         return;
@@ -240,7 +241,7 @@ static void _gsb_data_report_amount_comparison_free ( struct_amount_comparison *
  * */
 gboolean gsb_data_report_amount_comparison_remove ( gint amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no ( amount_comparison_number );
 
@@ -264,8 +265,8 @@ gboolean gsb_data_report_amount_comparison_remove ( gint amount_comparison_numbe
  * */
 gint gsb_data_report_amount_comparison_dup ( gint last_amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
-    struct_amount_comparison *last_amount_comparison;
+    AmountComparaison *amount_comparison;
+    AmountComparaison *last_amount_comparison;
     gint amount_comparison_number;
 
     last_amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (last_amount_comparison_number);
@@ -276,6 +277,9 @@ gint gsb_data_report_amount_comparison_dup ( gint last_amount_comparison_number
     amount_comparison_number = gsb_data_report_amount_comparison_new (0);
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
+    if (NULL == amount_comparison)
+        return 0;
+
     amount_comparison -> report_number = last_amount_comparison -> report_number;
     amount_comparison -> link_to_last_amount_comparison = last_amount_comparison -> link_to_last_amount_comparison;
     amount_comparison -> first_comparison = last_amount_comparison -> first_comparison;
@@ -300,7 +304,7 @@ gint gsb_data_report_amount_comparison_dup ( gint last_amount_comparison_number
 gboolean gsb_data_report_amount_comparison_set_report_number ( gint amount_comparison_number,
 							       gint report_number)
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -321,7 +325,7 @@ gboolean gsb_data_report_amount_comparison_set_report_number ( gint amount_compa
  * */
 gint gsb_data_report_amount_comparison_get_link_to_last_amount_comparison ( gint amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -342,7 +346,7 @@ gint gsb_data_report_amount_comparison_get_link_to_last_amount_comparison ( gint
 gboolean gsb_data_report_amount_comparison_set_link_to_last_amount_comparison ( gint amount_comparison_number,
 										gint link_to_last_amount_comparison)
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -363,7 +367,7 @@ gboolean gsb_data_report_amount_comparison_set_link_to_last_amount_comparison (
  * */
 gint gsb_data_report_amount_comparison_get_first_comparison ( gint amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -384,7 +388,7 @@ gint gsb_data_report_amount_comparison_get_first_comparison ( gint amount_compar
 gboolean gsb_data_report_amount_comparison_set_first_comparison ( gint amount_comparison_number,
 								  gint first_comparison)
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -404,9 +408,9 @@ gboolean gsb_data_report_amount_comparison_set_first_comparison ( gint amount_co
  *
  * \return the  of the amount_comparison, -1 if problem
  * */
-gsb_real gsb_data_report_amount_comparison_get_first_amount ( gint amount_comparison_number )
+GsbReal gsb_data_report_amount_comparison_get_first_amount ( gint amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -425,9 +429,9 @@ gsb_real gsb_data_report_amount_comparison_get_first_amount ( gint amount_compar
  * \return TRUE if ok
  * */
 gboolean gsb_data_report_amount_comparison_set_first_amount ( gint amount_comparison_number,
-							      gsb_real first_amount)
+							      GsbReal first_amount)
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -449,7 +453,7 @@ gboolean gsb_data_report_amount_comparison_set_first_amount ( gint amount_compar
  * */
 gint gsb_data_report_amount_comparison_get_link_first_to_second_part ( gint amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -470,7 +474,7 @@ gint gsb_data_report_amount_comparison_get_link_first_to_second_part ( gint amou
 gboolean gsb_data_report_amount_comparison_set_link_first_to_second_part ( gint amount_comparison_number,
 									   gint link_first_to_second_part)
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -492,7 +496,7 @@ gboolean gsb_data_report_amount_comparison_set_link_first_to_second_part ( gint
  * */
 gint gsb_data_report_amount_comparison_get_second_comparison ( gint amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -513,7 +517,7 @@ gint gsb_data_report_amount_comparison_get_second_comparison ( gint amount_compa
 gboolean gsb_data_report_amount_comparison_set_second_comparison ( gint amount_comparison_number,
 								   gint second_comparison)
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -533,9 +537,9 @@ gboolean gsb_data_report_amount_comparison_set_second_comparison ( gint amount_c
  *
  * \return the  of the amount_comparison, -1 if problem
  * */
-gsb_real gsb_data_report_amount_comparison_get_second_amount ( gint amount_comparison_number )
+GsbReal gsb_data_report_amount_comparison_get_second_amount ( gint amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -554,9 +558,9 @@ gsb_real gsb_data_report_amount_comparison_get_second_amount ( gint amount_compa
  * \return TRUE if ok
  * */
 gboolean gsb_data_report_amount_comparison_set_second_amount ( gint amount_comparison_number,
-							       gsb_real second_amount)
+							       GsbReal second_amount)
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -578,7 +582,7 @@ gboolean gsb_data_report_amount_comparison_set_second_amount ( gint amount_compa
  * */
 gpointer gsb_data_report_amount_comparison_get_hbox_line ( gint amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -599,7 +603,7 @@ gpointer gsb_data_report_amount_comparison_get_hbox_line ( gint amount_compariso
 gboolean gsb_data_report_amount_comparison_set_hbox_line ( gint amount_comparison_number,
 							   gpointer hbox_line)
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -620,7 +624,7 @@ gboolean gsb_data_report_amount_comparison_set_hbox_line ( gint amount_compariso
  * */
 gpointer gsb_data_report_amount_comparison_get_button_link ( gint amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -641,7 +645,7 @@ gpointer gsb_data_report_amount_comparison_get_button_link ( gint amount_compari
 gboolean gsb_data_report_amount_comparison_set_button_link ( gint amount_comparison_number,
 							     gpointer button_link)
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -662,7 +666,7 @@ gboolean gsb_data_report_amount_comparison_set_button_link ( gint amount_compari
  * */
 gpointer gsb_data_report_amount_comparison_get_button_first_comparison ( gint amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -683,7 +687,7 @@ gpointer gsb_data_report_amount_comparison_get_button_first_comparison ( gint am
 gboolean gsb_data_report_amount_comparison_set_button_first_comparison ( gint amount_comparison_number,
 									 gpointer button_first_comparison)
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -704,7 +708,7 @@ gboolean gsb_data_report_amount_comparison_set_button_first_comparison ( gint am
  * */
 gpointer gsb_data_report_amount_comparison_get_entry_first_amount ( gint amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -725,7 +729,7 @@ gpointer gsb_data_report_amount_comparison_get_entry_first_amount ( gint amount_
 gboolean gsb_data_report_amount_comparison_set_entry_first_amount ( gint amount_comparison_number,
 								    gpointer entry_first_amount)
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -746,7 +750,7 @@ gboolean gsb_data_report_amount_comparison_set_entry_first_amount ( gint amount_
  * */
 gpointer gsb_data_report_amount_comparison_get_button_link_first_to_second_part ( gint amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -767,7 +771,7 @@ gpointer gsb_data_report_amount_comparison_get_button_link_first_to_second_part
 gboolean gsb_data_report_amount_comparison_set_button_link_first_to_second_part ( gint amount_comparison_number,
 										  gpointer button_link_first_to_second_part)
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -788,7 +792,7 @@ gboolean gsb_data_report_amount_comparison_set_button_link_first_to_second_part
  * */
 gpointer gsb_data_report_amount_comparison_get_hbox_second_part ( gint amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -809,7 +813,7 @@ gpointer gsb_data_report_amount_comparison_get_hbox_second_part ( gint amount_co
 gboolean gsb_data_report_amount_comparison_set_hbox_second_part ( gint amount_comparison_number,
 								  gpointer hbox_second_part)
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -830,7 +834,7 @@ gboolean gsb_data_report_amount_comparison_set_hbox_second_part ( gint amount_co
  * */
 gpointer gsb_data_report_amount_comparison_get_button_second_comparison ( gint amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -851,7 +855,7 @@ gpointer gsb_data_report_amount_comparison_get_button_second_comparison ( gint a
 gboolean gsb_data_report_amount_comparison_set_button_second_comparison ( gint amount_comparison_number,
 									  gpointer button_second_comparison)
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -872,7 +876,7 @@ gboolean gsb_data_report_amount_comparison_set_button_second_comparison ( gint a
  * */
 gpointer gsb_data_report_amount_comparison_get_entry_second_amount ( gint amount_comparison_number )
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
@@ -893,7 +897,7 @@ gpointer gsb_data_report_amount_comparison_get_entry_second_amount ( gint amount
 gboolean gsb_data_report_amount_comparison_set_entry_second_amount ( gint amount_comparison_number,
 								     gpointer entry_second_amount)
 {
-    struct_amount_comparison *amount_comparison;
+    AmountComparaison *amount_comparison;
 
     amount_comparison = gsb_data_report_amount_comparison_get_struct_by_no (amount_comparison_number);
 
