@@ -543,37 +543,37 @@ gboolean gsb_data_transaction_set_date ( gint transaction_number,
     /* if the transaction is a split, change all the children */
     if (transaction -> split_of_transaction)
     {
-	GSList *tmp_list;
-	GSList *save_tmp_list;
+		GSList *tmp_list;
+		GSList *save_tmp_list;
 
-	tmp_list = gsb_data_transaction_get_children (transaction -> transaction_number, FALSE);
-	save_tmp_list = tmp_list;
+		tmp_list = gsb_data_transaction_get_children (transaction -> transaction_number, FALSE);
+		save_tmp_list = tmp_list;
 
-	while (tmp_list)
-	{
-	    transaction = tmp_list -> data;
+		while (tmp_list)
+		{
+			transaction = tmp_list -> data;
 
-	    if (transaction -> date)
-            g_date_free (transaction -> date);
-	    transaction -> date = gsb_date_copy (date);
+			if (transaction -> date)
+				g_date_free (transaction -> date);
+			transaction -> date = gsb_date_copy (date);
 
-        /* si l'opération fille est un transfert on regarde si la contre opération est rapprochée
-         * si elle ne l'est pas on peut mettre à jour la date */
-        if ( transaction->transaction_number_transfer > 0 )
-        {
-            gint contra_marked_transaction = 0;
+			/* si l'opération fille est un transfert on regarde si la contre opération est rapprochée
+			 * si elle ne l'est pas on peut mettre à jour la date */
+			if ( transaction->transaction_number_transfer > 0 )
+			{
+				gint contra_marked_transaction = 0;
 
-            contra_marked_transaction = gsb_data_transaction_get_marked_transaction (
-                        transaction->transaction_number_transfer );
+				contra_marked_transaction = gsb_data_transaction_get_marked_transaction (
+							transaction->transaction_number_transfer );
 
-            if ( contra_marked_transaction != OPERATION_RAPPROCHEE )
-            {
-                gsb_data_transaction_set_date ( transaction->transaction_number_transfer, transaction -> date );
-                gsb_transactions_list_update_transaction ( transaction->transaction_number_transfer );
-            }
-        }
+				if ( contra_marked_transaction != OPERATION_RAPPROCHEE )
+				{
+					gsb_data_transaction_set_date ( transaction->transaction_number_transfer, date );
+					gsb_transactions_list_update_transaction ( transaction->transaction_number_transfer );
+				}
+			}
 
-	    tmp_list = tmp_list -> next;
+			tmp_list = tmp_list -> next;
 	}
 	g_slist_free (save_tmp_list);
     }
@@ -779,28 +779,60 @@ GsbReal gsb_data_transaction_get_adjusted_amount_for_currency ( gint transaction
     /* if the transaction currency is the same of the account's one,
      * we just return the transaction's amount */
     if ( transaction -> currency_number == return_currency_number )
-        return gsb_real_adjust_exponent  ( transaction -> transaction_amount,
-					   return_exponent );
-/* printf ("get_adjusted_amount transaction_number = %d transaction -> currency_number = %d return_currency_number = %d\n",
-    transaction_number, transaction -> currency_number, return_currency_number); */
-    /* now we can adjust the amount */
+	{
+        return gsb_real_adjust_exponent  ( transaction -> transaction_amount, return_exponent );
+	}
+
+	/* now we can adjust the amount */
 	/* the exchange is saved in the transaction itself */
-    if ( transaction -> exchange_rate.mantissa )
+	if (transaction->exchange_rate.mantissa)
     {
+		gint account_currency;
+
         if ( transaction -> change_between_account_and_transaction )
-            amount = gsb_real_div ( transaction -> transaction_amount,
-                        transaction -> exchange_rate );
+            amount = gsb_real_div (transaction -> transaction_amount, transaction -> exchange_rate);
         else
-            amount = gsb_real_mul ( transaction -> transaction_amount,
-                        transaction -> exchange_rate );
+            amount = gsb_real_mul (transaction -> transaction_amount, transaction -> exchange_rate );
 
         /* The costs are still deducted from the transaction. In case of internal transfer there is no charge. */
         amount = gsb_real_sub (amount, transaction -> exchange_fees);
+
+		account_currency = gsb_data_account_get_currency (transaction->account_number);
+		if (account_currency != return_currency_number)
+		{
+			if ((link_number = gsb_data_currency_link_search (account_currency, return_currency_number)))
+			{
+				/* there is a hard link between the account currency and the return currency */
+				if ( gsb_data_currency_link_get_first_currency (link_number) == account_currency)
+					amount = gsb_real_mul (amount, gsb_data_currency_link_get_change_rate (link_number));
+				else
+					amount = gsb_real_div (amount, gsb_data_currency_link_get_change_rate (link_number));
+			}
+			else
+			{
+				GsbReal current_exchange;
+				GsbReal current_exchange_fees;
+
+				gsb_currency_exchange_dialog (account_currency,
+											  return_currency_number,
+											  0,
+											  null_real,
+											  null_real,
+											  TRUE);
+
+				current_exchange = gsb_currency_get_current_exchange ();
+				current_exchange_fees = gsb_currency_get_current_exchange_fees ();
+
+				amount = gsb_real_div (amount, current_exchange);
+				if (current_exchange_fees.mantissa != 0)
+					amount = gsb_real_sub (amount, current_exchange_fees);
+			}
+		}
     }
     else if ( (link_number = gsb_data_currency_link_search ( transaction -> currency_number,
 							return_currency_number ) ) )
     {
-	/* there is a hard link between the transaction currency and the return currency */
+		/* there is a hard link between the transaction currency and the return currency */
         if ( gsb_data_currency_link_get_first_currency (link_number) == transaction -> currency_number)
             amount = gsb_real_mul ( transaction -> transaction_amount,
                         gsb_data_currency_link_get_change_rate (link_number));
@@ -988,7 +1020,7 @@ GsbReal gsb_data_transaction_get_exchange_rate ( gint transaction_number )
 {
     struct_transaction *transaction;
 
-    transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
+	transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
     if ( !transaction )
 	return null_real;
@@ -2149,25 +2181,25 @@ gboolean gsb_data_transaction_copy_transaction ( gint source_transaction_number,
     target_transaction -> archive_number = 0;
 
     /* make a new copy of all the pointers */
-    if ( target_transaction -> notes)
-	target_transaction -> notes = my_strdup ( source_transaction -> notes );
+    if (source_transaction -> notes)
+		target_transaction -> notes = my_strdup ( source_transaction -> notes );
 
-    if ( target_transaction -> voucher)
-	target_transaction -> voucher = my_strdup ( source_transaction -> voucher );
+    if (source_transaction -> voucher)
+		target_transaction -> voucher = my_strdup ( source_transaction -> voucher );
 
-    if ( target_transaction -> bank_references)
-	target_transaction -> bank_references = my_strdup ( source_transaction -> bank_references );
+    if (source_transaction -> bank_references)
+		target_transaction -> bank_references = my_strdup ( source_transaction -> bank_references );
 
-    if ( target_transaction -> date)
-	target_transaction -> date = gsb_date_copy (source_transaction -> date);
+    if (source_transaction->date && g_date_valid (source_transaction->date))
+		target_transaction -> date = gsb_date_copy (source_transaction -> date);
 
-    if ( target_transaction -> value_date)
-	target_transaction -> value_date = gsb_date_copy (source_transaction -> value_date);
+    if (source_transaction -> value_date)
+		target_transaction -> value_date = gsb_date_copy (source_transaction -> value_date);
 
-    if ( target_transaction -> method_of_payment_content)
-	target_transaction -> method_of_payment_content = my_strdup (
-                        source_transaction -> method_of_payment_content );
-    return TRUE;
+    if (source_transaction -> method_of_payment_content)
+		target_transaction -> method_of_payment_content = my_strdup (source_transaction->method_of_payment_content);
+
+	return TRUE;
 }
 
 /**
