@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -147,7 +147,7 @@ gboolean gsb_file_others_save_category ( gchar *filename )
 
     /* the file is in memory, we can save it */
 
-	file = utf8_fopen ( filename, "w" );
+	file = utils_files_utf8_fopen ( filename, "w" );
 
     if ( !file
 	 ||
@@ -162,6 +162,8 @@ gboolean gsb_file_others_save_category ( gchar *filename )
         dialogue_error ( tmp_str );
         g_free ( tmp_str );
         g_free ( file_content );
+        if (file)
+            fclose(file);
         return ( FALSE );
     }
 
@@ -191,6 +193,7 @@ gboolean gsb_file_others_save_budget ( gchar *filename )
     gulong length_part;
 
     devel_debug (filename);
+    gboolean ret = TRUE;
 
     /* we begin to try to reserve enough memory to make the entire file
      * if not enough, we will make it growth later
@@ -237,7 +240,7 @@ gboolean gsb_file_others_save_budget ( gchar *filename )
 
     /* the file is in memory, we can save it */
 
-	file = utf8_fopen ( filename, "w" );
+	file = utils_files_utf8_fopen ( filename, "w" );
 
     if ( !file
 	 ||
@@ -251,14 +254,14 @@ gboolean gsb_file_others_save_budget ( gchar *filename )
                         g_strerror ( errno ) );
         dialogue_error ( tmp_str );
         g_free ( tmp_str );
-        g_free ( file_content );
-        return ( FALSE );
+        ret = FALSE;
     }
 
-    fclose ( file );
+    if (file)
+	fclose ( file );
     g_free ( file_content);
 
-    return ( TRUE );
+    return ( ret );
 }
 
 /**
@@ -328,8 +331,7 @@ gboolean gsb_file_others_save_report ( gchar *filename )
 
     /* the file is in memory, we can save it */
 
-    file = fopen ( filename,
-			  "w" );
+    file = utils_files_utf8_fopen ( filename, "w" );
 
     if ( !file
 	 ||
@@ -344,6 +346,8 @@ gboolean gsb_file_others_save_report ( gchar *filename )
         dialogue_error ( tmp_str);
         g_free ( tmp_str );
         g_free ( file_content );
+        if (file)
+            fclose(file);
         return ( FALSE );
     }
 
@@ -520,11 +524,11 @@ gboolean gsb_file_others_load ( gchar *filename,
         return FALSE;
     }
 
+    gint report_number;
+
 	/* now, import_list contains the list of categories/budget or report */
 	switch ( origin )
 	{
-	    gint report_number;
-
 	    case 0:
 		/* comes for category */
 		categories_fill_list ();
@@ -563,16 +567,16 @@ gboolean gsb_file_others_load ( gchar *filename,
 		    gsb_data_report_set_financial_year_list ( report_number,
 							      NULL );
 		    /* erase the accounts */
-		    gsb_data_report_set_account_numbers ( report_number,
+		    gsb_data_report_set_account_numbers_list ( report_number,
 							  NULL);
 		    /* erase the transferts accounts */
-		    gsb_data_report_set_transfer_account_numbers ( report_number,
+		    gsb_data_report_set_transfer_account_numbers_list ( report_number,
 								   NULL );
 		    /* erase the categories */
-		    gsb_data_report_set_category_struct ( report_number,
+		    gsb_data_report_set_category_struct_list ( report_number,
 							  NULL );
 		    /* erase the parties */
-		    gsb_data_report_set_payee_numbers ( report_number,
+		    gsb_data_report_set_payee_numbers_list ( report_number,
 							NULL );
 		    /* erase the kinds of payment */
 		    gsb_data_report_set_method_of_payment_list ( report_number,
