@@ -2,6 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
+/*                 2009-2016 Pierre Biava (grisbi@pierre.biava.name)          */
 /*          http://www.grisbi.org                                             */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -27,7 +28,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -39,6 +40,7 @@
 #include "gsb_calendar_entry.h"
 #include "gsb_combo_box.h"
 #include "gsb_currency.h"
+#include "dialog.h"
 #include "gsb_data_payment.h"
 #include "gsb_data_scheduled.h"
 #include "utils_dates.h"
@@ -94,13 +96,17 @@ static GSList *scheduled_element_list = NULL;
 
 /**
  * used when change the account with the button, have only the new account,
- * so can use that variable wich will be set to the new account at the end
+ * so can use that variable which will be set to the new account at the end
  * of the callback when change the button (gsb_form_scheduler_change_account)
  * */
 static gint last_account_number = 0;
 
-
-
+/******************************************************************************/
+/* Private Methods                                                            */
+/******************************************************************************/
+/******************************************************************************/
+/* Public Methods                                                             */
+/******************************************************************************/
 /**
  * create the scheduled part : that widgets are created at the beginning
  * and normally never destroyed, they are showed only for
@@ -116,6 +122,7 @@ gboolean gsb_form_scheduler_create ( GtkWidget *table )
 {
     gint row, column;
     struct_element *element;
+
     devel_debug (NULL);
     if (!table)
         return FALSE;
@@ -124,23 +131,6 @@ gboolean gsb_form_scheduler_create ( GtkWidget *table )
     if (scheduled_element_list)
         gsb_form_scheduler_free_list ( );
 
-    /* check the dimensions,
-     * if problem give a warning message but continue the program with changing the values */
-    g_object_get ( G_OBJECT (table),
-		   "n-columns", &column,
-		   "n-rows", &row,
-		   NULL );
-    if ( column != SCHEDULED_WIDTH
-	 ||
-	 row != SCHEDULED_HEIGHT )
-    {
-        warning_debug ( _("gsb_form_scheduler_create is called with a bad table,\n"
-                          "the number of rows or columns is not good.\n"
-                          "The function will resize the table to the correct values but "
-                          "should check that warning."));
-        gtk_table_resize ( GTK_TABLE (table), SCHEDULED_HEIGHT, SCHEDULED_WIDTH );
-    }
-
     /* ok, now fill the form
      * we play with height and width, but for now it's fix : 6 columns and 1 line */
     for ( row=0 ; row < SCHEDULED_HEIGHT ; row++ )
@@ -159,25 +149,36 @@ gboolean gsb_form_scheduler_create ( GtkWidget *table )
 	    switch ( element_number )
 	    {
 		case SCHEDULED_FORM_ACCOUNT:
-		    widget = gsb_account_create_combo_list ( G_CALLBACK ( gsb_form_scheduler_change_account ),
-                        NULL, FALSE);
-		    gtk_combo_box_set_active ( GTK_COMBO_BOX (widget), 0 );
-		    tooltip_text = _("Choose the account");
+			widget = gsb_account_create_combo_list (G_CALLBACK (gsb_form_scheduler_change_account), NULL, FALSE);
+			gtk_widget_set_hexpand (widget, TRUE);
+			if (etat.scheduler_set_default_account)
+			{
+				g_signal_handlers_block_by_func (widget, gsb_form_scheduler_change_account, NULL);
+				gsb_account_set_combo_account_number (widget, etat.scheduler_default_account_number);
+				g_signal_handlers_unblock_by_func (widget, gsb_form_scheduler_change_account, NULL);
+			}
+			else
+				gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
+
+			tooltip_text = _("Choose the account");
 		    break;
 
 		case SCHEDULED_FORM_AUTO:
 		    widget = gsb_combo_box_new_with_index ( text_auto, NULL, NULL );
+			gtk_widget_set_hexpand (widget, TRUE);
 		    tooltip_text = _("Automatic/manual scheduled transaction");
 		    break;
 
 		case SCHEDULED_FORM_FREQUENCY_BUTTON:
 		    widget = gsb_combo_box_new_with_index ( text_frequency,
                         G_CALLBACK (gsb_form_scheduler_frequency_button_changed), NULL );
+			gtk_widget_set_hexpand (widget, TRUE);
 		    tooltip_text = _("Frequency");
 		    break;
 
         case SCHEDULED_FORM_LIMIT_DATE:
             widget = gsb_calendar_entry_new (FALSE);
+			gtk_widget_set_hexpand (widget, TRUE);
             g_signal_connect ( G_OBJECT (widget),
                         "button-press-event",
                         G_CALLBACK (gsb_form_scheduler_button_press_event),
@@ -228,15 +229,10 @@ gboolean gsb_form_scheduler_create ( GtkWidget *table )
                         element );
 
 	    /* set in the form */
-	    gtk_table_attach ( GTK_TABLE (table),
-                        widget,
-                        column, column+1,
-                        row, row+1,
-                        GTK_EXPAND | GTK_FILL,
-                        GTK_EXPAND | GTK_FILL,
-                        0, 0);
+	    gtk_grid_attach ( GTK_GRID (table), widget, column, row, 1, 1 );
 	}
     gsb_form_scheduler_clean ( );
+
     return FALSE;
 }
 
@@ -265,10 +261,6 @@ gboolean gsb_form_scheduler_free_list ( void )
 	struct_element *element;
 
 	element = list_tmp -> data;
-	if (element -> element_widget
-	    &&
-	    GTK_IS_WIDGET (element -> element_widget))
-	    gtk_widget_destroy (element -> element_widget);
 	g_free (element);
 
 	list_tmp = list_tmp -> next;
@@ -309,7 +301,7 @@ gboolean gsb_form_scheduler_change_account ( GtkWidget *button,
     if ( category_entry )
     {
         tmp_str = gtk_combofix_get_text ( GTK_COMBOFIX ( category_entry) );
-        if ( gsb_form_widget_check_empty (GTK_COMBOFIX (category_entry) -> entry)
+        if ( gsb_form_widget_check_empty (category_entry)
          &&
          tmp_str
          && strlen ( tmp_str ) > 0
@@ -332,12 +324,11 @@ gboolean gsb_form_scheduler_change_account ( GtkWidget *button,
     save_execute = GPOINTER_TO_INT (g_object_get_data ( G_OBJECT (gsb_form_get_form_widget ()),
 							"execute_scheduled"));
     content_list = gsb_form_scheduler_get_content_list ();
-
-    gsb_form_fill_from_account (new_account_number);
+	gsb_form_clean (new_account_number);
 
     /* a problem now, fill_from_account will clean the form,
      * and make unsensitive some part of the form (method of payment...)
-     * and make sensitive some other part wich could be unsensitive (for split for example)
+     * and make sensitive some other part which could be unsensitive (for split for example)
      * so we call gsb_form_set_sensitive, but 2 args, split or child.
      * cannot be a child because child cannot access to the account button, so just to check
      * if it's a split (done before)
@@ -381,7 +372,7 @@ GSList *gsb_form_scheduler_get_content_list ( void )
 
 	element = tmp_list -> data;
 
-	if (GTK_WIDGET_VISIBLE (element -> element_widget))
+	if (gtk_widget_get_visible (element -> element_widget))
 	{
 	    content_element *element_save;
 
@@ -441,13 +432,15 @@ GSList *gsb_form_scheduler_get_content_list ( void )
 		case TRANSACTION_FORM_PARTY:
 		case TRANSACTION_FORM_CATEGORY:
 		case TRANSACTION_FORM_BUDGET:
-		    if (!gsb_form_widget_check_empty (GTK_COMBOFIX (element -> element_widget) -> entry))
+		    if (!gsb_form_widget_check_empty (element -> element_widget))
 		    {
-			element_save = g_malloc0 (sizeof (content_element));
-			element_save -> element_number = element -> element_number;
-			element_save -> element_string = my_strdup (gtk_combofix_get_text (GTK_COMBOFIX (element -> element_widget)));
-			content_list = g_slist_append ( content_list,
-							element_save );
+				const gchar *tmp_str;
+
+				tmp_str = gtk_combofix_get_text (GTK_COMBOFIX (element->element_widget));
+				element_save = g_malloc0 (sizeof (content_element));
+				element_save->element_number = element->element_number;
+				element_save->element_string = my_strdup (tmp_str);
+				content_list = g_slist_append ( content_list, element_save );
 		    }
 		    break;
 	    }
@@ -496,7 +489,7 @@ void gsb_form_scheduler_set_content_list ( GSList *content_list )
 
 	    form_element = form_list -> data;
 
-	    if (!GTK_WIDGET_VISIBLE (form_element -> element_widget)
+	    if (!gtk_widget_get_visible (form_element -> element_widget)
 		||
 		form_element -> element_number != element -> element_number)
 	    {
@@ -552,8 +545,7 @@ void gsb_form_scheduler_set_content_list ( GSList *content_list )
 		case TRANSACTION_FORM_BUDGET:
 		    gsb_form_entry_get_focus (form_element -> element_widget);
             if ( element -> element_string )
-                gtk_combofix_set_text ( GTK_COMBOFIX ( form_element -> element_widget ),
-                                element -> element_string );
+                gtk_combofix_set_text (GTK_COMBOFIX (form_element->element_widget), element->element_string);
 		    break;
 	    }
 	    form_list = form_list -> next;
@@ -630,6 +622,17 @@ gboolean gsb_form_scheduler_clean ( void )
 	    switch (column)
 	    {
 		case SCHEDULED_FORM_ACCOUNT:
+			if (etat.scheduler_set_default_account)
+			{
+				g_signal_handlers_block_by_func (widget, gsb_form_scheduler_change_account, NULL);
+				gsb_account_set_combo_account_number (widget, etat.scheduler_default_account_number);
+				g_signal_handlers_unblock_by_func (widget, gsb_form_scheduler_change_account, NULL);
+			}
+			else
+				gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
+			gtk_widget_set_sensitive ( widget, FALSE );
+			break;
+
 		case SCHEDULED_FORM_AUTO:
 		case SCHEDULED_FORM_FREQUENCY_BUTTON:
 		case SCHEDULED_FORM_FREQUENCY_USER_BUTTON:
@@ -771,7 +774,7 @@ GtkWidget *gsb_form_scheduler_get_element_widget ( gint element_number )
  * called when we press the button in an entry field in
  * the form for the scheduled part
  *
- * \param entry wich receive the signal
+ * \param entry which receive the signal
  * \param ev can be NULL
  * \param ptr_origin a pointer to int on the element_number
  *
@@ -781,11 +784,8 @@ gboolean gsb_form_scheduler_button_press_event ( GtkWidget *entry,
                         GdkEventButton *ev,
                         gint *ptr_origin )
 {
-    gint element_number;
     GtkWidget *date_entry;
 
-    element_number = GPOINTER_TO_INT (ptr_origin);
-
     /* set the form sensitive */
     gsb_form_change_sensitive_buttons (TRUE);
 
@@ -806,7 +806,7 @@ gboolean gsb_form_scheduler_button_press_event ( GtkWidget *entry,
  *
  * \param entry
  * \param ev
- * \param ptr_origin a pointer gint wich is the number of the element
+ * \param ptr_origin a pointer gint which is the number of the element
  *
  * \return FALSE
  * */
@@ -816,13 +816,10 @@ gboolean gsb_form_scheduler_entry_lose_focus ( GtkWidget *entry,
 {
     gchar *string;
     gint element_number;
-    gint account_number;
 
     /* remove the selection */
-
     gtk_editable_select_region ( GTK_EDITABLE ( entry ), 0, 0 );
     element_number = GPOINTER_TO_INT ( ptr_origin );
-    account_number = gsb_form_get_account_number ();
 
     /* string will be filled only if the field is empty */
     string = NULL;
@@ -871,7 +868,7 @@ gboolean gsb_form_scheduler_frequency_button_changed ( GtkWidget *combo_box,
 {
     gchar *selected_item;
 
-    selected_item = gtk_combo_box_get_active_text ( GTK_COMBO_BOX (combo_box));
+    selected_item = gsb_combo_box_get_active_text ( GTK_COMBO_BOX ( combo_box ) );
 
     if ( !strcmp ( selected_item,
 		   _("Once")))
@@ -1067,7 +1064,7 @@ GDate *gsb_form_scheduler_get_limit_date ( void )
 	||
 	gsb_form_widget_check_empty (entry)
 	||
-	!GTK_WIDGET_VISIBLE (entry))
+	!gtk_widget_get_visible (entry))
 	return NULL;
 
     date = gsb_calendar_entry_get_date (entry);
@@ -1089,7 +1086,7 @@ gboolean gsb_form_scheduler_set_limit_date ( GDate *date )
     entry = gsb_form_scheduler_get_element_widget ( SCHEDULED_FORM_LIMIT_DATE );
 
     /* if no entry, go away... */
-    if (!entry || !GTK_WIDGET_VISIBLE ( entry ) )
+    if (!entry || !gtk_widget_get_visible ( entry ) )
         return FALSE;
 
     if ( !date )
@@ -1145,7 +1142,7 @@ gboolean gsb_form_scheduler_set_frequency_user ( gint user_freq )
     /* if no entry, go away... */
     if (!entry
 	||
-	!GTK_WIDGET_VISIBLE (entry))
+	!gtk_widget_get_visible (entry))
 	return FALSE;
 
     string = utils_str_itoa (user_freq);
@@ -1195,7 +1192,7 @@ gboolean gsb_form_scheduler_set_frequency_user_button ( gboolean automatic )
     /* if no automatic button, go away... */
     if (!button
 	||
-	!GTK_WIDGET_VISIBLE (button))
+	!gtk_widget_get_visible (button))
 	return FALSE;
 
     return gsb_combo_box_set_index ( button,
@@ -1232,7 +1229,63 @@ gboolean gsb_form_scheduler_recover_splits_of_transaction ( gint scheduled_trans
     return FALSE;
 }
 
+/**
+ * set fixed date if available for the scheduled transaction
+ *
+ * \param	sheduled number
+ * \param	date
+ *
+ * \return
+ **/
+gint gsb_form_scheduler_get_last_day_of_month_dialog (gint scheduled_number,
+													  GDate *date)
+{
+	GtkWidget *dialog = NULL;
+	gchar *msg;
+	gchar *tmp_str;
+	GDateDay day;
+	gint fixed_date = 0;
+	gint result;
 
+	day = g_date_get_day (date);
+	tmp_str = g_strdup_printf (_("Keep the %d"), day);
+	msg = g_strdup_printf (_("Do you want to keep the \"%d\" as the date or to force the last day of the month?\n\n"), day);
+
+	dialog = dialogue_special_no_run (GTK_MESSAGE_QUESTION,
+									  GTK_BUTTONS_NONE,
+									  msg,
+									  _("This is the last day of the month"));
+
+	gtk_dialog_add_buttons (GTK_DIALOG(dialog),
+							tmp_str, GTK_RESPONSE_NO,
+							_("Force the last day of the month"), GTK_RESPONSE_YES,
+							NULL);
+
+	result = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	if (result == GTK_RESPONSE_YES)
+	{
+		fixed_date = 31;
+	}
+	else
+	{
+		fixed_date = day;
+	}
+
+	g_free (tmp_str);
+	g_free (msg);
+	gtk_widget_destroy (dialog);
+
+	return fixed_date;
+}
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
