@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -36,19 +36,23 @@
 /*START_INCLUDE*/
 #include "gsb_fyear_config.h"
 #include "dialog.h"
-#include "utils_dates.h"
+#include "grisbi_settings.h"
 #include "gsb_autofunc.h"
+#include "gsb_automem.h"
 #include "gsb_calendar_entry.h"
 #include "gsb_data_account.h"
 #include "gsb_data_fyear.h"
 #include "gsb_data_transaction.h"
 #include "gsb_file.h"
 #include "gsb_fyear.h"
-#include "traitement_variables.h"
-#include "utils.h"
-#include "transaction_list.h"
-#include "structures.h"
 #include "gsb_transactions_list.h"
+#include "structures.h"
+#include "traitement_variables.h"
+#include "transaction_list.h"
+#include "utils.h"
+#include "utils_buttons.h"
+#include "utils_dates.h"
+#include "utils_prefs.h"
 /*END_INCLUDE*/
 
 
@@ -59,9 +63,11 @@ enum fyear_list_column {
     FYEAR_END_DATE_COLUMN,
     FYEAR_INVALID_COLUMN,
     FYEAR_NUMBER_COLUMN,
-    NUM_FYEARS_COLUMNS,
+	FYEAR_ROW_COLOR,
+    NUM_FYEARS_COLUMNS
 };
 
+static GtkWidget *fyear_config_treeview = NULL;
 
 /*START_STATIC*/
 static gboolean gsb_fyear_config_add_fyear ( GtkWidget *tree_view );
@@ -69,7 +75,7 @@ static void gsb_fyear_config_append_line ( GtkTreeModel *model,
 				    gint fyear_number,
 				    GtkTreeIter *iter_to_fill );
 static gboolean gsb_fyear_config_associate_transactions ( void );
-static GtkWidget *gsb_fyear_config_create_list ();
+static GtkWidget *gsb_fyear_config_create_list ( void );
 static void gsb_fyear_config_fill_list ( GtkTreeModel *model );
 static gboolean gsb_fyear_config_modify_fyear ( GtkWidget *entry,
 					 GtkWidget *tree_view);
@@ -82,7 +88,39 @@ static void gsb_fyear_update_invalid ( GtkWidget *tree_view );
 /*START_EXTERN*/
 /*END_EXTERN*/
 
+/******************************************************************************/
+/* Private Functions                                                          */
+/******************************************************************************/
+/**
+ *
+ *
+ * \param
+ * \param
+ *
+ * \return
+ * */
+static void gsb_fyear_config_button_sort_order_clicked (GtkWidget *toggle_button,
+														  gpointer data)
+{
+	GSettings *settings;
+    GtkTreeModel *model;
 
+	settings = grisbi_settings_get_settings (SETTINGS_PREFS);
+	g_settings_set_int ( G_SETTINGS (settings),
+                        "prefs-fyear-sort-order",
+                        conf.prefs_fyear_sort_order);
+
+    model = gtk_tree_view_get_model (GTK_TREE_VIEW (fyear_config_treeview));
+    gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE(model),
+                                          FYEAR_NAME_COLUMN,
+                                          conf.prefs_fyear_sort_order);
+    gtk_tree_sortable_sort_column_changed (GTK_TREE_SORTABLE(model));
+    gsb_fyear_config_fill_list (model);
+}
+
+/******************************************************************************/
+/* Public Functions                                                           */
+/******************************************************************************/
 /**
  * Creates the "Financial years" tab.  It creates a financial years
  * list and then a form that allows to edit selected financial year.
@@ -93,176 +131,133 @@ static void gsb_fyear_update_invalid ( GtkWidget *tree_view );
  */
 GtkWidget *gsb_fyear_config_create_page ( void )
 {
-    GtkWidget *vbox_pref, *label;
-    GtkWidget *scrolled_window, *vbox, *hbox;
-    GtkWidget *paddingbox, *table;
-    GtkWidget *tree_view;
-    GtkTreeModel *tree_model;
+    GtkWidget *vbox_pref;
+    GtkWidget *label;
+    GtkWidget *scrolled_window;
+    GtkWidget *paddinggrid;
     GtkWidget *entry;
     GtkWidget *button;
+    GtkTreeModel *tree_model;
 
-    vbox_pref = new_vbox_with_title_and_icon ( _("Financial years"),
-					       "financial-years.png" );
-    paddingbox = new_paddingbox_with_title ( vbox_pref, TRUE,
-					     _("Known financial years") );
-    hbox = gtk_hbox_new ( FALSE, 5 );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox,
-			 TRUE, TRUE, 0);
+    vbox_pref = new_vbox_with_title_and_icon (_("Financial years"), "gsb-financial-years-32.png");
+
+    paddinggrid = utils_prefs_paddinggrid_new_with_title (vbox_pref, _("Known financial years"));
 
     /* Create financial years list */
-    scrolled_window = gtk_scrolled_window_new ( NULL, NULL );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), scrolled_window,
-			 TRUE, TRUE, 0);
-    gtk_scrolled_window_set_policy ( GTK_SCROLLED_WINDOW ( scrolled_window ),
-				     GTK_POLICY_AUTOMATIC,
-				     GTK_POLICY_AUTOMATIC);
+    scrolled_window = utils_prefs_scrolled_window_new (NULL, GTK_SHADOW_IN, SW_COEFF_UTIL_PG, SW_MIN_HEIGHT);
+    gtk_grid_attach (GTK_GRID (paddinggrid), scrolled_window, 0, 0, 2, 3);
 
-    tree_view = gsb_fyear_config_create_list ();
-    tree_model = gtk_tree_view_get_model (GTK_TREE_VIEW (tree_view));
-    gtk_container_add ( GTK_CONTAINER ( scrolled_window ),
-			tree_view);
-    g_signal_connect ( gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view)),
+	/* Create button for sort variable */
+	button = gsb_automem_checkbutton_blue_new (_("Sort the exercises by descending name"),
+                        &(conf.prefs_fyear_sort_order),
+                        G_CALLBACK (gsb_fyear_config_button_sort_order_clicked),
+                        "prefs-fyear-sort-order");
+    gtk_grid_attach (GTK_GRID (paddinggrid), button, 0, 3, 2, 1);
+
+    fyear_config_treeview = gsb_fyear_config_create_list ();
+    tree_model = gtk_tree_view_get_model (GTK_TREE_VIEW (fyear_config_treeview));
+    gtk_container_add (GTK_CONTAINER ( scrolled_window ), fyear_config_treeview);
+    g_signal_connect ( gtk_tree_view_get_selection (GTK_TREE_VIEW (fyear_config_treeview)),
 		       "changed",
 		       G_CALLBACK (gsb_fyear_config_select),
 		       NULL );
 
-
     /* Do not activate unless an account is opened */
     if ( gsb_data_account_get_accounts_amount () )
-	gsb_fyear_config_fill_list (tree_model);
+	{
+		gsb_fyear_config_fill_list (tree_model);
+		/* set column color */
+		utils_set_list_store_background_color (fyear_config_treeview, FYEAR_ROW_COLOR);
+	}
     else
-	gtk_widget_set_sensitive ( vbox_pref, FALSE );
-
-
-    /* Order buttons in a vbox */
-    vbox = gtk_vbox_new ( FALSE, 5 );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), vbox,
-			 FALSE, FALSE, 0 );
+		gtk_widget_set_sensitive ( vbox_pref, FALSE );
 
     /* Add button */
-    button = gtk_button_new_from_stock (GTK_STOCK_ADD);
+    button = utils_buttons_button_new_from_stock ("gtk-add", _("Add"));
+    gtk_widget_set_margin_end (button, MARGIN_END);
+    utils_widget_set_padding (button, 0, MARGIN_TOP);
     g_signal_connect_swapped ( G_OBJECT (button),
 			       "clicked",
 			       G_CALLBACK  (gsb_fyear_config_add_fyear),
-			       tree_view );
-    gtk_box_pack_start ( GTK_BOX ( vbox ), button,
-			 FALSE, FALSE, 5 );
-    /* Remove button */
-    button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
-    gtk_widget_set_sensitive ( button, FALSE );
-    g_object_set_data ( G_OBJECT (tree_model),
-			"remove_fyear_button", button );
-    g_signal_connect_swapped ( G_OBJECT (button),
+			       fyear_config_treeview );
+    gtk_grid_attach (GTK_GRID (paddinggrid), button, 0, 4, 1, 1);
+
+    /* Button "Remove" */
+    button = utils_buttons_button_new_from_stock ("gtk-remove", _("Remove"));
+    utils_widget_set_padding (button, 0, MARGIN_TOP);
+    gtk_widget_set_sensitive (button, FALSE);
+    g_object_set_data ( G_OBJECT (tree_model), "remove_fyear_button", button );
+    g_signal_connect_swapped (G_OBJECT (button),
 			       "clicked",
 			       G_CALLBACK  (gsb_fyear_config_remove_fyear),
-			       tree_view );
-    gtk_box_pack_start ( GTK_BOX ( vbox ), button,
-			 FALSE, FALSE, 5 );
+			       fyear_config_treeview);
+    gtk_grid_attach (GTK_GRID (paddinggrid), button, 1, 4, 1, 1);
 
     /* Associate operations : under the list */
-    hbox = gtk_hbox_new ( FALSE, 5 );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox,
-			 FALSE, FALSE, 0);
-
     button = gtk_button_new_with_label ( _("Associate operations without financial years") );
-    g_signal_connect ( G_OBJECT ( button ),
+    g_signal_connect (G_OBJECT ( button ),
 			 "clicked",
 			 G_CALLBACK ( gsb_fyear_config_associate_transactions ),
-			 NULL );
-    gtk_box_pack_start ( GTK_BOX (hbox), button,
-			 FALSE, FALSE, 5 );
+			 NULL);
+    gtk_grid_attach (GTK_GRID (paddinggrid), button, 0, 5, 2, 1);
     gtk_widget_show ( button );
 
     /* Financial year details */
-    paddingbox = new_paddingbox_with_title ( vbox_pref, FALSE,
-						     _("Financial year details") );
-    g_object_set_data ( G_OBJECT (tree_model),
-			"paddingbox_details", paddingbox );
-
-    /* create a hbox, the table on the left
-     * and the warning on the right */
-    hbox = gtk_hbox_new ( FALSE, 0);
-    gtk_box_pack_start ( GTK_BOX (paddingbox), hbox,
-			 FALSE, FALSE, 0 );
-
-    /* Put stuff in a table */
-    table = gtk_table_new ( 2, 2, FALSE );
-    gtk_table_set_row_spacings ( GTK_TABLE ( table ), 6 );
-    gtk_table_set_col_spacings ( GTK_TABLE ( table ), 6 );
-    gtk_box_pack_start ( GTK_BOX (hbox), table,
-			 FALSE, FALSE, 0 );
+    paddinggrid = utils_prefs_paddinggrid_new_with_title ( vbox_pref, _("Financial year details") );
+    g_object_set_data ( G_OBJECT (tree_model), "paddingbox_details", paddinggrid );
 
     /* Financial year name */
     label = gtk_label_new ( _("Name: ") );
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 0, 1,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+	utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 0, 1, 1);
+
     entry = gsb_autofunc_entry_new ( NULL,
-				     G_CALLBACK (gsb_fyear_config_modify_fyear), tree_view,
+				     G_CALLBACK (gsb_fyear_config_modify_fyear), fyear_config_treeview,
 				     G_CALLBACK (gsb_data_fyear_set_name), 0 );
-    g_object_set_data ( G_OBJECT (tree_model),
-			"fyear_name_entry", entry );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       entry, 1, 2, 0, 1,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    g_object_set_data ( G_OBJECT (tree_model), "fyear_name_entry", entry );
+    gtk_widget_set_margin_end (entry, MARGIN_END);
+    gtk_grid_attach (GTK_GRID (paddinggrid), entry, 1, 0, 1, 1);
 
     /* Start */
     label = gtk_label_new ( _("Start: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 1, 2,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 1, 1, 1);
+
     entry = gsb_autofunc_date_new ( NULL,
-				    G_CALLBACK (gsb_fyear_config_modify_fyear), tree_view,
+				    G_CALLBACK (gsb_fyear_config_modify_fyear), fyear_config_treeview,
 				    G_CALLBACK (gsb_data_fyear_set_beginning_date), 0 );
-    g_object_set_data ( G_OBJECT (tree_model),
-			"fyear_begin_date_entry", entry );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       entry, 1, 2, 1, 2,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    g_object_set_data ( G_OBJECT (tree_model), "fyear_begin_date_entry", entry );
+    gtk_widget_set_margin_end (entry, MARGIN_END);
+    gtk_grid_attach (GTK_GRID (paddinggrid), entry, 1, 1, 1, 1);
 
     /* End */
     label = gtk_label_new ( _("End: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 2, 3,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 0, 2, 1, 1);
+
     entry = gsb_autofunc_date_new ( NULL,
-				    G_CALLBACK (gsb_fyear_config_modify_fyear), tree_view,
+				    G_CALLBACK (gsb_fyear_config_modify_fyear), fyear_config_treeview,
 				    G_CALLBACK (gsb_data_fyear_set_end_date), 0 );
-    g_object_set_data ( G_OBJECT (tree_model),
-			"fyear_end_date_entry", entry );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       entry, 1, 2, 2, 3,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    g_object_set_data ( G_OBJECT (tree_model), "fyear_end_date_entry", entry );
+    gtk_widget_set_margin_end (entry, MARGIN_END);
+    gtk_grid_attach (GTK_GRID (paddinggrid), entry, 1, 2, 1, 1);
 
     /* label showed if the fyear is invalid */
     label = gtk_label_new (NULL);
-    g_object_set_data ( G_OBJECT (tree_model),
-			"invalid_label", label );
-    gtk_box_pack_start ( GTK_BOX (hbox), label,
-			 FALSE, FALSE, 0 );
+	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+    g_object_set_data ( G_OBJECT (tree_model), "invalid_label", label );
+    gtk_grid_attach (GTK_GRID (paddinggrid), label, 2, 1, 2, 2);
 
     /* Activate in transaction form? */
     button = gsb_autofunc_checkbutton_new ( _("Activate financial year in transaction form"), FALSE,
 					    NULL, NULL,
 					    G_CALLBACK (gsb_data_fyear_set_form_show), 0);
-    g_object_set_data ( G_OBJECT (tree_model),
-			"fyear_show_button", button );
-    gtk_box_pack_start ( GTK_BOX (paddingbox), button,
-			 FALSE, FALSE, 0 );
+    g_object_set_data ( G_OBJECT (tree_model), "fyear_show_button", button );
+    gtk_widget_set_margin_top (button, MARGIN_TOP);
+    gtk_grid_attach (GTK_GRID (paddinggrid), button, 0, 3, 4, 1);
 
-    gtk_widget_set_sensitive (paddingbox, FALSE );
+    gtk_widget_set_sensitive (paddinggrid, FALSE );
 
     return ( vbox_pref );
 }
@@ -270,13 +265,13 @@ GtkWidget *gsb_fyear_config_create_page ( void )
 
 
 /**
- * create the tree wich contains the fyear list
+ * create the tree which contains the fyear list
  *
  * \param
  *
  * \return a GtkTreeView
  */
-GtkWidget *gsb_fyear_config_create_list ()
+GtkWidget *gsb_fyear_config_create_list ( void )
 {
     GtkListStore *model;
     GtkWidget *treeview;
@@ -295,12 +290,13 @@ GtkWidget *gsb_fyear_config_create_list ()
 				 G_TYPE_STRING,
 				 G_TYPE_STRING,
 				 G_TYPE_STRING,
-				 G_TYPE_INT );
+				 G_TYPE_INT,
+				 GDK_TYPE_RGBA);
 
     /* Create tree tree_view */
     treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(model));
+	gtk_widget_set_name (treeview, "tree_view");
     g_object_unref (G_OBJECT(model));
-    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
 
     /* for all the columns it's a text */
     cell_renderer = gtk_cell_renderer_text_new ();
@@ -312,34 +308,36 @@ GtkWidget *gsb_fyear_config_create_list ()
      * the last value of the model mustn't be to text...
      * so FYEAR_NUMBER_COLUMN must be the first column after the last column showed */
 
-    for (i=0 ; i<FYEAR_NUMBER_COLUMN ; i++ )
+    for (i=0 ; i<FYEAR_NUMBER_COLUMN - 1; i++ )
     {
-	GtkTreeViewColumn *column;
+		GtkTreeViewColumn *column;
 
-	if ( i == FYEAR_INVALID_COLUMN )
-	{
-	    column = gtk_tree_view_column_new_with_attributes ( title[i],
-								gtk_cell_renderer_pixbuf_new (),
-								"stock-id", i,
-								NULL );
-	}
-	else
-	{
-	    column = gtk_tree_view_column_new_with_attributes ( title[i],
-								cell_renderer,
-								"text", i,
-								NULL );
-	    gtk_tree_view_column_set_sizing ( column,
-					      GTK_TREE_VIEW_COLUMN_AUTOSIZE );
-	    gtk_tree_view_column_set_expand ( column, TRUE );
-	}
-	gtk_tree_view_append_column ( GTK_TREE_VIEW(treeview),
-				      column );
+		if ( i == FYEAR_INVALID_COLUMN )
+		{
+			column = gtk_tree_view_column_new_with_attributes ( title[i],
+									gtk_cell_renderer_pixbuf_new (),
+									"stock-id", i,
+									"cell-background-rgba", FYEAR_ROW_COLOR,
+									NULL );
+		}
+		else
+		{
+			column = gtk_tree_view_column_new_with_attributes ( title[i],
+									cell_renderer,
+									"text", i,
+									"cell-background-rgba", FYEAR_ROW_COLOR,
+									NULL );
+			gtk_tree_view_column_set_sizing ( column,
+							  GTK_TREE_VIEW_COLUMN_AUTOSIZE );
+			gtk_tree_view_column_set_expand ( column, TRUE );
+		}
+		gtk_tree_view_append_column ( GTK_TREE_VIEW(treeview), column );
     }
 
     /* Sort columns accordingly */
     gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE(model),
-					  FYEAR_NAME_COLUMN, GTK_SORT_ASCENDING);
+                                          FYEAR_NAME_COLUMN,
+                                          conf.prefs_fyear_sort_order);
 
     return treeview;
 }
@@ -395,7 +393,7 @@ void gsb_fyear_config_append_line ( GtkTreeModel *model,
 	iter_ptr = &local_iter;
 
     if ( gsb_data_fyear_get_invalid (fyear_number))
-	invalid = GTK_STOCK_DIALOG_WARNING;
+	invalid = "gtk-dialog-warning";
     else
 	invalid = NULL;
 
@@ -426,7 +424,6 @@ gboolean gsb_fyear_config_select ( GtkTreeSelection *tree_selection,
     GtkTreeModel *model;
     GtkTreeIter iter;
     gint fyear_number;
-    GtkWidget *tree_view;
     GtkWidget *widget;
 
     if (!gtk_tree_selection_get_selected ( GTK_TREE_SELECTION (tree_selection),
@@ -439,8 +436,6 @@ gboolean gsb_fyear_config_select ( GtkTreeSelection *tree_selection,
 			 FYEAR_NUMBER_COLUMN, &fyear_number,
 			 -1 );
 
-    tree_view = GTK_WIDGET (gtk_tree_selection_get_tree_view (tree_selection));
-
     /* set the name */
     widget = g_object_get_data ( G_OBJECT (model),
 				 "fyear_name_entry" );
@@ -500,7 +495,7 @@ gboolean gsb_fyear_config_select ( GtkTreeSelection *tree_selection,
  * called when something change for a fyear
  * update the list and the invalid
  *
- * \param entry the entry wich change
+ * \param entry the entry which change
  * \param tree_view the tree_view
  *
  * \return FALSE
@@ -539,7 +534,7 @@ gboolean gsb_fyear_config_modify_fyear ( GtkWidget *entry,
      if (gsb_data_fyear_get_invalid (fyear_number))
      {
 	 /* and now focus on the current fyear */
-	 invalid = GTK_STOCK_DIALOG_WARNING;
+	 invalid = "gtk-dialog-warning";
 	 gtk_label_set_markup ( GTK_LABEL (widget),
 				gsb_data_fyear_get_invalid_message (fyear_number));
 	 gtk_widget_show (widget);
@@ -592,7 +587,7 @@ void gsb_fyear_update_invalid ( GtkWidget *tree_view )
 			     FYEAR_NUMBER_COLUMN, &fyear_number,
 			     -1 );
 	if (gsb_data_fyear_get_invalid (fyear_number))
-	    invalid = GTK_STOCK_DIALOG_WARNING;
+	    invalid = "gtk-dialog-warning";
 	else
 	    invalid = NULL;
 
@@ -677,9 +672,10 @@ gboolean gsb_fyear_config_remove_fyear ( GtkWidget *tree_view )
     GSList *tmp_list;
 
     selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
-    gtk_tree_selection_get_selected ( GTK_TREE_SELECTION (selection),
+    if (! gtk_tree_selection_get_selected ( GTK_TREE_SELECTION (selection),
 				      &model,
-				      &iter );
+				      &iter ))
+        return FALSE;
     gtk_tree_model_get ( GTK_TREE_MODEL (model),
 			 &iter,
 			 FYEAR_NUMBER_COLUMN, &fyear_number,
@@ -711,9 +707,9 @@ gboolean gsb_fyear_config_remove_fyear ( GtkWidget *tree_view )
 	    {
 		gint result;
 
-		result = question_yes_no_hint ( _("The selected financial year is used in the file"),
-						_("If you really remove it, all the associated transactions will be without financial year.\nAre you sure?"),
-						GTK_RESPONSE_NO );
+		result = question_yes_no ( _("If you really remove it, all the associated transactions will be without financial year.\nAre you sure?"),
+		                           _("The selected financial year is used in the file"),
+		                           GTK_RESPONSE_NO );
 		if (result)
 		{
 		    gsb_data_transaction_set_financial_year_number (transaction_number, 0);
@@ -732,19 +728,19 @@ gboolean gsb_fyear_config_remove_fyear ( GtkWidget *tree_view )
 	||
 	!tmp_list )
     {
-	gsb_data_fyear_remove (fyear_number);
+        gsb_data_fyear_remove (fyear_number);
 
-	gtk_list_store_remove ( GTK_LIST_STORE (model),
-				&iter );
-	gtk_widget_set_sensitive ( g_object_get_data ( G_OBJECT (model),
-						       "paddingbox_details" ),
-				   FALSE );
-	gtk_widget_set_sensitive ( g_object_get_data ( G_OBJECT (model),
-						       "remove_fyear_button" ),
-				   FALSE );
+        gtk_list_store_remove ( GTK_LIST_STORE (model), &iter );
 
-	/* Update various menus */
-	gsb_fyear_update_fyear_list ();
+        if (g_slist_length ( gsb_data_fyear_get_fyears_list ()) == 0)
+        {
+            gtk_widget_set_sensitive ( g_object_get_data ( G_OBJECT (model), "paddingbox_details" ),
+                           FALSE );
+            gtk_widget_set_sensitive ( g_object_get_data ( G_OBJECT (model), "remove_fyear_button" ),
+                           FALSE );
+        }
+
+        /* Update various menus */
         gsb_file_set_modified ( TRUE );
     }
     return FALSE;
@@ -766,9 +762,9 @@ gboolean gsb_fyear_config_associate_transactions ( void )
     GSList *list_tmp;
     gint modification_number = 0;
 
-    if (!question_yes_no_hint ( _("Automatic association of financial years?"),
-				_("This function assigns each transaction without a financial year to the one related to its transaction date.  If no financial year matches, the transaction will not be changed."),
-				GTK_RESPONSE_NO ))
+    if (!question_yes_no ( _("This function assigns each transaction without a financial year to the one related to its transaction date.  If no financial year matches, the transaction will not be changed."),
+                           _("Automatic association of financial years?"),
+                           GTK_RESPONSE_NO ))
 	return FALSE;
 
     list_tmp = gsb_data_transaction_get_complete_transactions_list ();
@@ -808,9 +804,13 @@ gboolean gsb_fyear_config_associate_transactions ( void )
     return FALSE;
 }
 
-
-
-
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ * */
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
