@@ -1,8 +1,9 @@
 /* ************************************************************************** */
 /*                                                                            */
-/*     copyright (c)	2000-2007 Cédric Auger (cedric@grisbi.org)	          */
-/*			2004-2007 Benjamin Drieu (bdrieu@april.org) 	                  */
-/*			http://www.grisbi.org   			                              */
+/*     copyright (c)    2000-2007 Cédric Auger (cedric@grisbi.org)            */
+/*          2004-2007 Benjamin Drieu (bdrieu@april.org)                       */
+/*                      2008-2013 Pierre Biava (grisbi@pierre.biava.name)     */
+/*          http://www.grisbi.org                                             */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -25,7 +26,7 @@
  * all that you need for the config of the payment method is here !!!
  */
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -35,6 +36,7 @@
 #include "gsb_payment_method_config.h"
 #include "dialog.h"
 #include "gsb_autofunc.h"
+#include "gsb_combo_box.h"
 #include "gsb_data_account.h"
 #include "gsb_data_form.h"
 #include "gsb_data_payment.h"
@@ -50,6 +52,8 @@
 #include "traitement_variables.h"
 #include "transaction_list.h"
 #include "utils.h"
+#include "utils_buttons.h"
+#include "utils_prefs.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -73,8 +77,8 @@ static gboolean gsb_payment_method_config_select ( GtkTreeSelection *selection,
 					    GtkWidget *tree_view );
 static gboolean gsb_payment_method_config_show_entry_changed ( GtkWidget *button,
 							GtkWidget *tree_view );
-static gboolean gsb_payment_method_config_sign_changed ( GtkWidget *menu_item,
-						  gint *sign );
+static gboolean gsb_payment_method_config_sign_changed ( GtkWidget *combo,
+                        gpointer data );
 static gboolean gsb_payment_method_config_switch_payment ( gint payment_number );
 static gboolean gsb_payment_method_config_toggled ( GtkCellRendererToggle *cell,
 					     gchar *path_str,
@@ -97,6 +101,13 @@ static GtkWidget *button_show_entry;
 
 /** Global to handle sensitiveness */
 static GtkWidget *details_paddingbox;
+static gchar *payment_sign_list[] =
+{
+    N_("Neutral"),
+    N_("Debit"),
+    N_("Credit"),
+    NULL
+};
 
 
 /**
@@ -108,34 +119,24 @@ static GtkWidget *details_paddingbox;
  */
 GtkWidget *gsb_payment_method_config_create ( void )
 {
-    GtkWidget *vbox_pref, *hbox, *scrolled_window, *paddingbox;
-    GtkWidget *vbox, *table, *menu, *item, *label;
+    GtkWidget *vbox_pref, *scrolled_window;
+    GtkWidget *paddinggrid;
+    GtkWidget *label;
     GtkTreeViewColumn *column;
     GtkCellRenderer *cell;
     GtkWidget *bouton_ajouter_type;
     GtkTreeStore *payment_method_model;
-    gint width_entry = 80;
+    gint width_entry = 150;
 
     /* Now we have a model, create view */
-    vbox_pref = new_vbox_with_title_and_icon ( _("Payment methods"),
-					       "payment.png" );
+    vbox_pref = new_vbox_with_title_and_icon (_("Payment methods"), "gsb-payment-32.png");
 
     /* Known payment methods */
-    paddingbox = new_paddingbox_with_title (vbox_pref, TRUE,
-					    _("Known payment methods"));
-    hbox = gtk_hbox_new ( FALSE, 6 );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox,
-			 TRUE, TRUE, 0 );
+    paddinggrid = utils_prefs_paddinggrid_new_with_title (vbox_pref, _("Known payment methods"));
 
     /* Create tree */
-    scrolled_window = gtk_scrolled_window_new ( NULL, NULL );
-    gtk_scrolled_window_set_policy ( GTK_SCROLLED_WINDOW ( scrolled_window ),
-				     GTK_POLICY_AUTOMATIC,
-				     GTK_POLICY_AUTOMATIC );
-    gtk_scrolled_window_set_shadow_type ( GTK_SCROLLED_WINDOW ( scrolled_window ),
-					  GTK_SHADOW_IN);
-    gtk_box_pack_start ( GTK_BOX ( hbox ), scrolled_window,
-			 TRUE, TRUE, 0 );
+    scrolled_window = utils_prefs_scrolled_window_new (NULL, GTK_SHADOW_IN, SW_COEFF_UTIL_PG, 250);
+    gtk_grid_attach (GTK_GRID (paddinggrid), scrolled_window, 0, 0, 2, 3);
 
     /* Create tree view */
     payment_method_model = gtk_tree_store_new (NUM_PAYMENT_METHODS_COLUMNS,
@@ -148,8 +149,8 @@ GtkWidget *gsb_payment_method_config_create ( void )
 					       G_TYPE_INT,
 					       G_TYPE_INT );
     payment_method_treeview = gtk_tree_view_new_with_model ( GTK_TREE_MODEL (payment_method_model) );
+	gtk_widget_set_name (payment_method_treeview, "tree_view");
     g_object_unref (G_OBJECT(payment_method_model));
-    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (payment_method_treeview), TRUE);
     g_signal_connect (gtk_tree_view_get_selection (GTK_TREE_VIEW (payment_method_treeview)),
 		      "changed",
 		      G_CALLBACK (gsb_payment_method_config_select),
@@ -192,149 +193,90 @@ GtkWidget *gsb_payment_method_config_create ( void )
     gtk_tree_view_append_column ( GTK_TREE_VIEW(payment_method_treeview), column);
 
     /* expand all rows after the treeview widget has been realized */
-    g_signal_connect (payment_method_treeview, "realize",
-		      G_CALLBACK (gtk_tree_view_expand_all), NULL);
-    gtk_container_add ( GTK_CONTAINER ( scrolled_window ),
-			payment_method_treeview );
+    g_signal_connect (payment_method_treeview,
+                      "realize",
+                      G_CALLBACK (gtk_tree_view_expand_all),
+                      NULL);
+    gtk_container_add ( GTK_CONTAINER ( scrolled_window ), payment_method_treeview );
 
     gsb_payment_method_config_fill_list (GTK_TREE_MODEL (payment_method_model));
 
-    /* Create "Add" & "Remove" buttons */
-    vbox = gtk_vbox_new ( FALSE, 6 );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), vbox,
-			 FALSE, FALSE, 0 );
-
     /* "Add payment method" button */
-    bouton_ajouter_type = gtk_button_new_from_stock (GTK_STOCK_ADD);
-    gtk_button_set_relief ( GTK_BUTTON ( bouton_ajouter_type ),
-			    GTK_RELIEF_NONE );
+    bouton_ajouter_type = utils_buttons_button_new_from_stock ("gtk-add", _("Add"));
+    gtk_widget_set_margin_end (bouton_ajouter_type, MARGIN_END);
+    utils_widget_set_padding (bouton_ajouter_type, 0, MARGIN_TOP);
     g_signal_connect ( G_OBJECT ( bouton_ajouter_type ),
 		       "clicked",
 		       G_CALLBACK (gsb_payment_method_config_add),
 		       payment_method_treeview );
-    gtk_box_pack_start ( GTK_BOX ( vbox ), bouton_ajouter_type,
-			 TRUE, FALSE, 5 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), bouton_ajouter_type, 0, 3, 1, 1);
 
     /* "Remove payment method" button */
-    payment_remove_button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
-    gtk_button_set_relief ( GTK_BUTTON ( payment_remove_button ),
-			    GTK_RELIEF_NONE );
-    gtk_widget_set_sensitive ( payment_remove_button, FALSE );
+    payment_remove_button = utils_buttons_button_new_from_stock ("gtk-remove", _("Remove"));
+    gtk_widget_set_margin_end (payment_remove_button, MARGIN_END);
+    utils_widget_set_padding (payment_remove_button, 0, MARGIN_TOP);
+    gtk_widget_set_sensitive (payment_remove_button, FALSE);
     g_signal_connect ( G_OBJECT ( payment_remove_button ),
 		       "clicked",
 		       G_CALLBACK (gsb_payment_method_config_remove),
 		       payment_method_treeview );
-    gtk_box_pack_start ( GTK_BOX ( vbox ), payment_remove_button,
-			 TRUE, FALSE, 5 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), payment_remove_button, 1, 3, 1, 1);
 
     /* Payment method details */
-    details_paddingbox = new_paddingbox_with_title (vbox_pref, FALSE,
-						    _("Payment method details"));
+    details_paddingbox = utils_prefs_paddinggrid_new_with_title (vbox_pref, _("Payment method details"));
     gtk_widget_set_sensitive ( details_paddingbox, FALSE );
 
     /* Payment method name */
-    table = gtk_table_new ( 3, 3, FALSE );
-    gtk_table_set_col_spacings ( GTK_TABLE ( table ), 6 );
-    gtk_table_set_row_spacings ( GTK_TABLE ( table ), 6 );
-    gtk_box_pack_start ( GTK_BOX ( details_paddingbox ), table,
-			 TRUE, TRUE, 6 );
-
     label = gtk_label_new ( _("Name: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 0, 1,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (details_paddingbox), label, 0, 0, 1, 1);
+
     payment_name_entry = gsb_autofunc_entry_new ( NULL,
                         G_CALLBACK (gsb_payment_method_config_name_changed),
                         payment_method_treeview,
                         G_CALLBACK (gsb_data_payment_set_name), 0 );
     gtk_widget_set_size_request ( payment_name_entry, width_entry, -1 );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       payment_name_entry, 1, 2, 0, 1,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (details_paddingbox), payment_name_entry, 1, 0, 1, 1);
 
     /* button show entry, automatic numbering button will be shown only if entry is showed */
     button_show_entry = gsb_autofunc_checkbutton_new ( _("Need entry field"),
 						       FALSE,
 						       G_CALLBACK (gsb_payment_method_config_show_entry_changed), payment_method_treeview,
 						       G_CALLBACK (gsb_data_payment_set_show_entry), 0 );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       button_show_entry, 2, 3, 0, 1,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (details_paddingbox), button_show_entry, 2, 0, 1, 1);
 
 
     /* Automatic numbering */
     label = gtk_label_new ( _("Automatic numbering: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 1, 2,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (details_paddingbox), label, 0, 1, 1, 1);
+
     payment_last_number_entry = gsb_autofunc_spin_new ( 0,
 						G_CALLBACK (gsb_payment_method_config_auto_entry_changed),
                         payment_method_treeview,
 						G_CALLBACK (gsb_data_payment_set_last_number_from_int),
                         0 );
     gtk_widget_set_size_request ( payment_last_number_entry, width_entry, -1 );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       payment_last_number_entry, 1, 2, 1, 2,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (details_paddingbox), payment_last_number_entry, 1, 1, 1, 1);
 
     /* button automatic numbering, activate it sensitive the automatic numbering entry */
     button_auto_numbering = gsb_autofunc_checkbutton_new ( _("Activate"),
 							   FALSE,
 							   G_CALLBACK (gsb_payment_method_config_auto_button_changed), payment_method_treeview,
 							   G_CALLBACK (gsb_data_payment_set_automatic_numbering), 0 );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       button_auto_numbering, 2, 3, 1, 2,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    gtk_grid_attach (GTK_GRID (details_paddingbox), button_auto_numbering, 2, 1, 1, 1);
 
     /* Payment method method_ptr */
     label = gtk_label_new ( _("Type: ") );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       label, 0, 1, 2, 3,
-		       GTK_SHRINK | GTK_FILL, 0,
-		       0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0, 1);
+    gtk_grid_attach (GTK_GRID (details_paddingbox), label, 0, 2, 1, 1);
 
-    /* Create menu */
-    payment_sign_button = gtk_option_menu_new ();
-    menu = gtk_menu_new();
-    /* Neutral method_ptr */
-    item = gtk_menu_item_new_with_label ( _("Neutral") );
-    g_signal_connect ( G_OBJECT ( item ),
-		       "activate",
-		       G_CALLBACK ( gsb_payment_method_config_sign_changed ),
-		       GINT_TO_POINTER (GSB_PAYMENT_NEUTRAL));
-    gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), item );
-    /* Debit method_ptr */
-    item = gtk_menu_item_new_with_label ( _("Debit") );
-    g_signal_connect ( G_OBJECT ( item ),
-		       "activate",
-		       G_CALLBACK ( gsb_payment_method_config_sign_changed ),
-		       GINT_TO_POINTER (GSB_PAYMENT_DEBIT));
-    gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), item );
-    /* Credit method_ptr */
-    item = gtk_menu_item_new_with_label ( _("Credit") );
-    g_signal_connect ( G_OBJECT ( item ),
-		       "activate",
-		       G_CALLBACK ( gsb_payment_method_config_sign_changed ),
-		       GINT_TO_POINTER (GSB_PAYMENT_CREDIT));
-    gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), item );
-    /* Set menu */
-    gtk_option_menu_set_menu ( GTK_OPTION_MENU ( payment_sign_button ), menu );
-    gtk_table_attach ( GTK_TABLE ( table ),
-		       payment_sign_button, 1, 3, 2, 3,
-		       GTK_EXPAND | GTK_FILL, 0,
-		       0, 0 );
+    //~ /* Create menu */
+    payment_sign_button = gsb_combo_box_new_with_index  ( payment_sign_list,
+                                G_CALLBACK ( gsb_payment_method_config_sign_changed ),
+                                NULL );
+    gtk_widget_set_size_request (payment_sign_button, width_entry, -1);
+    gtk_grid_attach (GTK_GRID (details_paddingbox), payment_sign_button, 1, 2, 1, 1);
 
     /** Do not set this tab sensitive is no account file is opened. */
     if ( !gsb_data_account_get_accounts_amount () )
@@ -523,8 +465,8 @@ gboolean gsb_payment_method_config_select ( GtkTreeSelection *selection,
 	    gsb_autofunc_checkbutton_set_value ( button_auto_numbering,
 						 gsb_data_payment_get_automatic_numbering (payment_number),
 						 payment_number );
-	    gtk_option_menu_set_history ( GTK_OPTION_MENU ( payment_sign_button ),
-					  gsb_data_payment_get_sign (payment_number));
+	    gsb_combo_box_set_index ( payment_sign_button,
+					  gsb_data_payment_get_sign ( payment_number ) );
 	    /* Activating widgets */
 	    gtk_widget_set_sensitive ( button_auto_numbering,
 				       gsb_data_payment_get_show_entry (payment_number));
@@ -544,7 +486,7 @@ gboolean gsb_payment_method_config_select ( GtkTreeSelection *selection,
 	    gtk_widget_set_sensitive ( button_auto_numbering, FALSE );
 	    gtk_widget_set_sensitive ( payment_last_number_entry, FALSE );
 	    /* We set menu to "Neutral" as a default*/
-	    gtk_option_menu_set_history ( GTK_OPTION_MENU ( payment_sign_button ), 0);
+        gsb_combo_box_set_index ( payment_sign_button, 0);
 	    /* Nothing to remove */
 	    gtk_widget_set_sensitive ( payment_remove_button, TRUE );
 
@@ -562,7 +504,7 @@ gboolean gsb_payment_method_config_select ( GtkTreeSelection *selection,
 	gtk_widget_set_sensitive ( button_auto_numbering, FALSE );
 	gtk_widget_set_sensitive ( payment_last_number_entry, FALSE );
 	/* We set menu to "Neutral" as a default*/
-	gtk_option_menu_set_history ( GTK_OPTION_MENU ( payment_sign_button ), 0);
+    gsb_combo_box_set_index ( payment_sign_button, 0);
 	/* Nothing to remove */
 	gtk_widget_set_sensitive ( payment_remove_button, TRUE );
 
@@ -733,7 +675,7 @@ gboolean gsb_payment_method_config_name_changed ( GtkWidget *entry,
 							   GSB_PAYMENT_DEBIT,
 							   account_number, 0, FALSE );
 
-		    if (GTK_WIDGET_VISIBLE (widget))
+		    if (gtk_widget_get_visible (widget))
 		    {
 			gsb_payment_method_set_combobox_history ( widget,
 								  gsb_data_account_get_default_debit (account_number), TRUE );
@@ -757,7 +699,7 @@ gboolean gsb_payment_method_config_name_changed ( GtkWidget *entry,
  * deactivated for current payment method.  It activates or
  * deactivates the automatic numbering button
  *
- * \param button the checkbutton wich send the signal
+ * \param button the checkbutton which send the signal
  * \param tree_view
  *
  * \return FALSE
@@ -795,7 +737,7 @@ gboolean gsb_payment_method_config_show_entry_changed ( GtkWidget *button,
  * deactivates the "current number" field and updates display of
  * current number in the list.
  *
- * \param button the checkbutton wich send the signal
+ * \param button the checkbutton which send the signal
  * \param tree_view
  *
  * \return FALSE
@@ -941,87 +883,99 @@ gint gsb_payment_method_config_get_transaction_by_sign ( gint account_number,
 /**
  * callback called when changing the sign type of the method of payment
  *
- * \param menu_item the widget wich receive the signal
+ * \param menu_item the widget which receive the signal
  * \param sign a pointer to an int : GSB_PAYMENT_NEUTRAL, GSB_PAYMENT_DEBIT or GSB_PAYMENT_CREDIT
  *
  * \return FALSE
  */
-gboolean gsb_payment_method_config_sign_changed ( GtkWidget *menu_item,
-						  gint *sign )
+gboolean gsb_payment_method_config_sign_changed ( GtkWidget *combo,
+                        gpointer data )
 {
+    GtkTreeModel *model;
     GtkTreeSelection *selection;
     GtkTreeIter iter;
     gboolean good;
 
-    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (payment_method_treeview));
-    good = gtk_tree_selection_get_selected (selection, NULL, &iter);
+    selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( payment_method_treeview ) );
+    good = gtk_tree_selection_get_selected ( selection, &model, &iter );
 
-    if (good)
+    if ( good )
     {
-	GtkTreeModel *model;
-	gint payment_number;
+        gint payment_number;
+        gint index;
 
-	model = gtk_tree_view_get_model ( GTK_TREE_VIEW (payment_method_treeview));
-	gtk_tree_model_get ( GTK_TREE_MODEL(model), &iter,
-			     PAYMENT_METHODS_NUMBER_COLUMN, &payment_number,
-			     -1 );
+        /* on bloque l'appel à la fonction gsb_payment_method_config_sign_changed */
+        g_signal_handlers_block_by_func ( payment_sign_button,
+                        G_CALLBACK ( gsb_payment_method_config_sign_changed ),
+                        NULL );
 
-	if (payment_number)
-	{
-	    gint account_number;
+        index = gtk_combo_box_get_active ( GTK_COMBO_BOX ( combo ) );
 
-	    /* Call this callback so that we "unselect" things */
-	    gsb_payment_method_config_select ( selection, payment_method_treeview);
+        gtk_tree_model_get ( GTK_TREE_MODEL ( model ),
+                        &iter,
+                        PAYMENT_METHODS_NUMBER_COLUMN, &payment_number,
+                        -1 );
 
-	    account_number = gsb_data_payment_get_account_number (payment_number);
+        if ( payment_number )
+        {
+            gint account_number;
 
-	    /* as we have changed the sign of the method of payment, check if it was the default
-	     * for the account, and if yes, change the default for that account */
-	    switch (gsb_data_payment_get_sign (payment_number))
-	    {
-		case GSB_PAYMENT_DEBIT:
-		    if ( gsb_data_account_get_default_debit (account_number) == payment_number)
-		    {
-			/* the current method of payment was a debit and was the default debit for its account,
-			 * so change the default to another debit */
-			gsb_data_account_set_default_debit ( account_number,
-							     gsb_payment_method_config_get_transaction_by_sign (account_number,
-											  GSB_PAYMENT_DEBIT,
-											  payment_number));
-		    }
-		    break;
+            /* Call this callback so that we "unselect" things */
+            gsb_payment_method_config_select ( selection, payment_method_treeview );
 
-		case GSB_PAYMENT_CREDIT:
-		    if ( gsb_data_account_get_default_credit (account_number) == payment_number)
-		    {
-			/* the current method of payment was a credit and was the default credit for its account,
-			 * so change the default to another credit */
-			gsb_data_account_set_default_credit ( account_number,
-							      gsb_payment_method_config_get_transaction_by_sign (account_number,
-											   GSB_PAYMENT_CREDIT,
-											   payment_number));
-		    }
-		    break;
-	    }
-	    gsb_data_payment_set_sign ( payment_number,
-					GPOINTER_TO_INT (sign));
+            account_number = gsb_data_payment_get_account_number ( payment_number );
 
-	    /* Update tree */
-	    g_signal_handlers_block_by_func ( selection,
-					      G_CALLBACK (gsb_payment_method_config_select),
-					      model );
-	    gsb_payment_method_config_fill_list (model);
-	    gtk_tree_view_expand_all ( GTK_TREE_VIEW(payment_method_treeview) );
-	    g_signal_handlers_unblock_by_func ( selection,
-						G_CALLBACK (gsb_payment_method_config_select),
-						model );
-	    gtk_tree_model_foreach ( GTK_TREE_MODEL (model),
-				     (GtkTreeModelForeachFunc) gsb_payment_method_config_foreach_select,
-				     GINT_TO_POINTER (payment_number));
-	    /* need to clear and fill the reconciliation tree becaus if it was a neutral changing to credit/debit
-	     * and neutral was split... */
-	    gsb_reconcile_sort_config_fill ();
-	}
+            /* as we have changed the sign of the method of payment, check if it was the default
+             * for the account, and if yes, change the default for that account */
+            switch (gsb_data_payment_get_sign ( payment_number ) )
+            {
+            case GSB_PAYMENT_DEBIT:
+                if ( gsb_data_account_get_default_debit ( account_number ) == payment_number)
+                {
+                /* the current method of payment was a debit and was the default debit for its account,
+                 * so change the default to another debit */
+                gsb_data_account_set_default_debit ( account_number,
+                                gsb_payment_method_config_get_transaction_by_sign ( account_number,
+                                GSB_PAYMENT_DEBIT,
+                                payment_number ) );
+                }
+                break;
+
+            case GSB_PAYMENT_CREDIT:
+                if ( gsb_data_account_get_default_credit ( account_number ) == payment_number)
+                {
+                    /* the current method of payment was a credit and was the default credit for its account,
+                     * so change the default to another credit */
+                    gsb_data_account_set_default_credit ( account_number,
+                                gsb_payment_method_config_get_transaction_by_sign ( account_number,
+                                GSB_PAYMENT_CREDIT,
+                                payment_number ) );
+                }
+                break;
+            }
+            gsb_data_payment_set_sign ( payment_number, index );
+
+            /* Update tree */
+            g_signal_handlers_block_by_func ( selection,
+                                G_CALLBACK ( gsb_payment_method_config_select ),
+                                model );
+            gsb_payment_method_config_fill_list (model);
+            gtk_tree_view_expand_all ( GTK_TREE_VIEW(payment_method_treeview ) );
+            g_signal_handlers_unblock_by_func ( selection,
+                            G_CALLBACK ( gsb_payment_method_config_select ),
+                            model );
+            gtk_tree_model_foreach ( GTK_TREE_MODEL (model),
+                         (GtkTreeModelForeachFunc) gsb_payment_method_config_foreach_select,
+                         GINT_TO_POINTER (payment_number));
+
+            /* need to clear and fill the reconciliation tree becaus if it was a neutral changing to credit/debit
+             * and neutral was split... */
+            gsb_reconcile_sort_config_fill ();
+        }
+        /* on débloque l'appel à la fonction gsb_payment_method_config_sign_changed */
+        g_signal_handlers_unblock_by_func ( payment_sign_button,
+                            G_CALLBACK ( gsb_payment_method_config_sign_changed ),
+                            NULL );
     }
     return FALSE;
 }
@@ -1038,71 +992,72 @@ gboolean gsb_payment_method_config_sign_changed ( GtkWidget *menu_item,
 gboolean gsb_payment_method_config_add ( GtkWidget *button,
 					 GtkWidget *tree_view )
 {
-    GtkTreeSelection * selection;
+    GtkTreeSelection *selection;
     GtkTreeIter iter, parent, root, child, *final;
-    GtkTreePath * treepath;
+    GtkTreePath *tree_path;
+    GtkTreePath *final_path;
     gint account_number, type_final;
     gboolean good;
     gint payment_number;
     GtkTreeModel *model;
 
-    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
-    good = gtk_tree_selection_get_selected (selection, NULL, &iter);
-    model = gtk_tree_view_get_model (GTK_TREE_VIEW (tree_view));
+    selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( tree_view ) );
+    good = gtk_tree_selection_get_selected ( selection, &model, &iter );
 
     if ( good )
     {
-	/* there is a selection, get corrent iters */
-	gtk_tree_model_get ( GTK_TREE_MODEL(model), &iter,
-			     PAYMENT_METHODS_NUMBER_COLUMN, &payment_number,
-			     -1 );
-	if (payment_number)
-	{
-	    /* Select parent */
-	    gtk_tree_model_iter_parent ( GTK_TREE_MODEL(model),
-					 &parent, &iter );
-	    final = &parent;
-	    type_final = gsb_data_payment_get_sign (payment_number);
-	    gtk_tree_model_iter_parent (GTK_TREE_MODEL(model), &root, &parent);
-	}
-	else
-	{
-	    gchar *name;
+        /* there is a selection, get current iters */
+        gtk_tree_model_get ( GTK_TREE_MODEL( model ),
+                        &iter,
+                        PAYMENT_METHODS_NUMBER_COLUMN, &payment_number,
+                        -1 );
+        if ( payment_number )
+        {
+            /* Select parent */
+            gtk_tree_model_iter_parent ( GTK_TREE_MODEL ( model ), &parent, &iter );
+            final = &parent;
+            type_final = gsb_data_payment_get_sign ( payment_number );
+            gtk_tree_model_iter_parent ( GTK_TREE_MODEL ( model ), &root, &parent );
+            /* ici root = compte, parent = type, iter = moyen de payement sélectionné */
+        }
+        else
+        {
+            gchar *name;
 
-	    gtk_tree_model_get ( GTK_TREE_MODEL(model), &iter,
-				 PAYMENT_METHODS_NAME_COLUMN, &name,
-				 -1 );
+            gtk_tree_model_get ( GTK_TREE_MODEL ( model ),
+                        &iter,
+                        PAYMENT_METHODS_NAME_COLUMN, &name,
+                        -1 );
 
-	    if (gtk_tree_model_iter_parent (GTK_TREE_MODEL(model), &root, &iter))
-	    {
-		/* We are on "Credit" or "Debit" or "Neutral" */
-		final = &iter;
-		if ( !strcmp(name, _("Credit")) )
-		{
-		    type_final = GSB_PAYMENT_CREDIT;
-		}
-		else if ( !strcmp(name, _("Debit")) )
-		{
-		    type_final = GSB_PAYMENT_DEBIT;
-		}
-		else 		/* Neutral */
-		{
-		    type_final = GSB_PAYMENT_NEUTRAL;
-		}
-	    }
-	    else
-	    {
-		/* We are on an account, method_ptr will be the same as the
-		   first node  */
-		if (!gtk_tree_model_iter_children( GTK_TREE_MODEL(model),
-						   &child, &iter ))
-		    /* Should not happen! */
-		    dialogue_error_brain_damage ();
+            if ( gtk_tree_model_iter_parent ( GTK_TREE_MODEL ( model ), &root, &iter ) )
+            {
+                /* We are on "Credit" or "Debit" or "Neutral" */
+                final = &iter;
+                if ( !strcmp ( name, _("Credit") ) )
+                {
+                    type_final = GSB_PAYMENT_CREDIT;
+                }
+                else if ( !strcmp ( name, _("Debit") ) )
+                {
+                    type_final = GSB_PAYMENT_DEBIT;
+                }
+                else        /* Neutral */
+                {
+                    type_final = GSB_PAYMENT_NEUTRAL;
+                }
+            }
+            else
+            {
+                /* We are on an account, method_ptr will be the same as the
+                   first node  */
+                if ( !gtk_tree_model_iter_children ( GTK_TREE_MODEL ( model ), &child, &iter ) )
+                    /* Should not happen! */
+                    dialogue_error_brain_damage ();
 
-		final = &child;
-		type_final = GSB_PAYMENT_DEBIT;
-	    }
-	}
+                final = &child;
+                type_final = GSB_PAYMENT_DEBIT;
+            }
+        }
     }
     else
     {
@@ -1139,16 +1094,20 @@ gboolean gsb_payment_method_config_add ( GtkWidget *button,
 			PAYMENT_METHODS_NUMBER_COLUMN, payment_number,
 			-1 );
 
+    tree_path = gtk_tree_model_get_path ( GTK_TREE_MODEL ( model ), &iter );
+    gtk_tree_model_row_inserted ( GTK_TREE_MODEL ( model ), tree_path, &iter );
+
     /* Select and view new position */
+    final_path = gtk_tree_model_get_path ( GTK_TREE_MODEL ( model ), final );
+    if ( !gtk_tree_view_row_expanded ( GTK_TREE_VIEW ( tree_view ), final_path ) )
+        gtk_tree_view_expand_to_path ( GTK_TREE_VIEW ( tree_view ), final_path );
+    gtk_tree_path_free ( final_path );
     gtk_tree_selection_select_iter ( selection, &iter );
-    treepath = gtk_tree_model_get_path ( GTK_TREE_MODEL(model), &iter );
-    gtk_tree_view_scroll_to_cell ( GTK_TREE_VIEW(tree_view), treepath, NULL,
-				   TRUE, 0.5, 0);
-    gtk_tree_path_free ( treepath );
+    gtk_tree_view_scroll_to_cell ( GTK_TREE_VIEW ( tree_view ), tree_path, NULL, TRUE, 0.5, 0);
+    gtk_tree_path_free ( tree_path );
 
     /* add to the sorted list */
-    gsb_data_account_sort_list_add ( account_number,
-				     payment_number );
+    gsb_data_account_sort_list_add ( account_number, payment_number );
     gsb_reconcile_sort_config_fill ();
 
     /* Mark file as modified */
@@ -1270,16 +1229,16 @@ gboolean gsb_payment_method_config_switch_payment ( gint payment_number )
     dialog = gtk_dialog_new_with_buttons ( _("Delete a payment method"),
 					   GTK_WINDOW ( fenetre_preferences ),
 					   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					   GTK_STOCK_OK, GTK_RESPONSE_OK,
+					   "gtk-cancel", GTK_RESPONSE_CANCEL,
+					   "gtk-ok", GTK_RESPONSE_OK,
 					   NULL );
 
     gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
     gtk_window_set_resizable ( GTK_WINDOW ( dialog ), FALSE );
 
     /* Ugly dance to avoid side effects on dialog's vbox. */
-    hbox = gtk_hbox_new ( FALSE, 0 );
-    gtk_box_pack_start ( GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox, FALSE, FALSE, 0 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, 0 );
+    gtk_box_pack_start ( GTK_BOX ( dialog_get_content_area ( dialog ) ), hbox, FALSE, FALSE, 0 );
     paddingbox = new_paddingbox_with_title ( hbox, TRUE, _("Payment method is used by transactions") );
     gtk_container_set_border_width ( GTK_CONTAINER(hbox), 6 );
     gtk_container_set_border_width ( GTK_CONTAINER(paddingbox), 6 );
@@ -1298,27 +1257,27 @@ gboolean gsb_payment_method_config_switch_payment ( gint payment_number )
 	return FALSE;
     }
 
-    if (GTK_WIDGET_VISIBLE (combo_box))
+    if (gtk_widget_get_visible (combo_box))
 	label = gtk_label_new ( _("Some transactions still use that payment method.  As deletion of this method is irreversible, these transactions are to be associated with another payment method."));
     else
 	label = gtk_label_new (_("No target method of payment to switch the transactions to another method of payment. If you continue, the transactions with this method of payment will have no new one."));
     gtk_label_set_line_wrap ( GTK_LABEL (label), TRUE );
-	gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.0 );
+	utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.0 );
     gtk_widget_set_size_request ( label, 400, -1 );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), label, FALSE, FALSE, 0 );
     gtk_widget_show (label);
 
-    hbox = gtk_hbox_new ( FALSE, 0 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, 0 );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Associate transactions with: "));
-	gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.5 );
+	utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.5 );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, TRUE, TRUE, 0 );
 
     /* the combo_box was created before */
     gtk_box_pack_start ( GTK_BOX ( hbox ), combo_box, TRUE, TRUE, 0 );
 
-    if (GTK_WIDGET_VISIBLE (combo_box))
+    if (gtk_widget_get_visible (combo_box))
     gtk_widget_show_all ( hbox );
 
     resultat = gtk_dialog_run ( GTK_DIALOG ( dialog ));
