@@ -13,7 +13,7 @@ enum payment_methods_columns {
     PAYMENT_METHODS_ACTIVABLE_COLUMN,
     PAYMENT_METHODS_NUMBER_COLUMN,
     PAYMENT_METHODS_ACCOUNT_COLUMN,
-    NUM_PAYMENT_METHODS_COLUMNS,
+    NUM_PAYMENT_METHODS_COLUMNS
 };
 
 
@@ -21,6 +21,6 @@ enum payment_methods_columns {
 /* END_INCLUDE_H */
 
 /* START_DECLARATION */
-GtkWidget *gsb_payment_method_config_create ( void );
+GtkWidget *	gsb_payment_method_config_create	(void);
 /* END_DECLARATION */
 #endif
