@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -36,6 +36,7 @@
 /*START_INCLUDE*/
 #include "gsb_reconcile_config.h"
 #include "dialog.h"
+#include "grisbi_win.h"
 #include "gsb_assistant_reconcile_config.h"
 #include "gsb_autofunc.h"
 #include "gsb_automem.h"
@@ -49,6 +50,7 @@
 #include "traitement_variables.h"
 #include "utils.h"
 #include "utils_dates.h"
+#include "utils_prefs.h"
 #include "utils_real.h"
 /*END_INCLUDE*/
 
@@ -81,6 +83,66 @@ static GtkWidget *delete_reconcile_button;
 /******************************************************************************/
 /* Private Methods                                                            */
 /******************************************************************************/
+ /**
+ *
+ *
+ * \param
+ * \param
+ *
+ * \return
+ **/
+static void gsb_reconcile_button_collapse_row_clicked (GtkButton *button,
+													   GtkTreeSelection *selection)
+{
+	GtkTreeView *tree_view;
+    GtkTreeModel *model;
+    GtkTreeIter iter;
+	GtkTreePath *path;
+
+	if ( !gtk_tree_selection_get_selected (selection, &model, &iter))
+        return;
+	path = gtk_tree_model_get_path (model, &iter);
+	tree_view = gtk_tree_selection_get_tree_view (selection);
+	gtk_tree_view_collapse_row (tree_view, path);
+}
+
+/**
+ *
+ *
+ * \param
+ * \param
+ * \param
+ * \param
+ *
+ * \return
+ **/
+static void gsb_reconcile_treeview_row_collapsed (GtkTreeView *treeview,
+												 GtkTreeIter *iter,
+												 GtkTreePath *path,
+												 GtkWidget *button)
+{
+	gtk_widget_set_sensitive (button, FALSE);
+}
+
+/**
+ *
+ *
+ * \param
+ * \param
+ * \param
+ * \param
+ *
+ * \return
+ **/
+static void gsb_reconcile_treeview_row_expanded (GtkTreeView *treeview,
+												 GtkTreeIter *iter,
+												 GtkTreePath *path,
+												 GtkWidget *button)
+{
+	utils_set_tree_store_background_color (GTK_WIDGET (treeview), RECONCILIATION_BACKGROUND_COLOR);
+	gtk_widget_set_sensitive (button, TRUE);
+}
+
 /**
  *
  *
@@ -105,8 +167,9 @@ static void gsb_reconcile_config_sort_reconcile (GtkToggleButton *togglebutton,
  */
 GtkWidget *gsb_reconcile_config_create ( void )
 {
-    GtkWidget *hbox, *scrolled_window;
-    GtkWidget *vbox_pref, *paddingbox;
+    GtkWidget *scrolled_window;
+    GtkWidget *vbox_pref;
+    GtkWidget *paddinggrid;
     GtkTreeViewColumn *column;
     GtkCellRenderer *cell;
     GtkTreeStore *reconcile_model;
@@ -124,36 +187,33 @@ GtkWidget *gsb_reconcile_config_create ( void )
     GtkWidget *table_selection;
     GtkWidget *button;
     gint width_entry = 80;
+	GrisbiWinEtat *w_etat;
 
+	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
     vbox_pref = new_vbox_with_title_and_icon ( _("Reconciliation"),
-					       "reconciliationlg.png" );
+					       "gsb-reconciliation-32.png" );
 
     gsb_automem_radiobutton3_new_with_title ( vbox_pref,
                         _("Select the end date of reconciliation: "),
                         _("Start Date + one month"),
                         _("Today's date"),
                         NULL,
-                        &etat.reconcile_end_date,
+                        &w_etat->reconcile_end_date,
                         G_CALLBACK ( gsb_reconcile_config_end_date_changed ),
                         NULL,
                         GTK_ORIENTATION_HORIZONTAL );
 
-    paddingbox = new_paddingbox_with_title ( vbox_pref, TRUE,
-					     _("List of reconciliations") );
+    paddinggrid = utils_prefs_paddinggrid_new_with_title (vbox_pref, _("List of reconciliations"));
+	gtk_widget_set_vexpand (paddinggrid, TRUE);
 
     /* set the list */
-    scrolled_window = gtk_scrolled_window_new ( NULL, NULL );
-    gtk_box_pack_start ( GTK_BOX (paddingbox), scrolled_window,
-			 TRUE, TRUE, 0);
-    gtk_scrolled_window_set_policy ( GTK_SCROLLED_WINDOW ( scrolled_window ),
-				     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-    gtk_scrolled_window_set_shadow_type ( GTK_SCROLLED_WINDOW ( scrolled_window ),
-					  GTK_SHADOW_IN);
+    scrolled_window = utils_prefs_scrolled_window_new ( NULL, GTK_SHADOW_IN, SW_COEFF_UTIL_PG, 200);
+    gtk_grid_attach (GTK_GRID (paddinggrid), scrolled_window, 0, 0, 3, 3);
 
     /* need to create first the table to set it in the arg of the changed signal of selection */
-    table_selection = gtk_table_new ( 4, 3, FALSE );
-    gtk_table_set_row_spacings ( GTK_TABLE ( table_selection ), 6 );
-    gtk_table_set_col_spacings ( GTK_TABLE ( table_selection ), 6 );
+    table_selection = gtk_grid_new ();
+    gtk_grid_set_row_spacing (GTK_GRID (table_selection), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (table_selection), 6);
 
     /* create the model */
     reconcile_model = gtk_tree_store_new ( NUM_RECONCILIATION_COLUMNS,
@@ -164,18 +224,21 @@ GtkWidget *gsb_reconcile_config_create ( void )
 					   G_TYPE_STRING,    /* final balance  */
 					   G_TYPE_INT,       /* Account number */
 					   G_TYPE_INT,       /* Bold or regular text */
-					   G_TYPE_INT );     /* reconciliation number */
-    reconcile_treeview = gtk_tree_view_new_with_model ( GTK_TREE_MODEL (reconcile_model) );
+					   G_TYPE_INT,		 /* reconciliation number */
+					   GDK_TYPE_RGBA);
+
+	reconcile_treeview = gtk_tree_view_new_with_model ( GTK_TREE_MODEL (reconcile_model) );
+	gtk_widget_set_name (reconcile_treeview, "tree_view");
     g_object_unref (G_OBJECT(reconcile_model));
-    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (reconcile_treeview), TRUE);
     gtk_tree_selection_set_mode ( gtk_tree_view_get_selection (GTK_TREE_VIEW (reconcile_treeview)),
 				  GTK_SELECTION_SINGLE );
-    gtk_container_add ( GTK_CONTAINER (scrolled_window),
-			reconcile_treeview );
+    gtk_container_add ( GTK_CONTAINER (scrolled_window), reconcile_treeview );
 
     reconcile_selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (reconcile_treeview));
-    g_signal_connect (reconcile_selection, "changed",
-		      G_CALLBACK (gsb_reconcile_config_select), table_selection);
+    g_signal_connect (reconcile_selection,
+                      "changed",
+                      G_CALLBACK (gsb_reconcile_config_select),
+                      table_selection);
 
     /* Name */
     for (i=RECONCILIATION_NAME_COLUMN ; i<RECONCILIATION_ACCOUNT_COLUMN ; i++)
@@ -194,6 +257,7 @@ GtkWidget *gsb_reconcile_config_create ( void )
 	gtk_tree_view_column_set_attributes (column, cell,
 					     "text", i,
 					     "weight", RECONCILIATION_WEIGHT_COLUMN,
+						 "cell-background-rgba", RECONCILIATION_BACKGROUND_COLOR,
 					     NULL);
 	gtk_tree_view_column_set_expand ( column, TRUE );
 	gtk_tree_view_column_set_resizable ( column,
@@ -206,98 +270,105 @@ GtkWidget *gsb_reconcile_config_create ( void )
 
     /* Set the reconcile_sort */
     button = gsb_automem_checkbutton_new (_("Sort by descending date the reconciliations"),
-                                          &etat.reconcile_sort,
+                                          &w_etat->reconcile_sort,
                                           G_CALLBACK (gsb_reconcile_config_sort_reconcile),
                                           NULL);
-    gtk_box_pack_start ( GTK_BOX (paddingbox), button, FALSE, FALSE, 0);
+    gtk_widget_set_margin_top (button, MARGIN_TOP);
+    gtk_grid_attach (GTK_GRID (paddinggrid), button, 0, 3, 1, 1);
+
+	button = gtk_button_new_with_label (_("Collapse row"));
+	gtk_widget_set_sensitive (button, FALSE);
+	g_signal_connect (G_OBJECT (button),
+					  "clicked",
+					  G_CALLBACK (gsb_reconcile_button_collapse_row_clicked),
+					  reconcile_selection);
+	gtk_grid_attach (GTK_GRID (paddinggrid), button, 1, 3, 1, 1);
+
+	/* set signal here because data is button */
+    g_signal_connect (reconcile_treeview,
+                      "row-expanded",
+                      G_CALLBACK (gsb_reconcile_treeview_row_expanded),
+                      button);
+
+    g_signal_connect (reconcile_treeview,
+                      "row-collapsed",
+                      G_CALLBACK (gsb_reconcile_treeview_row_collapsed),
+                      button);
 
     /* set the modifying part under the list */
-    hbox = new_paddingbox_with_title ( vbox_pref, FALSE,
-				       _("Selected reconcile") );
+    paddinggrid = utils_prefs_paddinggrid_new_with_title (vbox_pref,_("Selected reconcile") );
 
     /* for that we make a table 2x3 but with the names 4x3,
      * the table has been set before to accept as arg on the changed selection */
-    gtk_box_pack_start ( GTK_BOX (hbox), table_selection, FALSE, FALSE, 0 );
+    gtk_grid_attach (GTK_GRID (paddinggrid), table_selection, 0, 0, 1, 1);
 
     /* set the name */
 	label = gtk_label_new ( _("Reconciliation reference: ") );
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+	utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-	gtk_table_attach ( GTK_TABLE ( table_selection ), label, 0, 1, 0, 1,
-			GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table_selection), label, 0, 0, 1, 1);
 
 	reconcile_name_entry = gsb_autofunc_entry_new ( NULL,
 			G_CALLBACK (gsb_reconcile_config_update_line), reconcile_treeview,
 			G_CALLBACK (gsb_data_reconcile_set_name), 0 );
     gtk_widget_set_size_request ( reconcile_name_entry, width_entry, -1 );
-	gtk_table_attach ( GTK_TABLE ( table_selection ), reconcile_name_entry, 1, 2, 0, 1,
-			GTK_EXPAND | GTK_FILL, 0, 10, 0 );
+	gtk_grid_attach (GTK_GRID (table_selection), reconcile_name_entry, 1, 0, 1, 1);
 
 	/* set the initial date */
 	label = gtk_label_new ( _("Initial date: ") );
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+	utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-	gtk_table_attach ( GTK_TABLE ( table_selection ), label, 0, 1, 1, 2,
-			GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table_selection), label, 0, 1, 1, 1);
 
 	reconcile_init_date_entry = gsb_autofunc_date_new ( NULL,
 			G_CALLBACK (gsb_reconcile_config_update_line), reconcile_treeview,
 			G_CALLBACK (gsb_data_reconcile_set_init_date), 0 );
     gtk_widget_set_size_request ( reconcile_init_date_entry, width_entry, -1 );
-	gtk_table_attach ( GTK_TABLE ( table_selection ), reconcile_init_date_entry, 1, 2, 1, 2,
-			GTK_EXPAND | GTK_FILL, 0, 10, 0 );
+	gtk_grid_attach (GTK_GRID (table_selection), reconcile_init_date_entry, 1, 1, 1, 1);
 
     /* set the final date */
 	label = gtk_label_new ( _("Final date: ") );
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+	utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-	gtk_table_attach ( GTK_TABLE ( table_selection ), label, 0, 1, 2, 3,
-			GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table_selection), label, 0, 2, 1, 1);
 
 	reconcile_final_date_entry = gsb_autofunc_date_new ( NULL,
 			G_CALLBACK (gsb_reconcile_config_update_line), reconcile_treeview,
 			G_CALLBACK (gsb_data_reconcile_set_final_date), 0 );
     gtk_widget_set_size_request ( reconcile_final_date_entry, width_entry, -1 );
-	gtk_table_attach ( GTK_TABLE ( table_selection ), reconcile_final_date_entry, 1, 2, 2, 3,
-			GTK_EXPAND | GTK_FILL, 0, 10, 0 );
+	gtk_grid_attach (GTK_GRID (table_selection), reconcile_final_date_entry, 1, 2, 1, 1);
 
     /* set the delete button */
 	delete_reconcile_button = gtk_button_new_with_label (_("Delete the reconcile"));
-    gtk_button_set_relief ( GTK_BUTTON (delete_reconcile_button),
-			GTK_RELIEF_NONE );
+    gtk_button_set_relief ( GTK_BUTTON (delete_reconcile_button), GTK_RELIEF_NORMAL);
 	g_signal_connect ( G_OBJECT (delete_reconcile_button), "clicked",
 			G_CALLBACK (gsb_reconcile_config_delete),
 			reconcile_treeview );
-	gtk_table_attach ( GTK_TABLE ( table_selection ), delete_reconcile_button, 2, 4, 0, 1,
-			GTK_EXPAND | GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table_selection), delete_reconcile_button, 2, 0, 2, 1);
 
 	/* set the initial balance */
 	label = gtk_label_new ( _("Initial balance: ") );
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+	utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-	gtk_table_attach ( GTK_TABLE ( table_selection ), label, 2, 3, 1, 2,
-			GTK_SHRINK | GTK_FILL, 0, 10, 0 );
+	gtk_grid_attach (GTK_GRID (table_selection), label, 2, 1, 1, 1);
 
 	reconcile_init_balance_entry = gsb_autofunc_real_new ( null_real,
 			G_CALLBACK (gsb_reconcile_config_update_line), reconcile_treeview,
 			G_CALLBACK (gsb_data_reconcile_set_init_balance), 0 );
     gtk_widget_set_size_request ( reconcile_init_balance_entry, width_entry, -1 );
-	gtk_table_attach ( GTK_TABLE ( table_selection ), reconcile_init_balance_entry, 3, 4, 1, 2,
-			GTK_EXPAND | GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table_selection), reconcile_init_balance_entry, 3, 1, 1, 1);
 
     /* set the final balance */
 	label = gtk_label_new ( _("Final balance: ") );
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+	utils_labels_set_alignment ( GTK_LABEL (label), 0, 0.5);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-	gtk_table_attach ( GTK_TABLE ( table_selection ), label, 2, 3, 2, 3,
-			GTK_SHRINK | GTK_FILL, 0, 10, 0 );
+	gtk_grid_attach (GTK_GRID (table_selection), label, 2, 2, 1, 1);
 
 	reconcile_final_balance_entry = gsb_autofunc_real_new ( null_real,
 			G_CALLBACK (gsb_reconcile_config_update_line), reconcile_treeview,
 			G_CALLBACK (gsb_data_reconcile_set_final_balance), 0 );
     gtk_widget_set_size_request ( reconcile_final_balance_entry, width_entry, -1 );
-    gtk_table_attach ( GTK_TABLE ( table_selection ), reconcile_final_balance_entry, 3, 4, 2, 3,
-			GTK_EXPAND | GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (table_selection), reconcile_final_balance_entry, 3, 2, 1, 1);
 
 	/* at the beginning, the table is unsensitive */
 	gtk_widget_set_sensitive ( table_selection, FALSE );
@@ -305,16 +376,18 @@ GtkWidget *gsb_reconcile_config_create ( void )
     /* set the button to find non-associated transactions */
 	button = gtk_button_new_with_label (
                         _("Find all marked transactions not associated with a reconciliation"));
-	gtk_button_set_relief ( GTK_BUTTON (button),
-			GTK_RELIEF_NONE );
-	g_signal_connect ( G_OBJECT (button), "clicked",
-			G_CALLBACK (gsb_reconcile_config_find_alone_transactions), NULL );
-	gtk_box_pack_start ( GTK_BOX (vbox_pref),
-			 button, FALSE, FALSE, 0 );
+	gtk_button_set_relief ( GTK_BUTTON (button), GTK_RELIEF_NORMAL );
+    utils_widget_set_padding (button, 0, MARGIN_TOP);
+	g_signal_connect ( G_OBJECT (button),
+                      "clicked",
+                      G_CALLBACK (gsb_reconcile_config_find_alone_transactions),
+                      NULL );
+    gtk_grid_attach (GTK_GRID (paddinggrid), button, 0, 1, 1, 1);
 
     gtk_widget_show_all (vbox_pref);
+	utils_set_tree_store_background_color (reconcile_treeview, RECONCILIATION_BACKGROUND_COLOR);
 
-    if ( !gsb_data_account_get_accounts_amount () )
+	if ( !gsb_data_account_get_accounts_amount () )
     {
 	gtk_widget_set_sensitive ( vbox_pref, FALSE );
     }
@@ -335,12 +408,13 @@ void gsb_reconcile_config_fill ( void )
 {
     GtkTreeModel *model;
     GSList *tmp_list;
+	GrisbiWinEtat *w_etat;
 
     if (!reconcile_treeview)
-	return;
+		return;
 
+	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
     model = gtk_tree_view_get_model ( GTK_TREE_VIEW (reconcile_treeview));
-
     gtk_tree_store_clear (GTK_TREE_STORE(model));
 
     /* we make a tree_model containing the accounts,
@@ -366,8 +440,8 @@ void gsb_reconcile_config_fill ( void )
 
 	/* for each account, get the concerned reconciles */
 	reconcile_list = gsb_data_reconcile_get_sort_reconcile_list (account_number);
-    if (etat.reconcile_sort)
-        reconcile_list = g_list_reverse (reconcile_list);
+    if (w_etat->reconcile_sort)
+		reconcile_list = g_list_reverse (reconcile_list);
 
 	while (reconcile_list)
 	{
@@ -562,8 +636,7 @@ gboolean gsb_reconcile_config_delete ( GtkWidget *button,
 	     * we ask if the user want to continue and warn him */
 	    gchar* tmpstr = g_strdup_printf (_("Caution, you are about to delete a reconciliation.\nIf you continue, the reconciliation %s will be erased and all the transactions marked by this reconciliation will be un-reconciled and marked P.\nAre you sure you want to continue?"),
 							 gsb_data_reconcile_get_name (reconcile_number));
-	    if (!question_yes_no_hint ( _("Delete reconciliation"),
-					tmpstr,
+	    if (!question_yes_no (tmpstr, _("Delete reconciliation"),
 					GTK_RESPONSE_NO ))
 	    {
 		g_free ( tmpstr );
@@ -583,7 +656,7 @@ gboolean gsb_reconcile_config_delete ( GtkWidget *button,
 		gsb_transactions_list_update_tree_view (account_number, TRUE);
 
 		/* update the last statement for that account */
-		gsb_navigation_update_statement_label (account_number);
+		gsb_gui_navigation_update_statement_label (account_number);
 	    }
             gsb_file_set_modified ( TRUE );
 	}
@@ -615,7 +688,10 @@ gboolean gsb_reconcile_config_end_date_changed ( GtkWidget *checkbutton,
                         GdkEventButton *event,
                         gpointer data )
 {
-    etat.reconcile_end_date = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( checkbutton ), "pointer" ) );
+	GrisbiWinEtat *w_etat;
+
+	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
+    w_etat->reconcile_end_date = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( checkbutton ), "pointer" ) );
 
     gsb_file_set_modified ( TRUE );
 
@@ -623,6 +699,13 @@ gboolean gsb_reconcile_config_end_date_changed ( GtkWidget *checkbutton,
 }
 
 
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ * */
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
