@@ -3,7 +3,8 @@
 
 #include <gtk/gtk.h>
 
-enum reconciliation_columns {
+enum ReconciliationColumns
+{
     RECONCILIATION_NAME_COLUMN = 0,
     RECONCILIATION_INIT_DATE_COLUMN,
     RECONCILIATION_FINAL_DATE_COLUMN,
@@ -12,7 +13,8 @@ enum reconciliation_columns {
     RECONCILIATION_ACCOUNT_COLUMN,
     RECONCILIATION_RECONCILE_COLUMN,
     RECONCILIATION_WEIGHT_COLUMN,
-    NUM_RECONCILIATION_COLUMNS,
+	RECONCILIATION_BACKGROUND_COLOR,
+    NUM_RECONCILIATION_COLUMNS
 };
 
 
@@ -20,7 +22,7 @@ enum reconciliation_columns {
 /* END_INCLUDE_H */
 
 /* START_DECLARATION */
-GtkWidget *gsb_reconcile_config_create ( void );
-void gsb_reconcile_config_fill ( void );
+GtkWidget *	gsb_reconcile_config_create		(void);
+void		gsb_reconcile_config_fill		(void);
 /* END_DECLARATION */
 #endif
