@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2001-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
-/*          2009-2018 Pierre Biava (grisbi@pierre.biava.name)                 */
+/*          2009-2019 Pierre Biava (grisbi@pierre.biava.name)                 */
 /*          http://www.grisbi.org                                             */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -34,7 +34,12 @@
 /*START_INCLUDE*/
 #include "gtk_combofix.h"
 #include "grisbi_win.h"
+#include "gsb_data_account.h"
+#include "gsb_data_budget.h"
+#include "gsb_data_category.h"
+#include "gsb_data_form.h"
 #include "gsb_form.h"
+#include "gsb_form_widget.h"
 #include "structures.h"
 #include "utils_buttons.h"
 #include "utils_str.h"
@@ -103,6 +108,65 @@ enum CombofixKeyDirection
 /******************************************************************************/
 /* Private functions                                                          */
 /******************************************************************************/
+/**
+ * positionne le bouton "Change" du formulaire si le compte destinataire
+ * du transfert a une devise différente du compte de départ.
+ *
+ * \param
+ * \param
+ * \param
+ * \param
+ *
+ * \return FALSE
+ **/
+static gboolean gtk_combofix_completion_match_selected (GtkEntryCompletion *widget,
+														GtkTreeModel *model,
+														GtkTreeIter *iter,
+														GtkComboFix *combofix)
+{
+    GtkComboFixPrivate *priv;
+
+    priv = gtk_combofix_get_instance_private (combofix);
+	devel_debug (NULL);
+
+	if (priv->type == METATREE_CATEGORY)
+	{
+		gchar *tmp_str;
+
+		gtk_tree_model_get (GTK_TREE_MODEL (model), iter, 0, &tmp_str, -1);
+		if (g_str_has_prefix (tmp_str, _("Transfer : ")))
+		{
+			GtkWidget *widget;
+
+			widget = gsb_form_widget_get_widget (TRANSACTION_FORM_DEVISE);
+			if (widget != NULL && gtk_widget_get_visible (widget))
+			{
+				const gchar *entry_account_name;
+				gint entry_account_currency;
+				gint entry_account_number;
+				gint form_account_nb;
+				gint form_account_currency;
+
+				form_account_nb = gsb_form_get_account_number ();
+				form_account_currency = gsb_data_account_get_currency (form_account_nb);
+
+				/* data of selected account */
+				entry_account_name = memchr (tmp_str, ':', strlen (tmp_str));
+				entry_account_name = entry_account_name + 2;
+				entry_account_number = gsb_data_account_get_no_account_by_name (entry_account_name);
+				entry_account_currency = gsb_data_account_get_currency (entry_account_number);
+
+				if (entry_account_currency == form_account_currency)
+					gtk_widget_hide (gsb_form_widget_get_widget (TRANSACTION_FORM_CHANGE));
+				else
+					gtk_widget_show (gsb_form_widget_get_widget (TRANSACTION_FORM_CHANGE));
+			}
+		}
+		g_free (tmp_str);
+	}
+	return FALSE;
+}
+
 /**
  * get the first item of completion and fill the entry with it
  * Works if the length of the text >= the length of the completion key
@@ -163,22 +227,31 @@ static void gtk_combofix_completion_insert_new_item (GtkComboFix *combofix,
 
 	if (gtk_tree_model_get_iter_first (store, &iter))
 	{
-
 		do
 		{
 			gchar *tmp_str;
+			gchar *str_to_free1;
+			gchar *str_to_free2;
 
 			gtk_tree_model_get (store, &iter, 0, &tmp_str, -1);
 			if (!tmp_str)
 				continue;
 
-			if (g_utf8_collate (g_utf8_casefold (text, -1), g_utf8_casefold (tmp_str, -1)) < 0)
+			str_to_free1 = g_utf8_casefold (text, -1);
+			str_to_free2 = g_utf8_casefold (tmp_str, -1);
+			if (g_utf8_collate (str_to_free1, str_to_free2) < 0)
 			{
 				gtk_list_store_insert_before (GTK_LIST_STORE (store), &new_iter, &iter);
 				gtk_list_store_set (GTK_LIST_STORE (store), &new_iter, 0, text, -1);
+				g_free (str_to_free1);
+				g_free (str_to_free2);
+				g_free (tmp_str);
 
 				return;
 			}
+			g_free (str_to_free1);
+			g_free (str_to_free2);
+			g_free (tmp_str);
 		}
 		while (gtk_tree_model_iter_next (store, &iter));
 	}
@@ -554,7 +627,30 @@ static gboolean gtk_combofix_fill_store (GtkComboFix *combofix,
 				else
 				{
 					/* on n'affiche pas la tête de categ/IB dans la completion si force Categ/IB est TRUE */
-					if (priv->type && !priv->force)
+					/* et il existe des sous catégories. On traite les listes credit et débit */
+					if (priv->type && priv->force && list_number < 2)
+					{
+						gint div_number;
+						gint nbre_sub_division = 0;
+
+						if (priv->type == METATREE_CATEGORY)
+						{
+							div_number = gsb_data_category_get_number_by_name (string, priv->force, priv->type);
+							nbre_sub_division = gsb_data_category_get_sub_category_list_length (div_number);
+						}
+						else
+						{
+							div_number = gsb_data_budget_get_number_by_name (string, priv->force, priv->type);
+							nbre_sub_division = gsb_data_budget_get_sub_budget_list_length (div_number);
+						}
+
+						if (nbre_sub_division == 0)
+						{
+							gtk_list_store_append (GTK_LIST_STORE (completion_store), &new_iter);
+							gtk_list_store_set (GTK_LIST_STORE (completion_store), &new_iter, 0, string, -1);
+						}
+					}
+					else
 					{
 						gtk_list_store_append (GTK_LIST_STORE (completion_store), &new_iter);
 						gtk_list_store_set (GTK_LIST_STORE (completion_store), &new_iter, 0, string, -1);
@@ -1576,6 +1672,13 @@ static void gtk_combofix_create_entry (GtkComboFix *combofix)
                         	"focus-out-event",
                         	G_CALLBACK (gtk_combofix_focus_out),
                         	combofix);
+
+ 	/* set completion signal */
+   g_signal_connect (G_OBJECT (completion),
+                      "match-selected",
+                      G_CALLBACK (gtk_combofix_completion_match_selected),
+                      combofix);
+
     gtk_widget_set_hexpand (priv->entry, TRUE);
     gtk_widget_show (priv->entry);
 }
