@@ -21,7 +21,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -30,24 +30,25 @@
 
 /*START_INCLUDE*/
 #include "meta_budgetary.h"
-#include "imputation_budgetaire.h"
+#include "grisbi_win.h"
 #include "gsb_data_budget.h"
 #include "gsb_data_scheduled.h"
 #include "gsb_data_transaction.h"
 #include "gsb_real.h"
+#include "imputation_budgetaire.h"
 #include "structures.h"
 #include "utils_str.h"
 /*END_INCLUDE*/
 
 
 /*START_STATIC*/
-static gint budgetary_line_add_div ();
+static gint budgetary_line_add_div ( void );
 static gint budgetary_line_add_sub_div ( int div_id );
 static gboolean budgetary_line_add_transaction_to_div ( gint transaction_number,
 						 int div_id );
 static gchar *budgetary_line_div_name ( gint div );
-static gint budgetary_line_get_without_div_pointer ( );
-static gsb_real budgetary_line_sub_div_balance ( gint div, gint sub_div );
+static gint budgetary_line_get_without_div_pointer ( void );
+static GsbReal budgetary_line_sub_div_balance ( gint div, gint sub_div );
 static gchar *budgetary_line_sub_div_name ( gint div, gint sub_div );
 static gint budgetary_line_sub_div_nb_transactions ( gint div, gint sub_div );
 static gint budgetary_lint_get_number_by_name ( const gchar *name, gboolean create );
@@ -82,7 +83,7 @@ static gint budgetary_line_transaction_div_id (gint transaction_number)
 
 static MetatreeInterface _budgetary_interface = {
     2,
-    2,
+    METATREE_BUDGET,
     budgetary_line_tree_currency,
     N_("Budgetary line"),
     N_("budgetary line"),
@@ -134,9 +135,13 @@ static MetatreeInterface *budgetary_interface = &_budgetary_interface;
  *
  *
  */
-gint budgetary_line_tree_currency ( )
+gint budgetary_line_tree_currency ( void )
 {
-    return etat.no_devise_totaux_ib;
+	GrisbiWinEtat *w_etat;
+
+	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
+
+	return w_etat->no_devise_totaux_ib;
 }
 
 
@@ -145,7 +150,7 @@ gint budgetary_line_tree_currency ( )
  *
  *
  */
-gint budgetary_line_get_without_div_pointer ( )
+gint budgetary_line_get_without_div_pointer ( void )
 {
     return 0;
 }
@@ -213,7 +218,7 @@ gchar * budgetary_line_sub_div_name ( gint div, gint sub_div )
  *
  *
  */
-gsb_real budgetary_line_sub_div_balance ( gint div, gint sub_div )
+GsbReal budgetary_line_sub_div_balance ( gint div, gint sub_div )
 {
     if ( sub_div )
     {
@@ -234,7 +239,7 @@ gsb_real budgetary_line_sub_div_balance ( gint div, gint sub_div )
  *
  *
  */
-gint budgetary_line_add_div ()
+gint budgetary_line_add_div ( void )
 {
     gint new_budget_number;
     gchar * name;
