@@ -20,7 +20,7 @@
 /* ************************************************************************** */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -43,26 +43,26 @@
 /*END_EXTERN*/
 
 /*START_STATIC*/
-static gchar * child_content ( xmlNodePtr node, gchar * child_name );
-static struct struct_compte_importation * find_imported_account_by_name ( gchar * name );
-static struct struct_compte_importation * find_imported_account_by_uid ( gchar * guid );
+static gchar * child_content ( xmlNodePtr node, const gchar * child_name );
+static struct ImportAccount * find_imported_account_by_name ( gchar * name );
+static struct ImportAccount * find_imported_account_by_uid ( gchar * guid );
 static struct gnucash_category * find_imported_categ_by_uid ( gchar * guid );
-static struct gnucash_split * find_split ( GSList * split_list, gsb_real amount,
-				    struct struct_compte_importation * account,
+static struct gnucash_split * find_split ( GSList * split_list, GsbReal amount,
+				    struct ImportAccount * account,
 				    struct gnucash_category * categ );
-static xmlNodePtr get_child ( xmlNodePtr node, gchar * child_name );
+static xmlNodePtr get_child ( xmlNodePtr node, const gchar * child_name );
 static gchar * get_currency ( xmlNodePtr currency_node );
-static gsb_real gnucash_value ( gchar * value );
-static struct gnucash_split * new_split ( gsb_real amount, gchar * account, gchar * categ );
-static struct struct_ope_importation * new_transaction_from_split ( struct gnucash_split * split,
+static GsbReal gnucash_value ( gchar * value );
+static struct gnucash_split * new_split ( GsbReal amount, gchar * account, gchar * categ );
+static struct ImportTransaction * new_transaction_from_split ( struct gnucash_split * split,
 							     gchar * tiers, GDate * date );
-static gboolean node_strcmp ( xmlNodePtr node, gchar * name );
+static gboolean node_strcmp ( xmlNodePtr node, const gchar * name );
 static xmlDocPtr parse_gnucash_file ( gchar * filename );
 static void recuperation_donnees_gnucash_book ( xmlNodePtr book_node );
 static void recuperation_donnees_gnucash_categorie ( xmlNodePtr categ_node );
 static void recuperation_donnees_gnucash_compte ( xmlNodePtr compte_node );
 static void recuperation_donnees_gnucash_transaction ( xmlNodePtr transaction_node );
-static void update_split ( struct gnucash_split * split, gsb_real amount,
+static void update_split ( struct gnucash_split * split, GsbReal amount,
 		    gchar * account, gchar * categ );
 /*END_STATIC*/
 
@@ -83,12 +83,12 @@ struct gnucash_category {
 };
 
 struct gnucash_split {
-  gsb_real amount;
+  GsbReal amount;
   gchar * category;
   gchar * account;
   gchar * contra_account;
   gchar * notes;
-  enum operation_etat_rapprochement p_r;
+  gint p_r;
 };
 
 /* Variables */
@@ -106,11 +106,12 @@ gchar * gnucash_filename = NULL;
  * \return TRUE upon success.  FALSE otherwise.
  */
 gboolean recuperation_donnees_gnucash ( GtkWidget * assistant,
-					struct imported_file * imported )
+					struct ImportFile * imported )
 {
   xmlDocPtr doc;
-  struct struct_compte_importation * account;
+  struct ImportAccount * account;
 
+  (void)assistant;
   gnucash_filename = my_strdup ( imported -> name );
   doc = parse_gnucash_file ( gnucash_filename );
 
@@ -128,7 +129,7 @@ gboolean recuperation_donnees_gnucash ( GtkWidget * assistant,
   }
 
   /* So, we failed to import file. */
-  account = g_malloc0 ( sizeof ( struct struct_compte_importation ));
+  account = g_malloc0 ( sizeof ( struct ImportAccount ));
   account -> origine = _( "Gnucash" );
   account -> nom_de_compte = _("Invalid Gnucash account, please check gnucash file is not compressed.");
   account -> filename = my_strdup ( imported -> name );
@@ -189,7 +190,7 @@ void recuperation_donnees_gnucash_book ( xmlNodePtr book_node )
 
 
 /**
- * Parse XML account node and fill a struct_compte_importation with
+ * Parse XML account node and fill a ImportAccount with
  * results.  Add account to the global accounts list
  * gnucash_accounts.
  *
@@ -197,11 +198,10 @@ void recuperation_donnees_gnucash_book ( xmlNodePtr book_node )
  */
 void recuperation_donnees_gnucash_compte ( xmlNodePtr compte_node )
 {
-    struct struct_compte_importation *compte;
+    struct ImportAccount *compte;
     gchar * type = child_content ( compte_node, "type" );
-    gsb_real null_real = { 0, 0 };
 
-    compte = calloc ( 1, sizeof ( struct struct_compte_importation ));
+    compte = calloc ( 1, sizeof ( struct ImportAccount ));
 
     /* Gnucash import */
     compte -> origine = my_strdup ( "Gnucash" );
@@ -230,7 +230,7 @@ void recuperation_donnees_gnucash_compte ( xmlNodePtr compte_node )
     compte -> guid = child_content ( compte_node, "id" );
     compte -> operations_importees = NULL;
 
-    compte -> nom_de_compte = unique_imported_name ( compte -> nom_de_compte );
+    compte -> nom_de_compte = gsb_import_unique_imported_name ( compte -> nom_de_compte );
 
     gsb_import_register_account ( compte );
 
@@ -290,20 +290,20 @@ void recuperation_donnees_gnucash_categorie ( xmlNodePtr categ_node )
 
 
 /**
- * Parse XML transaction node and fill a struct_ope_importation with results.
+ * Parse XML transaction node and fill a ImportTransaction with results.
  *
  * \param transaction_node	XML transaction node to parse.
  */
 void recuperation_donnees_gnucash_transaction ( xmlNodePtr transaction_node )
 {
-  struct struct_ope_importation * transaction;
-  struct struct_compte_importation * account = NULL;
+  struct ImportTransaction * transaction;
+  struct ImportAccount * account = NULL;
   struct gnucash_split * split;
   gchar * date_string, *space, *tiers;
   GDate * date;
   xmlNodePtr splits, split_node, date_node;
   GSList * split_list = NULL;
-  gsb_real total = { 0 , 0 };
+  GsbReal total = { 0 , 0 };
 
   /* Transaction amount, category, account, etc.. */
   splits = get_child ( transaction_node, "splits" );
@@ -311,11 +311,10 @@ void recuperation_donnees_gnucash_transaction ( xmlNodePtr transaction_node )
 
   while ( split_node )
     {
-      struct struct_compte_importation * split_account = NULL;
+      struct ImportAccount * split_account = NULL;
       struct gnucash_category * categ = NULL;
-      struct gnucash_split * split;
-      enum operation_etat_rapprochement p_r = OPERATION_NORMALE;
-      gsb_real amount;
+      gint p_r = OPERATION_NORMALE;
+      GsbReal amount;
 
       /**
        * Gnucash transactions are in fact "splits", much like grisbi's
@@ -400,8 +399,8 @@ void recuperation_donnees_gnucash_transaction ( xmlNodePtr transaction_node )
 
       while ( split_list )
 	{
-	  struct gnucash_split * split = split_list -> data;
-	  struct struct_compte_importation * account = NULL;
+	  split = split_list -> data;
+	  account = NULL;
 
 	  transaction = new_transaction_from_split ( split, tiers, date );
 	  transaction -> ope_de_ventilation = 1;
@@ -436,9 +435,9 @@ gchar * get_currency ( xmlNodePtr currency_node )
  *
  * \param guid		Textual guid of account to search.
  *
- * \return		A pointer to a struct_compte_importation or NULL upon failure.
+ * \return		A pointer to a ImportAccount or NULL upon failure.
  */
-struct struct_compte_importation * find_imported_account_by_uid ( gchar * guid )
+struct ImportAccount * find_imported_account_by_uid ( gchar * guid )
 {
   GSList * liste_tmp;
 
@@ -449,7 +448,7 @@ struct struct_compte_importation * find_imported_account_by_uid ( gchar * guid )
 
   while ( liste_tmp )
     {
-      struct struct_compte_importation * account = liste_tmp -> data;
+      struct ImportAccount * account = liste_tmp -> data;
 
       if ( account -> guid && !strcmp ( account -> guid, guid ))
 	{
@@ -469,9 +468,9 @@ struct struct_compte_importation * find_imported_account_by_uid ( gchar * guid )
  *
  * \param guid		Name of account to search.
  *
- * \return		A pointer to a struct_compte_importation or NULL upon failure.
+ * \return		A pointer to a ImportAccount or NULL upon failure.
  */
-struct struct_compte_importation * find_imported_account_by_name ( gchar * name )
+struct ImportAccount * find_imported_account_by_name ( gchar * name )
 {
   GSList * liste_tmp;
 
@@ -482,7 +481,7 @@ struct struct_compte_importation * find_imported_account_by_name ( gchar * name
 
   while ( liste_tmp )
     {
-      struct struct_compte_importation * account = liste_tmp -> data;
+      struct ImportAccount * account = liste_tmp -> data;
 
       if ( !strcmp ( account -> nom_de_compte, name ))
 	{
@@ -538,7 +537,7 @@ struct gnucash_category * find_imported_categ_by_uid ( gchar * guid )
  *
  * \return		Numeric value of argument 'value'.
  */
-gsb_real gnucash_value ( gchar * value )
+GsbReal gnucash_value ( gchar * value )
 {
   gchar **tab_value;
   gdouble number, mantisse;
@@ -567,7 +566,7 @@ xmlDocPtr parse_gnucash_file ( gchar * filename )
   FILE * filein, * tempfile;
   xmlDocPtr doc;
 
-  filein = utf8_fopen ( filename, "r" );
+  filein = utils_files_utf8_fopen ( filename, "r" );
   if ( ! filein )
   {
       dialogue_error_hint ( g_strdup_printf ( _("Either file \"%s\" does not exist or it is not a regular file."),
@@ -577,7 +576,7 @@ xmlDocPtr parse_gnucash_file ( gchar * filename )
   }
 
   tempname = g_strdup_printf ( "gsbgnc%05d", g_random_int_range (0,99999) );
-  tempfile = utf8_fopen ( tempname, "w" );
+  tempfile = utils_files_utf8_fopen ( tempname, "w" );
   if ( ! tempfile )
   {
     gchar *tmp_str;
@@ -592,6 +591,7 @@ xmlDocPtr parse_gnucash_file ( gchar * filename )
 
     g_free ( tmp_str );
     g_free ( tmp_str_2 );
+    fclose(filein);
 
       return NULL;
   }
@@ -609,9 +609,10 @@ xmlDocPtr parse_gnucash_file ( gchar * filename )
 
     if ( tag )
 	{
-        gchar *ns[14] = { "gnc", "cd", "book", "act", "trn", "split", "cmdty",
-                        "ts", "slots", "slot", "price", "sx", "fs", NULL };
-        gchar **iter;
+        const gchar *ns[14] = { "gnc", "cd", "book", "act", "trn", "split",
+			"cmdty", "ts", "slots", "slot", "price", "sx", "fs", NULL };
+
+        const gchar **iter;
 
         tag += 7;
         *tag = 0;
@@ -659,12 +660,13 @@ xmlDocPtr parse_gnucash_file ( gchar * filename )
  *
  * \return		A gnucash_split upon success.  NULL otherwise.
  */
-struct gnucash_split * find_split ( GSList * split_list, gsb_real amount,
-				    struct struct_compte_importation * account,
+struct gnucash_split * find_split ( GSList * split_list, GsbReal amount,
+				    struct ImportAccount * account,
 				    struct gnucash_category * categ )
 {
   GSList * tmp;
 
+  (void)account;
   tmp = split_list;
   while ( tmp )
     {
@@ -698,7 +700,7 @@ struct gnucash_split * find_split ( GSList * split_list, gsb_real amount,
  * \param account	Account to set if not NULL.
  * \param categ		Category to set if not NULL.
  */
-void update_split ( struct gnucash_split * split, gsb_real amount,
+void update_split ( struct gnucash_split * split, GsbReal amount,
 		    gchar * account, gchar * categ )
 {
   if ( categ )
@@ -731,7 +733,7 @@ void update_split ( struct gnucash_split * split, gsb_real amount,
  *
  * \return		A newly created gnucash_split.
  */
-struct gnucash_split * new_split ( gsb_real amount, gchar * account, gchar * categ )
+struct gnucash_split * new_split ( GsbReal amount, gchar * account, gchar * categ )
 {
   struct gnucash_split * split;
 
@@ -753,22 +755,22 @@ struct gnucash_split * new_split ( gsb_real amount, gchar * account, gchar * cat
 
 
 /**
- * Allocate and return a struct_ope_importation created from a
+ * Allocate and return a ImportTransaction created from a
  * gnucash_split and some arguments.
  *
  * \param split		Split to use as a base.
  * \param tiers		Transaction payee name.
  * \param date		Transaction date.
  *
- * \return 		A newly allocated struct_ope_importation.
+ * \return 		A newly allocated ImportTransaction.
  */
-struct struct_ope_importation * new_transaction_from_split ( struct gnucash_split * split,
+struct ImportTransaction * new_transaction_from_split ( struct gnucash_split * split,
 							     gchar * tiers, GDate * date )
 {
-  struct struct_ope_importation * transaction;
+  struct ImportTransaction * transaction;
 
   /** Basic properties are set according to split. */
-  transaction = calloc ( 1, sizeof ( struct struct_ope_importation ));
+  transaction = calloc ( 1, sizeof ( struct ImportTransaction ));
   transaction -> montant = split -> amount;
   transaction -> notes = split -> notes;
   transaction -> p_r = split -> p_r;
@@ -778,22 +780,24 @@ struct struct_ope_importation * new_transaction_from_split ( struct gnucash_spli
   if ( split -> contra_account )
     {
       /** If split contains a contra account, then this is a transfer. */
-      struct struct_compte_importation * contra_account;
-      struct struct_ope_importation * contra_transaction;
-
-      contra_transaction = calloc ( 1, sizeof ( struct struct_ope_importation ));
-      contra_transaction -> montant = gsb_real_opposite (split -> amount);
-      contra_transaction -> notes = split -> notes;
-      contra_transaction -> tiers = tiers;
-      contra_transaction -> date = date;
-      contra_transaction -> p_r = split -> p_r;
-
-      transaction -> categ = g_strconcat ( "[", split -> contra_account, "]", NULL );
-      contra_transaction -> categ = g_strconcat ( "[", split -> account, "]", NULL );
+      struct ImportAccount * contra_account;
+      struct ImportTransaction * contra_transaction;
 
       contra_account = find_imported_account_by_name ( split -> contra_account );
       if ( contra_account )
-	contra_account -> operations_importees = g_slist_append ( contra_account -> operations_importees, contra_transaction );
+      {
+	  contra_transaction = calloc ( 1, sizeof ( struct ImportTransaction ));
+	  contra_transaction -> montant = gsb_real_opposite (split -> amount);
+	  contra_transaction -> notes = split -> notes;
+	  contra_transaction -> tiers = tiers;
+	  contra_transaction -> date = date;
+	  contra_transaction -> p_r = split -> p_r;
+
+	  transaction -> categ = g_strconcat ( "[", split -> contra_account, "]", NULL );
+	  contra_transaction -> categ = g_strconcat ( "[", split -> account, "]", NULL );
+
+	  contra_account -> operations_importees = g_slist_append ( contra_account -> operations_importees, contra_transaction );
+      }
     }
   else
     {
@@ -808,19 +812,21 @@ struct struct_ope_importation * new_transaction_from_split ( struct gnucash_spli
 
 
 
-gboolean node_strcmp ( xmlNodePtr node, gchar * name )
+gboolean node_strcmp ( xmlNodePtr node, const gchar * name )
 {
   return node -> name && ! strcmp ( ( gchar *) node -> name, name );
 }
 
 
 
-xmlNodePtr get_child ( xmlNodePtr node, gchar * child_name )
+xmlNodePtr get_child ( xmlNodePtr node, const gchar * child_name )
 {
-  xmlNodePtr iter_node = node -> children;
+  xmlNodePtr iter_node;
 
   if (!node) return NULL;
 
+  iter_node = node -> children;
+
   while ( iter_node )
     {
       if ( node_strcmp(iter_node, child_name) )
@@ -833,7 +839,7 @@ xmlNodePtr get_child ( xmlNodePtr node, gchar * child_name )
 }
 
 
-gchar * child_content ( xmlNodePtr node, gchar * child_name )
+gchar * child_content ( xmlNodePtr node, const gchar * child_name )
 {
   xmlNodePtr child_node;
 
