@@ -38,6 +38,7 @@
 
 /*START_INCLUDE*/
 #include "prefs_page_accueil.h"
+#include "grisbi_app.h"
 #include "grisbi_settings.h"
 #include "gsb_automem.h"
 #include "gsb_locale.h"
@@ -262,6 +263,7 @@ static void prefs_page_accueil_setup_accueil_page (PrefsPageAccueil *page)
 
 	if (is_loading)
 	{
+		GtkWidget *window;
 		GtkWidget *treeview;
 	    GtkListStore *list_store;
 		GtkTreeViewColumn *column;
@@ -271,6 +273,8 @@ static void prefs_page_accueil_setup_accueil_page (PrefsPageAccueil *page)
 		GtkTreeDragSourceIface * src_iface;
 		static GtkTargetEntry row_targets[] = {{"GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET, 0}};
 
+		window = GTK_WIDGET (grisbi_app_get_active_window (NULL));
+
 		/* create the model */
 		list_store = gsb_partial_balance_create_model ();
 
@@ -366,7 +370,7 @@ static void prefs_page_accueil_setup_accueil_page (PrefsPageAccueil *page)
 		src_iface = GTK_TREE_DRAG_SOURCE_GET_IFACE (list_store);
 		if (src_iface)
 		{
-			gtk_selection_add_target (treeview,
+			gtk_selection_add_target (window,
 						  GDK_SELECTION_PRIMARY,
 						  GDK_SELECTION_TYPE_ATOM,
 						  1);
