@@ -67,7 +67,10 @@ struct _PrefsPageImportAssoPrivate
     GtkWidget *         button_import_asso_add;
     GtkWidget *         button_import_asso_remove;
 	GtkWidget *			checkbutton_import_asso_case_insensitive;
+	GtkWidget *			eventbox_import_asso_case_insensitive;
+	GtkWidget *			hbox_import_asso_use_regex;
 	GtkWidget *			checkbutton_import_asso_use_regex;
+	GtkWidget *			eventbox_import_asso_use_regex;
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (PrefsPageImportAsso, prefs_page_import_asso, GTK_TYPE_BOX)
@@ -78,6 +81,30 @@ static GtkTreePath *path_selected;
 /******************************************************************************/
 /* Private functions                                                          */
 /******************************************************************************/
+/**
+ * Appellée lorsqu'on coche la case "Automatic filling transactions from payee"
+ *
+ * \param
+ * \param
+ *
+ * \return
+ **/
+static void prefs_page_import_asso_checkbutton_import_asso_case_insensitive_toggle (GtkWidget *checkbutton,
+																					PrefsPageImportAsso *page)
+{
+	GtkWidget *entry;
+    gint payee_number;
+ 	PrefsPageImportAssoPrivate *priv;
+
+	priv = prefs_page_import_asso_get_instance_private (page);
+	entry = gtk_combofix_get_entry (GTK_COMBOFIX (priv->combo_import_asso_payee));
+    payee_number = gsb_data_payee_get_number_by_name (gtk_editable_get_chars
+													  (GTK_EDITABLE (entry), 0, -1),
+													  FALSE);
+	gsb_data_payee_set_ignore_case (payee_number,
+									gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbutton)));
+}
+
 /**
  * Select the row which show the payee with number passed in data
  *
@@ -585,18 +612,31 @@ static void prefs_page_import_asso_setup_import_asso_page (PrefsPageImportAsso *
 								  w_run->import_asso_case_insensitive);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_import_asso_use_regex),
 								  w_run->import_asso_use_regex);
+	gtk_widget_set_sensitive (priv->hbox_import_asso_use_regex, FALSE);
 
 	/* Connect signal checkbutton_import_asso_case_insensitive */
     g_signal_connect (priv->checkbutton_import_asso_case_insensitive,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
 					  &w_run->import_asso_case_insensitive);
+    g_signal_connect (priv->eventbox_import_asso_case_insensitive,
+					  "button-press-event",
+					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
+					  priv->checkbutton_import_asso_case_insensitive);
+    g_signal_connect_after (priv->checkbutton_import_asso_case_insensitive,
+							"toggled",
+							G_CALLBACK (prefs_page_import_asso_checkbutton_import_asso_case_insensitive_toggle),
+							page);
 
 	/* Connect signal checkbutton_import_asso_use_regex */
     g_signal_connect (priv->checkbutton_import_asso_use_regex,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
 					  &w_run->import_asso_use_regex);
+    g_signal_connect (priv->eventbox_import_asso_use_regex,
+					  "button-press-event",
+					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
+					  priv->checkbutton_import_asso_use_regex);
 
 	/* setup treeview_associations */
 	prefs_page_import_asso_setup_treeview_asso (page);
@@ -656,7 +696,10 @@ static void prefs_page_import_asso_class_init (PrefsPageImportAssoClass *klass)
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageImportAsso, button_import_asso_add);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageImportAsso, button_import_asso_remove);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageImportAsso, checkbutton_import_asso_case_insensitive);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageImportAsso, eventbox_import_asso_case_insensitive);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageImportAsso, checkbutton_import_asso_use_regex);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageImportAsso, eventbox_import_asso_use_regex);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageImportAsso, hbox_import_asso_use_regex);
 }
 
 /******************************************************************************/
