@@ -25,7 +25,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -37,9 +37,9 @@
 #include "gsb_autofunc.h"
 #include "gsb_automem.h"
 #include "gsb_calendar_entry.h"
-#include "gsb_color.h"
 #include "gsb_data_print_config.h"
 #include "gsb_data_transaction.h"
+#include "gsb_rgba.h"
 #include "utils.h"
 #include "print_dialog_config.h"
 #include "transaction_model.h"
@@ -139,13 +139,13 @@ GtkWidget * print_transactions_list_layout_config ( GtkPrintOperation * operatio
 
     size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
-    vbox = gtk_vbox_new ( FALSE, 6 );
-    gtk_container_set_border_width ( GTK_CONTAINER(vbox), 12 );
+    vbox = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER(vbox), BOX_BORDER_WIDTH );
     paddingbox = new_paddingbox_with_title ( vbox, FALSE, _("Layout") );
 
     /* set up the title and dates, this is never saved, so ask each time */
     /* title line */
-    hbox = gtk_hbox_new (FALSE, 10);
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start (GTK_BOX (paddingbox),
 			hbox,
 			FALSE, FALSE, 0);
@@ -166,7 +166,7 @@ GtkWidget * print_transactions_list_layout_config ( GtkPrintOperation * operatio
 			TRUE, TRUE, 0);
 
     /* add the dates interval */
-    hbox = gtk_hbox_new (FALSE, 10);
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
 
     check_button = gsb_autofunc_checkbutton_new (_("Select dates interval: "),
 						 gsb_data_print_config_get_draw_interval_dates (),
@@ -263,14 +263,14 @@ GtkWidget * print_transactions_list_layout_config ( GtkPrintOperation * operatio
 
     /* set up the font of the transactions,
      * by default use the font of the lists */
-    hbox = gtk_hbox_new (FALSE, 12);
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start (GTK_BOX (paddingbox),
 			hbox,
 			FALSE, FALSE, 0);
 
     label = gtk_label_new (_("Transactions font"));
     gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5);
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0, 0.5);
     gtk_size_group_add_widget ( size_group, label );
     gtk_box_pack_start (GTK_BOX (hbox),
 			label,
@@ -286,14 +286,14 @@ GtkWidget * print_transactions_list_layout_config ( GtkPrintOperation * operatio
 			TRUE, TRUE, 0);
 
     /* set up the font for the title */
-    hbox = gtk_hbox_new (FALSE, 12);
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start (GTK_BOX (paddingbox),
 			hbox,
 			FALSE, FALSE, 0);
 
     label = gtk_label_new (_("Title font"));
     gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5);
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0, 0.5);
     gtk_size_group_add_widget ( size_group, label );
     gtk_box_pack_start (GTK_BOX (hbox),
 			label,
@@ -348,9 +348,9 @@ gboolean print_transactions_list_apply ( GtkPrintOperation * operation,
     font_button_title = g_object_get_data ( G_OBJECT( operation ), "font_title_button" );
 
     gsb_data_print_config_set_font_transaction ( pango_font_description_from_string (
-                        gtk_font_button_get_font_name ( font_button_transactions ) ) );
+                        gtk_font_chooser_get_font (GTK_FONT_CHOOSER (font_button_transactions))));
     gsb_data_print_config_set_font_title ( pango_font_description_from_string (
-                        gtk_font_button_get_font_name ( font_button_title ) ) );
+                        gtk_font_chooser_get_font (GTK_FONT_CHOOSER (font_button_title))));
 
 
     if ( gsb_data_print_config_get_draw_interval_dates () )
@@ -581,7 +581,7 @@ gboolean print_transactions_list_draw_page ( GtkPrintOperation *operation,
 
 	/* we are on the last record of the transaction or archive,
 	 * decrease the number of transactions to draw */
-	if (record -> what_is_line == IS_TRANSACTION)
+	if (record && record -> what_is_line == IS_TRANSACTION)
 	{
 	    transactions_to_draw--;
 	    total_transactions_printed++;
@@ -806,9 +806,9 @@ static void print_transactions_list_draw_background ( CustomRecord *record,
 
     if (record -> what_is_line == IS_ARCHIVE)
     {
-        GdkColor *color;
+        GdkRGBA *color;
 
-        color = gsb_color_get_couleur ( "archive_background_color" );
+        color = gsb_rgba_get_couleur ( "background_archive" );
         cairo_rectangle ( cr, 0, line_position, page_width, size_row + 2*gsb_data_print_config_get_draw_lines ( ) );
         cairo_set_source_rgb ( cr,
                         (gdouble) color -> red/65535,
@@ -818,12 +818,12 @@ static void print_transactions_list_draw_background ( CustomRecord *record,
     else
     {
         CustomList *custom_list = transaction_model_get_model ( );
-        GdkColor *color;
+        GdkRGBA *color;
 
         if ( color_bg )
-            color = gsb_color_get_couleur_with_indice ( "couleur_fond", 0 );
+            color = gsb_rgba_get_couleur_with_indice ( "couleur_fond", 0 );
         else
-            color = gsb_color_get_couleur_with_indice ( "couleur_fond", 1 );
+            color = gsb_rgba_get_couleur_with_indice ( "couleur_fond", 1 );
 
         cairo_rectangle (cr, 0, line_position, page_width,
                         custom_list -> nb_rows_by_transaction * size_row + 2*gsb_data_print_config_get_draw_lines ( ) );
