@@ -21,7 +21,7 @@
 /* ************************************************************************** */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -275,7 +275,7 @@ gboolean print_tree_view_list_begin ( GtkPrintOperation *operation,
         line_position = print_tree_view_list_draw_columns_title ( context, line_position, tree_view );
 
     /* draw the lines */
-    line_position = print_tree_view_list_draw_rows_data ( context, line_position, tree_view, page );
+    print_tree_view_list_draw_rows_data ( context, line_position, tree_view, page );
 
     return FALSE;
 }
@@ -335,7 +335,7 @@ static gint print_tree_view_list_draw_row ( GtkPrintContext *context,
             if ( !text )
             {
                 /* draw first the column */
-                column_position = print_tree_view_list_draw_column ( column_position, line_position );
+                print_tree_view_list_draw_column ( column_position, line_position );
 
                 list_tmp  = list_tmp -> next;
                 column++;
@@ -968,13 +968,13 @@ GtkWidget *print_tree_view_list_layout_config ( GtkPrintOperation *operation, gp
 
     size_group = gtk_size_group_new ( GTK_SIZE_GROUP_HORIZONTAL );
 
-    vbox = gtk_vbox_new ( FALSE, 6 );
-    gtk_container_set_border_width ( GTK_CONTAINER ( vbox ), 12 );
+    vbox = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER ( vbox ), BOX_BORDER_WIDTH );
     paddingbox = new_paddingbox_with_title ( vbox, FALSE, _("Layout") );
 
     /* set up the title, this is never saved, so ask each time */
     /* title line */
-    hbox = gtk_hbox_new ( FALSE, 10 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
 
     entry = gsb_automem_entry_new ( &title_string, NULL, NULL);
@@ -1015,12 +1015,12 @@ GtkWidget *print_tree_view_list_layout_config ( GtkPrintOperation *operation, gp
 
     /* set up the font of the transactions,
      * by default use the font of the lists */
-    hbox = gtk_hbox_new ( FALSE, 12 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Transactions font") );
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5 );
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0, 0.5 );
     gtk_size_group_add_widget ( size_group, label );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 0 );
 
@@ -1032,12 +1032,12 @@ GtkWidget *print_tree_view_list_layout_config ( GtkPrintOperation *operation, gp
     gtk_box_pack_start ( GTK_BOX ( hbox ), font_button_transactions, TRUE, TRUE, 0 );
 
     /* set up the font for the title */
-    hbox = gtk_hbox_new (FALSE, 12);
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 0 );
 
     label = gtk_label_new ( _("Title font") );
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5);
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0, 0.5);
     gtk_size_group_add_widget ( size_group, label );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 0 );
 
@@ -1098,17 +1098,14 @@ static void print_tree_view_list_draw_background ( GtkPrintContext *context,
     {
         gchar *str_color;
         gint col_color;
-        GdkColor color;
+        GdkRGBA color;
 
         col_color = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( tree_view ), "color_data_model" ) );
         gtk_tree_model_get ( model, &iter, col_color, &str_color, -1 );
-        gdk_color_parse ( str_color, &color );
+        (void)gdk_rgba_parse (&color, str_color);
 
         cairo_rectangle ( cr, 0, line_position, page_width, size_row + 2 * gsb_data_print_config_get_draw_lines () );
-        cairo_set_source_rgb ( cr,
-                        (gdouble) color.red/65535,
-                        (gdouble) color.green/65535,
-                        (gdouble) color.blue/65535 );
+        cairo_set_source_rgb ( cr, color.red, color.green, color.blue);
 
         cairo_fill (cr);
         cairo_set_source_rgb (cr, 0.0, 0.0, 0.0);
@@ -1137,7 +1134,7 @@ static gint print_tree_view_list_get_columns_data_nbre_lines ( GtkTreeView *tree
     while ( list_tmp )
     {
         GtkTreeViewColumn *col;
-        const gchar *text;
+        const gchar *text = NULL;
         gint nbre_motifs = 0;
         gint col_num_model;
         GType col_type_model;
