@@ -29,7 +29,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -44,7 +44,7 @@
 /* END_INCLUDE */
 
 /* START_STATIC */
-static void gsb_data_account_cunit__gsb_data_account_calculate_current_and_marked_balances();
+static void gsb_data_account_cunit__gsb_data_account_calculate_current_and_marked_balances(void);
 static int gsb_data_account_cunit_clean_suite(void);
 static int gsb_data_account_cunit_init_suite(void);
 /* END_STATIC */
@@ -68,7 +68,7 @@ int gsb_data_account_cunit_clean_suite(void)
     return 0;
 }
 
-void gsb_data_account_cunit__gsb_data_account_calculate_current_and_marked_balances()
+void gsb_data_account_cunit__gsb_data_account_calculate_current_and_marked_balances(void)
 {
     GDate *date = gdate_today() ;
 
@@ -82,10 +82,10 @@ void gsb_data_account_cunit__gsb_data_account_calculate_current_and_marked_balan
 
     gint tr_number_1 = gsb_data_transaction_new_transaction(account_number);
     CU_ASSERT_EQUAL(1, tr_number_1);
-    gsb_real amount = { 2100000021, 2 };
+    GsbReal amount = { 2100000021, 2 };
     CU_ASSERT_EQUAL(TRUE, gsb_data_transaction_set_amount(tr_number_1, amount));
     CU_ASSERT_EQUAL(TRUE, gsb_data_transaction_set_date(tr_number_1, date));
-    gsb_real balance = gsb_data_account_calculate_current_and_marked_balances(account_number);
+    GsbReal balance = gsb_data_account_calculate_current_and_marked_balances(account_number);
     CU_ASSERT_EQUAL(2100000021, balance.mantissa);
     CU_ASSERT_EQUAL(2, balance.exponent);
 
@@ -112,16 +112,16 @@ void gsb_data_account_cunit__gsb_data_account_calculate_current_and_marked_balan
     CU_ASSERT_EQUAL(2100000021, balance.mantissa);
     CU_ASSERT_EQUAL(2, balance.exponent);
 
-    gsb_data_transaction_remove_transaction( tr_number_3 );
-    gsb_data_transaction_remove_transaction( tr_number_2 );
-    gsb_data_transaction_remove_transaction( tr_number_1 );
+    //gsb_data_transaction_remove_transaction( tr_number_3 );
+    //gsb_data_transaction_remove_transaction( tr_number_2 );
+    //gsb_data_transaction_remove_transaction( tr_number_1 );
 
     gsb_data_account_delete( account_number );
     g_date_free(date);
     CU_ASSERT_EQUAL(TRUE, gsb_data_currency_remove ( cur_number ));
 }
 
-CU_pSuite gsb_data_account_cunit_create_suite()
+CU_pSuite gsb_data_account_cunit_create_suite(void)
 {
     CU_pSuite pSuite = CU_add_suite("gsb_data_account",
                                     gsb_data_account_cunit_init_suite,
