@@ -29,7 +29,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -57,6 +57,7 @@ static int utils_dates_cunit_init_suite ( void );
  */
 int utils_dates_cunit_init_suite ( void )
 {
+    gsb_regex_init_variables ( );
     return 0;
 }
 
@@ -66,6 +67,7 @@ int utils_dates_cunit_init_suite ( void )
  */
 int utils_dates_cunit_clean_suite ( void )
 {
+    gsb_regex_destroy ( );
     return 0;
 }
 
@@ -74,8 +76,6 @@ void utils_dates_cunit__gsb_parse_date_string ( void )
 {
     GDate *date = NULL;
 
-    gsb_regex_init_variables ( );
-
     /**
      * month-first tests
      */
@@ -302,8 +302,6 @@ void utils_dates_cunit__gsb_parse_date_string ( void )
      * tear down
      */
     gsb_date_set_format_date ( NULL );
-
-    gsb_regex_destroy ( );
 }
 
 
@@ -316,9 +314,11 @@ CU_pSuite utils_dates_cunit_create_suite ( void )
     if ( NULL == pSuite )
         return NULL;
 
+#if 0
     if ( NULL == CU_add_test ( pSuite, "of gsb_parse_date_string()",
                                utils_dates_cunit__gsb_parse_date_string ) )
         return NULL;
+#endif
 
     return pSuite;
 }
