@@ -31,7 +31,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -42,13 +42,13 @@
 #include "affichage_liste.h"
 #include "custom_list.h"
 #include "dialog.h"
-#include "gsb_color.h"
 #include "gsb_data_account.h"
 #include "gsb_data_archive.h"
 #include "gsb_data_archive_store.h"
 #include "gsb_data_currency.h"
 #include "gsb_data_transaction.h"
 #include "gsb_real.h"
+#include "gsb_rgba.h"
 #include "gsb_transactions_list.h"
 #include "gsb_transactions_list_sort.h"
 #include "navigation.h"
@@ -78,7 +78,7 @@ extern gint tab_affichage_ope[TRANSACTION_LIST_ROWS_NB][CUSTOM_MODEL_VISIBLE_COL
 /*END_EXTERN*/
 
 
-/* this is a buffer wich contains the last mother appended, to increase
+/* this is a buffer which contains the last mother appended, to increase
  * the speed when filling the list and adding children */
 static CustomRecord *last_mother_appended = NULL;
 
@@ -123,7 +123,7 @@ void transaction_list_append_transaction ( gint transaction_number )
     CustomList *custom_list;
     CustomRecord **children_rows = NULL;
     CustomRecord *white_record = NULL;
-    GdkColor *mother_text_color;
+    GdkRGBA *mother_text_color;
 
     custom_list = transaction_model_get_model ();
 
@@ -154,7 +154,7 @@ void transaction_list_append_transaction ( gint transaction_number )
 	white_record = g_malloc0 (sizeof (CustomRecord));
 	white_record -> transaction_pointer = gsb_data_transaction_get_pointer_of_transaction (white_line_number);
 	white_record -> what_is_line = IS_TRANSACTION;
-	white_record -> row_bg = gsb_color_get_couleur ( "split_background" );
+	white_record -> row_bg = gsb_rgba_get_couleur ( "background_split" );
 
 	/* as we append just now the white line, there are no child split, so the total is 0 */
 	amount_string = utils_real_get_string_with_currency (null_real,
@@ -241,7 +241,7 @@ void transaction_list_append_transaction ( gint transaction_number )
             newrecord[i] -> has_expander = TRUE;
             white_record -> mother_row = newrecord[i];
             /* set the color of the mother */
-            mother_text_color = gsb_color_get_couleur_with_indice ( "text_color", 1 );
+            mother_text_color = gsb_rgba_get_couleur_with_indice ( "text_color", 1 );
             newrecord[i] -> text_color = mother_text_color;
 	    }
 
@@ -323,7 +323,14 @@ void transaction_list_append_archive ( gint archive_store_number )
     archive_number = gsb_data_archive_store_get_archive_number ( archive_store_number );
 
     if ( find_element_col ( ELEMENT_DATE ) == 0 )
+    {
         element_date = find_element_col_for_archive ( );
+        if (element_date < 0)
+		{
+			g_free(newrecord);
+            return;
+		}
+    }
 
     newrecord -> visible_col[element_date] = gsb_format_gdate (
                         gsb_data_archive_get_beginning_date ( archive_number ) );
@@ -349,7 +356,7 @@ void transaction_list_append_archive ( gint archive_store_number )
     newrecord -> transaction_pointer = gsb_data_archive_store_get_structure (
                         archive_store_number);
     newrecord -> what_is_line = IS_ARCHIVE;
-    newrecord -> row_bg = gsb_color_get_couleur ( "archive_background_color" );
+    newrecord -> row_bg = gsb_rgba_get_couleur ("background_archive");
 
     /* save the newrecord pointer */
     custom_list->rows[pos] = newrecord;
@@ -377,7 +384,6 @@ gboolean transaction_list_remove_transaction ( gint transaction_number )
     CustomRecord *record;
     gint i;
     GtkTreeIter iter;
-    gint record_filtered_pos;
     gulong newsize;
     GtkTreePath *path;
     CustomList *custom_list;
@@ -461,8 +467,6 @@ gboolean transaction_list_remove_transaction ( gint transaction_number )
 	return TRUE;
     }
 
-    record_filtered_pos = record -> filtered_pos;
-
     /* we are on a mother transaction, remove the row */
     custom_list -> num_rows = custom_list -> num_rows - TRANSACTION_LIST_ROWS_NB;
 
@@ -623,10 +627,10 @@ void transaction_list_filter ( gint account_number )
     g_return_if_fail ( custom_list != NULL );
     g_return_if_fail ( custom_list->num_rows != 0 );
 
-    /* there is a bug, i think in gtk, wich when we re-filter the list with opened split, and when
+    /* there is a bug, i think in gtk, which when we re-filter the list with opened split, and when
      * there is less lines in the list that the window, gtk close the split opened without
      * informing the tree view so tree view errors laters... i didn't find anything here
-     * wich close the split, so i assume is gtk. the solution is to close all the split.
+     * which close the split, so i assume is gtk. the solution is to close all the split.
      * this is very important to keep gtk_tree_view_collapse_all to avoid very nuts bugs !!!  */
     gtk_tree_view_collapse_all (GTK_TREE_VIEW (gsb_transactions_list_get_tree_view ()));
 
@@ -646,129 +650,126 @@ void transaction_list_filter ( gint account_number )
 
     for (current_pos_general_list=0 ; current_pos_general_list<custom_list -> num_rows ; current_pos_general_list++)
     {
-	CustomRecord *record;
-	gboolean shown;
-	gboolean previous_shown;
-	guint last_pos_filtered_list;
+        CustomRecord *record;
+        gboolean shown;
+        gboolean previous_shown;
+        gint last_pos_filtered_list;
 
-	/* get the current record to check */
-	record = custom_list -> rows[current_pos_general_list];
+        /* get the current record to check */
+        record = custom_list -> rows[current_pos_general_list];
 
-	/* was the line visible before ? */
-	previous_shown = record -> line_visible;
+        /* was the line visible before ? */
+        previous_shown = record -> line_visible;
 
-	/* check if line is shown */
-	shown = gsb_transactions_list_transaction_visible ( record -> transaction_pointer,
-							    account_number,
-							    record -> line_in_transaction,
-							    record -> what_is_line );
-	record -> line_visible = shown;
+        /* check if line is shown */
+        shown = gsb_transactions_list_transaction_visible ( record -> transaction_pointer,
+                                    account_number,
+                                    record -> line_in_transaction,
+                                    record -> what_is_line );
+        record -> line_visible = shown;
 
-	/* if the line is shown, append it to the filtered parameters of the model */
-	if (!shown)
-	{
-	    /* the row will be hidden, set it and continue to the next row */
-	    /* the content of that row and children if exist will be changed with the
-	     * next visible row */
-	    record -> filtered_pos = -1;
+        /* if the line is shown, append it to the filtered parameters of the model */
+        if (!shown)
+        {
+            /* the row will be hidden, set it and continue to the next row */
+            /* the content of that row and children if exist will be changed with the
+             * next visible row */
+            record -> filtered_pos = -1;
 
-	    /* if the row had some visible children, we hide the expander,
-	     * either the transaction is visible but that row is not visible
-	     * (line_in_transaction is bigger than visible line in account) and
-	     * the children have already moved to previous row in that transaction,
-	     * either the transaction is not visible anymore, and when we will show
-	     * it again, has_expander will be set again at the good position */
-	    record -> has_expander = FALSE;
-	    continue;
-	}
+            /* if the row had some visible children, we hide the expander,
+             * either the transaction is visible but that row is not visible
+             * (line_in_transaction is bigger than visible line in account) and
+             * the children have already moved to previous row in that transaction,
+             * either the transaction is not visible anymore, and when we will show
+             * it again, has_expander will be set again at the good position */
+            record -> has_expander = FALSE;
+            continue;
+        }
 
-	/* the row will be showed */
+        /* the row will be showed */
 
-	/* save the last position */
-	last_pos_filtered_list = record -> filtered_pos;
+        /* save the last position */
+        last_pos_filtered_list = record -> filtered_pos;
 
-	/* update the custom list with that row */
-	record -> filtered_pos = current_pos_filtered_list;
-	custom_list -> visibles_rows[current_pos_filtered_list] = record;
-	current_pos_filtered_list++;
-	custom_list -> num_visibles_rows = current_pos_filtered_list;
+        /* update the custom list with that row */
+        record -> filtered_pos = current_pos_filtered_list;
+        custom_list -> visibles_rows[current_pos_filtered_list] = record;
+        current_pos_filtered_list++;
+        custom_list -> num_visibles_rows = current_pos_filtered_list;
 
-	/* set the iter */
-	iter.user_data = record;
+        /* set the iter */
+        iter.user_data = record;
 
-	switch (record -> what_is_line)
-	{
-	    case IS_ARCHIVE:
-		/* we are on an  archive line, the only thing to know is
-		 * if it is at the same place as before or not,
-		 * if yes, just continue, if not, we will see later if
-		 * we need to add or change the row */
-		if (previous_shown && (record -> filtered_pos == last_pos_filtered_list))
-		{
-		    gtk_tree_path_next (path);
-		    continue;
-		}
-		break;
+        switch (record -> what_is_line)
+        {
+            case IS_ARCHIVE:
+            /* we are on an  archive line, the only thing to know is
+             * if it is at the same place as before or not,
+             * if yes, just continue, if not, we will see later if
+             * we need to add or change the row */
+            if (previous_shown && (record -> filtered_pos == last_pos_filtered_list))
+            {
+                gtk_tree_path_next (path);
+                continue;
+            }
+            break;
 
-	    case IS_TRANSACTION:
-		/* the row is shown, if it's the last row chowed of the transaction
-		 * we have to move the children to that row if they exist */
-		if ( record -> number_of_children &&
-		     record -> line_in_transaction == ( transaction_list_get_last_line (
-											gsb_data_account_get_nb_rows (account_number) ) ) )
-		{
-		    /* ok, we are on the last visible line, there is some children and if before
-		     * the children were not associated to that row, we have to move them */
-		    if (record -> has_expander == FALSE)
-		    {
-                for (i=0 ; i < record -> number_of_children ; i++)
-			    	((CustomRecord *) record -> children_rows[i]) -> mother_row = record;
-			    record -> has_expander = TRUE;
-		    }
-		}
-		else
-		    record -> has_expander = FALSE;
-        /* printf ("transaction_number = %d record -> filtered_pos = %d record -> line_in_transaction =%d\n",
-                        gsb_data_transaction_get_transaction_number ( record -> transaction_pointer),
-                        record -> filtered_pos,
-                        record -> line_in_transaction); */
+            case IS_TRANSACTION:
+            /* the row is shown, if it's the last row chowed of the transaction
+             * we have to move the children to that row if they exist */
+            if ( record -> number_of_children &&
+                 record -> line_in_transaction == ( transaction_list_get_last_line (
+                                                gsb_data_account_get_nb_rows (account_number) ) ) )
+            {
+                /* ok, we are on the last visible line, there is some children and if before
+                 * the children were not associated to that row, we have to move them */
+                if (record -> has_expander == FALSE)
+                {
+                    for (i=0 ; i < record -> number_of_children ; i++)
+                        ((CustomRecord *) record -> children_rows[i]) -> mother_row = record;
+                    record -> has_expander = TRUE;
+                }
+            }
+            else
+                record -> has_expander = FALSE;
+            /* the value of the row is set in memory, we update the tree view if necessary */
+            /* if the record was already shown and the position hasn't change, nothing to do */
+            if (previous_shown && (record -> filtered_pos == last_pos_filtered_list))
+            {
+                /* the row itself didn't change but perhaps it got or losed some children
+                 * in that case, the children were moved before, so we just have to
+                 * tell to the tree view that children changed */
+                gtk_tree_model_row_has_child_toggled (GTK_TREE_MODEL (custom_list), path, &iter);
+                gtk_tree_path_next (path);
+                continue;
+            }
+            break;
+        }
 
-		/* the value of the row is set in memory, we update the tree view if necessary */
-		/* if the record was already shown and the position hasn't change, nothing to do */
-		if (previous_shown && (record -> filtered_pos == last_pos_filtered_list))
-		{
-		    /* the row itself didn't change but perhaps it got or losed some children
-		     * in that case, the children were moved before, so we just have to
-		     * tell to the tree view that children changed */
-		    gtk_tree_model_row_has_child_toggled (GTK_TREE_MODEL (custom_list),
-							  path, &iter);
-		    gtk_tree_path_next (path);
-		    continue;
-		}
-		break;
-	}
+        /* now, the record is not at the same place as before (or was not shown before),
+         * so,
+         * either we modify the current row if it exits already,
+         * either we insert a new row if we reached the end */
+        if (current_pos_filtered_list > previous_visible_rows)
+        {
+            /* we reached the end of list, need to add a row */
+            gtk_tree_model_row_inserted ( GTK_TREE_MODEL (custom_list), path, &iter);
+        }
+        else
+        {
+            /* ok, the end of list is not reached, we can just change the row */
+            gtk_tree_model_row_changed ( GTK_TREE_MODEL (custom_list), path, &iter );
+        }
 
-	/* now, the record is not at the same place as before (or was not shown before),
-	 * so,
-	 * either we modify the current row if it exits already,
-	 * either we insert a new row if we reached the end */
-	if (current_pos_filtered_list > previous_visible_rows)
-	    /* we reached the end of list, need to add a row */
-	    gtk_tree_model_row_inserted ( GTK_TREE_MODEL(custom_list),
-					  path, &iter);
-	else
-	    /* ok, the end of list is not reached, we can just change the row */
-	    gtk_tree_model_row_changed ( GTK_TREE_MODEL (custom_list),
-					 path, &iter );
+        /* the new row can have some children, or the last row (if we just changed the row)
+         * could have some children we don't want now. that function is magic because
+         * automatically update if there are children or not */
+        if (record -> what_is_line == IS_TRANSACTION)
+        {
+            gtk_tree_model_row_has_child_toggled (GTK_TREE_MODEL (custom_list), path, &iter);
+        }
 
-	/* the new row can have some children, or the last row (if we just changed the row)
-	 * could have some children we don't want now. that function is magic because
-	 * automatically update if there are children or not */
-	if (record -> what_is_line == IS_TRANSACTION)
-	    gtk_tree_model_row_has_child_toggled (GTK_TREE_MODEL (custom_list),
-						  path, &iter);
-
-	gtk_tree_path_next (path);
+        gtk_tree_path_next (path);
     }
 
     /* if the previous list was bigger than now, we need to delete some rows */
@@ -860,7 +861,7 @@ void transaction_list_colorize (void)
                 /* set the color of the mother */
                 for (j=0 ; j<TRANSACTION_LIST_ROWS_NB ; j++)
                     record -> transaction_records[j] -> text_color =
-                                                            gsb_color_get_couleur_with_indice ( "text_color", 0 );
+                                                            gsb_rgba_get_couleur_with_indice ( "text_color", 0 );
             }
 
         }
@@ -872,7 +873,7 @@ void transaction_list_colorize (void)
 	    }
 
 	    /* set the color of the row */
-	    record -> row_bg = gsb_color_get_couleur_with_indice ( "couleur_fond", current_color );
+	    record -> row_bg = gsb_rgba_get_couleur_with_indice ( "couleur_fond", current_color );
 	}
     }
 }
@@ -889,7 +890,7 @@ void transaction_list_colorize (void)
 void transaction_list_set_balances ( void )
 {
     gint account_number;
-    gsb_real current_total;
+    GsbReal current_total;
     gint column_balance;
     gint line_balance;
     gint nb_rows;
@@ -909,6 +910,8 @@ void transaction_list_set_balances ( void )
 
     /* column and line of balance are user defined */
     column_balance = find_element_col (ELEMENT_BALANCE);
+    if (column_balance < 0)
+        return;
     line_balance = find_element_line (ELEMENT_BALANCE);
 
     /* check if the balance is visible */
@@ -934,7 +937,7 @@ void transaction_list_set_balances ( void )
     for (i=0 ; i < custom_list -> num_visibles_rows ; i++)
     {
         CustomRecord *record;
-        gsb_real amount = null_real;
+        GsbReal amount = null_real;
 
         record = custom_list -> visibles_rows[i];
 
@@ -1023,7 +1026,7 @@ gboolean transaction_list_update_transaction ( gint transaction_number )
 
     g_return_val_if_fail ( custom_list != NULL, FALSE);
 
-    /* we can update a transaction wich is not visible, so need to find the iter into
+    /* we can update a transaction which is not visible, so need to find the iter into
      * all the transactions */
     if (!transaction_model_get_transaction_iter (&iter, transaction_number, 0))
         return FALSE;
@@ -1056,7 +1059,7 @@ gboolean transaction_list_update_transaction ( gint transaction_number )
         white_record -> transaction_pointer = gsb_data_transaction_get_pointer_of_transaction (
                             white_line_number);
         white_record -> what_is_line = IS_TRANSACTION;
-        white_record -> row_bg = gsb_color_get_couleur ( "split_background" );
+        white_record -> row_bg = gsb_rgba_get_couleur ( "background_split" );
 
         /* as we append just now the white line, there are no child split, so the total is 0 */
         amount_string = utils_real_get_string_with_currency (null_real,
@@ -1347,7 +1350,7 @@ gboolean transaction_list_update_column ( gint column,
 
 /**
  * update a cell with it's element
- * usually you need transaction_list_update_element wich will update all the cells of the element
+ * usually you need transaction_list_update_element which will update all the cells of the element
  * this function is called to erase some cell after moving the element
  * (ie the notes element has moved the cell location, we need to erase the last cells,
  *     so we call this with the last cell_col and cell_line
@@ -1525,7 +1528,7 @@ gboolean transaction_list_show_toggle_mark ( gboolean show )
  * \param iter        iter of the row
 
  * \param column    number of column
- * \param value        value for the column (gchar *, GdkColor, gpointer, gint, PangoFontDescription, gboolean)
+ * \param value        value for the column (gchar *, GdkRGBA, gpointer, gint, PangoFontDescription, gboolean)
  * ...
  * \para -1        finish the list of cells to modify
  *
@@ -1581,7 +1584,7 @@ void transaction_list_set ( GtkTreeIter *iter, ... )
 		record -> visible_col[column] = va_arg (var_args, gchar *);
 		break;
 	    case CUSTOM_MODEL_BACKGROUND:
-		record -> row_bg = va_arg (var_args, GdkColor *);
+		record -> row_bg = va_arg (var_args, GdkRGBA *);
 		break;
 	    case CUSTOM_MODEL_AMOUNT_COLOR:
 		record -> amount_color = va_arg (var_args, gchar *);
@@ -1593,7 +1596,7 @@ void transaction_list_set ( GtkTreeIter *iter, ... )
 		record -> what_is_line = va_arg (var_args, gint);
 		break;
 	    case CUSTOM_MODEL_SAVE_BACKGROUND:
-		record -> row_bg_save = va_arg (var_args, GdkColor *);
+		record -> row_bg_save = va_arg (var_args, GdkRGBA *);
 		break;
 	    case CUSTOM_MODEL_FONT:
 		record -> font = va_arg (var_args, gchar *);
@@ -1772,7 +1775,7 @@ static void transaction_list_append_child ( gint transaction_number )
         else
         {
             /* we didn't find the mother of the child, we append the child number to
-             * orphan_child_transactions and the function wich called here has to play
+             * orphan_child_transactions and the function which called here has to play
              * with it
              * (it happens in the versions before 0.6 when the children could have a number
              * before the mother */
@@ -1828,7 +1831,7 @@ static void transaction_list_append_child ( gint transaction_number )
     white_record -> filtered_pos = pos;
 
     /* set the color */
-    newrecord -> row_bg = gsb_color_get_couleur ( "split_background" );
+    newrecord -> row_bg = gsb_rgba_get_couleur ( "background_split" );
 
     /* we can now save the new number of children and the new children rows into their mothers */
     for (i=0 ; i < TRANSACTION_LIST_ROWS_NB ; i++)
@@ -1854,7 +1857,7 @@ static void transaction_list_append_child ( gint transaction_number )
 	GtkTreeIter iter;
     gint last_line;
 
-	/* we go on the last mother record, wich contains the expander */
+	/* we go on the last mother record, which contains the expander */
     last_line = transaction_list_get_last_line ( custom_list -> nb_rows_by_transaction );
 	mother_record = mother_record -> transaction_records[last_line];
 
@@ -1862,7 +1865,7 @@ static void transaction_list_append_child ( gint transaction_number )
 	/* this is very important to keep to compatibility with the normal transactions */
 	newrecord -> transaction_records[0] = newrecord;
 
-	/* update the new line, wich replace the white line */
+	/* update the new line, which replace the white line */
 	path = gtk_tree_path_new();
 	gtk_tree_path_append_index(path, mother_record->filtered_pos);
 	gtk_tree_path_append_index(path, newrecord->filtered_pos);
@@ -1873,7 +1876,7 @@ static void transaction_list_append_child ( gint transaction_number )
 	gtk_tree_model_row_changed (GTK_TREE_MODEL(custom_list), path, &iter);
 	gtk_tree_path_free(path);
 
-	/* update white line, wich moved to the end */
+	/* update white line, which moved to the end */
 	path = gtk_tree_path_new();
 	gtk_tree_path_append_index(path, mother_record->filtered_pos);
 	gtk_tree_path_append_index(path, white_record->filtered_pos);
@@ -1901,9 +1904,6 @@ static CustomRecord *transaction_list_create_record ( gint transaction_number,
 {
     gint column;
     CustomRecord *newrecord;
-    CustomList *custom_list;
-
-    custom_list = transaction_model_get_model ();
 
     /* create the new record */
     newrecord = g_malloc0 (sizeof (CustomRecord));
@@ -1913,14 +1913,14 @@ static CustomRecord *transaction_list_create_record ( gint transaction_number,
 	newrecord -> visible_col[column] = gsb_transactions_list_grep_cell_content ( transaction_number,
 										     tab_affichage_ope[line_in_transaction][column]);
 
-    if ( conf.utilise_fonte_listes )
+    if ( conf.custom_fonte_listes )
 	    newrecord -> font = conf.font_string;
     newrecord -> transaction_pointer = gsb_data_transaction_get_pointer_of_transaction (transaction_number);
     newrecord -> what_is_line = IS_TRANSACTION;
     newrecord -> line_in_transaction = line_in_transaction;
     newrecord -> checkbox_visible_reconcile = line_in_transaction == 0 ? 1 : 0;
     newrecord -> checkbox_active = gsb_data_transaction_get_marked_transaction (transaction_number) != 0;
-    newrecord -> text_color = gsb_color_get_couleur_with_indice ( "text_color", 0 );
+    newrecord -> text_color = gsb_rgba_get_couleur_with_indice ( "text_color", 0 );
 
     return newrecord;
 }
@@ -1936,14 +1936,14 @@ static CustomRecord *transaction_list_create_record ( gint transaction_number,
  * */
 static gboolean transaction_list_update_white_child ( CustomRecord *white_record )
 {
-    gsb_real total_split = null_real;
-    gsb_real variance;
+    GsbReal total_split = null_real;
+    GsbReal variance;
     gchar *amount_string;
     gchar *variance_string;
     CustomRecord *mother_record;
     gint i;
     gint transaction_number;
-    GdkColor *mother_text_color;
+    GdkRGBA *mother_text_color;
 
     if (!white_record)
 	    return FALSE;
@@ -1971,17 +1971,20 @@ static gboolean transaction_list_update_white_child ( CustomRecord *white_record
 							 gsb_data_transaction_get_currency_number (transaction_number), TRUE);
 
     /* show the variance and sub-total only if different of the transaction */
-    if (variance.mantissa)
+	if (white_record->visible_col[2])
+		g_free (white_record->visible_col[2]);
+
+	if (variance.mantissa)
     {
 	white_record -> visible_col[2] = g_strdup_printf ( _("Total: %s (variance : %s)"),
 							   amount_string,
 							   variance_string );
-	mother_text_color = gsb_color_get_couleur_with_indice ( "text_color", 1 );
+	mother_text_color = gsb_rgba_get_couleur_with_indice ( "text_color", 1 );
     }
     else
     {
 	white_record -> visible_col[2] = NULL;
-	mother_text_color = gsb_color_get_couleur_with_indice ( "text_color", 0 );
+	mother_text_color = gsb_rgba_get_couleur_with_indice ( "text_color", 0 );
     }
 
     /* set the color of the mother */
@@ -2075,7 +2078,7 @@ gint transaction_list_get_last_line ( gint nb_rows )
  *
  * \return
  * */
-void transaction_list_set_color_jour ( gint account_number )
+gint transaction_list_set_color_jour ( gint account_number )
 {
     GDate *date_jour;
     gint i, j;
@@ -2085,7 +2088,7 @@ void transaction_list_set_color_jour ( gint account_number )
     CustomList *custom_list;
 
     custom_list = transaction_model_get_model ();
-    g_return_if_fail ( custom_list != NULL );
+    g_return_val_if_fail ( custom_list != NULL, 0);
 
     date_jour = gdate_today ( );
     element_sort = gsb_data_account_get_element_sort ( account_number,
@@ -2116,19 +2119,21 @@ void transaction_list_set_color_jour ( gint account_number )
                     /* colorize the record */
                     for (j=0 ; j < custom_list -> nb_rows_by_transaction ; j++)
                     {
-                        record -> row_bg = gsb_color_get_couleur ( "couleur_jour" );
+                        record -> row_bg = gsb_rgba_get_couleur ( "couleur_jour" );
                         i--;
                         if ( i >= 0 )
                             record = custom_list -> visibles_rows[i];
                     }
-                    /* on se positionne sur la première ligne */
-                    record = custom_list -> visibles_rows[0];
-                    break;
+					g_date_free (date_jour);
+
+					return transaction_number;
                 }
             }
         }
     }
     g_date_free ( date_jour );
+
+	return 0;
 }
 
 
@@ -2142,8 +2147,8 @@ gboolean transaction_list_get_variance ( gint transaction_number )
 {
     CustomRecord *white_record = NULL;
     CustomList *custom_list;
-    gsb_real total_split = null_real;
-    gsb_real variance;
+    GsbReal total_split = null_real;
+    GsbReal variance;
     CustomRecord *mother_record;
     gint i;
 
